import CDPDrawer from './CDPDrawer';
import { Entitlement } from "cdp-js/dist/api/iam/types";
export declare const DOWNLOAD_APPS_PATH = "/commonconsole/downloads/apps.v2.json";
export interface App {
    /** Name / identifier for the app. */
    name: string;
    /** Visible display name for the app. */
    displayName: string;
    /** SVG logo for the app. */
    logo: string;
    /**
     * Base url portion of the app's full url. Can be set to altus or mow in order to have the
     * real base url calculated automatically depending on the current environment.
     */
    baseUrl?: string;
    /** Path portion of app's full url. */
    path: string;
    /** App is hidden if this entitlement is not granted to the account. */
    entitlement?: string;
    /** App is hidden if this entitlement is granted to the account. */
    disablingEntitlement?: string;
    /** category used to determine location on landing page and in app-switcher */
    category?: string;
    /**
     * Optional "tag" that can be displayed along with the product text logo at
     * the top of the sidebar. We've used this to display a temporary "BETA" tag,
     * for example.
     */
    productDisplayNameTag?: string;
}
export interface Config {
    parent: HTMLElement;
    apps?: App[];
    /**
     * Base url for the environment your service is deployed in. E.g.: console.dps.mow-dev.cloudera.com
     * This url is used for calculating the application and API urls. If not provided, we'll use the
     * current url. Apps that are not part of the control plane and are deployed to customer VPCs
     * should pass this option in.
     */
    environmentBaseUrl?: string;
    entitlements?: Entitlement[];
}
export default class CDPAppSwitcher {
    drawer: CDPDrawer;
    config?: Config;
    trigger: HTMLAnchorElement;
    apps?: App[];
    entitlements: Entitlement[];
    render(config: Config): Promise<void>;
    static getFallbackApps(): ({
        name: string;
        displayName: string;
        logo: string;
        baseUrl: string;
        path: string;
        category?: undefined;
    } | {
        name: string;
        displayName: string;
        logo: string;
        baseUrl: string;
        path: string;
        category: string;
    })[];
    renderApp(app: App, parent: HTMLElement): void;
    getApps(): Promise<App[]>;
    destroy(): void;
}
