// Copyright (c) 2019 Cloudera, Inc. All rights reserved.
var styles = {
    drawer: 'cdp-drawer'
};
var CDPDrawer = /** @class */ (function () {
    function CDPDrawer() {
        var _this = this;
        this.config = {};
        this.isOpen = false;
        this.drawer = document.createElement('div');
        this.show = function () {
            _this.isOpen = true;
            _this.drawer.classList.add('open');
            // Register event handlers for closing the drawer
            document.addEventListener('keydown', _this.onKeyPress);
            document.addEventListener('click', _this.onDocumentClick);
            if (_this.config.onShow) {
                _this.config.onShow(_this);
            }
        };
        this.hide = function () {
            _this.isOpen = false;
            _this.drawer.classList.remove('open');
            document.removeEventListener('keydown', _this.onKeyPress);
            document.removeEventListener('click', _this.onDocumentClick);
            if (_this.config.onHide) {
                _this.config.onHide(_this);
            }
        };
        this.onDocumentClick = this.onDocumentClick.bind(this);
        this.onKeyPress = this.onKeyPress.bind(this);
        this.toggle = this.toggle.bind(this);
    }
    CDPDrawer.prototype.onKeyPress = function (e) {
        if (this.isOpen && e.key === 'Escape') {
            this.toggle();
        }
    };
    CDPDrawer.prototype.onDocumentClick = function (e) {
        var target = (e.target || e.srcElement);
        if (!this.isOpen ||
            !target ||
            (this.config.trigger && this.config.trigger.contains(target)) ||
            this.drawer.contains(target) ||
            // If element was removed from dom due to click ignore the click
            !document.body.contains(target)) {
            return;
        }
        this.toggle();
    };
    CDPDrawer.prototype.toggle = function (e) {
        if (e) {
            e.preventDefault();
        }
        this.isOpen = !this.isOpen;
        this.isOpen ? this.show() : this.hide();
        return false;
    };
    CDPDrawer.prototype.render = function (config) {
        this.destroy();
        this.config = config;
        this.drawer.classList.add(styles.drawer);
        if (this.config.className) {
            this.drawer.classList.add(this.config.className);
        }
        (this.config.parent || document.body).appendChild(this.drawer);
        if (this.config.trigger) {
            this.config.trigger.addEventListener('click', this.toggle);
        }
        return this.drawer;
    };
    CDPDrawer.prototype.setContent = function (content) {
        this.drawer.innerHTML = '';
        this.drawer.appendChild(content);
    };
    CDPDrawer.prototype.destroy = function () {
        this.drawer.innerHTML = '';
        if (this.config.trigger) {
            this.config.trigger.removeEventListener('click', this.toggle);
        }
    };
    return CDPDrawer;
}());
export default CDPDrawer;
