import CDPAppSwitcher from './CDPAppSwitcher';
import CDPDrawer from './CDPDrawer';
import { Entitlement, User } from "cdp-js/dist/api/iam/types";
/**
 * @deprecated The old CDPSidebar has been deprecated and will soon be removed
 */
export interface SidebarLinkItem {
    /** Identifier for the sidebar item */
    name: string;
    displayName: string;
    /** Content of the SVG icon for the item */
    icon?: string;
    /**
     * Class name to assign to the icon component. E.g., "fa fa-database". If provided, the icon
     * field is ignored.
     */
    iconClass?: string;
    /**
     * Base url portion of the sidebar item's full url. Can be set to altus or mow in order to have
     * the real base url calculated automatically depending on the current environment.
     */
    baseUrl?: string;
    /** Path portion of sidebar item's full url. */
    path?: string;
    /**
     * Regular expression to use when checking if this item is active. Ignore if isItemActive is
     * provided as part of the config.
     */
    matcher?: string;
    children?: SidebarLinkItem[];
    /** Sidebar item is hidden if this entitlement is not granted to the account. */
    entitlement?: string;
    /** Sidebar item is hidden if this entitlement is granted to the account. */
    disablingEntitlement?: string;
}
/**
 * @deprecated The old CDPSidebar has been deprecated and will soon be removed
 */
export interface SidebarSpacerItem {
    type: 'spacer';
}
/**
 * @deprecated The old CDPSidebar has been deprecated and will soon be removed
 */
export declare type SidebarItem = SidebarSpacerItem | SidebarLinkItem;
/**
 * @deprecated The old CDPSidebar has been deprecated and will soon be removed
 */
interface SupportItem {
    href?: string;
    baseUrl?: string;
    path?: string;
    target?: string;
    name: string;
}
declare type ClickHandler = (event: Event) => void;
/**
 * @deprecated The old CDPSidebar has been deprecated and will soon be removed
 */
export interface Config {
    title?: string;
    parent: HTMLElement;
    localStoragePrefix?: string;
    sidebarItems?: SidebarItem[];
    supportItems?: SupportItem[];
    productLogo?: string;
    companyLogo?: string;
    collapsible?: boolean;
    /**
     * Callback method for overriding how navigation happens. The link click event is stopped if this
     * method returns true and the caller is expected to initiate the navigation action.
     */
    onNavigate?: (itemData: SidebarLinkItem) => boolean;
    isItemActive?: (itemData: SidebarLinkItem) => boolean;
    logoHref?: string | ClickHandler;
    user?: User;
    showAppSwitcher?: boolean;
    showUserItem?: boolean;
    hideUserItemProfileLink?: boolean;
    showSupportItems?: boolean;
    /** URL to hit when user clicks the logout link in the user popover. */
    logoutUrl?: string;
    /** Color for the product. Used as the background color for the collapsed header. */
    productColor?: string;
    /** Topic name for the contextual help panel. */
    helpTopic?: string;
    /**
     * Base url for the environment your service is deployed in. E.g.: console.dps.mow-dev.cloudera.com
     * This url is used for calculating the application and API urls. If not provided, we'll use the
     * current url. Apps that are not part of the control plane and are deployed to customer VPCs
     * should pass this option in.
     */
    environmentBaseUrl?: string;
    /** Callback that is called when sidebar is expanded. */
    onExpand?: () => void;
    /** Callback that is called when sidebar is collapsed. */
    onCollapse?: () => void;
    entitlements?: Entitlement[];
    /**
     * Include feedback button
     */
    includeFeedbackSurvey?: boolean;
}
interface RenderedItem {
    itemData: SidebarItem;
    element: HTMLElement;
}
/**
 * @deprecated The old CDPSidebar has been deprecated and will soon be removed
 */
export default class CDPSidebar {
    config?: Config;
    collapsed?: boolean;
    defaultLocalStoragePrefix: string;
    renderedItems: RenderedItem[];
    appSwitcher: CDPAppSwitcher;
    helpDrawer: CDPDrawer;
    userDrawer: CDPDrawer;
    tourDrawer: CDPDrawer;
    sidebarItems?: SidebarItem[];
    user?: User;
    entitlements: Entitlement[];
    /**
     * internal flag to indicated if entitlements were provided to the sidebar. This
     * is used to inform if we need to fetch.
     * This is a bit of a band-aid fix to get the app switcher to work.
     * When we redo the sidebar, this would be a good candidate for refactoring.
     */
    hasCustomEntitlements: boolean;
    render(config: Config): void;
    /**
     * Adds feedback button that opens up survey modal.
     * For owner/stakeholders for this check with:
     *  - Johan Dorner <jdorner@cloudera.com>
     *  - Houshang Livian <hlivian@cloudera.com>
     */
    addSurveyIfNeeded(): void;
    renderHeader(header: HTMLDivElement): void;
    renderBody(body: HTMLElement): Promise<void>;
    renderFooter(footer: HTMLDivElement): Promise<void>;
    renderItemSpacer(itemData: SidebarSpacerItem, parent: HTMLElement): void;
    renderItem(itemData: SidebarLinkItem, parent: HTMLElement): HTMLAnchorElement | HTMLDivElement | undefined;
    /**
     * Returns a div that contains the first letter of the display name and a random background color.
     */
    getUserIcon: (user: User) => string;
    getUserMenu(user: User): HTMLDivElement;
    getSupportMenu(config: Config): HTMLDivElement;
    isItemActive(itemData: SidebarLinkItem): boolean | "" | undefined;
    onNavigate(itemData: SidebarLinkItem, e: MouseEvent): void;
    update(): void;
    setHelpTopic(helpTopic: string): void;
    toggleSidebar(e: MouseEvent): void;
    isCollapsible(): boolean;
    getPreference(key: string, defaultValue: any): any;
    setPreference(key: string, value: any): void;
    static getFallbackConf(): ({
        name: string;
        displayName: string;
        icon: string;
        baseUrl: string;
        path: string;
        matcher: string;
    } | {
        name: string;
        displayName: string;
        baseUrl: string;
        path: string;
        icon: string;
        matcher?: undefined;
    })[];
    getSidebarItems(): Promise<SidebarItem[]>;
    destroy(): void;
}
/**
 * This component could have been implemented as a singleton or a static object to make things easier
 * since where it is instantiated and where it is updated might be different so the users will have to
 * keep a handle to the instance somewhere. In order to make that easier, we now export a default
 * instance that can be used like a singleton.
 * @deprecated The old CDPSidebar has been deprecated and will soon be removed
 */
export declare const cdpSidebar: CDPSidebar;
/**
 * @deprecated The old CDPSidebar has been deprecated and will soon be removed
 */
export declare const sidebarItemsRequiresEntitlement: (items?: SidebarItem[]) => boolean;
export {};
