var __read = (this && this.__read) || function (o, n) {
    var m = typeof Symbol === "function" && o[Symbol.iterator];
    if (!m) return o;
    var i = m.call(o), r, ar = [], e;
    try {
        while ((n === void 0 || n-- > 0) && !(r = i.next()).done) ar.push(r.value);
    }
    catch (error) { e = { error: error }; }
    finally {
        try {
            if (r && !r.done && (m = i["return"])) m.call(i);
        }
        finally { if (e) throw e.error; }
    }
    return ar;
};
/** @jsx h */
// Copyright (c) 2020 Cloudera, Inc. All rights reserved.
import { h } from 'preact';
import { useCallback, useState, useRef, useEffect } from 'preact/hooks';
import classnames from 'classnames';
import BaseNavigationItem from './BaseNavigationItem.preact';
import BaseNavigationItemTooltip from './BaseNavigationItemTooltip.preact';
import useOnParentScroll from '../preact/hooks/useOnParentScroll';
import PageNextIcon from '@cloudera/cuix-core/icons/preact/PageNextIcon.preact';
/**
 * Show a single item inside an accordion in the dropdown or tooltip
 */
var AccordionSubItem = function (_a) {
    var active = _a.active, item = _a.item, disabled = _a.disabled;
    return (h(BaseNavigationItem, { className: classnames('cdp-sidebar-v2-sidebar-item-accordion-sub-item', {
            'cdp-sidebar-v2-sidebar-item-accordion-sub-item-active': active
        }), key: item.name, disabled: disabled, item: item }, item.displayName));
};
/**
 * Accordion items can contain one or more of navigation items. The accordion itself can not
 * navigate and will expand/collapse when clicked, or when the sidebar is in collapsed state
 * it will show tooltip with items on hover.
 */
var AccordionItem = function (_a) {
    var displayName = _a.displayName, IconComponent = _a.IconComponent, children = _a.children, isCollapsed = _a.isCollapsed, activeItemName = _a.activeItemName;
    var isActive = children.some(function (item) { return item.name === activeItemName; });
    /** Tooltip is used when the sidebar is in collapsed state */
    var _b = __read(useState(undefined), 2), tooltip = _b[0], setTooltip = _b[1];
    /** if expanded/collapsed when the sidebar is in the expanded state */
    var _c = __read(useState(isActive), 2), isOpen = _c[0], setIsOpen = _c[1];
    var _d = __read(useState(false), 2), isTooltipScrolled = _d[0], setIsTooltipScrolled = _d[1];
    var containerRef = useRef(null);
    var inlineAccordionItemsRef = useRef(null);
    var openTooltip = useCallback(function (el, fromKeyboard) {
        var rect = el.getBoundingClientRect();
        // maxHeight is needed for the edge-cases where the accordion tooltip content would
        // otherwise render outside the viewport.
        var maxHeight = window.innerHeight - rect.top;
        setIsTooltipScrolled(false);
        setTooltip({
            top: rect.top,
            right: rect.right,
            height: rect.height,
            maxHeight: maxHeight,
            fromKeyboard: fromKeyboard
        });
    }, []);
    var onMouseEnter = useCallback(function (event) {
        if (isCollapsed) {
            openTooltip(event.target);
        }
    }, [isCollapsed, openTooltip]);
    var onKeyPress = useCallback(function (event) {
        if ((event.key === 'Enter' || event.key === ' ') && isCollapsed) {
            if (!tooltip) {
                openTooltip(event.target, true);
            }
            else {
                setTooltip(undefined);
            }
        }
    }, [isCollapsed, openTooltip, tooltip]);
    var onMouseLeave = useCallback(function () {
        setTooltip(undefined);
    }, []);
    // Close tooltip when using keyboard for focus and we focus
    // outside of the open tooltip either via keyboard or mouse
    var onFocusOut = useCallback(function () {
        if (!tooltip) {
            return;
        }
        setTimeout(function () {
            var el = containerRef.current;
            if ((tooltip === null || tooltip === void 0 ? void 0 : tooltip.fromKeyboard) && el && !el.contains(document.activeElement)) {
                setTooltip(undefined);
            }
        }, 10);
    }, [tooltip]);
    useOnParentScroll({
        containerRef: containerRef,
        enabled: !!tooltip,
        onParentScroll: function () {
            setTooltip(undefined);
        }
    });
    // Adjust the height manually so that we'll get the css transitions when
    // we open/close the accordion with the sidebar expandd
    useEffect(function () {
        var el = inlineAccordionItemsRef.current;
        if (!el) {
            return;
        }
        if (isOpen) {
            el.style.height = "".concat(el.scrollHeight, "px");
        }
        else {
            el.style.height = '0';
        }
    }, [isOpen]);
    // when we have an accordion with many items, close the bottom of the screen
    // we might have a scrollbar, and we want the scroll indicator to shown when
    // user has scrolled.
    var onTooltipAccordionItemsScroll = useCallback(function (event) {
        setIsTooltipScrolled(event.target.scrollTop > 0);
    }, []);
    return (h("div", { onMouseEnter: onMouseEnter, onMouseLeave: onMouseLeave, ref: containerRef, className: classnames('cdp-sidebar-v2-accordion-item', {
            'cdp-sidebar-v2-active': isActive
        }), 
        // @ts-ignore - doesn't seem to be typed yet
        onfocusout: onFocusOut },
        h("button", { className: classnames('cdp-sidebar-v2-base-btn', 'cdp-sidebar-v2-sidebar-item', {
                'cdp-sidebar-v2-active': isActive,
                'cdp-sidebar-v2-accordion-item-btn-open': tooltip
            }), "aria-label": displayName, onClick: function () {
                if (!isCollapsed) {
                    setIsOpen(function (state) { return !state; });
                }
            }, onKeyPress: onKeyPress },
            h("div", { className: classnames('cdp-sidebar-v2-accordion-collapse-icon', {
                    'cdp-sidebar-v2-accordion-collapse-icon-open': isOpen
                }) },
                h(PageNextIcon, null)),
            h("div", { className: "cdp-sidebar-v2-sidebar-item-icon" },
                h(IconComponent, null)),
            h("span", null, displayName),
            h("div", { style: { flexGrow: 1 } })),
        (isOpen || inlineAccordionItemsRef.current) && (h("div", { className: "cdp-sidebar-v2-accordion-items", ref: inlineAccordionItemsRef, "aria-hidden": !isOpen || isCollapsed }, children.map(function (item) { return (h(AccordionSubItem, { key: item.name, item: item, active: activeItemName === item.name, disabled: !isOpen || isCollapsed })); }))),
        tooltip && isCollapsed && (h("div", { className: "cdp-sidebar-v2-sidebar-item-tooltip-extra-hover-area", style: {
                top: (tooltip === null || tooltip === void 0 ? void 0 : tooltip.top) || 0,
                left: (tooltip === null || tooltip === void 0 ? void 0 : tooltip.right) ? (tooltip === null || tooltip === void 0 ? void 0 : tooltip.right) - 28 : 0
            } })),
        h(BaseNavigationItemTooltip, { visible: tooltip && isCollapsed, className: "cdp-sidebar-v2-sidebar-item-tooltip", style: {
                top: (tooltip === null || tooltip === void 0 ? void 0 : tooltip.top) || 0,
                left: (tooltip === null || tooltip === void 0 ? void 0 : tooltip.right) || 0,
                maxHeight: (tooltip === null || tooltip === void 0 ? void 0 : tooltip.maxHeight) || 0
            }, role: "tooltip" },
            h("div", { className: classnames('cdp-sidebar-v2-sidebar-item-tooltip-primary', {
                    'cdp-sidebar-v2-active': isActive
                }), style: { height: (tooltip === null || tooltip === void 0 ? void 0 : tooltip.height) || 0 } }, displayName),
            h("div", { className: classnames('cdp-sidebar-v2-sidebar-item-tooltip-accordion-items', {
                    'cdp-sidebar-v2-sidebar-item-tooltip-accordion-items-overflow-top': isTooltipScrolled
                }), onScroll: onTooltipAccordionItemsScroll }, children.map(function (item) { return (h(AccordionSubItem, { key: item.name, item: item, active: activeItemName === item.name })); })))));
};
export default AccordionItem;
