/** @jsx h */
// Copyright (c) 2020 Cloudera, Inc. All rights reserved.
import { h, Fragment } from 'preact';
import { useInternalOrExternalFetchedEntitlements } from './useInternalOrExternalFetchedData.preact';
import titleIcon from '../images/app-switcher-title.svg';
import closeIcon from '@cloudera/cuix-core/icons/svg/ic-close.svg';
import BaseNavigationItem from './BaseNavigationItem.preact';
import useApps from './useApps';
import TrialInfo from './TrialInfo.preact';
/**
 * CDP App switcher content
 */
var AppSwitcher = function (_a) {
    var entitlements = _a.entitlements, onClose = _a.onClose, activeAppName = _a.activeAppName, activeProductColor = _a.activeProductColor;
    var _b = useInternalOrExternalFetchedEntitlements(entitlements), actualEntitlements = _b.value, fetchingEntitlements = _b.isFetching;
    var _c = useApps(actualEntitlements), apps = _c.apps, fetchingApps = _c.fetching;
    var isFetching = fetchingApps || fetchingEntitlements;
    var isEntitledToTrial = actualEntitlements === null || actualEntitlements === void 0 ? void 0 : actualEntitlements.find(function (item) { return item.entitlementName === 'CDPONE_TRIAL'; });
    return (h(Fragment, null,
        h("h3", { className: "cdp-app-switcher-header" },
            h("img", { alt: "Cloudera Data Platform", src: titleIcon }),
            h("button", { onClick: onClose, className: "cdp-sidebar-v2-base-btn", "data-event-category": "Sidebar", "data-event": "Close App Switcher" },
                h("img", { src: closeIcon, alt: "Close" }))),
        isFetching && h("div", { className: "cdp-app-switcher-loading" }, "Loading\u2026"),
        !isFetching && (h("ul", { className: "cdp-app-switcher-app-list" }, apps.map(function (app) {
            var isActive = app.name === activeAppName;
            return (h("li", { key: app.name, "aria-current": isActive || undefined },
                h(BaseNavigationItem, { item: app, "data-event-category": "Sidebar", "data-event": "App Switcher", "data-event-label": app.displayName },
                    h("div", { className: "cdp-app-switcher-indicator", style: {
                            background: isActive ? activeProductColor : ''
                        } }),
                    h("div", { className: "cdp-app-switcher-app-icon", dangerouslySetInnerHTML: { __html: app.logo } }),
                    h("span", null,
                        app.displayName,
                        app.productDisplayNameTag && " ".concat(app.productDisplayNameTag)))));
        }))),
        isEntitledToTrial && h(TrialInfo, null)));
};
export default AppSwitcher;
