var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __read = (this && this.__read) || function (o, n) {
    var m = typeof Symbol === "function" && o[Symbol.iterator];
    if (!m) return o;
    var i = m.call(o), r, ar = [], e;
    try {
        while ((n === void 0 || n-- > 0) && !(r = i.next()).done) ar.push(r.value);
    }
    catch (error) { e = { error: error }; }
    finally {
        try {
            if (r && !r.done && (m = i["return"])) m.call(i);
        }
        finally { if (e) throw e.error; }
    }
    return ar;
};
/** @jsx h */
// Copyright (c) 2020 Cloudera, Inc. All rights reserved.
import { h } from 'preact';
import { useCallback, useEffect, useRef, useState } from 'preact/hooks';
import classnames from 'classnames';
import NavigationItem from './NavigationItem.preact';
import AccordionItem from './AccordionItem.preact';
import SectionItem from './SectionItem.preact';
import SpacerItem from './SpacerItem.preact';
/**
 * The body of the Sidebar component where we render the in-app navigation links
 */
var Body = function (_a) {
    var sidebarItems = _a.sidebarItems, activeItemName = _a.activeItemName, isCollapsed = _a.isCollapsed;
    var scrollableContainerRef = useRef(null);
    var _b = __read(useState('none'), 2), overflowIndicator = _b[0], setOverflowIndicator = _b[1];
    // When there is content that is outside of the view, we'll show indicators
    // indicating that there is content above/below or both that is hidden.
    var detectOverflow = useCallback(function (el) {
        var hasOverflowOnTop = el.scrollTop > 0;
        var hasOverflowOnBtm = el.scrollHeight - el.scrollTop > el.clientHeight;
        if (hasOverflowOnTop && hasOverflowOnBtm) {
            setOverflowIndicator('both');
        }
        else if (hasOverflowOnTop) {
            setOverflowIndicator('top');
        }
        else if (hasOverflowOnBtm) {
            setOverflowIndicator('bottom');
        }
        else {
            setOverflowIndicator('none');
        }
    }, []);
    var onScroll = useCallback(function (event) {
        detectOverflow(event.currentTarget);
    }, [detectOverflow]);
    // overflow conditions could change if we have new items and/or other changes we'll need to check
    // on re-render as well
    useEffect(function () {
        var el = scrollableContainerRef.current;
        if (!el) {
            return;
        }
        detectOverflow(el);
    });
    var showOverflowIndicatorTop = overflowIndicator === 'both' || overflowIndicator === 'top';
    var showOverflowIndicatorBtm = overflowIndicator === 'both' || overflowIndicator === 'bottom';
    return (h("nav", { className: classnames('cdp-sidebar-v2-body', {
            'cdp-sidebar-v2-body-overflow-top': showOverflowIndicatorTop,
            'cdp-sidebar-v2-body-overflow-bottom': showOverflowIndicatorBtm
        }), onScroll: onScroll, ref: scrollableContainerRef }, sidebarItems.map(function (item, index) {
        if (item.type === 'spacer') {
            return h(SpacerItem, { key: "space-".concat(index) });
        }
        else if (item.type === 'accordion') {
            return (h(AccordionItem, __assign({ key: item.name }, item, { activeItemName: activeItemName, isCollapsed: isCollapsed })));
        }
        else if (item.type === 'section') {
            return (h(SectionItem, __assign({ key: item.name }, item, { activeItemName: activeItemName, isCollapsed: isCollapsed })));
        }
        return (h(NavigationItem, { item: item, key: item.name, active: item.name === activeItemName, isCollapsed: isCollapsed }));
    })));
};
export default Body;
