var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __read = (this && this.__read) || function (o, n) {
    var m = typeof Symbol === "function" && o[Symbol.iterator];
    if (!m) return o;
    var i = m.call(o), r, ar = [], e;
    try {
        while ((n === void 0 || n-- > 0) && !(r = i.next()).done) ar.push(r.value);
    }
    catch (error) { e = { error: error }; }
    finally {
        try {
            if (r && !r.done && (m = i["return"])) m.call(i);
        }
        finally { if (e) throw e.error; }
    }
    return ar;
};
/** @jsx h */
// Copyright (c) 2020 Cloudera, Inc. All rights reserved.
import { h, Fragment } from 'preact';
import { useCallback, useEffect, useMemo, useState } from 'preact/hooks';
import classnames from 'classnames';
import Body from './Body.preact';
import useCookiePreference from '../preact/hooks/useCookiePreference';
import SidebarDrawer from './SidebarDrawer.preact';
import UserDrawerContent from './UserDrawerContent.preact';
import HelpDrawerContent from './HelpDrawerContent.preact';
import VersionsDrawerContent from './VersionsDrawerContent.preact';
import AppSwitcherDrawerContent from './AppSwitcherDrawerContent.preact';
import AppSwitcherIcon from '@cloudera/cuix-core/icons/preact/AppSwitcherIcon.preact';
import UserIcon from './UserIcon.preact';
import NavigationItem from './NavigationItem.preact';
import { getAssigneeDisplayName } from "cdp-js/dist/helpers/iamHelpers";
import ToursPanel from '../tour/sidebar/ToursPanel';
import { shouldTourAutoOpen, shouldShowTourDevOverride, isEntitledToShowTours } from '../tour/pageUtils';
import { resumeActiveTour } from '../tour/index';
import collapseImage from '../images/collapse-nav.svg';
import BaseNavigationItem from './BaseNavigationItem.preact';
import { PRIVATE_CLOUD_SUPPORT_ITEMS, PUBLIC_CLOUD_SUPPORT_ITEMS, HELP_ITEM, TOUR_ITEM, WHATS_NEW_ITEM } from './defaultItems';
import appConfig from "cdp-js/dist/lib/appConfig";
import { hasRunCuixInit } from '../cuix-init';
import { useInternalOrExternalFetchedUser, useInternalOrExternalFetchedEntitlements } from './useInternalOrExternalFetchedData.preact';
import { fetchAppsOnce } from '../utils';
import { getExpiredWorkloadPasswordDetails } from "cuix/dist/utils/workloadPasswordNotificationUtil";
export var DEFAULT_SUPPORT_ITEMS = appConfig.isPrivateCloud()
    ? PRIVATE_CLOUD_SUPPORT_ITEMS
    : PUBLIC_CLOUD_SUPPORT_ITEMS;
var Sidebar = function (_a) {
    var _b, _c;
    var productColor = _a.productColor, entitlements = _a.entitlements, hideAppSwitcher = _a.hideAppSwitcher, hideUserItemProfileLink = _a.hideUserItemProfileLink, hideHelpMenu = _a.hideHelpMenu, hideTourMenu = _a.hideTourMenu, logoHref = _a.logoHref, productDisplayName = _a.productDisplayName, productName = _a.productName, productIconLogoSrc = _a.productIconLogoSrc, productTextLogoSrc = _a.productTextLogoSrc, sidebarItems = _a.sidebarItems, activeItemName = _a.activeItemName, user = _a.user, helpTopic = _a.helpTopic, baseHelpUrl = _a.baseHelpUrl, helpItems = _a.helpItems, defaultCollapsed = _a.defaultCollapsed, versionNumber = _a.versionNumber, buildDetails = _a.buildDetails, logoutUrl = _a.logoutUrl, logoutHandler = _a.logoutHandler, whatsNew = _a.whatsNew, productDisplayNameTag = _a.productDisplayNameTag, productDisplayNameTagClass = _a.productDisplayNameTagClass;
    var _d = __read(useCookiePreference('cdp-sidebar-collapsed', defaultCollapsed || false), 2), isCollapsed = _d[0], setIsCollapsed = _d[1];
    var _e = __read(useState(shouldTourAutoOpen() ? 'tour' : null), 2), drawerTopic = _e[0], setDrawerTopic = _e[1];
    var onHide = useCallback(function () {
        setDrawerTopic(null);
    }, [setDrawerTopic]);
    useMemo(function () {
        resumeActiveTour({ onShowTourPanel: function () { return setDrawerTopic('tour'); } });
    }, []);
    useMemo(function () {
        if (entitlements === undefined) {
            console.warn('entitlements prop can not be undefined. See InternalOrExternalFetchedData.');
        }
    }, [entitlements]);
    useMemo(function () {
        if (user === undefined) {
            console.warn('user prop can not be undefined. See InternalOrExternalFetchedData.');
        }
    }, [user]);
    useMemo(function () {
        if (!hasRunCuixInit()) {
            console.error('cuixInit must run before render');
        }
        // TODO: [future] re-enable this once we have it validated a bit more (arne)
        // if (!hasRunCuixInitAnalytics()) {
        //   console.warn('cuixInitAnalytics should run before render');
        // }
    }, []);
    useEffect(function () {
        if (hideAppSwitcher) {
            return;
        }
        // Preload apps for app switcher, so it open more seamlessly. We add a small delay
        // so we don't compete with more pressing matters.
        setTimeout(function () {
            fetchAppsOnce();
        }, 2000);
    }, [hideAppSwitcher]);
    var _f = useInternalOrExternalFetchedUser(user), actualUser = _f.value, isFetchingUser = _f.isFetching;
    var _g = useInternalOrExternalFetchedEntitlements(entitlements), actualEntitlements = _g.value, isFetchingEntitlements = _g.isFetching;
    var shouldShowTours = useMemo(function () {
        if (shouldShowTourDevOverride()) {
            return true;
        }
        return !hideTourMenu && isEntitledToShowTours(actualEntitlements);
    }, [actualEntitlements, hideTourMenu]);
    var showAppSwitcher = !hideAppSwitcher && (isFetchingEntitlements || actualEntitlements);
    // We expose the user on the window object, this will then be consumed by our medallia
    // feedback integration (when enabled). It does feel a bit misplaced here, but this is the one
    // spot where most CDP products will call and also have user info available, so seems the most
    // practical for now.
    // Other options:
    // - Putting it in cuixInit would not work well, as that can be called before we have user info
    //   available.
    // - Add a new call e.g. `registerMedalliaUser` makes extra work for everyone, and we might not
    //   have a good way to enforce that people use that.
    window._cuix_user = actualUser;
    var workloadPasswordDetails = getExpiredWorkloadPasswordDetails(actualUser === null || actualUser === void 0 ? void 0 : actualUser.workloadPasswordDetails);
    return (h(Fragment, null,
        h("div", { className: classnames('cdp-sidebar-v2-drawers', {
                'cdp-sidebar-v2-collapsed': isCollapsed
            }), style: (_b = {}, _b['--cdp-sidebar-v2-selection-color'] = productColor, _b) },
            h(SidebarDrawer, { show: drawerTopic === 'appswitcher', onHide: onHide, className: "cdp-sidebar-v2-app-drawer", "aria-label": "App Switcher" },
                h(AppSwitcherDrawerContent, { entitlements: entitlements, activeAppName: productName, activeProductColor: productColor, onClose: onHide })),
            h(SidebarDrawer, { show: drawerTopic === 'tour', onHide: onHide, className: "cdp-sidebar-v2-tour-drawer cdp-sidebar-v2-right-drawer" },
                isFetchingEntitlements && h("span", null, "Loading\u2026"),
                !isFetchingEntitlements && (h(ToursPanel, { onClose: onHide, userEntitlements: actualEntitlements, user: actualUser }))),
            h(SidebarDrawer, { show: drawerTopic === 'help', onHide: onHide, className: "cdp-sidebar-v2-help-drawer cdp-sidebar-v2-right-drawer", "aria-label": "Help" },
                isFetchingEntitlements && h("span", null, "Loading\u2026"),
                !isFetchingEntitlements && (h(HelpDrawerContent, { onClose: onHide, helpTopic: helpTopic, helpItems: helpItems || DEFAULT_SUPPORT_ITEMS, entitlements: actualEntitlements, baseHelpUrl: baseHelpUrl }))),
            h(SidebarDrawer, { show: drawerTopic === 'versions', onHide: onHide, className: "cdp-sidebar-v2-version-drawer cdp-sidebar-v2-right-drawer" },
                h(VersionsDrawerContent, { onClose: onHide, buildDetails: buildDetails })),
            h(SidebarDrawer, { show: drawerTopic === 'user', onHide: onHide, className: "cdp-sidebar-v2-user-drawer cdp-sidebar-v2-right-drawer", "aria-label": "User Info" }, actualUser && (h(UserDrawerContent, { user: actualUser, hideUserItemProfileLink: hideUserItemProfileLink, logoutUrl: logoutUrl, logoutHandler: logoutHandler, workloadPasswordDetails: workloadPasswordDetails })))),
        h("div", { className: classnames('cdp-sidebar-v2', { 'cdp-sidebar-v2-collapsed': isCollapsed }), style: (_c = {}, _c['--cdp-sidebar-v2-selection-color'] = productColor, _c) },
            h("div", { className: "cdp-sidebar-v2-header" },
                showAppSwitcher && (h("button", { className: "cdp-sidebar-v2-base-btn cdp-sidebar-v2-app-switcher-trigger", onClick: function () { return setDrawerTopic('appswitcher'); }, "data-event-category": "Sidebar", "data-event": "Click App Switcher Icon" },
                    h(AppSwitcherIcon, { "aria-label": "App Switcher", role: "img" }))),
                h("a", { href: logoHref, className: "cdp-sidebar-v2-header-logo", title: productDisplayName, "data-event-category": "Sidebar", "data-event": "Click Cloudera Logo" },
                    h("img", { alt: productDisplayName, className: "cdp-sidebar-v2-header-product-icon-logo", src: productIconLogoSrc }),
                    h("img", { alt: productDisplayName, className: "cdp-sidebar-v2-header-product-text-logo", src: productTextLogoSrc }),
                    productDisplayNameTag && (h("div", { className: productDisplayNameTagClass }, productDisplayNameTag)))),
            h(Body, { sidebarItems: sidebarItems, activeItemName: activeItemName, isCollapsed: isCollapsed }),
            h("div", { className: "cdp-sidebar-v2-footer" },
                !isFetchingUser && (h(Fragment, null,
                    (whatsNew === null || whatsNew === void 0 ? void 0 : whatsNew.url) && (h(NavigationItem, { item: __assign(__assign({}, WHATS_NEW_ITEM), { url: whatsNew.url }), isCollapsed: isCollapsed, "data-event-category": "Sidebar", "data-event": "Open Whats New Url" })),
                    whatsNew && (whatsNew === null || whatsNew === void 0 ? void 0 : whatsNew.handler) && (h(NavigationItem, { item: __assign(__assign({}, WHATS_NEW_ITEM), { handler: function () { return ((whatsNew === null || whatsNew === void 0 ? void 0 : whatsNew.handler) ? whatsNew === null || whatsNew === void 0 ? void 0 : whatsNew.handler() : {}); } }), isCollapsed: isCollapsed, "data-event-category": "Sidebar", "data-event": "Open Whats New Handler" })),
                    entitlements !== null && shouldShowTours && (h(NavigationItem, { item: __assign(__assign({}, TOUR_ITEM), { handler: function () { return setDrawerTopic('tour'); } }), isCollapsed: isCollapsed, "data-event-category": "Sidebar", "data-event": "Open Tours" })),
                    !hideHelpMenu && (h(NavigationItem, { item: __assign(__assign({}, HELP_ITEM), { handler: function () { return setDrawerTopic('help'); } }), isCollapsed: isCollapsed, "data-event-category": "Sidebar", "data-event": "Open Help" })),
                    actualUser && (h(NavigationItem, { item: {
                            type: 'navigation',
                            name: 'user',
                            displayName: getAssigneeDisplayName(actualUser),
                            showExclamationMark: workloadPasswordDetails.showNotification,
                            handler: function () { return setDrawerTopic('user'); },
                            IconComponent: function () { return h(UserIcon, { user: actualUser }); }
                        }, isCollapsed: isCollapsed, "data-event-category": "Sidebar", "data-event": "Open User Info" })))),
                h("div", { className: "cdp-sidebar-v2-footer-bottom-row" },
                    h("div", { className: "cdp-sidebar-v2-footer-version-number" },
                        buildDetails && (h(BaseNavigationItem, { item: {
                                handler: function () { return setDrawerTopic('versions'); },
                                name: 'versions'
                            }, "data-event-category": "Sidebar", "data-event": "Open Versions" }, versionNumber)),
                        !buildDetails && versionNumber),
                    h(BaseNavigationItem, { className: "cdp-sidebar-v2-footer-collapse-btn", item: {
                            handler: function () { return setIsCollapsed(function (state) { return !state; }); },
                            name: 'sidebar-collapse-btn'
                        }, "data-event-category": "Sidebar", "data-event": "Collapse Sidebar" },
                        h("img", { src: collapseImage, alt: "Sidebar collapse" }))),
                h("div", { className: "cdp-sidebar-v2-footer-bottom-color-line" })))));
};
export default Sidebar;
