var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
/** @jsx h */
// Copyright (c) 2020 Cloudera, Inc. All rights reserved.
import { h } from 'preact';
import { useEffect, useRef } from 'preact/hooks';
import classnames from 'classnames';
/**
 * Drawer that slides out from under the sidebar with help/user/tour content
 */
var SidebarDrawer = function (_a) {
    var show = _a.show, onHide = _a.onHide, children = _a.children, className = _a.className, otherProps = __rest(_a, ["show", "onHide", "children", "className"]);
    var containerRef = useRef(null);
    var showRef = useRef(show);
    showRef.current = show; // see comment below for this odd construct
    useEffect(function () {
        // we need to add/remove these class names
        // after (initial) render in order for the css transitions
        // to work.
        var el = containerRef.current;
        if (!el) {
            return;
        }
        if (show) {
            el.classList.add('open');
        }
        else {
            el.classList.remove('open');
        }
    }, [show]);
    useEffect(function () {
        if (!show) {
            return;
        }
        var onKeyPress = function (e) {
            if (showRef && e.key === 'Escape') {
                onHide();
            }
        };
        var onDocumentClick = function (e) {
            var target = (e.target || e.srcElement);
            if (!showRef.current) {
                // so this can get get called *after* the component is hidden
                // since this effect is torn-down after the render where it is marked as hidden.
                // Using a ref to get current value, so we don't call hide
                // when hidden.
                return;
            }
            if (containerRef.current && containerRef.current.contains(target)) {
                // clicks inside our content should not close the drawer
                return;
            }
            if (!document.body.contains(target)) {
                // if the target is no longer in the document, we'll assume it was previously in the drawer and was
                // removed. This happens in the tour panel, where clicking on a button, will take you to a new content,
                // removing the button you clicked before it is captured here.
                return;
            }
            onHide();
        };
        document.addEventListener('keydown', onKeyPress);
        document.addEventListener('click', onDocumentClick);
        return function () {
            document.removeEventListener('keydown', onKeyPress);
            document.removeEventListener('click', onDocumentClick);
        };
    }, [show, onHide]);
    if (!show && !containerRef.current) {
        // if it is hidden, and we haven't rendered it previously
        // we can wait to render it (aka lazy render).
        return null;
    }
    return (h("div", __assign({ ref: containerRef, className: classnames('cdp-sidebar-v2-drawer', className), role: "dialog", "aria-hidden": !show }, otherProps), show && children));
};
export default SidebarDrawer;
