/** @jsx h */
import { h, Component, JSX } from 'preact';
export interface CssPosition {
    top?: number;
    right?: number;
    bottom?: number;
    left?: number;
}
export interface Coordinates {
    x: number;
    y: number;
}
export interface Size {
    w: number;
    h: number;
}
export interface Props extends JSX.HTMLAttributes {
    /** Css Selector for handle element */
    handleSelector?: string;
    /** Initial css fixed position like {left: 0, bottom: 10}  */
    position?: CssPosition;
    /** Allows to specify minimal required distance from page borders */
    margin?: number;
    /** Called when mouse drag is finished. Returns new css position */
    onChangePosition?: Function;
    children?: preact.ComponentChildren;
}
interface State {
    inMotion: boolean;
}
/**
 * Allows to wrap any HTML/Preact content and make it Floating on the screen.
 *
 * ### Example
 * ```js
 * <FloatingPanel
 *    handleSelector=".handle"
 *    margin={10}
 *    position={{right:10, bottom:50}}
 *    onChangePosition={position => console.log(position)}  >
 *      <span className="handle">Drag Me</span>
 *      <p> Some content to float on the page</p>
 *  </FloatingPanel>
 *  ```
 */
export default class FloatingPanel extends Component<Props, State> {
    private ref;
    state: {
        inMotion: boolean;
    };
    position: CssPosition;
    cursorOffset: Coordinates | undefined;
    clientXY: Coordinates | undefined;
    size: Size | undefined;
    margin: number;
    hasNestedHandle: boolean | undefined;
    handleEl: HTMLElement | undefined;
    componentDidMount: () => void;
    componentWillUnmount: () => void;
    render(): h.JSX.Element;
    start: (event: MouseEvent) => void;
    move: (event: MouseEvent) => void;
    end: (event: MouseEvent) => void;
    /**
     * Update fixed css position while dragging a floatingPanel handle.
     * We don't update styles in react render method
     * to make sure update happens as fast as possible. */
    setCssPosition: (pos: CssPosition) => void;
    calculateBestPosition: (event: MouseEvent) => CssPosition | undefined;
}
export {};
