var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (Object.prototype.hasOwnProperty.call(b, p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        if (typeof b !== "function" && b !== null)
            throw new TypeError("Class extends value " + String(b) + " is not a constructor or null");
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
/** @jsx h */
// Copyright (c) 2020 Cloudera, Inc. All rights reserved.
import { h, createRef, Component } from 'preact';
/**
 * Allows to wrap any HTML/Preact content and make it Floating on the screen.
 *
 * ### Example
 * ```js
 * <FloatingPanel
 *    handleSelector=".handle"
 *    margin={10}
 *    position={{right:10, bottom:50}}
 *    onChangePosition={position => console.log(position)}  >
 *      <span className="handle">Drag Me</span>
 *      <p> Some content to float on the page</p>
 *  </FloatingPanel>
 *  ```
 */
var FloatingPanel = /** @class */ (function (_super) {
    __extends(FloatingPanel, _super);
    function FloatingPanel() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.ref = createRef();
        _this.state = { inMotion: false };
        _this.position = __assign({}, _this.props.position);
        _this.margin = _this.props.margin || 0;
        _this.componentDidMount = function () {
            var _a;
            var handleSelector = _this.props.handleSelector;
            var floatingPanelEl = _this.ref.current;
            if (floatingPanelEl) {
                var handleEl = handleSelector && floatingPanelEl.querySelector(handleSelector);
                _this.hasNestedHandle = !!handleEl;
                _this.handleEl = (handleEl || floatingPanelEl);
                (_a = _this.handleEl) === null || _a === void 0 ? void 0 : _a.classList.add('floating-panel-handle');
                _this.handleEl.addEventListener('mousedown', _this.start);
                _this.setCssPosition(_this.position);
            }
        };
        _this.componentWillUnmount = function () {
            _this.handleEl && _this.handleEl.removeEventListener('mousedown', _this.start);
            document.removeEventListener('mousemove', _this.move);
            document.removeEventListener('mouseup', _this.end);
        };
        _this.start = function (event) {
            var floatingPanelEl = _this.ref.current;
            if (!floatingPanelEl) {
                return;
            }
            _this.setState({ inMotion: true });
            var floatingPanelBounds = floatingPanelEl.getBoundingClientRect();
            _this.cursorOffset = {
                x: event.clientX - floatingPanelBounds.x + parseInt((floatingPanelEl === null || floatingPanelEl === void 0 ? void 0 : floatingPanelEl.style.marginLeft) || '0'),
                y: event.clientY - floatingPanelBounds.y + parseInt((floatingPanelEl === null || floatingPanelEl === void 0 ? void 0 : floatingPanelEl.style.marginTop) || '0')
            };
            var offsetWidth = floatingPanelEl.offsetWidth, offsetHeight = floatingPanelEl.offsetHeight;
            _this.size = { w: offsetWidth, h: offsetHeight };
            document.addEventListener('mousemove', _this.move);
            document.addEventListener('mouseup', _this.end);
        };
        _this.move = function (event) {
            if (_this.ref.current && _this.cursorOffset) {
                _this.setCssPosition({
                    left: event.clientX - _this.cursorOffset.x,
                    top: event.clientY - _this.cursorOffset.y
                });
            }
            else {
                _this.end(event);
            }
        };
        _this.end = function (event) {
            _this.setState({ inMotion: false });
            document.removeEventListener('mousemove', _this.move);
            document.removeEventListener('mouseup', _this.end);
            var position = _this.calculateBestPosition(event);
            if (position) {
                _this.setCssPosition(position);
                var onChangePosition = _this.props.onChangePosition;
                if (typeof onChangePosition === 'function') {
                    onChangePosition(position);
                }
            }
        };
        /**
         * Update fixed css position while dragging a floatingPanel handle.
         * We don't update styles in react render method
         * to make sure update happens as fast as possible. */
        _this.setCssPosition = function (pos) {
            var floatingPanelEl = _this.ref.current;
            if (floatingPanelEl) {
                var top_1 = pos.top, right = pos.right, bottom = pos.bottom, left = pos.left;
                Object.assign(floatingPanelEl.style, {
                    top: top_1 === undefined ? '' : top_1 + 'px',
                    right: right === undefined ? '' : right + 'px',
                    bottom: bottom === undefined ? '' : bottom + 'px',
                    left: left === undefined ? '' : left + 'px'
                });
            }
        };
        _this.calculateBestPosition = function (event) {
            var floatingPanelEl = _this.ref.current;
            if (!floatingPanelEl || !_this.cursorOffset || !_this.size) {
                return;
            }
            var offsetWidth = floatingPanelEl.offsetWidth, offsetHeight = floatingPanelEl.offsetHeight;
            var x = event.clientX - _this.cursorOffset.x;
            var y = event.clientY - _this.cursorOffset.y;
            var windowHeight = window.innerHeight;
            var windowWidth = window.innerWidth;
            var position = {};
            x <= (windowWidth - offsetWidth) / 2 // floatingPanel more in left part of a page
                ? (position.left = Math.max(_this.margin, x))
                : (position.right = Math.max(_this.margin, windowWidth - _this.size.w - x));
            y <= (windowHeight - offsetHeight) / 2 // floatingPanel more in top part of a page
                ? (position.top = Math.max(_this.margin, y))
                : (position.bottom = Math.max(_this.margin, windowHeight - _this.size.h - y));
            var roundedPosition = Object.keys(position).reduce(function (acc, k) {
                var v = position[k];
                if (v !== undefined) {
                    acc[k] = Math.round(v);
                }
                return acc;
            }, {});
            return roundedPosition;
        };
        return _this;
    }
    FloatingPanel.prototype.render = function () {
        var _a = this.props, position = _a.position, onChangePosition = _a.onChangePosition, otherProps = __rest(_a, ["position", "onChangePosition"]);
        return (h("div", __assign({}, otherProps, { className: 'floating-panel' +
                (this.state.inMotion ? ' floating-panel-in-motion' : '') +
                (this.hasNestedHandle === false ? ' floating-panel-handle' : ''), ref: this.ref }), this.props.children));
    };
    return FloatingPanel;
}(Component));
export default FloatingPanel;
