import { SubstepProps, SubstepEventName } from '../Tour/interfaces';
/**
 LIFECYCLE:
  INIT
  DELAY
  START
  WAIT_FOR (some element to be present, not_preset)
    - error
  LOCATE_TARGET
    - not found error
  ON_TARGET_CLICK subscribe
  ON_OUTSIDE_TARGET_CLICK subscribe
  SHOW_POPPER
  .
  . . . . handle : onNext, onPrev, onClose, onTargetClick
  .
  DESTROY
    - unsubscribe dom listeners
    - DESTROY_POPPER
 */
export interface Props {
    start: () => Promise<void>;
    destroy: () => void;
    didExpectedPathMatch: boolean | undefined;
}
export declare class SubstepController implements Props {
    private propper;
    private props;
    protected targetEl: Element | null;
    private observedEl;
    private mutationObserver;
    private isActive;
    private _didExpectedPathMatch;
    private _isInputEmpty;
    constructor(props: SubstepProps);
    get didExpectedPathMatch(): boolean | undefined;
    redraw: () => Promise<void>;
    start: () => Promise<void>;
    delay: () => Promise<void>;
    waitForExpectedUrl: () => Promise<boolean>;
    waitForTarget: () => Promise<boolean>;
    waitForNextStepAvailability: () => Promise<void>;
    locateTarget: () => void;
    onRequiredValueInput: (e: Event) => void;
    subscribeRequiredInputValueChange: () => void;
    unsubscribeRequiredInputValueChange: () => void;
    subscribeOnceTargetClick: () => void;
    unsubscribeTargetClick: () => void;
    /**
     * We listen for onBodyMouseDown to catch the moments when user tries to interact with ui page
     * to make sure he follows product tour toolip(popper) instructions and interacts only with allowed elements.
     * User freedom for each substep is declared in
     * allowInteraction property
     * true/false - allows/forbids interaction with all elements
     * "css-selector" - allows elements who match css-selector
     * ["css-selector1", "css-selector2"] - allows elements who match any of listed selectors.
     * Regardless of allowInteraction value user can all the times interact with substep.target elemement, tooltip content and floating checklist.
     */
    onBodyMouseDown: (event: MouseEvent) => void;
    isTourUiElement: (path: Element[]) => boolean;
    isElementAllowedForInteraction: (path: Element[]) => boolean;
    onKeyDown: (e: KeyboardEvent) => void;
    subscribeTargetOutisdeClick: () => void;
    unsubscribeTargetOutsideClick: () => void;
    subscribeKeyDown: () => void;
    ussubscribeKeyDown: () => void;
    runCallback: (callbackName: SubstepEventName, event?: any) => void;
    runEffects: (eventName: SubstepEventName, event?: any) => void;
    runEffectsAndCallback: (eventName: SubstepEventName, event?: any) => void;
    onNext: (event?: any) => void;
    onPrev: (event?: any) => void;
    onClose: (event?: any) => void;
    onCollapse: (event?: any) => void;
    onDone: (event?: any) => void;
    onInit: (event?: any) => void;
    onStart: (event?: any) => void;
    onWaitSuccess: (event?: any) => void;
    onWaitError: (event?: any) => void;
    onDelay: (event?: any) => void;
    onTargetFound: (event?: any) => void;
    onTargetNotFound: (event?: any) => void;
    onShow: (event?: any) => void;
    onTargetClick: (event?: any) => void;
    onClickOutside: (event: MouseEvent) => void;
    highlightTarget: () => void;
    unhighlightTarget: () => void;
    showPopper: () => void;
    scrollIntoView: () => void;
    subscribeForDomMutations: () => void;
    destroy: () => void;
}
