var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __read = (this && this.__read) || function (o, n) {
    var m = typeof Symbol === "function" && o[Symbol.iterator];
    if (!m) return o;
    var i = m.call(o), r, ar = [], e;
    try {
        while ((n === void 0 || n-- > 0) && !(r = i.next()).done) ar.push(r.value);
    }
    catch (error) { e = { error: error }; }
    finally {
        try {
            if (r && !r.done && (m = i["return"])) m.call(i);
        }
        finally { if (e) throw e.error; }
    }
    return ar;
};
import { getCookie, setCookie, clearCookie } from './cookie';
import { tourController } from './TourController';
import { ACTIVE_TOUR_COOKIE_NAME, ACTIVE_TOUR_COOKIE_DAYS, VISITED_TOURS_COOKIE_NAME, VISITED_TOURS_COOKIE_DAYS, VISITED_TOURS_V2_COOKIE_NAME, COMMON_CONSOLE_APP_ID } from '../variables';
import { removeTourStateFromUrl, getQueryParam } from '../Substep/utils';
export var isTourStateValid = function (tourState) {
    var tourId = tourState.tourId, paused = tourState.paused, stepNumber = tourState.stepNumber, substepNumber = tourState.substepNumber, appId = tourState.appId, stepId = tourState.stepId, substepNestedNumber = tourState.substepNestedNumber;
    var isValid = typeof tourId === 'string' &&
        tourId.length > 0 &&
        typeof paused === 'boolean' &&
        !isNaN(stepNumber) &&
        stepNumber >= -1 &&
        !isNaN(substepNumber) &&
        substepNumber >= -1 &&
        appId !== undefined
        ? stepId !== undefined && substepNestedNumber !== undefined
        : true;
    return isValid;
};
export var getActiveTourStateFromUrl = function () {
    return decompressActiveTourState(getQueryParam(ACTIVE_TOUR_COOKIE_NAME), true);
};
export var getActiveTourStateFromCookie = function () {
    return decompressActiveTourState(getCookie(ACTIVE_TOUR_COOKIE_NAME));
};
export var getActiveTourName = function () { var _a; return (_a = readTourState()) === null || _a === void 0 ? void 0 : _a.tourId; };
// TOUR STATE COOKIE
export var isTourActive = function (tourId) {
    var state = readTourState();
    return state && state.tourId === tourId;
};
export var isVisitedTour = function (tourId) {
    return isTourActive(tourId) ||
        getVisitedToursV2()[tourId] !== undefined ||
        getVisitedToursV1()[tourId] !== undefined;
};
export var saveTourStateIntoCookie = function (activeTourState) {
    if (activeTourState) {
        var stateString = activeTourState.tourId ? compressActiveTourState(activeTourState) : '';
        setCookie(ACTIVE_TOUR_COOKIE_NAME, stateString, ACTIVE_TOUR_COOKIE_DAYS);
        var tourId = activeTourState.tourId, stepNumber = activeTourState.stepNumber, stepId = activeTourState.stepId;
        patchVisitedToursCookie(tourId, stepNumber, stepId);
    }
};
/**
 * Reads Tour State from Url and Cookie.
 * If url has tourState it is updated into extended version and transfered into activeTour cookie
 */
export var readTourState = function () {
    try {
        var tourStateFromUrl = getActiveTourStateFromUrl();
        if (tourStateFromUrl) {
            saveTourStateIntoCookie(tourStateFromUrl);
            if (window.history) {
                window.history.replaceState(null, '', removeTourStateFromUrl(window.location.href));
            }
            return tourStateFromUrl;
        }
        else {
            return getActiveTourStateFromCookie();
        }
    }
    catch (e) {
        console.error(e);
        return;
    }
};
export var clearTourStateCookie = function () {
    clearCookie(ACTIVE_TOUR_COOKIE_NAME);
};
// VISITED TOURS COOKIE
export var getVisitedToursV1 = function () {
    return (readVisitedToursCookie() || {});
};
export var getVisitedToursV2 = function () {
    return (readVisitedToursCookie(VISITED_TOURS_V2_COOKIE_NAME) || {});
};
export var readVisitedToursCookie = function (cookieName) {
    if (cookieName === void 0) { cookieName = VISITED_TOURS_COOKIE_NAME; }
    var stateString = getCookie(cookieName);
    if (stateString) {
        try {
            return JSON.parse(stateString);
        }
        catch (e) {
            return undefined;
        }
    }
    return undefined;
};
export var setVisitedToursV1Cookie = function (visitedTours) {
    setCookie(VISITED_TOURS_COOKIE_NAME, JSON.stringify(visitedTours), VISITED_TOURS_COOKIE_DAYS);
    // TODO use binary compression
};
export var setVisitedToursV2Cookie = function (visitedToursV2) {
    setCookie(VISITED_TOURS_V2_COOKIE_NAME, JSON.stringify(visitedToursV2), VISITED_TOURS_COOKIE_DAYS);
    // TODO use binary compression
};
export var patchVisitedToursCookie = function (tourId, stepNumber, stepId) {
    var _a, _b;
    if (tourId) {
        setVisitedToursV1Cookie(__assign(__assign({}, getVisitedToursV1()), (_a = {}, _a[tourId] = stepNumber - 1 // unlike v2 in v1 we store visited step, not current
        , _a)));
        setVisitedToursV2Cookie(__assign(__assign({}, getVisitedToursV2()), (_b = {}, _b[tourId] = stepId, _b)));
    }
};
export var clearVisitedToursCookie = function () {
    clearCookie(VISITED_TOURS_COOKIE_NAME);
    clearCookie(VISITED_TOURS_V2_COOKIE_NAME);
};
export var getActiveTourStateUrlQueryParam = function () {
    var state = readTourState();
    if (!state) {
        return undefined;
    }
    var urlParam = "".concat(ACTIVE_TOUR_COOKIE_NAME, "=").concat(compressActiveTourState(state, true));
    return urlParam;
};
export var appendTourStateToUrl = function (url, useNextState) {
    if (useNextState === void 0) { useNextState = false; }
    var tourState = tourController.getIncrementedTourState(useNextState ? 1 : 0);
    if (!tourState) {
        return url;
    }
    var tourStateParam = "".concat(ACTIVE_TOUR_COOKIE_NAME, "=").concat(compressActiveTourState(tourState, true));
    var splitter = 'RelayState=';
    var urlParts = url.split(splitter);
    var lastIndex = urlParts.length - 1;
    var nextUrl = urlParts[lastIndex];
    urlParts[lastIndex] = nextUrl + (nextUrl.includes('?') ? '&' : '?') + tourStateParam;
    return urlParts.join(splitter);
};
export var appendNextTourStateToUrl = function (url) { return appendTourStateToUrl(url, true); };
export var compressActiveTourState = function (state, encode) {
    var appId = state.appId, tourId = state.tourId, paused = state.paused, stepNumber = state.stepNumber, stepId = state.stepId, substepNumber = state.substepNumber, substepNestedNumber = state.substepNestedNumber, vars = state.vars;
    var variables = vars && Object.keys(vars).length ? JSON.stringify(vars) : '';
    var compressedState = "".concat(tourId, "'").concat(stepNumber, "'").concat(substepNumber, "'").concat(paused ? 1 : 0, "'").concat(appId, "'").concat(stepId, "'").concat(substepNestedNumber).concat(variables);
    return encode ? encodeURIComponent(compressedState) : compressedState;
};
export var parseTourState = function (stateString) {
    if (stateString) {
        try {
            var tourState = JSON.parse(stateString);
            var isValid = isTourStateValid(tourState);
            if (!isValid) {
                console.error('ActiveTour State is not valid', tourState);
                return undefined;
            }
            return tourState;
        }
        catch (e) {
            console.error('Can not parse activeTour state from url', stateString);
            return undefined;
        }
    }
    return undefined;
};
export var calculateAppIdFromTourId = function (tourId) {
    var parts = tourId.split('-');
    var appId = parts[0];
    if (parts.length < 2 || appId.startsWith('get') || appId.length < 2) {
        // temp hack, remove in October 2020
        appId = COMMON_CONSOLE_APP_ID;
    }
    return appId;
};
export var decompressActiveTourState = function (compressedState, decode) {
    if (!compressedState) {
        return undefined;
    }
    var decoded = decode ? decodeURIComponent(compressedState) : compressedState;
    var parts = decoded.split('{');
    var _a = __read(parts[0].split("'"), 7), tourId = _a[0], stepNumber = _a[1], substepNumber = _a[2], paused = _a[3], appId = _a[4], stepId = _a[5], substepNestedNumber = _a[6];
    var vars = parts.length > 1 ? '{' + parts[1] : '{}';
    var tourState = {
        tourId: tourId,
        paused: !!parseInt(paused),
        stepNumber: parseInt(stepNumber),
        substepNumber: parseInt(substepNumber),
        appId: appId,
        stepId: stepId,
        substepNestedNumber: substepNestedNumber !== undefined ? parseInt(substepNestedNumber) : undefined,
        vars: JSON.parse(vars || '{}')
    };
    if (!isTourStateValid(tourState)) {
        console.error('ActiveTour State is not valid', tourState);
        return undefined;
    }
    return tourState;
};
