export declare type jsonValue = string;
export interface WaitFor {
    delay?: number;
    urlPattern?: string;
    presentSelector?: WaitForSelector | WaitForSelector[];
    nonPresentSelector?: WaitForSelector | WaitForSelector[];
    visibleSelector?: WaitForSelector | WaitForSelector[];
    hiddenSelector?: WaitForSelector | WaitForSelector[];
    waitTime?: number;
    retryDelay?: number;
    onSuccess?: Function;
    onError?: Function;
}
export declare type WaitForSelector = string | Selector;
export interface Selector {
    css?: string;
    content?: string;
    iframe?: string;
}
export interface RepriseTourProps {
    title: string;
    description: string;
    src: string;
}
export interface VideoProps {
    title: string;
    description: string;
    src: string;
}
export interface VideoPlaylist {
    title: string;
    description: string;
    src: string;
    items: VideoProps[];
}
export interface DocProps {
    title: string;
    description: string;
    href: string;
}
export interface StartConfig {
    vars?: TourVars;
    noReload?: boolean;
}
export interface AutoRestartConfig {
    environmentBaseUrl?: string;
    onShowTourPanel?: Function;
    currentUserEntitlements?: string[];
    vars?: TourVars;
    effects?: Record<string, EffectFunction>;
}
export declare type TourVars = Record<string, jsonValue>;
export interface WaitForRuntime {
    predicate: () => boolean;
    waitTime: number;
    retryDelay: number;
    onSuccess?: Function;
    onError?: Function;
}
export declare type ArrowPlacement = 'start' | 'end' | 'center' | undefined;
export declare type Placement = 'auto-start' | 'auto' | 'auto-end' | 'top-start' | 'top' | 'top-end' | 'right-start' | 'right' | 'right-end' | 'bottom-end' | 'bottom' | 'bottom-start' | 'left-end' | 'left' | 'left-start' | undefined;
export interface AppIndexItemMetaInfo {
    id?: string;
    entitlements?: string[];
    deniedEntitlements?: string[];
    tags?: string[];
}
export interface AppItemCore {
    id: string;
    title: string;
    description: string;
}
export interface AppTourWidget extends AppItemCore {
    progress: TourProgress;
}
export declare type AppItemWidget = AppItemCore & (AppTourWidget | VideoProps | DocProps | RepriseTourProps);
/**
 * Each tourId should start with appId and follow format: "appid-tour-name"
 * (for example: "cml-production")
 * AppId is used to resolve tour folder location.
 * If tour uses multiple applications his name should start with "common" like:
 * "common-tour-name"
 */
export declare type TourId = string;
export declare type AppId = string;
export interface TourJson extends AppItemCore {
    vars: Record<string, jsonValue>;
    steps: StepJson[];
    checklist?: Partial<Checklist> | boolean;
    showStepNumber?: boolean;
    highlightTarget?: boolean;
    debug?: boolean;
}
export interface TourExtendedJson extends TourJson {
    stepsAmount: number;
    progress: TourProgress;
}
export interface TourProps extends TourJson {
    allSubsteps: CommonSubstepProps[];
    substepsAmount: number;
    usedVars: string[];
    checklist?: Checklist;
}
export interface Checklist {
    title: string;
    description: string;
}
export declare type LinkTarget = '_blank' | undefined;
export interface ButtonOptions {
    baseUrl?: string;
    path?: string;
    linkTarget?: LinkTarget;
    title?: string;
    appendTourState?: boolean;
}
export interface StepJson {
    id: string;
    title: string;
    baseUrl: string;
    path: string;
    expectedPath?: string;
    substeps: SubstepJson[];
}
export interface SubstepJson extends SubstepCommonJson, SubstepEffectsJson {
}
interface ScrollIntoViewOptions {
    behavior: 'auto' | 'smooth' | undefined;
    block: 'start' | 'center' | 'end' | 'nearest' | undefined;
    inline: 'start' | 'center' | 'end' | 'nearest' | undefined;
}
interface WatchForDomMutations {
    selector: string;
    delay?: number;
}
/**
 * Note: If you edit this list, you need to update `substepCommonPropNames` below
 */
export interface SubstepCommonJson {
    /**
     * allowInteraction Allows user to interact with specified ui elements on page while tour tooltip is shown and pointing to the target.
     * true/false - allows/forbids interaction with all elements
     * "css-selector" - allows elements who match css-selector
     * ["css-selector1", "css-selector2"] - allows elements who match any of listed selectors.
     * Regardless of allowInteraction value user can all the times interact with target elemement, tooltip content and floating checklist.
     */
    allowInteraction?: boolean | string | string[];
    animationDelay?: number;
    arrowPlacement?: ArrowPlacement;
    checklistNextButton?: boolean | ButtonOptions;
    content: string;
    delay?: number;
    hidden?: boolean;
    highlightTarget?: boolean;
    maxWidth?: number;
    nextButton?: ButtonOptions;
    nextOnTargetClick?: boolean;
    nextOnWaitFor?: WaitFor;
    placement?: Placement;
    preventDefaultForKeys?: string[];
    requireInput?: boolean;
    scrollIntoView?: boolean | ScrollIntoViewOptions;
    showNext?: boolean;
    showPrev?: boolean;
    stopPropogationForKeys?: string[];
    showStepNumber?: boolean;
    /**
     * @type {string} target is a css selector that finds a target
     * either in the window.document,
     * or the an iframe document found via targetContent selector.
     */
    target?: string;
    /**
     * @type {string} targetContent is a pattern matcher.
     * When targetContent is provided, we user `target` to query all matching elements.
     * Then the first item that contains text matching targetContent is used.
     */
    targetContent?: string;
    /**
     * @type {string} targetIframe css selector to match an iframe element.
     * When the iframe element is matched, we use the document inside
     * the iframe to run querySelector instead of window.document.
     * This allows the `target` selector to match items inside an iframe.
     */
    targetIframe?: string;
    title: string;
    waitFor?: WaitFor;
    watchForDomMutations?: WatchForDomMutations;
}
export declare type ChecklistAction = 'next' | 'skip' | 'start';
export declare const substepCommonPropNames: string[];
declare type SubstepEffectsJson = Partial<Record<SubstepEventName, Effect>>;
declare type SubstepCallbacks = Partial<Record<SubstepEventName, Function>>;
export declare type SubstepEventName = 'onInit' | 'onDelay' | 'onStart' | 'onWaitSuccess' | 'onWaitError' | 'onTargetFound' | 'onTargetNotFound' | 'onShow' | 'onTargetClick' | 'onClickOutside' | 'onNext' | 'onPrev' | 'onClose' | 'onCollapse' | 'onDone';
export declare const EffectEvents: string[];
export interface VarsUsage {
    producedVars: string[];
    usedVars: string[];
}
export interface StepProps extends StepJson, VarsUsage {
    requiredVars: string[];
}
export interface CommonSubstepProps extends SubstepCommonJson, VarsUsage {
    stepNumber: number;
    stepId: string;
    substepNestedNumber: number;
    substepNumber: number;
    isFirst: boolean;
    isFirstInStep?: boolean;
    isLast: boolean;
    effects: Partial<Record<SubstepEventName, Effect>>;
    expectedPath?: string;
}
export interface SubstepProps extends CommonSubstepProps, SubstepCallbacks {
}
export interface EffectJson extends Record<string, any> {
    effect: string;
    varName?: string;
    tmpl?: string;
    attribute?: string;
    regexp?: string;
    regexpFlags?: string;
}
export declare type Effect = EffectJson | EffectJson[] | undefined;
export interface EffectCallParams extends Record<string, any> {
    effect: EffectJson;
    substep: Partial<CommonSubstepProps>;
    event?: any;
}
export declare type EffectFunction = (params: EffectCallParams) => void;
export interface TourState {
    tourId: string;
    stepNumber: number;
    substepNumber: number;
    paused: boolean;
    vars: TourVars;
    appId?: string;
    stepId?: string;
    substepNestedNumber?: number;
}
export declare type VisitedTours = Record<string, number>;
export declare type VisitedToursV2 = Record<string, string | undefined>;
export interface AppsItemJson {
    id: string;
    baseUrl: string;
    path: string;
    icon?: string;
}
export interface AppIndexCommon {
    app: string;
    title: string;
    description: string;
    items: string[];
    repriseTours: Record<string, RepriseTourProps & AppIndexItemMetaInfo>;
    videos: Record<string, (VideoProps | VideoPlaylist) & AppIndexItemMetaInfo>;
    docs: Record<string, DocProps & AppIndexItemMetaInfo>;
}
export interface AppIndexJson extends AppIndexCommon {
    tours: Record<AppId, AppIndexItemMetaInfo>;
}
export interface AppIndexProps extends AppIndexCommon {
    tours: Record<AppId, TourExtendedJson>;
}
export interface AppsItemProps extends AppsItemJson, AppIndexProps {
    metrics: AppMetrics;
}
export interface TourProgress {
    stepsAmount: number;
    currentStepNumber?: number;
    currentStepId?: string;
}
export interface AppMetrics {
    items: number;
    tours: number;
    repriseTours: number;
    videos: number;
    docs: number;
}
export {};
