var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __read = (this && this.__read) || function (o, n) {
    var m = typeof Symbol === "function" && o[Symbol.iterator];
    if (!m) return o;
    var i = m.call(o), r, ar = [], e;
    try {
        while ((n === void 0 || n-- > 0) && !(r = i.next()).done) ar.push(r.value);
    }
    catch (error) { e = { error: error }; }
    finally {
        try {
            if (r && !r.done && (m = i["return"])) m.call(i);
        }
        finally { if (e) throw e.error; }
    }
    return ar;
};
var __spreadArray = (this && this.__spreadArray) || function (to, from, pack) {
    if (pack || arguments.length === 2) for (var i = 0, l = from.length, ar; i < l; i++) {
        if (ar || !(i in from)) {
            if (!ar) ar = Array.prototype.slice.call(from, 0, i);
            ar[i] = from[i];
        }
    }
    return to.concat(ar || Array.prototype.slice.call(from));
};
// Copyright (c) 2019 Cloudera, Inc. All rights reserved.
import { EffectEvents, substepCommonPropNames } from './interfaces';
import flatten from 'lodash/flatten';
import pick from 'lodash/pick';
import { variableProducingEffects } from '../Effects/Effects';
import { tourController } from './TourController';
import uniq from 'lodash/uniq';
var TEMPLATE_VAR_REGEX = /\$\{([^}]+)\}/; // matching ${varName}
export var substepDefaults = {
    allowInteraction: false,
    placement: 'bottom',
    showNext: true,
    showPrev: false,
    delay: 300,
    showStepNumber: false
};
var substepJsonToProps = function (substep, stepNumber, stepId, substepNestedNumber, substepNumber, isFirstInStep, expectedPath, showStepNumber, highlightTarget) {
    var substepCommonProps = pick(substep, substepCommonPropNames);
    var substepProps = __assign(__assign(__assign(__assign(__assign({}, substepDefaults), { showStepNumber: showStepNumber }), substepCommonProps), { 
        // @ts-ignore
        effects: pick(substep, EffectEvents), stepNumber: stepNumber, stepId: stepId, substepNestedNumber: substepNestedNumber, substepNumber: substepNumber, isFirst: false, isLast: false, isFirstInStep: isFirstInStep }), extractVarsUsageFromSubstepJson(substep));
    // We want to inherit tour propety highlightTarget into substep
    // only if substep target need to be clicked by user
    if (substepProps.nextOnTargetClick &&
        substepProps.highlightTarget === undefined &&
        highlightTarget !== undefined) {
        substepProps.highlightTarget = highlightTarget;
    }
    if (expectedPath) {
        substepProps.expectedPath = expectedPath;
    }
    // Auto append target into waitFor.presentSelector
    var target = substep.target, targetContent = substep.targetContent, targetIframe = substep.targetIframe, _a = substep.waitFor, _b = _a === void 0 ? {} : _a, presentSelector = _b.presentSelector;
    if (target || targetContent || targetIframe) {
        var presentSelectorsWithTarget = [];
        if (presentSelector) {
            presentSelectorsWithTarget = Array.isArray(presentSelector)
                ? presentSelector
                : [presentSelector];
        }
        var targetSelector = targetContent || targetIframe
            ? {
                css: target,
                content: targetContent,
                iframe: targetIframe
            }
            : target;
        presentSelectorsWithTarget.push(targetSelector);
        substepProps.waitFor = __assign(__assign({}, substep.waitFor), { presentSelector: presentSelectorsWithTarget.length === 1
                ? presentSelectorsWithTarget[0]
                : presentSelectorsWithTarget });
    }
    // @ts-ignore
    return substepProps;
};
export var tourJsonToProps = function (tourJson) {
    var tour = JSON.parse(JSON.stringify(tourJson));
    var substepNumber = 0;
    var allSubsteps = [];
    var vars = tour.vars, showStepNumber = tour.showStepNumber;
    var usedVars = [];
    tour.steps.forEach(function (step, stepNumber) {
        usedVars = __spreadArray(__spreadArray([], __read(usedVars), false), __read(extractUsedVarsFromStepJson(step)), false);
        step.substeps.forEach(function (substep, i) {
            var substepProp = substepJsonToProps(substep, stepNumber, step.id, i, substepNumber, i === 0, step.expectedPath, showStepNumber, tourJson.highlightTarget);
            usedVars = __spreadArray(__spreadArray([], __read(usedVars), false), __read(substepProp.usedVars), false);
            allSubsteps.push(substepProp);
            substepNumber++;
        });
    });
    var substepsAmount = allSubsteps.length;
    if (substepsAmount) {
        allSubsteps[0].isFirst = true;
        allSubsteps[substepsAmount - 1].isLast = true;
        // TODO [future] collect step required vars from all following substeps. (andrii)
        // Excluding vars produced after current substep.
    }
    var tourProps = __assign(__assign({}, tour), { vars: vars, allSubsteps: allSubsteps, substepsAmount: substepsAmount, usedVars: uniq(usedVars) });
    if (tour.checklist) {
        tourProps.checklist = {
            title: tour.checklist.title || tour.displayName,
            description: tour.checklist.description || tour.description
        };
    }
    return tourProps;
};
/**
 * Recursive interpolate function
 *  @param {string} template like iam/index.html#/groups/${groupName}
 *  @param {object} vars like {groupName: "myGroup"}
 *  @return {string} interpolated template string using provided vars object.
 */
export var interpolate = function (tmpl, vars) {
    if (!tmpl || typeof tmpl !== 'string') {
        return tmpl;
    }
    var res = tmpl;
    var matches = res.match(TEMPLATE_VAR_REGEX);
    if (matches === null) {
        return res;
    }
    var _a = __read(matches, 2), match = _a[0], varName = _a[1];
    var varValue = vars[varName];
    if (varValue === undefined) {
        console.error("Can not interpolate template: ".concat(tmpl, ". Variable: \"").concat(varName, "\" is not defined."));
        return tmpl;
    }
    res = res.replace(match, varValue);
    return interpolate(res, vars);
};
export var interpolateWithTourVars = function (template) {
    var vars = tourController.getTourStateVars();
    return interpolate(template, vars);
};
export var extractVarNamesFromTemplate = function (tmpl) {
    if (!tmpl) {
        return [];
    }
    var matches = tmpl.match(TEMPLATE_VAR_REGEX);
    if (matches === null) {
        return [];
    }
    var _a = __read(matches, 2), match = _a[0], varName = _a[1];
    return __spreadArray([varName], __read(extractVarNamesFromTemplate(tmpl.replace(match, ''))), false);
};
export var extractVarNamesFromNextButton = function (_a) {
    var _b = _a.nextButton, nextButton = _b === void 0 ? {} : _b;
    var _c = nextButton.path, path = _c === void 0 ? '' : _c, _d = nextButton.baseUrl, baseUrl = _d === void 0 ? '' : _d, _e = nextButton.title, title = _e === void 0 ? '' : _e;
    return __spreadArray(__spreadArray(__spreadArray([], __read(extractVarNamesFromTemplate(path)), false), __read(extractVarNamesFromTemplate(baseUrl)), false), __read(extractVarNamesFromTemplate(title)), false);
};
export var extractUsedVarsFromStepJson = function (_a) {
    var baseUrl = _a.baseUrl, path = _a.path, expectedPath = _a.expectedPath;
    return __spreadArray(__spreadArray(__spreadArray([], __read(extractVarNamesFromTemplate(baseUrl)), false), __read(extractVarNamesFromTemplate(path)), false), __read(extractVarNamesFromTemplate(expectedPath)), false);
};
var getSubstepEffectsDeclarations = function (substep) {
    return flatten(Object.keys(substep)
        .filter(function (k) { return EffectEvents.includes(k); })
        // @ts-ignore
        .map(function (k) { return substep[k]; }));
};
/**
 * During demo user may create some resources. It is possible to collect and save
 * names of this resources in tourVariables (which are persisted in activeTour cookie)
 * Variables may be used in substep.target templates or in substep effects.
 *
 * This function analyzes substep.target and .effects to finds used variables
 *  - target (can be string template)
 *  - effects (searches for varName parameter)
 *
 * Having this data it is possible to calculate is supstep has enough info to be shown.
 */
export var extractVarsUsageFromSubstepJson = function (substep) {
    var varsUsedInTemplates = extractVarNamesFromTemplate(substep.target);
    var usedEffects = getSubstepEffectsDeclarations(substep);
    var varsUsedInNextButton = extractVarNamesFromNextButton(substep);
    var varsConsumedByEffects = usedEffects
        .filter(function (e) { return e.varName; })
        .filter(function (e) { return !variableProducingEffects.includes(e.effect); })
        .map(function (e) { return e.varName; });
    var varsProducedByEffects = usedEffects
        .filter(function (e) { return e.varName; })
        .filter(function (e) { return variableProducingEffects.includes(e.effect); })
        .map(function (e) { return e.varName; });
    return {
        // @ts-ignore
        producedVars: varsProducedByEffects,
        // @ts-ignore
        usedVars: __spreadArray(__spreadArray(__spreadArray([], __read(varsUsedInTemplates), false), __read(varsConsumedByEffects), false), __read(varsUsedInNextButton), false)
    };
};
