/** @jsx h */
// Copyright (c) 2020 Cloudera, Inc. All rights reserved.
import { h } from 'preact';
import { Propper } from '../Propper/Propper';
import TourModal from './TourModal';
import { TourModalVideo } from './TourModalVideo';
import { getComposedPath } from '../Substep/utils';
import { TourModalReprise } from './TourModalReprise';
var TourModalController = /** @class */ (function () {
    function TourModalController() {
        var _this = this;
        this.blockEsc = false;
        this.state = {
            propper: null
        };
        this.subscribeClickOutside = function () {
            document.body.addEventListener('mousedown', _this.onBodyMouseDown, {
                capture: true,
                once: false,
                passive: true
            });
        };
        this.unsubscribeClickOutisde = function () {
            document.body.removeEventListener('mousedown', _this.onBodyMouseDown, false);
            document.body.removeEventListener('mousedown', _this.onBodyMouseDown, true);
        };
        this.onBodyMouseDown = function (event) {
            var target = (event.target || event.srcElement);
            var path = getComposedPath(target);
            var propper = _this.state.propper;
            var isPropper = propper && path.includes(propper.contentEl);
            if (propper && !isPropper) {
                _this.hide();
                event.stopPropagation();
            }
        };
        this.escKeyListener = function (event) {
            var key = event.key;
            if (key === 'Escape') {
                if (!_this.blockEsc) {
                    _this.hide();
                }
                event.preventDefault();
                event.stopPropagation();
            }
        };
        this.subscribeEsc = function () {
            document.addEventListener('keydown', _this.escKeyListener, true);
        };
        this.unsubscribeEsc = function () {
            document.removeEventListener('keydown', _this.escKeyListener, true);
        };
        this.show = function (_a) {
            var header = _a.header, content = _a.content;
            _this.hide();
            _this.state.propper = new Propper({
                preactContent: (h(TourModal, { header: header, content: content, onClose: tourModalController.hide })),
                isModal: true
            });
            _this.subscribeClickOutside();
            _this.subscribeEsc();
        };
        this.showRepriseTour = function (_a) {
            var title = _a.title, description = _a.description, src = _a.src;
            _this.hide();
            _this.state.propper = new Propper({
                preactContent: (h(TourModalReprise, { title: title, description: description, src: src, onClose: tourModalController.hide })),
                isModal: true
            });
            // We want reprise modal window to stay even if user clicks outside or presses Esc button.
            _this.blockEsc = true;
            _this.subscribeEsc();
        };
        this.showVideo = function (_a) {
            var title = _a.title, description = _a.description, src = _a.src;
            _this.hide();
            _this.state.propper = new Propper({
                preactContent: (h(TourModalVideo, { title: title, description: description, src: src, onClose: tourModalController.hide })),
                isModal: true
            });
            _this.subscribeClickOutside();
            _this.subscribeEsc();
        };
        this.hide = function () {
            _this.blockEsc = false;
            _this.unsubscribeClickOutisde();
            _this.unsubscribeEsc();
            var propper = _this.state.propper;
            if (propper) {
                propper.destroy();
            }
        };
    }
    return TourModalController;
}());
export var tourModalController = new TourModalController();
