import { TourId, TourJson, TourState, AppsItemJson, AppId, AppIndexJson } from './Tour/interfaces';
export declare type TrackEvent = (category: string, action: string, label?: string, value?: number | string) => void;
export interface Analytics {
    trackEvent: TrackEvent;
}
export declare const getLocalStorageAppsOverride: () => any;
export declare const getLocalStorageAppIndexOverride: (appId: AppId) => any;
export declare const getLocalStorageTourOverride: (appId: AppId, tourId: TourId) => any;
/**
 * Fetches tour.json file by combination of baseUrl / appPath / tourId.
 * @returns TourJson from internet or from TOUR_OVERRIDES[tourId] if registered.
 */
export declare const fetchTourData: (appId: AppId, tourId: TourId) => Promise<TourJson | undefined>;
/**
 * Resolves content from appToursPath/index.json file or from its overrides.
 * It first tries to find overrides
 * from localstorage,
 * then from registerTourOverrides()
 * and only if not found, loads appToursPath/index.json
 * @returns Application tours index.json file, which declares tours and videos for application with id appId
 */
export declare const fetchAppIndex: (appId: string) => Promise<AppIndexJson | undefined>;
/**
 * Small helper function to find appConfig by appId from apps.json
 * It console.error_s if can't find config for appId.
 * @returns app config item for specified appId
 */
export declare const fetchAppConfig: (appId: AppId) => Promise<AppsItemJson | undefined>;
/**
 * Resolves content from Tour/apps.json file or from its overrides.
 * It first tries to find overrides
 * from localstorage,
 * then from registerTourOverrides()
 * and only if not found, loads apps.json from /commonConsole/downloads/tours/
 * @returns Array of application configs
 */
export declare const fetchAppsConfig: () => Promise<AppsItemJson[] | undefined>;
/**
 *  Currently static resources located in /commonconsole/downloads
 *  doesn't require authentication when queried.
 *  Other api requests require authentication.
 */
export declare const shouldUseAuth: (pathname: string) => boolean;
/**
 * Similar to fetchSidebarData, but allows to pass baseURl
 * @param path Path of the resource.
 * If path is not started with '/' then resouce will be resolved from TOURS_BASE_PATH folder
 * @param defaultValue Default value returned if fething fails
 * @params {string} baseUrl
 */
export declare const fetchToursData: <T>(path: string, baseUrl?: string) => Promise<T | undefined>;
export declare const realmIdFromEmail: (email: string | undefined) => string | undefined;
/**
 * Allows application to override items in apps.json and/or existing tour.json files
 * Overrides will be present till next page reload. They are not persisted in local or session storage.
 */
export declare const registerTourOverrides: ({ tours, apps, appIndexes }: {
    tours?: Record<string, TourJson> | undefined;
    apps?: AppsItemJson[] | undefined;
    appIndexes?: Record<string, AppIndexJson> | undefined;
}) => void;
export declare const registerDefaultTourAnalytics: (analytics: Analytics) => void;
export declare const registerTourAnalytics: (analytics: Analytics) => void;
/**
 * Replaces all tourVars values with ****** to make sure we don't send them to google analytics
 */
export declare const hideTourVars: (activeTourCookie: string | undefined) => string | undefined;
export declare const stateToSimpleString: (state: Partial<TourState> | undefined) => string;
export declare const trackTourError: (action: string, label?: string, value?: number) => void;
export declare const trackTourEvent: (action: string, label?: string, value?: number) => void;
