import 'whatwg-fetch';
export declare const SIDEBAR_DATA_CACHE: Record<string, any>;
export declare const DEFAULT_DOWNLOAD_BASE_URL: string;
/**
 * Currently there are two types of apps in CDP:
 * Legacy Altus Apps, and Manowar apps.
 * Legacy altus apps get routed to a different url
 * So they have a url of the form: console.cloudera.com
 * Manowar apps get routed to k8s-style apps.
 * They live under urls of the form: console.cdp.cloudera.com
 * In private cloud, all apps are k8s apps. So it is preferred to use 'altus'
 * instead of 'mow' because 'altus' generally means the same as the 'home' url of CDP.
 */
export declare const calcBaseUrl: (baseUrl?: string) => string;
interface SidebarFetchConfig {
    /**
     * optional value specifying if we want to use the cdp environment to fetch sidebar data
     * if it is false, the path is relative to the current application or absolute.
     */
    useCDPHost?: boolean;
}
/**
 * Fetches, caches, and returns a resource for the sidebar. Since the amount of resource we deal with
 * is pretty small at the moment we use a simple cache without worrying about cache size. The goal
 * of this cache is not to re-fetch stuff if the sidebar re-renders in SPAs.
 *
 * @param path Path of the resource
 * @param defaultValue Default value returned if fething fails
   @param config Optional config to configure the fetching of sidebar data.
 */
export declare const fetchSidebarData: <T>(path: string, defaultValue: T, config?: SidebarFetchConfig) => Promise<T>;
export declare const getLocalStorageValue: (path: string) => any;
/** Apps as specified in the apps.v3.json files */
export interface JSONApp {
    /** Name / identifier for the app. */
    name: string;
    /** Visible display name for the app. */
    displayName: string;
    /** SVG logo for the app. */
    logo: string;
    /**
     * Base url portion of the app's full url. Can be set to altus or mow in order to have the
     * real base url calculated automatically depending on the current environment.
     */
    baseUrl?: string;
    /** Path portion of app's full url. */
    path: string;
    /** App is hidden if this entitlement is not granted to the account. */
    entitlement?: string;
    /** App is hidden if this entitlement is granted to the account. */
    disablingEntitlement?: string;
    /** category used to determine location on landing page and in app-switcher */
    category?: string;
    /**
     * Optional "tag" that can be displayed along with the product text logo at
     * the top of the sidebar. We've used this to display a temporary "BETA" tag,
     * for example.
     */
    productDisplayNameTag?: string;
}
/**
 * Get the bundled set of apps. This is primarily used if the live connection fails,
 * but in that case wouldn't everything else fail too?
 * TODO: [future] considering removing this fallback, expecially if we still do JSON filtering
 * See CDPCP-4652
 */
export declare const getFallbackApps: () => ({
    name: string;
    displayName: string;
    logo: string;
    baseUrl: string;
    path: string;
    entitlement?: undefined;
    disablingEntitlement?: undefined;
    category?: undefined;
    productDisplayNameTag?: undefined;
} | {
    name: string;
    displayName: string;
    logo: string;
    baseUrl: string;
    path: string;
    entitlement: string;
    disablingEntitlement?: undefined;
    category?: undefined;
    productDisplayNameTag?: undefined;
} | {
    name: string;
    displayName: string;
    logo: string;
    baseUrl: string;
    path: string;
    disablingEntitlement: string;
    entitlement?: undefined;
    category?: undefined;
    productDisplayNameTag?: undefined;
} | {
    name: string;
    displayName: string;
    logo: string;
    baseUrl: string;
    path: string;
    disablingEntitlement: string;
    category: string;
    entitlement?: undefined;
    productDisplayNameTag?: undefined;
} | {
    name: string;
    displayName: string;
    logo: string;
    baseUrl: string;
    path: string;
    category: string;
    entitlement?: undefined;
    disablingEntitlement?: undefined;
    productDisplayNameTag?: undefined;
} | {
    name: string;
    displayName: string;
    logo: string;
    baseUrl: string;
    path: string;
    category: string;
    entitlement: string;
    productDisplayNameTag: string;
    disablingEntitlement?: undefined;
})[] | ({
    name: string;
    displayName: string;
    logo: string;
    baseUrl: string;
    path: string;
    disablingEntitlement?: undefined;
    entitlement?: undefined;
    category?: undefined;
} | {
    name: string;
    displayName: string;
    baseUrl: string;
    path: string;
    disablingEntitlement: string;
    logo: string;
    entitlement?: undefined;
    category?: undefined;
} | {
    name: string;
    displayName: string;
    logo: string;
    baseUrl: string;
    path: string;
    disablingEntitlement: string;
    entitlement: string;
    category?: undefined;
} | {
    name: string;
    displayName: string;
    logo: string;
    baseUrl: string;
    path: string;
    category: string;
    disablingEntitlement?: undefined;
    entitlement?: undefined;
})[];
/**
 * Fetch or re-use preivous fetched versions of the apps.v3.json
 */
export declare const fetchAppsOnce: {
    (): Promise<JSONApp[]>;
    clear(): undefined;
};
/**
 * Fetch trial details to display trial information
 */
export declare const fetchTrialDetailsOnce: {
    (): Promise<import("cdp-js/dist/lib/ApiResponse").default<import("cdp-js/dist/api/trialmanager/types").GetTrialDetailsResponse>>;
    clear(): undefined;
};
/**
 * Make request to convert to production
 */
export declare const createClouderaSalesReq: {
    (): Promise<import("cdp-js/dist/lib/ApiResponse").default<import("cdp-js/dist/api/trialmanager/types").CreateClouderaSalesRequestResponse>>;
    clear(): undefined;
};
export {};
