// Copyright (c) 2019 Cloudera, Inc. All rights reserved.
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __generator = (this && this.__generator) || function (thisArg, body) {
    var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
    return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function() { return this; }), g;
    function verb(n) { return function (v) { return step([n, v]); }; }
    function step(op) {
        if (f) throw new TypeError("Generator is already executing.");
        while (_) try {
            if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done) return t;
            if (y = 0, t) op = [op[0] & 2, t.value];
            switch (op[0]) {
                case 0: case 1: t = op; break;
                case 4: _.label++; return { value: op[1], done: false };
                case 5: _.label++; y = op[1]; op = [0]; continue;
                case 7: op = _.ops.pop(); _.trys.pop(); continue;
                default:
                    if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                    if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                    if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                    if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                    if (t[2]) _.ops.pop();
                    _.trys.pop(); continue;
            }
            op = body.call(thisArg, _);
        } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
        if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
    }
};
import 'whatwg-fetch';
import appConfig, { EnvironmentType } from "cdp-js/dist/lib/appConfig";
import publicFallbackApps from './cdp-public-conf/apps.v3.json';
import privateFallbackApps from './cdp-private-conf/apps.v3.json';
import apiCommon from "cdp-js/dist/lib/apiCommon";
import trialmanager from "cdp-js/dist/api/trialmanager";
import { SalesRequestType } from "cdp-js/dist/api/trialmanager/types";
export var SIDEBAR_DATA_CACHE = {};
export var DEFAULT_DOWNLOAD_BASE_URL = window.location.toString().match('[?&]localSidebar=true')
    ? 'http://localhost:8090'
    : '';
/**
 * Currently there are two types of apps in CDP:
 * Legacy Altus Apps, and Manowar apps.
 * Legacy altus apps get routed to a different url
 * So they have a url of the form: console.cloudera.com
 * Manowar apps get routed to k8s-style apps.
 * They live under urls of the form: console.cdp.cloudera.com
 * In private cloud, all apps are k8s apps. So it is preferred to use 'altus'
 * instead of 'mow' because 'altus' generally means the same as the 'home' url of CDP.
 */
export var calcBaseUrl = function (baseUrl) {
    /**
     * 'altus'
     * We want to use the base cdp or private cloud url.
     * In cdp public cloud it would be https://console.cdp.cloudera.com
     * In private cloud it will be the private cloud host: https://foo.kcloud.cloudera.com
     */
    if (baseUrl === 'altus') {
        return appConfig.getAltusBaseUrl();
    }
    /**
     * getMowBaseUrl returns urls like:
     * console.us-west-1.cdp.cloudera.com
     * or console.dps.mow-dev.cloudera.com
     * These urls are for K8S UI servers under the Manowar infrastructure.
     */
    if (baseUrl === 'mow') {
        return appConfig.getMowBaseUrl();
    }
    return baseUrl || '';
};
/**
 * Fetches, caches, and returns a resource for the sidebar. Since the amount of resource we deal with
 * is pretty small at the moment we use a simple cache without worrying about cache size. The goal
 * of this cache is not to re-fetch stuff if the sidebar re-renders in SPAs.
 *
 * @param path Path of the resource
 * @param defaultValue Default value returned if fething fails
   @param config Optional config to configure the fetching of sidebar data.
 */
export var fetchSidebarData = function (path, defaultValue, config) {
    if (config === void 0) { config = { useCDPHost: true }; }
    return __awaiter(void 0, void 0, void 0, function () {
        var devOverride, url, response, data, _a, e_1;
        return __generator(this, function (_b) {
            switch (_b.label) {
                case 0:
                    devOverride = getLocalStorageValue(path);
                    if (devOverride) {
                        return [2 /*return*/, devOverride];
                    }
                    if (SIDEBAR_DATA_CACHE[path]) {
                        return [2 /*return*/, SIDEBAR_DATA_CACHE[path]];
                    }
                    _b.label = 1;
                case 1:
                    _b.trys.push([1, 8, , 9]);
                    url = config.useCDPHost
                        ? (appConfig.getAltusDownloadsBaseUrl() || DEFAULT_DOWNLOAD_BASE_URL) + path
                        : path;
                    return [4 /*yield*/, fetch(url)];
                case 2:
                    response = _b.sent();
                    if (!(response.status === 200)) return [3 /*break*/, 7];
                    if (!(typeof defaultValue === 'string')) return [3 /*break*/, 4];
                    return [4 /*yield*/, response.text()];
                case 3:
                    _a = _b.sent();
                    return [3 /*break*/, 6];
                case 4: return [4 /*yield*/, response.json()];
                case 5:
                    _a = _b.sent();
                    _b.label = 6;
                case 6:
                    data = _a;
                    SIDEBAR_DATA_CACHE[path] = data;
                    return [2 /*return*/, data];
                case 7: return [3 /*break*/, 9];
                case 8:
                    e_1 = _b.sent();
                    return [2 /*return*/, defaultValue];
                case 9: return [2 /*return*/, defaultValue];
            }
        });
    });
};
export var getLocalStorageValue = function (path) {
    try {
        var devOverride = localStorage.getItem(path);
        var value = devOverride ? JSON.parse(devOverride) : undefined;
        return value;
    }
    catch (e) {
        console.error("Can't parse local storage ".concat(path, " value"), e);
        return undefined;
    }
};
/**
 * Get the bundled set of apps. This is primarily used if the live connection fails,
 * but in that case wouldn't everything else fail too?
 * TODO: [future] considering removing this fallback, expecially if we still do JSON filtering
 * See CDPCP-4652
 */
export var getFallbackApps = function () {
    return appConfig.getEnvironment() === EnvironmentType.PRIVATE_CLOUD
        ? privateFallbackApps
        : publicFallbackApps;
};
var DOWNLOAD_APPS_PATH = '/commonconsole/downloads/apps.v3.json';
/**
 * Fetch or re-use preivous fetched versions of the apps.v3.json
 */
export var fetchAppsOnce = apiCommon.fetchOnce(function () {
    return fetchSidebarData(DOWNLOAD_APPS_PATH, getFallbackApps());
});
/**
 * Fetch trial details to display trial information
 */
export var fetchTrialDetailsOnce = apiCommon.fetchOnce(function () { return trialmanager.getTrialDetails({}); });
/**
 * Make request to convert to production
 */
export var createClouderaSalesReq = apiCommon.fetchOnce(function () {
    return trialmanager.createClouderaSalesRequest({
        salesRequestType: SalesRequestType.REQUEST_CONVERT_TO_PRODUCTION
    });
});
