// Copyright (c) 2016 Cloudera, Inc. All rights reserved.
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __read = (this && this.__read) || function (o, n) {
    var m = typeof Symbol === "function" && o[Symbol.iterator];
    if (!m) return o;
    var i = m.call(o), r, ar = [], e;
    try {
        while ((n === void 0 || n-- > 0) && !(r = i.next()).done) ar.push(r.value);
    }
    catch (error) { e = { error: error }; }
    finally {
        try {
            if (r && !r.done && (m = i["return"])) m.call(i);
        }
        finally { if (e) throw e.error; }
    }
    return ar;
};
/**
 * @module cloud-common/utils/pages
 * @description
 * Provides utility functions around page redirection (for testing)
 * and common urls that you can lookup.
 */
import appConfig from "cdp-js/dist/lib/appConfig";
import { encodeSearchQuery, parseQueryString } from "cuix/dist/utils/searchQuery";
import getUrl, { getComputeUrl } from "cuix/dist/utils/getUrl";
import { getServiceUrl } from "../../../../sigma/src/react/env/common/urls";
var CLOUDERA_ACCOUNT_PROFILE = 'https://my.cloudera.com/account/profile';
var COMMUNITY_URL = 'https://community.cloudera.com/t5/Altus/ct-p/Altus';
var SUPPORT_HOME_URL = 'https://www.cloudera.com/support/';
var SERVICE_STATUS_URL = 'http://status.cloudera.com/';
var NOTICES_URL = 'https://www.cloudera.com/documentation/other/Licenses/topics/ctpl_altus.html';
var NOT_FOUND_URL = '/notfound.html';
var HOME_URL = '/';
var CLI_HELP = 'https://www.cloudera.com/documentation/altus/topics/alt_client_setup.html';
var MARKETING_HOME_URL = 'https://www.cloudera.com/products/cloudera-data-platform.html';
var CLI_INO_URL = '/downloads/latest-cli.json';
var CONTACT_SALES_URL = 'https://www.cloudera.com/contact-sales.html';
var GROUP_PAGE_URL = 'https://docs.cloudera.com/management-console/cloud/user-management/topics/mc-working-with-groups-on-the-console.html';
export var SDX_DOCUMENTATION_URL = 'https://www.cloudera.com/documentation/altus/topics/altsdx_sdx_guide.html';
var TERMS_AND_CONDITIONS_URL = 'https://www.cloudera.com/legal/terms-and-conditions.html';
var PRIVACY_POLICY_URL = 'https://www.cloudera.com/legal/policies.html';
var SUPPORTED_BROWSERS_URL = 'https://docs.cloudera.com/common/html/browser-support.html';
var SECURITY_RESPONSE_TEAM_URL = 'https://my.cloudera.com/security.html';
var CLOUDERA_MAIN_PAGE_URL = 'https://www.cloudera.com/';
var CLOUDERA_DOCUMENTATION_URL = 'https://docs.cloudera.com/';
var EXPRESS_ONBOARDIN_URL = '/cloud/express-onboarding';
/**
 * Maybe this is too defensive and we can just use sessionStorage.clear().
 * But the intent of this function is to only clear keys for your console.
 * Specifically when you are logged out on redirect.
 */
function clearSessionStorageForConsole() {
    for (var i = 0; i < sessionStorage.length; i++) {
        var key = sessionStorage.key(i);
        if (key && key.indexOf(CONSOLE_NAME) === 0) {
            sessionStorage.removeItem(key);
        }
    }
}
export var injectRedirectSearchParamIntoUrl = function (url, redirect) {
    var separator = !url.includes('?') ? '?' : '&';
    return "".concat(url).concat(separator, "redirect=").concat(encodeURIComponent(redirect));
};
export var getRedirectSearchParamFromCurrentUrl = function () {
    var searchString = document.location.search || (document.location.hash || '').replace(/.*\?/, '');
    return new URLSearchParams(searchString).get('redirect') || undefined;
};
var pages = {
    clouderaAccountProfile: function () { return CLOUDERA_ACCOUNT_PROFILE; },
    communityUrl: function () { return COMMUNITY_URL; },
    supportHomeUrl: function () { return SUPPORT_HOME_URL; },
    serviceStatusUrl: function () { return SERVICE_STATUS_URL; },
    supportUrl: function () { return pages.getUrl('support', 'index.html'); },
    noticesUrl: function () { return NOTICES_URL; },
    cliHelp: function () { return CLI_HELP; },
    homeUrl: function () { return HOME_URL; },
    marketingHomeUrl: function () { return MARKETING_HOME_URL; },
    cliInfoUrl: function () { return CLI_INO_URL; },
    contactSalesUrl: function () { return CONTACT_SALES_URL; },
    groupPageUrl: function () { return GROUP_PAGE_URL; },
    termsAndConditionsPageUrl: function () { return TERMS_AND_CONDITIONS_URL; },
    privacyPolicyUrl: function () { return PRIVACY_POLICY_URL; },
    supportedBrowsersUrl: function () { return SUPPORTED_BROWSERS_URL; },
    securityResponseTeamUrl: function () { return SECURITY_RESPONSE_TEAM_URL; },
    clouderaMainPageUrl: function () { return CLOUDERA_MAIN_PAGE_URL; },
    clouderaDocumentationUrl: function () { return CLOUDERA_DOCUMENTATION_URL; },
    expressOnboardingUrl: function () { return EXPRESS_ONBOARDIN_URL; },
    getUrl: function (service, page, section, params) {
        return getUrl(service, page, section, params);
    },
    /**
     * Sets the current window path.
     * Provided as a convenience method for overriding in test.
     * @param {string} path The path to go to.
     */
    redirectTo: function (page) {
        window.location.href = page;
    },
    redirectToLogout: function () {
        appConfig.doLogout();
    },
    isCDPDomain: function () {
        return (pages.currentHost().includes('cdp.cloudera.com') ||
            !!pages.currentHost().match('mow-(dev|int|stage).cloudera.com'));
    },
    getCDPHomeUrl: function () {
        return appConfig.getAltusBaseUrl() || '/cdp.html';
    },
    reload: function () {
        window.location.reload();
    },
    /**
     * This function exists to be overriden in test.
     */
    currentHref: function () {
        return window.location.href;
    },
    currentHost: function () {
        return window.location.host;
    },
    /**
     * Get search params from location/url
     */
    getCurrentPageParams: function () {
        var parts = window.location.hash.split('?');
        var query = parts[1] || '';
        return parseQueryString(query);
    },
    /**
     * This function redirects you to the index page and remembers the url you were at.
     */
    unauthorizedRedirect: function () {
        clearSessionStorageForConsole();
        var loginRedirectParam = 'loginRedirect=' + encodeURIComponent(this.currentHref());
        var connector = appConfig.getLoginUrl().indexOf('?') > -1 ? '&' : '?';
        var redirectUrl = appConfig.getLoginUrl() + connector + loginRedirectParam;
        this.redirectTo(redirectUrl);
    },
    getCommonConsoleUrl: function (section, params) {
        return pages.getUrl('', 'index.html', section, params);
    },
    getIAMUrl: function (section, params) {
        return pages.getUrl('iam', 'index.html', section, params);
    },
    getSdxUrl: function (section, params) {
        return pages.getUrl('sdx', 'index.html', section, params);
    },
    /**
     * When in lens-support-admin console we need to preserve a url param across all urls.
     * In the future we could potentially pull this out of pages.ts and into files that
     * are local to WXM.
     */
    insertLensAccountId: function (params) {
        if (params === void 0) { params = {}; }
        if (params.accountId || params.accountId === null) {
            return params;
        }
        var currentParams = this.getCurrentPageParams();
        params.accountId = currentParams.accountId;
        return params;
    },
    insertShowStaleClustersParam: function (params) {
        if (params === void 0) { params = {}; }
        if (params.showStaleClusters || params.showStaleClusters === null) {
            return params;
        }
        var currentParams = this.getCurrentPageParams();
        params.showStaleClusters = currentParams.showStaleClusters;
        return params;
    },
    /**
     *
     * @param section string. part of the url that will be inserted after root url.
     * @param params  object. search parameters that will be part of the generated url.
     * @param addServicePrefix boolean. Adds service prefix to all the urls in the new lens UI.
     * @returns valid url string that should ideally match to one of the routes defined.
     */
    getWorkloadXMUrl: function (section, params, addServicePrefix) {
        if (params === void 0) { params = {}; }
        if (addServicePrefix === void 0) { addServicePrefix = true; }
        params = this.insertLensAccountId(params);
        params = this.insertShowStaleClustersParam(params);
        if (addServicePrefix &&
            section &&
            section !== '/' &&
            section !== 'chargeback' &&
            !section.includes('env')) {
            section = getServiceUrl() + section;
        }
        return pages.getUrl(appConfig.getWxmPathPrefix(), 'index.html', section, params);
    },
    getWaManageAccessUrl: function (_a) {
        var type = _a.type, id = _a.id;
        var params = this.insertLensAccountId();
        return pages.getUrl(appConfig.getWxmPathPrefix(), 'index.html', "".concat(type, "/").concat(id, "/access"), params);
    },
    getCoreAdminUrl: function (section, params) {
        return pages.getUrl('coreadmin', 'index.html', section, params);
    },
    getOPDBUrl: function (section, params) {
        return pages.getUrl('opdb', 'index.html', section, params);
    },
    getTermsUrl: function () {
        return "".concat(appConfig.getAltusBaseUrl()).concat(pages.getUrl('iam', 'terms.html'));
    },
    getNamespaceDetailPageUrl: function (namespaceName) {
        return this.getSdxUrl('namespaces/' + encodeURIComponent(namespaceName));
    },
    redirectNotFound: function () {
        this.redirectTo(NOT_FOUND_URL);
    },
    getCloudformationDetailsUrl: function (stackId, region) {
        return "https://".concat(region, ".console.aws.amazon.com/cloudformation/home#/stack/detail?region=").concat(region, "&stackId=").concat(stackId);
    },
    getMowUrl: function (path) {
        return appConfig.getMowBaseUrl() + path;
    },
    getCurrentUrlWithUpdatedParams: function (params) {
        var _a = __read(this.currentHref().split('?'), 2), url = _a[0], query = _a[1];
        var newQueryObj = __assign(__assign({}, parseQueryString(query)), params);
        var newUrl = "".concat(url).concat(encodeSearchQuery(newQueryObj));
        return newUrl;
    },
    getUdxUrl: function (section, params) {
        return pages.getUrl('udx', 'index.html', section, params);
    },
    getComputeUrl: function (section, params) {
        return getComputeUrl(section, params);
    }
};
export default pages;
