import { User, Entitlement, Terms, GetAccountMessagesResponse } from "cdp-js/dist/api/iam/types";
import { AnyAction } from 'redux';
interface RootState {
    auth: AuthState;
}
export interface AuthState {
    user?: User;
    entitlements: Entitlement[];
    terms: Terms[];
    personas: {
        [key: string]: boolean;
    };
    resources: string[];
    error?: any;
    fetching: boolean;
    accountMessages: GetAccountMessagesResponse;
}
export declare const entitlements: {
    GRIDLINK: string;
    WA_NEW_SPARK_OVERVIEW: string;
    TRIAL_ENTITLEMENT: string;
    CDP_TRIAL: string;
    CDPONE_TRIAL: string;
    NO_TUNNEL_PROVISIONING: string;
    CDP: string;
    ALTUS: string;
    TRY_CDP_PRODUCT_TOUR: string;
    REPRISE_PRODUCT_TOUR: string;
    ML_WORKSPACE_ROLES: string;
    DATA_PRACTITIONER_CDP_HOME_PAGE: string;
};
export declare const types: {
    AUTHENTICATE: string;
    SET_AUTH_STATE: string;
    GET_USER_SUCCESS: string;
    AUTHENTICATE_SUCCESS: string;
};
export declare const actions: {
    authenticate: () => {
        type: string;
    };
    setAuthState: (authState: Partial<AuthState>) => {
        type: string;
        authState: Partial<AuthState>;
    };
    getUserSuccess: (user: User) => {
        type: string;
        user: User;
    };
    authenticateSuccess: () => {
        type: string;
    };
};
declare const authReducer: (state: AuthState | undefined, action: AnyAction) => AuthState;
export default authReducer;
export declare const getEntitlementNames: import("reselect").OutputSelector<RootState, string[], (res: Entitlement[]) => string[]>;
export declare const calcRemainingDays: (expiryDate?: string) => number | undefined;
export declare const createIsEntitledSelector: (entitlementName: string) => import("reselect").OutputSelector<RootState, boolean, (res: string[]) => boolean>;
export declare const selectors: {
    getEntitlementNames: import("reselect").OutputSelector<RootState, string[], (res: Entitlement[]) => string[]>;
    createIsEntitledSelector: (entitlementName: string) => import("reselect").OutputSelector<RootState, boolean, (res: string[]) => boolean>;
    isEntitledToTrial: (state: RootState) => boolean;
    isEntitledToCdpTrial: (state: RootState) => boolean;
    isEntitledToCdpOneTrial: (state: RootState) => boolean;
    isEntitledToDataPractitioner: (state: RootState) => boolean;
    isEntitledToManagedNamespace: (state: RootState) => boolean;
    isEntitledToCDP: (state: RootState) => boolean;
    isEntitledToAltus: (state: RootState) => boolean;
    isEntitledToNoTunnelProvisioning: (state: RootState) => boolean;
    isEntitledToTryCDPProductTour: (state: RootState) => boolean;
    isEntitledToMLWorkspaceRoles: (state: RootState) => boolean;
    getRemainingTrialDays: import("reselect").OutputSelector<RootState, number | undefined, (res: Terms | undefined) => number | undefined>;
    getUser: (state: RootState) => User | undefined;
    isPowerUser: (state: RootState) => boolean;
    isEnvironmentCreator: (state: RootState) => boolean;
    getAssignedResourceCrns: (state: RootState) => string[];
    isUsingClouderaSSO: (state: RootState) => boolean;
    /**
     * Whether user is currently using CDP. If they are entitled to both Altus and CDP this will return
     * true only if they are on cdp.cloudera.com. Otherwise, this will return true if the user is not
     * entitled to Altus.
     */
    isUsingCDP: (state: RootState) => any;
};
export declare const staticFeatures: {
    canShowIdentityProviderUI: () => boolean;
    /**
     * To always unhide option to add/remove member from the group irrespective of the rights he has.
     * This is needed in private cloud as the UI is unable to fetch the required rights correctly.
     * The reason is the rights are checked before page is loaded, and to check for add/remove from
     * group rights, we must provide the groupCrn as resourceCrn. Passing groupCrn is diificult before
     * the page is loaded.
     */
    shouldAlwaysShowAddRemoveGroupMember: () => boolean;
    /**
     * User sync is not present in Private cloud. So after deleting a user the UserSync notification
     * should not be coming up in private cloud
     */
    canShowDeleteUserSyncNotification: () => boolean;
    /**
     * According to CDPCP-8450, setting/viewing password policies are not relevant
     * for private cloud, only public cloud
     */
    canUsePasswordPolicies: () => boolean;
    canDeleteUser: () => boolean;
};
