// Copyright (c) 2018 Cloudera, Inc. All rights reserved.
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
import { createSelector } from 'reselect';
import moment from 'moment';
import { PERSONAS } from "../sagas/accessSaga";
import { getResourceName } from "cdp-js/dist/lib/Crn";
import pages from "../../js/utils/pages";
import appConfig from "cdp-js/dist/lib/appConfig";
var TRIAL_TERMS = 'TRIAL_TERMS';
var CLOUDERA_SSO_PROVIDER_NAME = 'cloudera-sso';
export var entitlements = {
    GRIDLINK: 'GRIDLINK',
    WA_NEW_SPARK_OVERVIEW: 'WA_NEW_SPARK_OVERVIEW',
    TRIAL_ENTITLEMENT: 'TRIAL_ENTITLEMENT',
    CDP_TRIAL: 'CDP_TRIAL',
    CDPONE_TRIAL: 'CDPONE_TRIAL',
    NO_TUNNEL_PROVISIONING: 'NO_TUNNEL_PROVISIONING',
    CDP: 'CDP',
    ALTUS: 'ALTUS',
    TRY_CDP_PRODUCT_TOUR: 'TRY_CDP_PRODUCT_TOUR',
    REPRISE_PRODUCT_TOUR: 'REPRISE_PRODUCT_TOUR',
    ML_WORKSPACE_ROLES: 'ML_WORKSPACE_ROLES',
    DATA_PRACTITIONER_CDP_HOME_PAGE: 'DATA_PRACTITIONER_CDP_HOME_PAGE'
};
export var types = {
    AUTHENTICATE: 'AUTHENTICATE',
    SET_AUTH_STATE: 'SET_AUTH_STATE',
    GET_USER_SUCCESS: 'GET_USER_SUCCESS',
    AUTHENTICATE_SUCCESS: 'AUTHENTICATE_SUCCESS'
};
export var actions = {
    authenticate: function () { return ({ type: types.AUTHENTICATE }); },
    setAuthState: function (authState) { return ({ type: types.SET_AUTH_STATE, authState: authState }); },
    getUserSuccess: function (user) { return ({ type: types.GET_USER_SUCCESS, user: user }); },
    authenticateSuccess: function () { return ({ type: types.AUTHENTICATE_SUCCESS }); }
};
var initialState = {
    user: undefined,
    entitlements: [],
    terms: [],
    personas: {},
    resources: [],
    error: undefined,
    fetching: false,
    accountMessages: {}
};
var authReducer = function (state, action) {
    if (state === void 0) { state = initialState; }
    switch (action.type) {
        case types.AUTHENTICATE:
            return __assign(__assign({}, state), { fetching: true });
        case types.SET_AUTH_STATE:
            return __assign(__assign({}, state), action.authState);
        case types.GET_USER_SUCCESS:
            return __assign(__assign({}, state), { user: action.user });
        case types.AUTHENTICATE_SUCCESS:
            return state;
        default:
            return state;
    }
};
export default authReducer;
// Selectors
export var getEntitlementNames = createSelector(function (state) { return state.auth.entitlements; }, function (entitlements) { return (entitlements || []).map(function (e) { return e.entitlementName; }); });
var isEntitled = function (entitlementName, state) {
    var entitlementNames = getEntitlementNames(state);
    return entitlementNames.includes(entitlementName);
};
// Calculates remaining days between a given expiry date and now.
export var calcRemainingDays = function (expiryDate) {
    var expiryDateMoment = moment(expiryDate);
    if (!expiryDate || !expiryDateMoment.isValid()) {
        return undefined;
    }
    var days = Math.round(expiryDateMoment.diff(moment(), 'hours') / 24);
    return Math.max(days, 0);
};
// Trial remaining days selector
var getRemainingTrialDays = createSelector(function (state) { return state.auth.terms.find(function (t) { return t.termsName === TRIAL_TERMS; }); }, function (trialTerms) { return calcRemainingDays(trialTerms ? trialTerms.expiryDate : undefined); });
export var createIsEntitledSelector = function (entitlementName) {
    return createSelector(getEntitlementNames, function (entitlementNames) {
        return entitlementNames.includes(entitlementName);
    });
};
// TODO: [future] console specific selectors should not be in the common codebase (maxim)
export var selectors = {
    getEntitlementNames: getEntitlementNames,
    createIsEntitledSelector: createIsEntitledSelector,
    isEntitledToTrial: isEntitled.bind(null, entitlements.TRIAL_ENTITLEMENT),
    isEntitledToCdpTrial: function (state) {
        return !appConfig.isGovCloud() && isEntitled(entitlements.CDP_TRIAL, state);
    },
    isEntitledToCdpOneTrial: function (state) {
        return !appConfig.isGovCloud() && isEntitled(entitlements.CDPONE_TRIAL, state);
    },
    isEntitledToDataPractitioner: isEntitled.bind(null, entitlements.DATA_PRACTITIONER_CDP_HOME_PAGE),
    isEntitledToManagedNamespace: isEntitled.bind(null, entitlements.GRIDLINK),
    isEntitledToCDP: isEntitled.bind(null, entitlements.CDP),
    isEntitledToAltus: isEntitled.bind(null, entitlements.ALTUS),
    isEntitledToNoTunnelProvisioning: isEntitled.bind(null, entitlements.NO_TUNNEL_PROVISIONING),
    isEntitledToTryCDPProductTour: function (state) {
        return !appConfig.isGovCloud() && isEntitled(entitlements.TRY_CDP_PRODUCT_TOUR, state);
    },
    isEntitledToMLWorkspaceRoles: isEntitled.bind(null, entitlements.ML_WORKSPACE_ROLES),
    getRemainingTrialDays: getRemainingTrialDays,
    getUser: function (state) { return state.auth.user; },
    isPowerUser: function (state) { return !!state.auth.personas[PERSONAS.POWER_USER]; },
    isEnvironmentCreator: function (state) { return !!state.auth.personas[PERSONAS.ENVIRONMENT_CREATOR]; },
    getAssignedResourceCrns: function (state) { return state.auth.resources || []; },
    isUsingClouderaSSO: function (state) {
        var user = selectors.getUser(state);
        if (!user) {
            return false;
        }
        var identityProviderName = getResourceName(user.identityProviderCrn);
        return identityProviderName === CLOUDERA_SSO_PROVIDER_NAME;
    },
    /**
     * Whether user is currently using CDP. If they are entitled to both Altus and CDP this will return
     * true only if they are on cdp.cloudera.com. Otherwise, this will return true if the user is not
     * entitled to Altus.
     */
    isUsingCDP: function (state) {
        if (appConfig.isWxmOnPrem()) {
            return false;
        }
        var isEntitledToCDP = selectors.isEntitledToCDP(state);
        var isEntitledToAltus = selectors.isEntitledToAltus(state);
        if (isEntitledToAltus && isEntitledToCDP) {
            return pages.isCDPDomain();
        }
        return !isEntitledToAltus;
    }
};
export var staticFeatures = {
    canShowIdentityProviderUI: function () { return !appConfig.isPrivateCloud(); },
    /**
     * To always unhide option to add/remove member from the group irrespective of the rights he has.
     * This is needed in private cloud as the UI is unable to fetch the required rights correctly.
     * The reason is the rights are checked before page is loaded, and to check for add/remove from
     * group rights, we must provide the groupCrn as resourceCrn. Passing groupCrn is diificult before
     * the page is loaded.
     */
    shouldAlwaysShowAddRemoveGroupMember: function () { return appConfig.isPrivateCloud(); },
    /**
     * User sync is not present in Private cloud. So after deleting a user the UserSync notification
     * should not be coming up in private cloud
     */
    canShowDeleteUserSyncNotification: function () { return !appConfig.isPrivateCloud(); },
    /**
     * According to CDPCP-8450, setting/viewing password policies are not relevant
     * for private cloud, only public cloud
     */
    canUsePasswordPolicies: function () { return !appConfig.isPrivateCloud(); },
    canDeleteUser: function () { return !appConfig.isPrivateCloud(); }
};
