import PropTypes from 'prop-types';
import { RoleInfo, ResourceRoleInfo, ResourceAssignmentInfo, ResourceInfo, Assignee, ResourceAssigneeInfo } from "../types/types";
import { RootState } from "cuix/dist/types/react-types";
import { Role, ResourceRole, Group, ResourceAssignment, ResourceAssignee, GetAssigneeAuthorizationInformationResponse } from "cdp-js/dist/api/iam/types";
export declare const ROLES: {
    IAM_USER: string;
    IAM_VIEWER: string;
    DATAENG_USER: string;
    DATAWARE_USER: string;
    SDX_ADMIN: string;
    DBUS_UPLOADER: string;
    POWER_USER: string;
    ENVIRONMENT_CREATOR: string;
};
export declare const RESOURCE_ROLE_NAMES: {
    IAM_GROUP_ADMIN: string;
    DATAENG_ENVIRONMENT_USER: string;
    DATAENG_NAMESPACE_USER: string;
    DATAWARE_CLUSTER_USER: string;
    DATAWARE_CLUSTER_ADMIN: string;
    DATAWARE_NAMESPACE_USER: string;
    WXM_CLUSTER_USER: string;
    WXM_LIMITED_CLUSTER_USER: string;
    WXM_CLUSTER_ADMIN: string;
    WXM_WORKLOAD_USER: string;
    ENVIRONMENT_ADMIN: string;
    ENVIRONMENT_PRIVILEGED_USER: string;
    ENVIRONMENT_USER: string;
    DATA_STEWARD: string;
    DE_ADMIN: string;
    DE_USER: string;
    ML_VIEWER: string;
    ML_ADMIN: string;
    ML_USER: string;
    ML_BUSINESS_USER: string;
    ML_WORKSPACE_ADMIN: string;
    ML_WORKSPACE_USER: string;
    ML_WORKSPACE_BUSINESS_USER: string;
    DW_ADMIN: string;
    DW_USER: string;
    OD_ADMIN: string;
    OD_USER: string;
    CLASSIC_CLUSTER_ADMIN: string;
    CLASSIC_CLUSTER_USER: string;
    DATA_HUB_ADMIN: string;
    DATA_HUB_CREATOR: string;
    DATA_HUB_USER: string;
    OWNER: string;
    SHARED_RESOURCE_USER: string;
    DF_ADMIN: string;
    DF_FLOW_ADMIN: string;
    DF_FLOW_DEVELOPER: string;
    DF_FLOW_USER: string;
    DF_PROJECT_ADMIN: string;
    DF_PROJECT_CREATOR: string;
    DF_PROJECT_MEMBER: string;
    DF_FUNCTION_MACHINE_USER: string;
    CDPONE_SERVICE_ADMIN: string;
};
export declare const RESOURCE_TYPE_ROLE_MAP: {
    [key: string]: any[];
};
export declare const isCdpEnvironmentRole: (roleName: string) => boolean;
/**
 * Returns a list of role info objects in RoleInfoPropType shape. Roles that are are not defined
 * above in the ROLES object are considered hidden and filtered out.
 */
export declare const getRoles: (state: RootState) => RoleInfo[];
export declare const getResourceRoles: (state: RootState, resourceType?: string) => ResourceRoleInfo[];
export declare const getAssignedGroups: (state: RootState) => Group[];
/**
 * Returns an array of RoleInfoPropType where each entry maps to a role assigned to current user
 * either directly or via a group membership.
 */
export declare const getAssignedRoles: (state: RootState) => RoleInfo[];
/**
 * Returns an array of ResourceAssignmentInfoPropType where each entry maps to a resource role
 *  assigned to current user either directly or via a group membership.
 */
export declare const getAssignedResources: (state: RootState) => ResourceAssignmentInfo[];
/**
 * Returns an array of ResourceAssigneeInfoPropType where each entry contains an assignee and an
 * array of resources roles directly assigned to this assignee.
 */
export declare const calculateResourceAssignees: (allAssignees: Assignee[], allResourceRoles: ResourceRoleInfo[], resourceAssignees: ResourceAssignee[]) => ResourceAssigneeInfo[];
export declare const getResourceAssignees: (state: RootState, allAssignees: Assignee[]) => ResourceAssigneeInfo[];
/**
 * Decorates a role object with additional information like description, group name, etc.
 */
export declare const getRoleInfo: ({ crn, policies }: Role, groupCrn?: string) => RoleInfo;
export declare const getResourceInfo: (crn: string) => ResourceInfo;
export declare const getResourceRoleInfo: (resourceRole: ResourceRole) => ResourceRoleInfo;
export declare const getResourceAssignmentInfo: (resourceCrn: string, resourceRole?: ResourceRole, groupCrn?: string) => ResourceAssignmentInfo | undefined;
/**
 * Returns all roles assigned to a user from the response of getAssigneeAuthorizationInformation
 * API call.
 * @param {object} assigneeAuthorizationInformation
 */
export declare const getAllAssignedRoles: (assigneeAuthorizationInformation: GetAssigneeAuthorizationInformationResponse) => string[];
/**
 * Returns all resource roles assigned to a user from the response of
 * getAssigneeAuthorizationInformation API call.
 * @param {object} assigneeAuthorizationInformation
 */
export declare const getAllAssignedResourceRoles: (assigneeAuthorizationInformation: GetAssigneeAuthorizationInformationResponse) => ResourceAssignment[];
export declare const roleNames2roles: (allRoles: RoleInfo[], roleNames: string[]) => RoleInfo[];
export declare const ResourceInfoPropType: PropTypes.Requireable<PropTypes.InferProps<{
    crn: PropTypes.Validator<string>;
    name: PropTypes.Validator<string>;
    type: PropTypes.Validator<string>;
    typeDisplayName: PropTypes.Validator<string>;
}>>;
export declare const ResourceRoleInfoPropType: PropTypes.Requireable<PropTypes.InferProps<{
    crn: PropTypes.Validator<string>;
    name: PropTypes.Validator<string>;
    rights: PropTypes.Validator<any[]>;
    description: PropTypes.Validator<string>;
}>>;
export declare const ResourceAssignmentInfoPropType: PropTypes.Requireable<PropTypes.InferProps<{
    resource: PropTypes.Validator<NonNullable<PropTypes.InferProps<{
        crn: PropTypes.Validator<string>;
        name: PropTypes.Validator<string>;
        type: PropTypes.Validator<string>;
        typeDisplayName: PropTypes.Validator<string>;
    }>>>;
    resourceRole: PropTypes.Validator<NonNullable<PropTypes.InferProps<{
        crn: PropTypes.Validator<string>;
        name: PropTypes.Validator<string>;
        rights: PropTypes.Validator<any[]>;
        description: PropTypes.Validator<string>;
    }>>>;
    groupCrn: PropTypes.Requireable<string>;
    groupName: PropTypes.Requireable<string>;
}>>;
export declare const RoleInfoPropType: PropTypes.Requireable<PropTypes.InferProps<{
    crn: PropTypes.Validator<string>;
    name: PropTypes.Validator<string>;
    description: PropTypes.Validator<string>;
    policies: PropTypes.Validator<any[]>;
    groupCrn: PropTypes.Requireable<string>;
    groupName: PropTypes.Requireable<string>;
}>>;
