import React, { SVGProps } from 'react';
import { CardSize } from '../Card';
import { Color } from "cuix/dist/types/types";
import { MenuProps } from 'antd';
type ActionCardSize = Exclude<CardSize, 'xs' | 'xl' | 'xxl'>;
export interface Props {
    /**
     *  `s` = 3 columns wide;
     *  `m` = 4 columns wide;
     *  `l` = 6 columns wide
     */
    size: ActionCardSize;
    /**
     * An icon from the brand icons set.
     */
    icon: React.ComponentType<SVGProps<SVGSVGElement>>;
    /**
     * The color of the brand icon.
     */
    color: Color;
    title: string;
    body?: string;
    /**
     * For a single item, a button will be rendered. For multiple items, a menu
     * will be rendered.
     */
    actions: {
        label: string;
        onClick: () => void;
    } | MenuProps['items'];
}
/**
 * Card containing a brand icon, text, and call(s) to action. Designed for use
 * primarily on product landing pages. The internal layout is responsive to the
 * grid width.
 */
declare const ActionCard: React.FC<Props>;
export default ActionCard;
