var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (Object.prototype.hasOwnProperty.call(b, p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        if (typeof b !== "function" && b !== null)
            throw new TypeError("Class extends value " + String(b) + " is not a constructor or null");
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __read = (this && this.__read) || function (o, n) {
    var m = typeof Symbol === "function" && o[Symbol.iterator];
    if (!m) return o;
    var i = m.call(o), r, ar = [], e;
    try {
        while ((n === void 0 || n-- > 0) && !(r = i.next()).done) ar.push(r.value);
    }
    catch (error) { e = { error: error }; }
    finally {
        try {
            if (r && !r.done && (m = i["return"])) m.call(i);
        }
        finally { if (e) throw e.error; }
    }
    return ar;
};
var __spreadArray = (this && this.__spreadArray) || function (to, from, pack) {
    if (pack || arguments.length === 2) for (var i = 0, l = from.length, ar; i < l; i++) {
        if (ar || !(i in from)) {
            if (!ar) ar = Array.prototype.slice.call(from, 0, i);
            ar[i] = from[i];
        }
    }
    return to.concat(ar || Array.prototype.slice.call(from));
};
// Copyright (c) 2018 Cloudera, Inc. All rights reserved.
import React from 'react';
import IconButton from '../LegacyIconButton';
import { getValueFromEvent } from '../../utils/formUtilsModern';
import "./ArrayInput.css";
import MinusIcon from '@cloudera/cuix-core/icons/react/MinusIcon';
import PlusIcon from '@cloudera/cuix-core/icons/react/PlusIcon';
/**
 * Returns undefined if the value array is empty or only has one undefined element. This allows us
 * to reset the field when user types something into the first input in the ArrayInput and deletes
 * what they type. (without user having to click the minus button)
 */
var cleanValue = function (value) {
    if (value.length === 0 || (value.length === 1 && value[0] === undefined)) {
        return undefined;
    }
    return value;
};
/**
 * This component is used for entering an array of items. Each item is represented by the input field
 * provided as the children to this component.
 */
var ArrayInput = /** @class */ (function (_super) {
    __extends(ArrayInput, _super);
    function ArrayInput() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.onChange = function (items) {
            var onChange = _this.props.onChange;
            if (typeof onChange === 'function') {
                onChange(items);
            }
        };
        _this.onBlur = function (items) {
            var onBlur = _this.props.onBlur;
            if (typeof onBlur === 'function') {
                onBlur(items);
            }
        };
        // Add a new element to items at given index
        _this.add = function (index) {
            var items = _this.getItems();
            var newItems = __spreadArray(__spreadArray(__spreadArray([], __read(items.slice(0, index)), false), [undefined], false), __read(items.slice(index)), false);
            _this.onChange(newItems);
        };
        // Remove item at given index
        _this.remove = function (index) {
            var items = _this.getItems();
            var newItems = cleanValue(__spreadArray(__spreadArray([], __read(items.slice(0, index)), false), __read(items.slice(index + 1)), false));
            _this.onChange(newItems);
            _this.onBlur(newItems);
        };
        // Update the value of item at given index
        _this.update = function (e, index) {
            var items = _this.getItems();
            var newItem = getValueFromEvent(e);
            var newItems = cleanValue(__spreadArray(__spreadArray(__spreadArray([], __read(items.slice(0, index)), false), [newItem], false), __read(items.slice(index + 1)), false));
            _this.onChange(newItems);
        };
        // Returns the input array or an array wit h one placeholder value so that users can start entering
        // data.
        _this.getItems = function () {
            return _this.props.value && _this.props.value.length ? _this.props.value : [undefined];
        };
        // Renders the input for the item at given index. We pass onChange and value props to the input
        // field in order to get notified of user actions.
        _this.renderItem = function (item, index) {
            var _a;
            var children = _this.props.children;
            var input = React.cloneElement(children, {
                onChange: function (e) { return _this.update(e, index); },
                onBlur: function () { return _this.onBlur(_this.props.value); },
                value: item,
                values: _this.props.value
            });
            var _b = _this.props, value = _b.value, maxItemCount = _b.maxItemCount;
            var hiddenStyle = { visibility: 'hidden' };
            var removeStyle = value === undefined ? hiddenStyle : {};
            var addStyle = maxItemCount && Number.isFinite(maxItemCount) && _this.getItems().length >= maxItemCount
                ? hiddenStyle
                : undefined;
            return (React.createElement("div", { className: "array-form-item", key: index, style: { lineHeight: (_a = _this.props.lineHeight) !== null && _a !== void 0 ? _a : '39px' } },
                input,
                React.createElement(IconButton, { icon: React.createElement(MinusIcon, { style: { fontSize: 20 } }), "data-event": "label.remove", onClick: function () { return _this.remove(index); }, style: removeStyle, disabled: _this.props.minusIconIsDisabled }),
                React.createElement(IconButton, { icon: React.createElement(PlusIcon, { style: { fontSize: 20 } }), "data-event": "label.add", onClick: function () { return _this.add(index + 1); }, style: addStyle, disabled: _this.props.plusIconIsDisabled })));
        };
        return _this;
    }
    ArrayInput.prototype.render = function () {
        return (React.createElement("div", { className: "array-form-input", id: this.props.id }, this.getItems().map(this.renderItem)));
    };
    return ArrayInput;
}(React.Component));
export default ArrayInput;
