var __makeTemplateObject = (this && this.__makeTemplateObject) || function (cooked, raw) {
    if (Object.defineProperty) { Object.defineProperty(cooked, "raw", { value: raw }); } else { cooked.raw = raw; }
    return cooked;
};
// Copyright (c) 2023 Cloudera, Inc. All rights reserved.
import React from 'react';
import styled from 'styled-components';
import Link from '../Link';
import Tooltip from '../Tooltip';
var TRUNCATION_MARKER = '…'; // This is an ellipsis character.
var truncateMiddle = function (label, numCharsToRemove) {
    if (label.length % 2) {
        numCharsToRemove--;
        var halfLength_1 = (label.length - 1) / 2;
        var firstHalf_1 = label.slice(0, halfLength_1);
        var secondHalf_1 = label.slice(-halfLength_1);
        var fromFirstHalf_1 = Math.ceil((numCharsToRemove + (numCharsToRemove % 2)) / 2);
        var fromSecondHalf_1 = Math.ceil((numCharsToRemove - (numCharsToRemove % 2)) / 2);
        return "".concat(firstHalf_1.slice(0, -fromFirstHalf_1)).concat(TRUNCATION_MARKER).concat(secondHalf_1.slice(fromSecondHalf_1));
    }
    var halfLength = label.length / 2;
    var firstHalf = label.slice(0, halfLength);
    var secondHalf = label.slice(-halfLength);
    var fromFirstHalf = (numCharsToRemove + (numCharsToRemove % 2)) / 2;
    var fromSecondHalf = (numCharsToRemove - (numCharsToRemove % 2)) / 2;
    return "".concat(firstHalf.slice(0, -fromFirstHalf)).concat(TRUNCATION_MARKER).concat(secondHalf.slice(fromSecondHalf));
};
var truncate = function (label, numCharsToRemove, truncateFrom, minChars) {
    if (truncateFrom === void 0) { truncateFrom = 'middle'; }
    if (minChars === void 0) { minChars = 6; }
    if (label.length <= minChars || numCharsToRemove <= TRUNCATION_MARKER.length) {
        return label;
    }
    if (label.length - numCharsToRemove < minChars) {
        numCharsToRemove = label.length - minChars;
    }
    switch (truncateFrom) {
        case 'start':
            return "".concat(TRUNCATION_MARKER).concat(label.slice(numCharsToRemove));
        case 'middle':
            return truncateMiddle(label, numCharsToRemove);
        case 'end':
            return "".concat(label.slice(0, -numCharsToRemove)).concat(TRUNCATION_MARKER);
    }
};
var BreadcrumbListItem = styled('li')(templateObject_1 || (templateObject_1 = __makeTemplateObject(["\n  list-style: none;\n  line-height: 1;\n"], ["\n  list-style: none;\n  line-height: 1;\n"])));
var BreadcrumbLink = styled(Link)(templateObject_2 || (templateObject_2 = __makeTemplateObject(["\n  margin: 0;\n  padding: 0;\n  line-height: 1;\n  white-space: nowrap;\n"], ["\n  margin: 0;\n  padding: 0;\n  line-height: 1;\n  white-space: nowrap;\n"])));
/**
 * Renders a single breadcrumb. Supports truncation.
 */
var Breadcrumb = function (_a) {
    var href = _a.href, label = _a.label, icon = _a.icon, shouldTruncate = _a.shouldTruncate, truncateFrom = _a.truncateFrom, truncateChars = _a.truncateChars;
    if (icon) {
        return (React.createElement(BreadcrumbListItem, null,
            React.createElement(Tooltip, { title: label, placement: "bottom" },
                React.createElement(BreadcrumbLink, { href: href, "aria-label": label }, icon))));
    }
    return (React.createElement(BreadcrumbListItem, null,
        React.createElement(Tooltip, { title: shouldTruncate ? label : undefined, placement: "bottom" },
            React.createElement(BreadcrumbLink, { href: href, "aria-label": label }, shouldTruncate ? truncate(label, truncateChars || 0, truncateFrom) : label))));
};
export default Breadcrumb;
var templateObject_1, templateObject_2;
