// Copyright (c) 2023 Cloudera, Inc. All rights reserved.
import React, { Fragment } from 'react';
import { Text } from '../Typography';
import BreadcrumbsDropdown from './BreadcrumbsDropdown';
import Breadcrumb from './Breadcrumb';
import { cdlIconSizeDefault, cdlSpacingTiny } from '@cloudera/cuix-core/variables';
import { color } from './theme';
import { useTheme } from "cuix/dist/styles/theme";
var Divider = function () {
    var theme = useTheme();
    return (React.createElement("svg", { style: { flex: 'none' }, xmlns: "http://www.w3.org/2000/svg", version: "1.1", preserveAspectRatio: "none", viewBox: "0 0 8 14", width: "8", height: "14", "aria-hidden": "true" },
        React.createElement("line", { x1: "0", x2: "8", y1: "14", y2: "0", stroke: color({ theme: theme }), strokeWidth: "1" })));
};
/**
 * Renders a list of breadcrumbs. If the list exceeds 50% of its container's
 * width, the breadcrumbs will be truncated. If truncation cannot make the
 * breadcrumbs fit in the allowed space, they are collapsed into a dropdown.
 */
var BreadcrumbList = function (_a) {
    var Icon = _a.homeIcon, breadcrumbs = _a.breadcrumbs, shouldTruncate = _a.shouldTruncate, truncateChars = _a.truncateChars, showDropdown = _a.showDropdown;
    var home = breadcrumbs[0];
    var firstBreadcrumb;
    if (breadcrumbs.length > 2) {
        firstBreadcrumb = breadcrumbs[1];
    }
    var middleBreadcrumbs;
    if (breadcrumbs.length > 3) {
        middleBreadcrumbs = breadcrumbs.slice(2, -1);
    }
    var pageTitle = breadcrumbs[breadcrumbs.length - 1];
    return (React.createElement("ol", { style: {
            display: 'inline-flex',
            verticalAlign: 'middle',
            alignItems: 'center',
            gap: cdlSpacingTiny,
            whiteSpace: 'nowrap',
            margin: 0,
            padding: 0
        } },
        React.createElement(Breadcrumb, { href: home.href, label: home.label, icon: React.createElement(Icon, { style: { height: cdlIconSizeDefault, width: cdlIconSizeDefault }, "aria-hidden": "true" }) }),
        firstBreadcrumb && (React.createElement(React.Fragment, null,
            React.createElement(Divider, null),
            React.createElement(Breadcrumb, { href: firstBreadcrumb.href, label: firstBreadcrumb.label, truncateFrom: firstBreadcrumb.truncateFrom, truncateChars: truncateChars, shouldTruncate: shouldTruncate && !showDropdown }))),
        middleBreadcrumbs &&
            (showDropdown ? (React.createElement(React.Fragment, null,
                React.createElement(Divider, null),
                React.createElement(BreadcrumbsDropdown, { breadcrumbs: middleBreadcrumbs }))) : (middleBreadcrumbs.map(function (_a, index) {
                var label = _a.label, href = _a.href, truncateFrom = _a.truncateFrom;
                return (React.createElement(Fragment, { key: index },
                    React.createElement(Divider, null),
                    React.createElement(Breadcrumb, { href: href, label: label, truncateFrom: truncateFrom, truncateChars: truncateChars, shouldTruncate: shouldTruncate })));
            }))),
        React.createElement(Divider, null),
        React.createElement(Text, null, pageTitle.label)));
};
export default BreadcrumbList;
