import React, { SVGProps } from 'react';
import { BreadcrumbProps } from './Breadcrumb';
export interface BreadcrumbsProps {
    /**
     * Icon displayed for the first breadcrumb.
     *
     * @default DashboardIcon
     */
    homeIcon?: React.ComponentType<SVGProps<SVGSVGElement>>;
    breadcrumbs: BreadcrumbProps[];
    /**
     * If true, the alternative "Back To Previous" link will be rendered using
     * the href of the first item in `breadcrumbs`.
     *
     * @default false
     */
    showPrevious?: boolean;
}
/**
 * Renders a list of breadcrumbs. If the list exceeds 50% of its container's
 * width, the breadcrumbs will be truncated. If truncation cannot make the
 * breadcrumbs fit in the allowed space, they are collapsed into a dropdown.
 *
 * Breadcrumbs are truncated from the middle by default. This is the preferred
 * method and should be used unless there is a specific reason to change it. If
 * necessary, individual breadcrumbs can specify how they should be truncated.
 *
 * Alternatively, this component can render the "Back to Previous" link.
 */
declare const Breadcrumbs: React.FC<BreadcrumbsProps>;
export default Breadcrumbs;
