var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __read = (this && this.__read) || function (o, n) {
    var m = typeof Symbol === "function" && o[Symbol.iterator];
    if (!m) return o;
    var i = m.call(o), r, ar = [], e;
    try {
        while ((n === void 0 || n-- > 0) && !(r = i.next()).done) ar.push(r.value);
    }
    catch (error) { e = { error: error }; }
    finally {
        try {
            if (r && !r.done && (m = i["return"])) m.call(i);
        }
        finally { if (e) throw e.error; }
    }
    return ar;
};
var __spreadArray = (this && this.__spreadArray) || function (to, from, pack) {
    if (pack || arguments.length === 2) for (var i = 0, l = from.length, ar; i < l; i++) {
        if (ar || !(i in from)) {
            if (!ar) ar = Array.prototype.slice.call(from, 0, i);
            ar[i] = from[i];
        }
    }
    return to.concat(ar || Array.prototype.slice.call(from));
};
// Copyright (c) 2023 Cloudera, Inc. All rights reserved.
import React, { useState, useLayoutEffect } from 'react';
import PreviousBreadcrumb from './PreviousBreadcrumb';
import BreadcrumbList from './BreadcrumbList';
import { useMeasure } from '@react-hookz/web/esm/useMeasure';
import DashboardIcon from '@cloudera/cuix-core/icons/react/DashboardIcon';
var initialState = {
    prevContainerWidth: 0,
    prevBreadcrumbsWidth: 0,
    shouldTruncate: false,
    truncateChars: 1,
    showDropdown: false
};
var getBreadcrumbsWidth = function (div) {
    var children = __spreadArray([], __read(div.children), false);
    return children.reduce(function (width, child) { return width + child.getBoundingClientRect().width; }, 0);
};
/**
 * Renders a list of breadcrumbs. If the list exceeds 50% of its container's
 * width, the breadcrumbs will be truncated. If truncation cannot make the
 * breadcrumbs fit in the allowed space, they are collapsed into a dropdown.
 *
 * Breadcrumbs are truncated from the middle by default. This is the preferred
 * method and should be used unless there is a specific reason to change it. If
 * necessary, individual breadcrumbs can specify how they should be truncated.
 *
 * Alternatively, this component can render the "Back to Previous" link.
 */
var Breadcrumbs = function (_a) {
    var _b = _a.homeIcon, homeIcon = _b === void 0 ? DashboardIcon : _b, breadcrumbs = _a.breadcrumbs, showPrevious = _a.showPrevious;
    var _c = __read(useState(initialState), 2), state = _c[0], setState = _c[1];
    var _d = __read(useMeasure(), 2), rect = _d[0], ref = _d[1];
    useLayoutEffect(function () {
        if (!(ref === null || ref === void 0 ? void 0 : ref.current)) {
            return;
        }
        var breadcrumbsWidth = getBreadcrumbsWidth(ref.current);
        if (state.prevContainerWidth && ref.current.offsetWidth !== state.prevContainerWidth) {
            setState(initialState);
        }
        else if (breadcrumbsWidth > ref.current.offsetWidth * 0.5 &&
            breadcrumbsWidth !== state.prevBreadcrumbsWidth) {
            setState(__assign(__assign({}, state), { prevContainerWidth: ref.current.offsetWidth || 0, prevBreadcrumbsWidth: breadcrumbsWidth, shouldTruncate: true, truncateChars: state.truncateChars + 1 }));
        }
        else if (!state.showDropdown && breadcrumbsWidth > ref.current.offsetWidth * 0.5) {
            setState(__assign(__assign({}, state), { showDropdown: true }));
        }
    }, [ref, rect, state]);
    if (showPrevious) {
        return React.createElement(PreviousBreadcrumb, { href: breadcrumbs[0].href, label: breadcrumbs[0].label });
    }
    return (React.createElement("div", { ref: ref, style: { visibility: ref.current ? 'visible' : 'hidden' } },
        React.createElement(BreadcrumbList, { homeIcon: homeIcon, breadcrumbs: breadcrumbs, shouldTruncate: state.shouldTruncate, truncateChars: state.truncateChars, showDropdown: state.showDropdown })));
};
export default Breadcrumbs;
