import { ButtonProps } from 'antd';
import React from 'react';
export interface DataEventProps {
    /**
     * Google analytics category name. If not provided, it defaults to 'User
     * Action'.
     */
    'data-event-category'?: string;
    /**
     * Google analytics event name. This should be something at least as
     * descriptive as the button text and/or aria-label, if not moreso. For
     * example, the button text might be just "Add", which is sufficient in
     * context for a user, but will not be informative when it shows up in the
     * analytics report. That said, keep the `data-event` string short.
     */
    'data-event': string;
    /**
     * Google analytics event label. You can use this to add an additional level
     * of detail to the event.
     */
    'data-event-label'?: string;
    /**
     * Google analytics event value.
     * A non-negative integer that will appear as the event value.
     * Example: price, await duration, stars rating or any useful measurement for analytics.
     */
    'data-event-value'?: number;
}
interface Props extends ButtonProps, DataEventProps {
    iconPosition?: 'left' | 'right';
    /** Make sure to use this if your button does not have any text. */
    'aria-label'?: string;
}
/**
 * A component that provides common functionality which is the basis for the
 * other button components. Should not be used directly.
 */
declare const ButtonBase: React.FC<Props>;
export interface CommonButtonProps extends Omit<Props, 'type' | 'danger'> {
}
export default ButtonBase;
