import React, { PureComponent } from 'react';
interface CompareItem {
    title: React.ReactNode;
}
export interface HeaderRow {
    title: React.ReactNode;
    kind: 'header';
}
export declare enum Importance {
    WARN = "warn"
}
export interface ValueRow {
    values: any[];
    title: string;
    onTitleClick?: (row: ValueRow) => void;
    unit?: string;
    indentationLevel?: number;
    importance?: Importance.WARN;
    kind: 'value';
}
interface InternalValueRow extends ValueRow {
    diff?: number;
    diffFraction?: number;
}
export declare type Row = HeaderRow | ValueRow;
declare type InternalRow = HeaderRow | InternalValueRow;
export declare type ValueFormatter = (val: number, row: ValueRow) => string;
declare type Domain = [number, number];
interface Props {
    items: CompareItem[];
    rows: Row[];
    metricsColTitle?: React.ReactNode;
    metricValueFormatter?: ValueFormatter;
    diffValueFormatter?: ValueFormatter;
}
/**
 * Table comparison for numerical metrics
 */
export default class CompareMetricsTable extends PureComponent<Props> {
    getMinMaxDiffFractionDomain(rows: InternalRow[]): Domain;
    getTransformedRows(rows: Row[]): InternalRow[];
    getTitleColumn(): {
        title: React.ReactNode;
        dataIndex: string;
        className: any;
        render: (_: any, row: InternalRow) => JSX.Element;
    };
    getCompareColumns(): {
        title: React.ReactNode;
        className: any;
        dataIndex: string;
        align: string;
        render: (_: any, row: InternalRow) => any;
    }[];
    getDiffColumns(diffFractionDomain: Domain): {
        title: boolean;
        key: string;
        align: string;
        render: (row: InternalRow) => JSX.Element | null;
    }[];
    render(): string | JSX.Element;
}
export {};
