var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (Object.prototype.hasOwnProperty.call(b, p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        if (typeof b !== "function" && b !== null)
            throw new TypeError("Class extends value " + String(b) + " is not a constructor or null");
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __read = (this && this.__read) || function (o, n) {
    var m = typeof Symbol === "function" && o[Symbol.iterator];
    if (!m) return o;
    var i = m.call(o), r, ar = [], e;
    try {
        while ((n === void 0 || n-- > 0) && !(r = i.next()).done) ar.push(r.value);
    }
    catch (error) { e = { error: error }; }
    finally {
        try {
            if (r && !r.done && (m = i["return"])) m.call(i);
        }
        finally { if (e) throw e.error; }
    }
    return ar;
};
var __spreadArray = (this && this.__spreadArray) || function (to, from, pack) {
    if (pack || arguments.length === 2) for (var i = 0, l = from.length, ar; i < l; i++) {
        if (ar || !(i in from)) {
            if (!ar) ar = Array.prototype.slice.call(from, 0, i);
            ar[i] = from[i];
        }
    }
    return to.concat(ar || Array.prototype.slice.call(from));
};
// Copyright (c) 2019 Cloudera, Inc. All rights reserved.
import React, { PureComponent } from 'react';
import i18n from '../../utils/i18n';
import * as Typography from "cuix/dist/components/Typography";
import Table from '../Table';
import LinkButton from '../LegacyLinkButton';
import CompareMetricsTableDiffBar from './CompareMetricsTableDiffBar';
import { fluidxBlue500, fluidxOrange500 } from '../../styles/variables';
import style from "./CompareMetricsTable.local.css";
export var Importance;
(function (Importance) {
    Importance["WARN"] = "warn";
})(Importance || (Importance = {}));
function isHeaderRow(row) {
    return row.kind === 'header';
}
/**
 * Table comparison for numerical metrics
 */
var CompareMetricsTable = /** @class */ (function (_super) {
    __extends(CompareMetricsTable, _super);
    function CompareMetricsTable() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    // TODO: [future] consider using react/util/array#aggregate (arne)
    CompareMetricsTable.prototype.getMinMaxDiffFractionDomain = function (rows) {
        // to display bar charts across rows, we need to determine the biggest postive and negative
        // diff as a fraction so we can scale the bars correctly across rows.
        var maxDiffFraction = 0;
        var minDiffFraction = 0;
        rows.forEach(function (row) {
            if (isHeaderRow(row)) {
                return;
            }
            var diffFraction = row.diffFraction;
            if (!diffFraction || !Number.isFinite(diffFraction)) {
                // we exclude infinte numbers, as they are handled with a non-bar vizualization.
                return;
            }
            maxDiffFraction = Math.max(diffFraction, maxDiffFraction);
            minDiffFraction = Math.min(diffFraction, minDiffFraction);
        });
        return [minDiffFraction, maxDiffFraction];
    };
    CompareMetricsTable.prototype.getTransformedRows = function (rows) {
        return rows.map(function (row) {
            if (isHeaderRow(row)) {
                return row;
            }
            var newRow = __assign({}, row);
            var _a = __read(row.values, 2), firstValue = _a[0], secondValue = _a[1];
            if (Number.isFinite(firstValue) && Number.isFinite(secondValue)) {
                newRow.diff = secondValue - firstValue;
                if (firstValue) {
                    newRow.diffFraction = newRow.diff / firstValue;
                }
                else if (secondValue > 0) {
                    newRow.diffFraction = Infinity;
                }
                else if (secondValue < 0) {
                    newRow.diffFraction = -Infinity;
                }
                else {
                    newRow.diffFraction = 0;
                }
            }
            return newRow;
        });
    };
    CompareMetricsTable.prototype.getTitleColumn = function () {
        var metricsColTitle = this.props.metricsColTitle;
        var titleColumn = {
            title: metricsColTitle,
            dataIndex: 'title',
            className: style.titleCol,
            render: function (_, row) {
                if (isHeaderRow(row)) {
                    return React.createElement("span", { className: style.headerRowTitle }, row.title);
                }
                var content;
                if (row.onTitleClick) {
                    var clickHandler_1 = row.onTitleClick;
                    content = (React.createElement(LinkButton, { style: { fontSize: 13 }, "data-event": "Metrics click", "aria-label": row.title, onClick: function () { return clickHandler_1(row); } }, row.title));
                }
                else {
                    content = React.createElement("span", null, row.title);
                }
                var indent = row.indentationLevel || 0;
                return (React.createElement("span", null,
                    React.createElement("span", { style: { display: 'inline-block', width: indent * 16 } }),
                    " ",
                    content,
                    ' '));
            }
        };
        return titleColumn;
    };
    CompareMetricsTable.prototype.getCompareColumns = function () {
        var _a = this.props, items = _a.items, metricValueFormatter = _a.metricValueFormatter;
        var compareColumns = items.map(function (compareItem, index) {
            return {
                title: compareItem.title,
                className: style.compareCol,
                dataIndex: "job".concat(index),
                align: 'right',
                render: function (_, row) {
                    if (isHeaderRow(row)) {
                        return null;
                    }
                    else if (!Number.isFinite(row.values[index])) {
                        return (React.createElement(Typography.Text, { type: "secondary" },
                            ' ',
                            i18n.t('label.compareMetricsTable.notAvailable'),
                            ' '));
                    }
                    return metricValueFormatter
                        ? metricValueFormatter(row.values[index], row)
                        : row.values[index];
                }
            };
        });
        return compareColumns;
    };
    CompareMetricsTable.prototype.getDiffColumns = function (diffFractionDomain) {
        var diffValueFormatter = this.props.diffValueFormatter;
        var shouldShowComparisonCell = function (row) {
            return !isHeaderRow(row) && Number.isFinite(row.diff);
        };
        var absoluteDiffColumn = {
            title: false,
            key: "job-diff-absolute",
            align: 'left',
            render: function (row) {
                if (!shouldShowComparisonCell(row)) {
                    return null;
                }
                row = row;
                var className;
                if (row.importance === Importance.WARN) {
                    className = style.warningColor;
                }
                var formattedValue = diffValueFormatter ? diffValueFormatter(row.diff, row) : row.diff;
                return React.createElement("span", { className: className },
                    " ",
                    formattedValue);
            }
        };
        var barCompareColumn = {
            title: false,
            key: "job-diff-bar",
            align: 'left',
            render: function (row) {
                if (!shouldShowComparisonCell(row)) {
                    return null;
                }
                row = row;
                var color = fluidxBlue500;
                var labelClassName;
                if (row.importance === Importance.WARN) {
                    color = fluidxOrange500;
                    labelClassName = style.warningColor;
                }
                return (React.createElement(CompareMetricsTableDiffBar, { width: 250, domain: diffFractionDomain, value: row.diffFraction, color: color, labelClassName: labelClassName }));
            }
        };
        return [absoluteDiffColumn, barCompareColumn];
    };
    CompareMetricsTable.prototype.render = function () {
        var items = this.props.items;
        if (!items || !items.length) {
            return i18n.t('label.compareMetricsTable.notAvailable');
        }
        var rows = this.getTransformedRows(this.props.rows);
        var diffFractionDomain = this.getMinMaxDiffFractionDomain(rows);
        var columns = __spreadArray([this.getTitleColumn()], __read(this.getCompareColumns()), false);
        if (items.length > 1) {
            columns.push.apply(columns, __spreadArray([], __read(this.getDiffColumns(diffFractionDomain)), false));
        }
        var onRowClassName = function (row) {
            if (row.importance === Importance.WARN) {
                return style.warningRow;
            }
        };
        return (React.createElement(Table, { rowKey: "title", columns: columns, dataSource: rows, pagination: false, rowClassName: onRowClassName, "data-test": "CompareMetricsTable" }));
    };
    return CompareMetricsTable;
}(PureComponent));
export default CompareMetricsTable;
