// Copyright (c) 2018 Cloudera, Inc. All rights reserved.
import React, { Fragment } from 'react';
import classNames from 'classnames';
import humanize from '../../utils/humanize';
import style from "./CompareMetricsTableDiffBar.local.css";
var formatFractionAsPercent = function (value) {
    value = Math.round(value * 100);
    if (Math.abs(value) < 1) {
        return '';
    }
    return humanize.humanizeCount(value) + '%';
};
/**
 * displays a bar that can show a negative or positive fraction/percentage
 * horizontally. It will either show a negative value with a bar facing left or a postive
 * value with a bar facing right. If the value is infinite, we'll display infinity icon
 */
var CompareMetricsTableDiffBar = function (_a) {
    var width = _a.width, domain = _a.domain, value = _a.value, color = _a.color, labelClassName = _a.labelClassName;
    var halfWidth = width / 2;
    // from experimentation we need about 55px for worst case label e.g. "22.3K %"
    var textWidth = 55;
    var barWidth = halfWidth - textWidth;
    // since the bars are dynamically sized based on domain if we only have small changes they will fill create
    // big bars. In order to reduce the impact of this we can force the bar at a minimum represent 20% change
    // when at full width. That way if all your changes are 1%, the bar will be 1/20 of max width.
    var adjustedDomain = [Math.min(domain[0], -0.2), Math.max(domain[1], 0.2)];
    var negBarWidth = 0;
    var posBarWidth = 0;
    var negLabel;
    var posLabel;
    var formattedValue = formatFractionAsPercent(value);
    // if value === 0, we leave everything empty
    if (value < 0) {
        negBarWidth = Math.max(1, (barWidth * value) / adjustedDomain[0]);
        negLabel = formattedValue;
    }
    else if (value > 0) {
        posBarWidth = Math.max(1, (barWidth * value) / adjustedDomain[1]);
        posLabel = formattedValue;
    }
    // TODO: [future] feedback from maxim: might be better to to avoid doing in-place calc in the jsx such as Math.round and move it all up (arne)
    var content;
    if (Math.abs(value) === Infinity) {
        content = (React.createElement("span", { style: { color: color }, className: style.infinity },
            value < 0 && '-',
            "\u221E"));
    }
    else {
        content = (React.createElement(Fragment, null,
            React.createElement("div", { style: { width: Math.round(halfWidth) }, className: style.leftContainer },
                React.createElement("div", { style: { width: textWidth }, className: classNames(style.leftLabel, labelClassName) }, negLabel),
                React.createElement("div", { style: { width: Math.round(negBarWidth), backgroundColor: color }, className: style.bar })),
            React.createElement("div", { style: { width: Math.round(halfWidth) }, className: style.rightContainer },
                React.createElement("div", { style: { width: Math.round(posBarWidth), backgroundColor: color }, className: style.bar }),
                React.createElement("div", { style: { width: textWidth }, className: classNames(style.rightLabel, labelClassName) }, posLabel))));
    }
    return (React.createElement("div", { style: { width: width }, className: style.container }, content));
};
export default CompareMetricsTableDiffBar;
