import React from 'react';
interface Props {
    onClick: () => Promise<void>;
    /**
     * Event handler that will be run if the copy succeeds.
     */
    onSuccess?: () => void;
    /**
     * Event handler that will be run if the copy fails.
     */
    onFailure?: () => void;
    /**
     * If not provided, an icon-only button will be rendered.
     */
    label?: string;
}
interface CopyTextButtonProps extends Omit<Props, 'onClick'> {
    /**
     * Text that will be written to the clipboard when the button is clicked.
     */
    text: string;
}
/**
 * A button that copies text to the clipboard when clicked.
 */
export declare const CopyTextButton: React.FC<CopyTextButtonProps>;
interface CopyBinaryButtonProps extends Omit<Props, 'onClick'> {
    /**
     * Data that will be written to the clipboard when the button is clicked.
     */
    clipboardItems: ClipboardItem[];
}
/**
 * A button that copies binary data to the clipboard when clicked.
 */
export declare const CopyBinaryButton: React.FC<CopyBinaryButtonProps>;
export {};
