var __read = (this && this.__read) || function (o, n) {
    var m = typeof Symbol === "function" && o[Symbol.iterator];
    if (!m) return o;
    var i = m.call(o), r, ar = [], e;
    try {
        while ((n === void 0 || n-- > 0) && !(r = i.next()).done) ar.push(r.value);
    }
    catch (error) { e = { error: error }; }
    finally {
        try {
            if (r && !r.done && (m = i["return"])) m.call(i);
        }
        finally { if (e) throw e.error; }
    }
    return ar;
};
// Copyright (c) 2022 Cloudera, Inc. All rights reserved.
import React, { useEffect, useState } from 'react';
import { IconButton, PrimaryButton } from "cuix/dist/components/Button";
import i18n from "cuix/dist/utils/i18n";
import CopyClipboardIcon from '@cloudera/cuix-core/icons/react/CopyClipboardIcon';
import CheckmarkIcon from '@cloudera/cuix-core/icons/react/CheckmarkIcon';
import { successColor } from "cuix/dist/styles/variables";
/**
 * Base component for CopyTextButton and CopyBinaryButton. Do not use directly.
 */
var CopyButton = function (_a) {
    var onClick = _a.onClick, onSuccess = _a.onSuccess, onFailure = _a.onFailure, label = _a.label;
    var _b = __read(useState(false), 2), success = _b[0], setSuccess = _b[1];
    useEffect(function () {
        var timeout;
        if (success === true) {
            timeout = setTimeout(function () { return setSuccess(false); }, 1000);
        }
        return function () { return clearTimeout(timeout); };
    }, [success]);
    var defaultOnSuccess = function () { return setSuccess(true); };
    var handleClick = function () {
        return onClick()
            .then(function () {
            if (onSuccess) {
                onSuccess();
            }
            else {
                defaultOnSuccess();
            }
        })
            .catch(function () { return onFailure === null || onFailure === void 0 ? void 0 : onFailure(); });
    };
    if (label) {
        return (React.createElement(PrimaryButton, { icon: success ? (React.createElement("div", { style: { color: successColor } },
                React.createElement(CheckmarkIcon, null))) : (React.createElement(CopyClipboardIcon, null)), "data-event": "Copy to Clipboard", onClick: handleClick, onAnimationEnd: function () { return setSuccess(false); } }, label));
    }
    return (React.createElement(IconButton, { icon: success ? (React.createElement("div", { style: { color: successColor } },
            React.createElement(CheckmarkIcon, null))) : (React.createElement(CopyClipboardIcon, null)), "aria-label": i18n.t('label.copy'), "data-event": "Copy to Clipboard", onClick: handleClick }));
};
/**
 * A button that copies text to the clipboard when clicked.
 */
export var CopyTextButton = function (_a) {
    var text = _a.text, onSuccess = _a.onSuccess, onFailure = _a.onFailure, label = _a.label;
    return (React.createElement(CopyButton, { onClick: function () { return navigator.clipboard.writeText(text); }, onSuccess: onSuccess, onFailure: onFailure, label: label }));
};
/**
 * A button that copies binary data to the clipboard when clicked.
 */
export var CopyBinaryButton = function (_a) {
    var clipboardItems = _a.clipboardItems, onSuccess = _a.onSuccess, onFailure = _a.onFailure, label = _a.label;
    return (React.createElement(CopyButton, { onClick: function () { return navigator.clipboard.write(clipboardItems); }, onSuccess: onSuccess, onFailure: onFailure, label: label }));
};
