var _a;
// Copyright (c) 2022 Cloudera, Inc. All rights reserved.
import React, { useContext } from 'react';
import { DocsContext } from '@storybook/addon-docs';
import { fluidxAmber100, fluidxGray200, fluidxGreen100, fluidxRed200 } from '@cloudera/cuix-core/variables';
import Markdown from 'markdown-to-jsx'; //bundled with storybook
import { DesignCompliance, Acceptance } from './types';
var complianceColor = (_a = {},
    _a[DesignCompliance.FULL] = fluidxGreen100,
    _a[DesignCompliance.PARTIAL] = fluidxAmber100,
    _a[DesignCompliance.UNKNOWN] = fluidxGray200,
    _a[DesignCompliance.NONE] = fluidxRed200,
    _a[DesignCompliance.NO_SPEC] = fluidxGray200,
    _a);
var useCuixParam = function () {
    var _a;
    return (_a = useContext(DocsContext).parameters) === null || _a === void 0 ? void 0 : _a.cuix;
};
export var CuixDescriptionInner = function (_a) {
    var spec = _a.spec;
    if (!spec) {
        return (React.createElement("div", { style: { background: complianceColor[DesignCompliance.UNKNOWN], padding: 4 } },
            "Design Compliance: ",
            React.createElement("strong", null, DesignCompliance.UNKNOWN),
            React.createElement("br", null),
            "No cuix spec/design info added for this component."));
    }
    if (spec.acceptance === Acceptance.NOT_APPLICABLE) {
        return null;
    }
    var acceptance = spec.acceptance || Acceptance.UNKNOWN;
    var compliance = spec.compliance || DesignCompliance.UNKNOWN;
    var backgroundColor = spec.acceptance === Acceptance.DEPRECATED ? fluidxRed200 : complianceColor[compliance];
    return (React.createElement("div", { style: { backgroundColor: backgroundColor, padding: 4 } },
        "Acceptance: ",
        React.createElement("strong", null, acceptance),
        ' ',
        spec.acceptance === Acceptance.DEPRECATED ? '- Avoid using in new work' : '',
        " ",
        React.createElement("br", null),
        "Design Compliance: ",
        React.createElement("strong", null, compliance),
        spec.complianceReviewDate && React.createElement(React.Fragment, null,
            " (as of ",
            spec.complianceReviewDate,
            ")"),
        spec.designSpecUrl && (React.createElement(React.Fragment, null,
            ' ',
            React.createElement("a", { href: spec.designSpecUrl, target: "_blank", rel: "noreferrer" }, "Spec"),
            ' ')),
        React.createElement("br", null),
        spec.note && (React.createElement(React.Fragment, null,
            React.createElement("hr", null),
            React.createElement(Markdown, null, spec.note)))));
};
/**
 * Show a "cuix description" for a component/story file in storybook e.g.
 * if it informed by the spec, last time it was reviewed etc. See story
 * book example for more usage samples.
 */
export var CuixDescription = function () {
    var spec = useCuixParam();
    return React.createElement(CuixDescriptionInner, { spec: spec });
};
