// Copyright (c) 2022 Cloudera, Inc. All rights reserved.
/**
 * It should be easy to contribute to CUIX. However, we do need to distinguish between
 * components that are well maintained and "official" like `Alert`, `Button` vs more
 * specialized components that might not be universal.
 */
export var Acceptance;
(function (Acceptance) {
    /**
     * A component that likely has or will have a design spec at design.cloudera.com and
     * and should be in most cases considered "the" implementation of said spec e.g `Alert`.
     */
    Acceptance["OFFICIAL"] = "Official";
    /**
     * A component that might be used by a single experience, but is general enough to be used
     * by other projects should they need something similar. These components are not covered
     * by the official design spec, though their design could be informed by general rules from the
     * design spec.
     */
    Acceptance["UNOFFICIAL"] = "Unofficial";
    /**
     * A component that is actively developed/recently added, and is likely to see potentially
     * significant changes in the near future. Use with care and expectations that it might change.
     */
    Acceptance["BETA"] = "Beta";
    /**
     * Components that whose usage is discouraged and should generally not be use for new work.
     * These will likely not be maintained and should eventually be removed.
     */
    Acceptance["DEPRECATED"] = "Deprecated";
    /**
     * Non-components or other things we have in storybook where these Acceptance levels don't
     * make sense.
     */
    Acceptance["NOT_APPLICABLE"] = "Not Applicable";
    Acceptance["UNKNOWN"] = "Unknown";
})(Acceptance || (Acceptance = {}));
/**
 * In addition to an acceptance level each component in CUIX (particularly official ones)
 * might have an official design spec or can be generally inferred from the design spec. In these
 * cases we can review the component and determine if we match the spec.
 */
export var DesignCompliance;
(function (DesignCompliance) {
    /**
     * To the best knowledge of the author/reviewer the component matches the spec.
     */
    DesignCompliance["FULL"] = "Full";
    /**
     * The component matches part of the spec, and/or the complete spec is not implemented.
     * Please add a note describing the status.
     */
    DesignCompliance["PARTIAL"] = "Partial";
    /**
     * No review has taken place so we don't know the compliance factor.
     */
    DesignCompliance["UNKNOWN"] = "Unknown";
    /**
     * The components matches none or very little of the spec.
     */
    DesignCompliance["NONE"] = "None";
    /**
     * The component has no design spec to follow.
     */
    DesignCompliance["NO_SPEC"] = "No spec";
})(DesignCompliance || (DesignCompliance = {}));
