// Copyright (c) 2018 Cloudera, Inc. All rights reserved.
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (Object.prototype.hasOwnProperty.call(b, p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        if (typeof b !== "function" && b !== null)
            throw new TypeError("Class extends value " + String(b) + " is not a constructor or null");
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
var __read = (this && this.__read) || function (o, n) {
    var m = typeof Symbol === "function" && o[Symbol.iterator];
    if (!m) return o;
    var i = m.call(o), r, ar = [], e;
    try {
        while ((n === void 0 || n-- > 0) && !(r = i.next()).done) ar.push(r.value);
    }
    catch (error) { e = { error: error }; }
    finally {
        try {
            if (r && !r.done && (m = i["return"])) m.call(i);
        }
        finally { if (e) throw e.error; }
    }
    return ar;
};
var _a;
import React from 'react';
import PropTypes from 'prop-types';
import { DatePicker } from 'antd';
import i18n from '../../utils/i18n';
import classNames from 'classnames';
import moment from 'moment';
import "./DateRangeInput.css";
var DATE_RANGE_SEPARATOR = '/';
var DATE_RANGE_FORMAT = 'YYYY-MM-DD';
/**
 * Parses a / separated date range string and returns an array of moment objects of size 2.
 * First element is the start date and the second is the end date.
 */
export var parseDateRangeQueryParam = function (dateRangeString) {
    if (!dateRangeString || dateRangeString.indexOf(DATE_RANGE_SEPARATOR) === -1) {
        return null;
    }
    var _a = __read(dateRangeString.split(DATE_RANGE_SEPARATOR), 2), startDateStr = _a[0], endDateStr = _a[1];
    var startDate = moment(startDateStr, DATE_RANGE_FORMAT);
    var endDate = moment(endDateStr, DATE_RANGE_FORMAT);
    if (!startDate.isValid() || !endDate.isValid()) {
        return null;
    }
    return [startDate, endDate];
};
/**
 * Creates a / separated date range string with given start and end dates.
 */
export var createDateRangeQueryParam = function (startDate, endDate) {
    if (!startDate || !startDate.isValid() || !endDate || !endDate.isValid()) {
        return null;
    }
    return (startDate.format(DATE_RANGE_FORMAT) + DATE_RANGE_SEPARATOR + endDate.format(DATE_RANGE_FORMAT));
};
var today = moment();
var presetRanges = (_a = {},
    _a[i18n.t('label.all')] = [moment.unix(0), today.clone()],
    _a[i18n.t('label.dateRange.today')] = [today.clone(), today.clone()],
    _a[i18n.t('label.dateRange.yesterday')] = [
        today.clone().subtract(1, 'days'),
        today.clone().subtract(1, 'days')
    ],
    _a[i18n.t('label.dateRange.last7Days')] = [today.clone().subtract(6, 'days'), today.clone()],
    _a[i18n.t('label.dateRange.last30Days')] = [today.clone().subtract(29, 'days'), today.clone()],
    _a[i18n.t('label.dateRange.last90Days')] = [today.clone().subtract(89, 'days'), today.clone()],
    _a[i18n.t('label.dateRange.thisMonth')] = [
        today.clone().startOf('month'),
        today.clone().endOf('month')
    ],
    _a[i18n.t('label.dateRange.lastMonth')] = [
        today.clone().subtract(1, 'month').startOf('month'),
        today.clone().subtract(1, 'month').endOf('month')
    ],
    _a);
var MIN_DATE = moment.unix(0);
var MAX_DATE = today;
var DateRangeInput = /** @class */ (function (_super) {
    __extends(DateRangeInput, _super);
    function DateRangeInput() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.onChange = function (_a) {
            var _b = __read(_a, 2), startDate = _b[0], endDate = _b[1];
            // Check if the date selection is cleared or ALL preset is selected
            if (!startDate ||
                !endDate ||
                (startDate.isSame(MIN_DATE, 'day') && endDate.isSame(MAX_DATE, 'day'))) {
                return _this.props.onChange(undefined);
            }
            var dateRangeString = createDateRangeQueryParam(startDate, endDate);
            _this.props.onChange(dateRangeString);
        };
        _this.isDateDisabled = function (date) { return date.isBefore(MIN_DATE, 'day') || date.isAfter(MAX_DATE, 'day'); };
        return _this;
    }
    DateRangeInput.prototype.render = function () {
        var _a = this.props, onChange = _a.onChange, value = _a.value, className = _a.className, otherProps = __rest(_a, ["onChange", "value", "className"]);
        var parsedDateRange = parseDateRangeQueryParam(value);
        return (React.createElement(DatePicker.RangePicker, __assign({ onChange: this.onChange, ranges: presetRanges, allowClear: false, format: "ll", placeholder: [i18n.t('label.all'), i18n.t('label.all')], className: classNames('altus-date-range-selector', className, {
                'empty-data-range-selector': !parsedDateRange
            }), value: parsedDateRange, disabledDate: this.isDateDisabled }, otherProps)));
    };
    DateRangeInput.propTypes = {
        /** Function to call when input value changes */
        onChange: PropTypes.func,
        /** Function to call input is blurred */
        onBlur: PropTypes.func,
        /** Value of the input. Value format should be in the "2018-12-04/2018-12-05" format. */
        value: PropTypes.string,
        /** Additional class name to add to the underlying picker component. */
        className: PropTypes.string
    };
    DateRangeInput.defaultProps = {
        onChange: function () { },
        onBlur: function () { }
    };
    return DateRangeInput;
}(React.Component));
export default DateRangeInput;
