import React from 'react';
import moment from 'moment';
export interface DateRangeOption {
    value: string;
    label: React.ReactNode;
    range?: [moment.Moment, moment.Moment];
}
export declare type CustomValue = [moment.Moment | null, moment.Moment | null];
export declare type DateRangeSelectValue = string | undefined | CustomValue;
interface Props {
    value: DateRangeSelectValue;
    options: DateRangeOption[];
    onChange: (valueOrCustomRange: DateRangeSelectValue) => any;
    /**
     * The date time format used in case of customized timerange.
     * Default is 'YYYY/MM/DD HH:mm:ss' e.g. 2022/12/14 00:01:00
     */
    dateTimeFormat?: string;
    bordered?: boolean;
    /**
     * Typically this is used in top-right corner, so
     * we'll use a default align style to make that present
     * better.
     */
    customAlign?: boolean;
    analyticActionName?: string;
    /**
     * Disabled date range, for example future dates
     */
    disabledDateRange?: (date: moment.Moment) => boolean;
    /**
     * For the custom date ranges, this period will be initially selected.
     * e.g. [moment().subtract(30, 'day').startOf('day'), moment().startOf('second')]
     * It can be implemented as either a function an array of 2 Moment objects
     * or a function returning an array of 2 Moment objects.
     */
    getDefaultCustomRange?: any;
}
/**
 * Component to select a predfined or custom time range.
 *
 * It should be implemented in a component which handles initial value, options and onChange (and extra customization).
 * Predefined options are in DateRange but custom ranges can be added as well.
 * An example implementation can look like
 * ```
 * const RangePickerContainer: React.FC = ({initialValue, onChange}) => {
 * // Use custom date ranges for yourself
 *  const options = [TODAY, YESTERDAY];
 * // get initial value (from API, url param or default value)
 *  const [currentValue, setCurrentValue] = useState(initialValue);
 * // handle timerange change in component implementation
 *  return <RangePicker options={options} value={currentValue} onChange={onChange} />
 * }
 * ```
 */
declare const DateRangeSelect: React.FC<Props>;
export default DateRangeSelect;
