/* Copyright (c) 2023 Cloudera, Inc. All rights reserved. */
var __read = (this && this.__read) || function (o, n) {
    var m = typeof Symbol === "function" && o[Symbol.iterator];
    if (!m) return o;
    var i = m.call(o), r, ar = [], e;
    try {
        while ((n === void 0 || n-- > 0) && !(r = i.next()).done) ar.push(r.value);
    }
    catch (error) { e = { error: error }; }
    finally {
        try {
            if (r && !r.done && (m = i["return"])) m.call(i);
        }
        finally { if (e) throw e.error; }
    }
    return ar;
};
import React, { useState } from 'react';
import Select from "cuix/dist/components/Select";
import { DatePicker } from 'antd';
import analytics from "cuix/dist/utils/analytics";
import i18n from "cuix/dist/utils/i18n";
var CUSTOMIZE = {
    value: 'customize',
    label: i18n.t('label.customize')
};
/** options make it work better as a drop down location in the top-right of page */
var pageDropDownAlign = {
    points: ['tr', 'br']
};
/**
 * Component to select a predfined or custom time range.
 *
 * It should be implemented in a component which handles initial value, options and onChange (and extra customization).
 * Predefined options are in DateRange but custom ranges can be added as well.
 * An example implementation can look like
 * ```
 * const RangePickerContainer: React.FC = ({initialValue, onChange}) => {
 * // Use custom date ranges for yourself
 *  const options = [TODAY, YESTERDAY];
 * // get initial value (from API, url param or default value)
 *  const [currentValue, setCurrentValue] = useState(initialValue);
 * // handle timerange change in component implementation
 *  return <RangePicker options={options} value={currentValue} onChange={onChange} />
 * }
 * ```
 */
var DateRangeSelect = function (_a) {
    var onChange = _a.onChange, options = _a.options, value = _a.value, bordered = _a.bordered, _b = _a.customAlign, customAlign = _b === void 0 ? true : _b, _c = _a.dateTimeFormat, dateTimeFormat = _c === void 0 ? 'YYYY/MM/DD HH:mm:ss' : _c, analyticActionName = _a.analyticActionName, disabledDateRange = _a.disabledDateRange, getDefaultCustomRange = _a.getDefaultCustomRange;
    var _d = __read(useState(false), 2), isPickerOpen = _d[0], setIsPickerOpen = _d[1];
    var isCustomRange = value && typeof value !== 'string';
    var daterangeOptions = [];
    var createDateRangesFromOptions = function () {
        options.map(function (item) {
            daterangeOptions.push(item);
        });
        daterangeOptions.push(CUSTOMIZE);
        return daterangeOptions;
    };
    var onSelectChange = function (selectValue) {
        if (selectValue === CUSTOMIZE.value) {
            setIsPickerOpen(true);
        }
        else {
            onChange(selectValue);
            if (analyticActionName) {
                analytics.trackEvent('User Action', analyticActionName, "preset: ".concat(selectValue));
            }
        }
    };
    var onCustomRangeChange = function (internalVal) {
        setIsPickerOpen(false);
        // when rangepicker is cleared, let's call with undefined value
        var value = internalVal || undefined;
        onChange(value);
        if (analyticActionName) {
            analytics.trackEvent('User Action', analyticActionName, value ? "custom: ".concat(value.toString()) : 'Clear');
        }
    };
    return (React.createElement(React.Fragment, null, isPickerOpen || isCustomRange ? (React.createElement(DatePicker.RangePicker, { open: isPickerOpen, onOpenChange: setIsPickerOpen, format: dateTimeFormat, showTime: true, onOk: onCustomRangeChange, onChange: onCustomRangeChange, disabledDate: disabledDateRange, defaultValue: getDefaultCustomRange, "data-test": "AntdRangePicker" })) : (React.createElement(Select, { options: createDateRangesFromOptions(), dropdownMatchSelectWidth: false, onChange: onSelectChange, value: value, bordered: bordered, dropdownAlign: customAlign ? pageDropDownAlign : undefined, "data-test": "AntdRangeSelect" }))));
};
export default DateRangeSelect;
