// Copyright (c) 2019 Cloudera, Inc. All rights reserved.
var __read = (this && this.__read) || function (o, n) {
    var m = typeof Symbol === "function" && o[Symbol.iterator];
    if (!m) return o;
    var i = m.call(o), r, ar = [], e;
    try {
        while ((n === void 0 || n-- > 0) && !(r = i.next()).done) ar.push(r.value);
    }
    catch (error) { e = { error: error }; }
    finally {
        try {
            if (r && !r.done && (m = i["return"])) m.call(i);
        }
        finally { if (e) throw e.error; }
    }
    return ar;
};
import React, { Fragment, useState, useEffect } from 'react';
var Phase;
(function (Phase) {
    Phase[Phase["INVISIBLE"] = 0] = "INVISIBLE";
    Phase[Phase["VISIBLE"] = 1] = "VISIBLE";
})(Phase || (Phase = {}));
/**
 * Render children after a delay.
 *
 * One use case:
 *   Sometimes you want to show a loading indicator only if the operation takes more than a certain
 *   time. For example, if an operation typically completes in 500ms 9 out of 10 times, you don't want to
 *   show a loading indcator for those. For the once case that takes 10s you do want a indicator.
 *   Same principle that is used by `<Loading />`.
 */
var Delayed = function (_a) {
    var delay = _a.delay, children = _a.children;
    var _b = __read(useState(Date.now()), 1), startTime = _b[0];
    var _c = __read(useState(Phase.INVISIBLE), 2), phase = _c[0], setPhase = _c[1];
    useEffect(function () {
        if (phase === Phase.VISIBLE) {
            return;
        }
        var now = Date.now();
        var elapsedTime = now - startTime;
        var timeLeft = Math.max(0, delay - elapsedTime);
        var timeout = setTimeout(function () {
            setPhase(Phase.VISIBLE);
        }, timeLeft);
        return function () { return clearTimeout(timeout); };
    });
    if (phase === Phase.INVISIBLE) {
        // if we wanted to still take up the space, we could add a prop
        // that would render it but with visibility or opacity set.
        // we could then also add fading-in for those cases.
        return null;
    }
    return React.createElement(Fragment, null, children);
};
export default Delayed;
