// Copyright (c) 2020 Cloudera, Inc. All rights reserved.
import React from 'react';
import { render, act } from '@testing-library/react';
// TODO: [future] re-enable test and lolex should be built into jest 26 (arne)
import lolex from 'lolex';
import Delayed from './Delayed';
describe('Delayed', function () {
    var clock;
    beforeEach(function () {
        // Jest doesn't mock Date.now along with timers, but lolex does
        // There were plans to use lolex in Jest directly, but looks like those
        // efforts have stalled due to FB.
        // https://github.com/facebook/jest/pull/7776
        clock = lolex.install();
    });
    afterEach(function () {
        clock.uninstall();
    });
    it('should not render child until delay has passed', function () {
        var container = render(React.createElement(Delayed, { delay: 100 },
            React.createElement("span", null, "span-child"),
            "text-child")).container;
        expect(container).toMatchInlineSnapshot("<div />");
        act(function () {
            clock.tick(99);
        });
        expect(container).toMatchInlineSnapshot("<div />");
        act(function () {
            clock.tick(2);
        });
        expect(container).toMatchInlineSnapshot("\n      <div>\n        <span>\n          span-child\n        </span>\n        text-child\n      </div>\n    ");
    });
    it('should have the same delay if a child is modified while hidden', function () {
        var _a = render(React.createElement(Delayed, { delay: 150 }, "foo")), container = _a.container, rerender = _a.rerender;
        expect(container.firstChild).toMatchInlineSnapshot("null");
        act(function () {
            clock.tick(149);
        });
        // changing the child
        rerender(React.createElement(Delayed, { delay: 150 }, "bar"));
        expect(container.firstChild).toMatchInlineSnapshot("null");
        act(function () {
            clock.tick(2);
        });
        expect(container.firstChild).toMatchInlineSnapshot("bar");
        rerender(React.createElement(Delayed, { delay: 150 }, "xyz"));
        expect(container.firstChild).toMatchInlineSnapshot("xyz");
    });
    it('should not hide if previously visible and delay is increased', function () {
        var _a = render(React.createElement(Delayed, { delay: 25 }, "hello")), container = _a.container, rerender = _a.rerender;
        act(function () {
            clock.tick(30);
        });
        expect(container.firstChild).toMatchInlineSnapshot("hello");
        // increase delay to 1000ms
        rerender(React.createElement(Delayed, { delay: 1000 }, "hello2"));
        expect(container.firstChild).toMatchInlineSnapshot("hello2");
    });
});
