import React from 'react';
interface Props {
    /**
     * Generally we don't display the specific error message to the user,
     * as they typically would be raw JS errors (but perhaps this could be argued).
     * In some cases we might produce our own nice errors and want to let them show.
     */
    showActualErrorMessage?: boolean;
    /**
     * Override the default unexpected error. This can be useful for example
     * for example if you're doing best-effort work to parse some data (e.g. we
     * expect or think there will be errors.) Then we might display
     * "Data parsing failed/Unsupported data structure" title or other
     * more descriptive title.
     */
    title?: string;
    /**
     * Customize the complete error rendering. For example if you're doing
     * best-effort work to parse some data to display it in a graph, then
     * in the fallback handler you could display the error **and** the
     * data in text format (assuming the data in text format is still
     * helpful to the user).
     */
    fallbackHandler?: (err: Error) => React.ReactNode;
}
interface State {
    error: false | Error;
}
/**
 * Catch/Handle errors in the React chain. See https://reactjs.org/docs/error-boundaries.html
 * for more details. As of now, this needs to be a class component.
 */
export default class ErrorBoundary extends React.Component<Props, State> {
    state: State;
    componentDidCatch(error: any): void;
    render(): React.ReactNode;
}
export {};
