var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
// Copyright (c) 2021 Cloudera, Inc. All rights reserved.
import autoComplete from 'javascript-autocomplete';
var classes = {
    container: 'facet-filter',
    icon: 'icon',
    iconType: 'icon-filter',
    token: 'token',
    tokenKeyEmpty: 'token-key-empty',
    tokenValueEmpty: 'token-value-empty',
    tokenCommitted: 'token-committed',
    tokenKeyInput: 'token-key-input',
    tokenKey: 'token-key',
    tokenValueInput: 'token-value-input',
    tokenValue: 'token-value',
    dropdownMenu: 'dropdown-menu',
    dropdownHeader: 'dropdown-header',
    dropdownItem: 'dropdown-item'
};
var TAB = 9;
var ENTER = 13;
var ESC = 27;
var UP = 38;
var DOWN = 40;
var ELEMENT_NODE = 1;
// Returns true if the element is truncated horizontally, within a certain tolerance.
// This is used to determine whether to add a tooltip to the element.
var isTruncatedX = function (element, tolerance) {
    var tol = tolerance || 2;
    return element.clientWidth + tol < element.scrollWidth;
};
var facetFilter = function (container, data, options) {
    if (!(container && container.nodeType === ELEMENT_NODE)) {
        throw new Error('Target container is not a DOM element.');
    }
    var facets = Array.isArray(data)
        ? data.map(function (facet) { return (__assign(__assign({}, facet), { used: false, values: facet.values ? facet.values.map(function (value) { return ({ value: value, used: false }); }) : [] })); })
        : [];
    var opts = __assign(__assign({ tooltips: true, autoFocus: true }, options), { css: __assign(__assign({}, classes), (options && options.css)) });
    var nextTokenId = 0; // Unique ID that will be used for the next token created within this control. This value will only increase.
    var containerClicked = false; // Keeps track of when the container was clicked on, which affects how we handle blur events for the filters.
    var triggerCount = 0; // Keeps track of how many times to re-trigger the keyDown even in handleUpDown().
    // Updates the set relationship attributes. Must be called after a filter is added or removed.
    var updateAriaSetRels = function () {
        var filters = getAllFilters();
        var setsize = filters.length;
        filters.forEach(function (filter, index) {
            filter.setAttribute('aria-posinset', (index + 1).toString());
            filter.setAttribute('aria-setsize', setsize.toString());
        });
    };
    // Creates the following HTML. This is the structure of a single filter inside the container.
    // <div class="token token-key-empty" aria-label="Token">
    //   <div class="icon icon-filter"></div> /* optional */
    //   <div class="token-key hide"></div>
    //   <div class="separator">:</div>
    //   <input class="token-key-input" type="button" aria-label="Key" aria-haspopup="listbox"></input>
    //   <div class="token-value hide"></div>
    //   <input class="token-value-input hide" role="combobox" aria-label="Value"></input>
    //   <button class="close hide" type="button" aria-label="Remove"></button>
    // </div>
    var addFilter = function (focus) {
        var filter = document.createElement('div');
        filter.className = "".concat(opts.css.token, " ").concat(opts.css.tokenKeyEmpty);
        filter.id = "".concat(container.id, "-token").concat(nextTokenId++);
        filter.setAttribute('aria-label', 'Token');
        var filterKey = document.createElement('div');
        filterKey.className = "".concat(opts.css.tokenKey, " hide");
        filterKey.id = "".concat(filter.id, "-key");
        var separator = document.createElement('div');
        separator.className = 'separator';
        separator.textContent = ':';
        var filterKeyInput = document.createElement('input');
        if (opts.css.tokenKeyInput) {
            filterKeyInput.className = opts.css.tokenKeyInput;
        }
        filterKeyInput.id = "".concat(filter.id, "-keyInput");
        filterKeyInput.setAttribute('type', 'button');
        filterKeyInput.setAttribute('aria-label', 'Key');
        filterKeyInput.setAttribute('aria-haspopup', 'listbox');
        filterKeyInput.addEventListener('focus', handleKeyFocus);
        filterKeyInput.addEventListener('blur', handleKeyBlur);
        filterKeyInput.addEventListener('keydown', handleKeyboard);
        var filterVal = document.createElement('div');
        filterVal.className = "".concat(opts.css.tokenValue, " hide");
        var filterValInput = document.createElement('input');
        filterValInput.className = "".concat(opts.css.tokenValueInput, " hide");
        filterValInput.id = "".concat(filter.id, "-valueInput");
        filterValInput.setAttribute('role', 'combobox');
        filterValInput.setAttribute('aria-label', 'Value');
        filterValInput.addEventListener('keydown', handleKeyboard);
        filterValInput.addEventListener('focus', handleValFocus);
        filterValInput.addEventListener('blur', handleValBlur);
        var closeBtn = document.createElement('button');
        closeBtn.className = 'close hide';
        closeBtn.setAttribute('type', 'button');
        closeBtn.setAttribute('aria-label', 'Remove');
        closeBtn.addEventListener('click', function (event) {
            if (event.target) {
                removeFilter(event.target);
            }
            updateAriaSetRels();
        });
        filter.appendChild(filterKey);
        filter.appendChild(separator);
        filter.appendChild(filterKeyInput);
        filter.appendChild(filterVal);
        filter.appendChild(filterValInput);
        filter.appendChild(closeBtn);
        container.insertBefore(filter, clearButton);
        var keys = facets
            .filter(function (facet) { return !facet.used; })
            .map(function (facet) { return ({ key: facet.key, header: facet.header }); });
        addAutoComplete('key', filterKeyInput, keys);
        if (focus) {
            filterKeyInput.focus();
        }
    };
    var getKeyDiv = function (filter) {
        return filter.querySelector(".".concat(opts.css.tokenKey));
    };
    var getKeyInput = function (filter) {
        return filter.querySelector(".".concat(opts.css.tokenKeyInput));
    };
    var getValueDiv = function (filter) {
        return filter.querySelector(".".concat(opts.css.tokenValue));
    };
    var getValueInput = function (filter) {
        return filter.querySelector(".".concat(opts.css.tokenValueInput));
    };
    var getCloseButton = function (filter) { return filter.querySelector('.close'); };
    var destroy = function (filter) {
        if (filter.sc && document.body.contains(filter) && document.body.contains(filter.sc)) {
            filter.sc.destroy();
        }
    };
    // Removes all uncommitted filters. "Uncommitted" refers to filters that can still have their value changed.
    // Once the user enters a valid value for a filter and hits the enter key or removes focus from the filter,
    // it is committed and its value can no longer be changed. Committed filters can only be removed.
    var removeUncommitted = function () {
        getAllFilters(":not(.".concat(opts.css.tokenCommitted, ")")).forEach(function (filterEl) {
            var keyInput = getKeyInput(filterEl);
            if (keyInput) {
                destroy(keyInput);
            }
            var valInput = getValueInput(filterEl);
            if (valInput) {
                destroy(valInput);
            }
            if (filterEl.parentElement) {
                filterEl.parentElement.removeChild(filterEl);
            }
        });
    };
    var removeFilter = function (target) {
        if (target) {
            var getFilterEl_1 = function (target) {
                if (Array.from(target.classList).includes(opts.css.token)) {
                    return target;
                }
                if (target.parentElement) {
                    return getFilterEl_1(target.parentElement);
                }
                return null;
            };
            // Return filter key and value to unused state.
            var filterEl = getFilterEl_1(target);
            if (filterEl) {
                var keyInput = getKeyInput(filterEl);
                var key_1 = keyInput && keyInput.value;
                if (key_1) {
                    var facet = facets.find(function (facet) { return facet.key === key_1; });
                    if (facet) {
                        facet.used = false;
                        var valInput = getValueInput(filterEl);
                        var val_1 = valInput && valInput.value;
                        if (val_1) {
                            var value = facet.values.find(function (value) { return value.value === val_1; });
                            if (value) {
                                value.used = false;
                            }
                        }
                        if (valInput) {
                            destroy(valInput);
                        }
                    }
                }
                if (keyInput) {
                    destroy(keyInput);
                }
                // Remove filter element from UI.
                // Check if it is still in the DOM (has a parent) first.
                if (filterEl.parentElement) {
                    filterEl.parentElement.removeChild(filterEl);
                }
            }
            // Remove uncommitted filters because the used items state may have changed
            removeUncommitted();
            // Hide Clear All button if there are no more filters
            if (getAllFilters().length === 0) {
                container.classList.add('empty');
                clearButton.className = 'close hide';
            }
            container.dispatchEvent(new Event('changed.facetfilter.tokenfield'));
            addFilter();
            updateAriaSetRels();
        }
    };
    var commitValue = function (filter) {
        var valueEl = getValueDiv(filter);
        var valInput = getValueInput(filter);
        var closeButton = getCloseButton(filter);
        if (closeButton &&
            valueEl &&
            valInput &&
            valInput.value !== '' &&
            !filter.classList.contains(opts.css.tokenCommitted)) {
            var keyInput = getKeyInput(filter);
            var key_2 = keyInput && keyInput.value;
            var facet = facets.find(function (facet) { return facet.key === key_2; });
            if (facet) {
                var value = facet.values.find(function (value) { return value.value === valInput.value; });
                // Only commit if value was found or the facet allows free text entry.
                if (value || facet.freeText) {
                    // 1. Mark the selected value as used.
                    if (value) {
                        value.used = true;
                    }
                    // 2. Commit the selected value in the UI.
                    filter.classList.replace(opts.css.tokenValueEmpty, opts.css.tokenCommitted);
                    valueEl.textContent = valInput.value;
                    valueEl.classList.remove('hide');
                    valInput.classList.add('hide');
                    closeButton.classList.remove('hide');
                    clearButton.classList.remove('hide'); // Show Clear All button
                    // 3. Add tooltip if needed.
                    if (typeof opts.attachTooltip === 'function' && isTruncatedX(valueEl)) {
                        opts.attachTooltip(valueEl, valInput.value);
                    }
                    // 4. Emit event.
                    container.dispatchEvent(new Event('changed.facetfilter.tokenfield'));
                    // 5. Add the next new filter.
                    addFilter(opts.autoFocus);
                    updateAriaSetRels();
                    return true;
                }
            }
        }
        return null;
    };
    var preventKeyScroll = function (event) {
        switch (event.keyCode) {
            case UP:
            case DOWN:
                event.preventDefault();
                break;
        }
    };
    var handleMouseDown = function () { return (containerClicked = true); };
    var handleMouseUp = function () { return (containerClicked = false); };
    var handleClick = function (event) {
        var uncommitted = Array.prototype.find.call(event.target.children, function (child) {
            return child.classList.contains(opts.css.token) &&
                !child.classList.contains(opts.css.tokenCommitted);
        });
        if (!uncommitted) {
            return;
        }
        var elementToFocus = uncommitted.classList.contains(opts.css.tokenKeyEmpty)
            ? getKeyInput(uncommitted)
            : getValueInput(uncommitted);
        if (elementToFocus) {
            elementToFocus.focus();
        }
    };
    var handleKeyFocus = function (event) {
        window.addEventListener('keydown', preventKeyScroll);
        event.target.setAttribute('aria-expanded', 'true');
    };
    var handleKeyBlur = function (event) {
        window.removeEventListener('keydown', preventKeyScroll);
        event.target.removeAttribute('aria-expanded');
        // If the element is blurred because the container was clicked on
        // and it is still in the uncommitted state, it will be immediately refocused.
        // In that case, we do not allow the blur event to propagate
        // because we want to keep the autocomplete menu visible.
        // However, if a close button within the container was clicked, then
        // event.relatedTarget will be populated, so we allow normal blurring behavior.
        if (containerClicked &&
            !event.relatedTarget &&
            !event.target.classList.contains(opts.css.tokenCommitted)) {
            event.stopImmediatePropagation();
        }
    };
    var handleValFocus = function (event) {
        if (event.target) {
            event.target.setAttribute('aria-expanded', 'true');
        }
    };
    var handleValBlur = function (event) {
        var target = event.target;
        if (target) {
            target.removeAttribute('aria-expanded');
            if (target.parentElement) {
                commitValue(target.parentElement);
            }
        }
    };
    var handleUpDown = function (code, target, isOriginalEvent) {
        var next;
        var selected = target.sc.querySelector(".".concat(opts.css.dropdownItem, ".selected"));
        if (!selected) {
            next =
                code === DOWN
                    ? target.sc.querySelector(".".concat(opts.css.dropdownItem)) // first
                    : target.sc.childNodes[target.sc.childNodes.length - 1]; // last
        }
        else {
            next =
                code === DOWN ? selected.nextSibling : selected.previousSibling;
        }
        if (next && next.classList.contains(opts.css.dropdownHeader)) {
            if (triggerCount === 0 && isOriginalEvent) {
                while (next) {
                    if (next.classList.contains(opts.css.dropdownHeader)) {
                        triggerCount++;
                    }
                    else {
                        break;
                    }
                    next = code === DOWN ? next.nextSibling : next.previousSibling;
                }
            }
            if (triggerCount > 0) {
                triggerCount--;
                //TODO: Replace use of deprecated keyCode
                //@ts-ignore
                var newEvent = new KeyboardEvent('keydown', { keyCode: code, detail: true });
                target.dispatchEvent(newEvent);
            }
        }
    };
    var handleKeyboard = function (event) {
        var target = event.target;
        if (!target) {
            return;
        }
        switch (event.keyCode) {
            case UP:
            case DOWN:
                handleUpDown(event.keyCode, target, !event.detail); // event.detail will be true if this is a re-triggered event from handleUpDown
                break;
            case ENTER:
                if (target.parentElement) {
                    commitValue(target.parentElement);
                }
                break;
            case TAB:
                if (target.parentElement) {
                    if (target.parentElement.classList.contains(opts.css.tokenKeyEmpty)) {
                        target.blur();
                    }
                    else if (!commitValue(target.parentElement)) {
                        removeFilter(target);
                        updateAriaSetRels();
                    }
                    else {
                        event.preventDefault();
                    }
                }
                break;
            case ESC:
                if (target.parentElement) {
                    if (target.parentElement.classList.contains(opts.css.tokenKeyEmpty)) {
                        target.blur();
                    }
                    else if (target.parentElement.classList.contains(opts.css.tokenValueEmpty)) {
                        removeFilter(target);
                        updateAriaSetRels();
                    }
                }
                break;
        }
    };
    var activateTooltips = function (mutationsList) {
        mutationsList
            .filter(function (mutation) { return mutation.type === 'childList' && mutation.addedNodes; })
            .forEach(function (mutation) {
            return mutation.addedNodes.forEach(function (child) {
                if (isTruncatedX(child)) {
                    if (typeof opts.attachTooltip === 'function') {
                        opts.attachTooltip(child, child.textContent || '');
                    }
                }
            });
        });
    };
    var addAutoComplete = function (type, selector, choices) {
        var ac = new autoComplete({
            selector: selector,
            menuClass: opts.css.dropdownMenu,
            minChars: Array.isArray(choices) ? 0 : 3,
            source: function (term, response) {
                // The very first time this is called,
                // when the control is constructed,
                // choices will contain all keys.
                term = term.toLowerCase();
                var matches;
                if (type === 'key') {
                    matches = choices.filter(function (choice) { return choice.key.toLowerCase().includes(term); });
                }
                else {
                    matches = choices.filter(function (choice) { return choice.toLowerCase().includes(term); });
                }
                response(matches);
            },
            renderItem: function (item, search) {
                search = search.replace(/[-/\\^$*+?.()|[\]{}]/g, '\\$&');
                var re = new RegExp('(' + search.split(' ').join('|') + ')', 'gi');
                var itemEl = document.createElement('div');
                itemEl.className = "autocomplete-suggestion ".concat(opts.css.dropdownItem);
                if (type === 'key') {
                    // The items to render for keys do not include the data-val property.
                    // This prevents the control from being in an undefined state if the user
                    // traverses the values in the dropdown using the arrow keys.
                    if (item.header) {
                        itemEl.classList.add(opts.css.dropdownHeader);
                        itemEl.setAttribute('role', 'heading');
                    }
                    else {
                        itemEl.setAttribute('role', 'option');
                    }
                    itemEl.textContent = item.key;
                }
                else {
                    itemEl.setAttribute('data-val', item);
                    itemEl.setAttribute('role', 'option');
                    var displayItem = item.replace(re, '<b>$1</b>');
                    itemEl.innerHTML = displayItem;
                }
                return itemEl.outerHTML;
            },
            onSelect: function (event, term, item) {
                if (item.classList.contains(opts.css.dropdownHeader)) {
                    event.stopImmediatePropagation();
                }
                else {
                    term = item.textContent;
                    var keyInput = selector;
                    var filterEl = keyInput.parentElement;
                    if (filterEl) {
                        if (type === 'key') {
                            // A key was just selected:
                            var keyEl = getKeyDiv(filterEl);
                            if (keyEl) {
                                container.classList.remove('empty');
                                // 1. Commit the selected key in the UI.
                                keyInput.classList.add('hide');
                                keyInput.removeAttribute('aria-expanded');
                                keyInput.value = term;
                                keyEl.textContent = term;
                                keyEl.classList.remove('hide');
                                filterEl.classList.replace(opts.css.tokenKeyEmpty, opts.css.tokenValueEmpty);
                                // 2. Add tooltip if needed.
                                if (typeof opts.attachTooltip === 'function' && isTruncatedX(keyEl)) {
                                    opts.attachTooltip(keyEl, keyEl.textContent || '');
                                }
                                // 3. Determine choices for next autocomplete, which should
                                //    contain the available values for the selected key.
                                var valChoices = [];
                                var facet = facets.find(function (facet) { return facet.key === term; });
                                if (facet) {
                                    // We found the selected key, so filter its values to get the ones not yet used.
                                    valChoices = facet.values.filter(function (val) { return !val.used; }).map(function (val) { return val.value; });
                                    // If the key is not reusable, mark it as used.
                                    if (facet.noRepeat) {
                                        facet.used = true;
                                    }
                                }
                                // 4. Create the autocomplete for the key's values using the available choices.
                                var valInput = getValueInput(filterEl);
                                if (valInput) {
                                    addAutoComplete('value', valInput, valChoices);
                                    // 5. Activate the value input for the filter.
                                    valInput.classList.remove('hide');
                                    valInput.focus();
                                    valInput.sc.setAttribute('aria-label', "Value Options for ".concat(keyEl.textContent));
                                }
                            }
                        }
                        else {
                            // A value was just selected
                            commitValue(filterEl);
                        }
                    }
                }
            }
        });
        selector.sc.destroy = ac.destroy;
        // Add ARIA attributes.
        var id = "".concat(selector.id, "-listbox");
        selector.setAttribute('aria-owns', id);
        selector.sc.id = id;
        selector.sc.setAttribute('role', 'listbox');
        if (type === 'key') {
            selector.sc.setAttribute('aria-label', 'Key Options');
        }
        else {
            selector.setAttribute('aria-autocomplete', 'list');
        }
        if (typeof opts.attachTooltip === 'function' && selector.sc) {
            var observer = new MutationObserver(activateTooltips);
            observer.observe(selector.sc, { childList: true });
        }
        return ac;
    };
    var getAllFilters = function (selector) {
        return Array.from(container.querySelectorAll(".".concat(opts.css.token).concat(selector || '')));
    };
    var icon = document.createElement('div');
    icon.className = "".concat(opts.css.icon, " ").concat(opts.css.iconType);
    switch (opts.css.iconType) {
        case 'icon-filter':
            // eslint-disable-next-line prettier/prettier
            icon.innerHTML = '<svg viewBox="0 0 1792 1792" xmlns="http://www.w3.org/2000/svg"><path d="M1595 295q17 41-14 70l-493 493v742q0 42-39 59-13 5-25 5-27 0-45-19l-256-256q-19-19-19-45v-486l-493-493q-31-29-14-70 17-39 59-39h1280q42 0 59 39z"/></svg>';
            break;
        case 'icon-search':
            // eslint-disable-next-line prettier/prettier
            icon.innerHTML = '<svg viewBox="0 0 1792 1792" xmlns="http://www.w3.org/2000/svg"><path d="M1216 832q0-185-131.5-316.5t-316.5-131.5-316.5 131.5-131.5 316.5 131.5 316.5 316.5 131.5 316.5-131.5 131.5-316.5zm512 832q0 52-38 90t-90 38q-54 0-90-38l-343-342q-179 124-399 124-143 0-273.5-55.5t-225-150-150-225-55.5-273.5 55.5-273.5 150-225 225-150 273.5-55.5 273.5 55.5 225 150 150 225 55.5 273.5q0 220-124 399l343 343q37 37 37 90z"/></svg>';
            break;
    }
    container.appendChild(icon);
    var clearButton = document.createElement('button');
    clearButton.className = 'close hide';
    clearButton.setAttribute('type', 'button');
    clearButton.setAttribute('aria-label', 'Remove All');
    clearButton.addEventListener('click', function () {
        getAllFilters().forEach(function (filter) { return removeFilter(filter); });
        updateAriaSetRels();
    });
    container.dispatchEvent(new Event('changed.facetfilter.tokenfield'));
    container.appendChild(clearButton);
    container.classList.add(opts.css.container, 'empty');
    if (opts.className) {
        container.classList.add.apply(null, opts.className.split(' '));
    }
    container.setAttribute('role', 'search');
    container.addEventListener('mousedown', handleMouseDown);
    container.addEventListener('click', handleClick);
    container.addEventListener('mouseup', handleMouseUp);
    addFilter();
    updateAriaSetRels();
    return {
        result: function () {
            var filters = getAllFilters();
            var query = {};
            filters.forEach(function (filter) {
                var keyInput = getKeyInput(filter);
                var key;
                if (keyInput) {
                    key = keyInput.value.toLowerCase();
                }
                var valInput = getValueInput(filter);
                var val;
                if (valInput) {
                    val = valInput.value;
                }
                if (key && val) {
                    if (key in query) {
                        if (typeof query[key] === 'string') {
                            // This is the second entry of a multi-valued filter,
                            // so turn the single string into an array.
                            var str = query[key];
                            query[key] = [str, val];
                        }
                        else {
                            query[key].push(val);
                        }
                    }
                    else {
                        query[key] = val;
                    }
                }
            });
            return query;
        }
    };
};
export default facetFilter;
