var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
// Copyright (c) 2019 Cloudera, Inc. All rights reserved.
import React from 'react';
import humanize from '../../utils/humanize';
import i18n from '../../utils/i18n';
import { fluidxBlue500, fluidxGray700, fluidxGray400 } from "cuix/dist/styles/variables";
// 1px wide lines will render sharp if they are centered on 0.5 offsets
var Y_ORIGIN = 0.5;
var AXIS_LABEL_MARGIN = 5;
var AXIS_LABEL_Y_OFFSET = 4;
// NOTE: if we alter labels to be signifcantly longer
// we'll need to update this as well. We could read the size from the dom
// but then we'd have to bother with a ref or other mechanism.
var ESTIMATED_IQR_LABEL_WIDTHS = 100;
var SIDE_PADDING = 70; // padding on each side to avoid labels being cut-off
var Q1_LABEL_SECOND_LINE_MOVE_DISTANCE = 16;
var HEIGHT_WITH_IQR_LABELS_ON_TWO_LINES = 76;
var HEIGHT_WITH_IQR_LABELS_ON_ONE_LINE = 60;
var IQRCircle = function (props) { return React.createElement("circle", __assign({ cy: Y_ORIGIN, r: "3", fill: fluidxBlue500 }, props)); };
var AxisLine = function (_a) {
    var length = _a.length;
    return (React.createElement("line", { x1: "0", y1: Y_ORIGIN, x2: length, y2: Y_ORIGIN, stroke: fluidxGray700, strokeDasharray: 3, strokeWidth: 1 }));
};
var AxisEndMarker = function (_a) {
    var x = _a.x;
    return (React.createElement("line", { x1: x, x2: x, y1: -3, y2: 4, stroke: fluidxGray700, strokeWidth: 1 }));
};
var Label = function (_a) {
    var text = _a.text, tooltip = _a.tooltip, otherProps = __rest(_a, ["text", "tooltip"]);
    return (React.createElement("text", __assign({}, otherProps),
        text,
        React.createElement("title", null, tooltip)));
};
var AxisStartLabel = function (props) { return (React.createElement(Label, __assign({ x: "0", y: Y_ORIGIN, dy: AXIS_LABEL_Y_OFFSET, dx: -AXIS_LABEL_MARGIN, textAnchor: "end", fill: fluidxGray700 }, props))); };
var AxisEndLabel = function (props) { return (React.createElement(Label, __assign({ y: Y_ORIGIN, dy: AXIS_LABEL_Y_OFFSET, dx: AXIS_LABEL_MARGIN, textAnchor: "start", fill: fluidxGray700 }, props))); };
var IQRLine = function (props) { return (React.createElement("line", __assign({ y1: Y_ORIGIN, y2: Y_ORIGIN, stroke: fluidxBlue500, strokeWidth: 2 }, props))); };
var LabelLine = function (props) { return (React.createElement("line", __assign({ strokeWidth: 1, stroke: fluidxGray400, shapeRendering: "crispEdges" }, props))); };
var IQRLabel = function (props) { return React.createElement(Label, __assign({ fill: fluidxGray700 }, props)); };
var MedianLabel = function (props) { return React.createElement(Label, __assign({ y: "-18", textAnchor: "middle" }, props)); };
/**
 * A box-plot variant to display distribution of file sizes e.g. can be used ot
 * show distribution of files sizes that are backing a hive table.
 */
var FileSizeBoxPlot = function (_a) {
    /*
      Box plot terminology
  
                       Median (Q2)
                          +
                          |
                          v
  
        |         +-------+----------+          |
        +---------+       |          +----------+
        |         +-------+----------+          |
  
        ^         ^                  ^          ^
        |         |                  |          |
        +         +                  +          + Maximum
  Minimum      First Quartile    Third Quartile
               (Q1)              (Q3)
  
                  <----------------->
                   IQR (i.e Q1 to Q3)
  
   */
    var stats = _a.stats, _b = _a.width, width = _b === void 0 ? 400 : _b;
    // overall size of the component
    var componentWidth = width;
    // width of the x-axis
    var innerWidth = componentWidth - SIDE_PADDING * 2;
    var scaleFactor = innerWidth / (stats.max - stats.min);
    if (stats.max - stats.min === 0) {
        // A (single) box plot is useless if there is no variation in size, as it would
        // have "zero" width.
        return (React.createElement("div", { style: { width: componentWidth } }, i18n.t('label.fileSizeBoxPlot.notAvailable')));
    }
    var point25 = (stats.percentile25 - stats.min) * scaleFactor;
    var point50 = (stats.median - stats.min) * scaleFactor;
    var point75 = (stats.percentile75 - stats.min) * scaleFactor;
    /*
    Label Edgecases
     Best case scenario, Q1 and Q3 are far apart and can both be center aligned
  
     Edge case:
      1) The labels are closer together so they might overlap, we move Q1 label
         down a line so they don't overlap
      2) If they are very close and 1) is not enough as Q3 label could overlap the
         the line from Q1 to the Q1 label. If that is the case we stop center
         aligning Q3 and move it so that it does not overlap with the Q1 label
         line.
  
     */
    // normal case for Q1 and Q3 labels/lines
    var iqrInfo = {
        label: {
            y: 26,
            dx: 0,
            textAnchor: 'middle'
        },
        line: {
            y1: 8,
            y2: 12
        }
    };
    var q1Info = {
        label: __assign({}, iqrInfo.label),
        line: __assign({}, iqrInfo.line)
    };
    var q3Info = {
        label: __assign({}, iqrInfo.label),
        line: __assign({}, iqrInfo.line)
    };
    var hasIQRLabelsOnTwoLines = false;
    if (point75 - point25 < ESTIMATED_IQR_LABEL_WIDTHS) {
        // Move the Q1 Label down a line
        q1Info.label.y += Q1_LABEL_SECOND_LINE_MOVE_DISTANCE;
        q1Info.line.y2 += Q1_LABEL_SECOND_LINE_MOVE_DISTANCE;
        hasIQRLabelsOnTwoLines = true;
        if (point75 - point25 < ESTIMATED_IQR_LABEL_WIDTHS / 2) {
            // Stop center aliging Q3 label and make sure it starts X px to the
            // right of the Q1 line.
            q3Info.label.textAnchor = 'start';
            var lineLabelPadding = 5;
            q3Info.label.dx = point25 - point75 + lineLabelPadding;
        }
    }
    var height = hasIQRLabelsOnTwoLines
        ? HEIGHT_WITH_IQR_LABELS_ON_TWO_LINES
        : HEIGHT_WITH_IQR_LABELS_ON_ONE_LINE;
    var viewBox = "".concat(-SIDE_PADDING, " -30 ").concat(componentWidth, " ").concat(height);
    return (React.createElement("svg", { viewBox: viewBox, width: componentWidth, height: height, preserveAspectRatio: "xMidYMid slice", style: { display: 'block' } },
        React.createElement(AxisLine, { length: innerWidth }),
        React.createElement(AxisEndMarker, { x: "0.5" }),
        React.createElement(AxisEndMarker, { x: innerWidth - 0.5 }),
        React.createElement(AxisStartLabel, { text: humanize.humanizeBytes(stats.min), tooltip: i18n.t('label.fileSizeBoxPlot.minTooltip') }),
        React.createElement(AxisEndLabel, { x: innerWidth, text: humanize.humanizeBytes(stats.max), tooltip: i18n.t('label.fileSizeBoxPlot.maxTooltip') }),
        React.createElement(IQRLine, { x1: point25, x2: point75 }),
        React.createElement(IQRCircle, { cx: point25 }),
        React.createElement(IQRCircle, { cx: point75 }),
        React.createElement(LabelLine, __assign({ x1: point25, x2: point25 }, q1Info.line)),
        React.createElement(IQRLabel, __assign({ x: point25 }, q1Info.label, { text: i18n.t('label.fileSizeBoxPlot.q1Label', humanize.humanizeBytes(stats.percentile25)), tooltip: i18n.t('label.fileSizeBoxPlot.q1Tooltip') })),
        React.createElement(LabelLine, __assign({ x1: point75, x2: point75 }, q3Info.line)),
        React.createElement(IQRLabel, __assign({ x: point75 }, q3Info.label, { text: i18n.t('label.fileSizeBoxPlot.q3Label', humanize.humanizeBytes(stats.percentile75)), tooltip: i18n.t('label.fileSizeBoxPlot.q3Tooltip') })),
        React.createElement(IQRCircle, { cx: point50, r: "5" }),
        React.createElement(LabelLine, { x1: point50, y1: "-8", x2: point50, y2: "-12" }),
        React.createElement(MedianLabel, { x: point50, text: "Median ".concat(humanize.humanizeBytes(stats.median)), tooltip: i18n.t('label.fileSizeBoxPlot.medianTooltip') })));
};
export default FileSizeBoxPlot;
