var __makeTemplateObject = (this && this.__makeTemplateObject) || function (cooked, raw) {
    if (Object.defineProperty) { Object.defineProperty(cooked, "raw", { value: raw }); } else { cooked.raw = raw; }
    return cooked;
};
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (Object.prototype.hasOwnProperty.call(b, p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        if (typeof b !== "function" && b !== null)
            throw new TypeError("Class extends value " + String(b) + " is not a constructor or null");
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
// Copyright (c) 2018 Cloudera, Inc. All rights reserved.
import React from 'react';
import PropTypes from 'prop-types';
import { Input, Radio, Button, Modal } from 'antd';
import CUIXInput from '../Input';
import Label from '../Label';
import i18n from '../../utils/i18n';
import get from 'lodash/get';
import { getValueFromEvent } from '../../utils/formUtils';
import styled from 'styled-components';
var TextArea = Input.TextArea;
var MODE = {
    PATH: { name: 'PATH', label: i18n.t('label.enterPath') },
    FILE: { name: 'FILE', label: i18n.t('label.fileUpload') },
    TEXT: { name: 'TEXT', label: i18n.t('label.directInput') },
    SKIP: { name: 'SKIP', label: i18n.t('label.skip') }
};
var StyledFormInput = styled.div(templateObject_1 || (templateObject_1 = __makeTemplateObject(["\n  cursor: pointer;\n  display: flex;\n"], ["\n  cursor: pointer;\n  display: flex;\n"])));
var FileTextInput = /** @class */ (function (_super) {
    __extends(FileTextInput, _super);
    function FileTextInput(props) {
        var _this = _super.call(this, props) || this;
        _this.onModeChange = function (e) {
            var mode = getValueFromEvent(e);
            var value = mode === 'SKIP' ? _this.props.skipValue : undefined;
            var previousValue = _this.state.value;
            _this.setState({ value: value, mode: mode, fileName: undefined }, function () {
                if (mode === 'SKIP') {
                    _this.onBlur();
                }
            });
            if (value !== previousValue) {
                _this.triggerValueChange(value);
            }
        };
        /**
         * Handles changes to the text value this component is controlling.
         */
        _this.onValueChange = function (e) {
            var value = getValueFromEvent(e);
            _this.setState({ value: value });
            _this.triggerValueChange(value);
        };
        _this.onBlur = function () { return _this.props.onBlur(_this.state.value); };
        /**
         * Notifies the parent component to value change using the onChange prop.
         */
        _this.triggerValueChange = function (value) {
            _this.props.onChange(value);
        };
        /**
         * Handles file uploads. Tries to read the file using FileReader and set the value to the
         * contents of the file.
         */
        _this.onFileChange = function (e) {
            var file = get(e, 'target.files[0]');
            if (!file) {
                return;
            }
            var reader = new FileReader();
            reader.onerror = function (e) {
                var title = get(e.target, 'error.name', i18n.t('label.unexpectedError.title'));
                var content = get(e.target, 'error.message');
                Modal.error({ title: title, content: content });
            };
            reader.onload = function (loadEvent) {
                if (!loadEvent.target.aborted) {
                    var value_1 = loadEvent.target.result;
                    _this.setState({ fileName: file.name, value: value_1 }, function () {
                        _this.triggerValueChange(value_1);
                        _this.onBlur();
                    });
                }
            };
            reader.readAsText(file);
        };
        /**
         * Triggers a click event on the hidden input[type="file"] DOM element when user clicks the Choose
         * File button.
         */
        _this.triggerFileInputClick = function () {
            if (_this.fileInputNode) {
                _this.fileInputNode.click();
            }
        };
        var mode = _this.props.mode;
        var value = _this.props.value;
        _this.options = _this.getRadioOptions();
        // Make sure a valid option is selected by default
        var validOptions = _this.options.map(function (o) { return o.name; });
        if (validOptions.indexOf(mode) === -1) {
            mode = _this.options[0].name;
        }
        // If there is value, we should default to TEXT mode
        if (value && validOptions.indexOf(MODE.TEXT.name) > -1) {
            mode = MODE.TEXT.name;
        }
        _this.state = { mode: mode, value: value, fileName: undefined };
        _this.fileInputNode = null;
        return _this;
    }
    FileTextInput.prototype.getRadioOptions = function () {
        var options = [];
        if (this.props.showPathMode) {
            options.push(__assign(__assign({}, MODE.PATH), { description: this.props.pathDescription }));
        }
        if (this.props.showFileMode) {
            options.push(MODE.FILE);
        }
        if (this.props.showInputMode) {
            options.push(MODE.TEXT);
        }
        if (this.props.showSkipMode) {
            options.push(__assign({}, MODE.SKIP));
        }
        return options;
    };
    FileTextInput.prototype.renderPathInput = function () {
        return (React.createElement(CUIXInput, { trim: true, placeholder: this.props.pathPlaceholder, value: this.state.value, onChange: this.onValueChange, onBlur: this.onBlur }));
    };
    FileTextInput.prototype.renderTextInput = function () {
        return (React.createElement(TextArea, { rows: 4, placeholder: this.props.textPlaceholder, value: this.state.value, onChange: this.onValueChange, onBlur: this.onBlur }));
    };
    FileTextInput.prototype.renderFileInput = function () {
        var _this = this;
        var fileInputButtonText = this.props.fileInputButtonText;
        return (React.createElement(StyledFormInput, { role: "button", onClick: this.triggerFileInputClick, onKeyPress: this.triggerFileInputClick, tabIndex: "0" },
            React.createElement(CUIXInput, { disabled: true, value: this.state.fileName, style: { marginRight: 8, pointerEvents: 'none' } }),
            React.createElement(Button, null, fileInputButtonText),
            React.createElement("input", { type: "file", ref: function (ref) {
                    _this.fileInputNode = ref;
                }, onChange: this.onFileChange, style: {
                    position: 'absolute',
                    top: '-9999px'
                } })));
    };
    FileTextInput.prototype.render = function () {
        var id = this.props.id;
        return (React.createElement("div", { id: id },
            this.options.length > 1 && (React.createElement(Radio.Group, { value: this.state.mode, onChange: this.onModeChange }, this.options.map(function (option) { return (React.createElement(Radio, { key: option.name, value: option.name },
                React.createElement(Label, { info: option.description }, option.label))); }))),
            React.createElement("div", null,
                this.state.mode === MODE.PATH.name && this.renderPathInput(),
                this.state.mode === MODE.FILE.name && this.renderFileInput(),
                this.state.mode === MODE.TEXT.name && this.renderTextInput(),
                this.state.mode === MODE.SKIP.name && this.props.skipMessage)));
    };
    FileTextInput.propTypes = {
        /** ID of the input element. */
        id: PropTypes.string,
        /** Default shown mode for the input. */
        mode: PropTypes.string,
        /** Whether to show the path entry option. */
        showPathMode: PropTypes.bool,
        /** Whether to show the file upload option. */
        showFileMode: PropTypes.bool,
        /**
         * Whether to show the skip option. Skip option allows user to choose Skip from the radio selector
         * and skip entering any text.
         */
        showSkipMode: PropTypes.bool,
        /** Whether to show the text entry option. */
        showInputMode: PropTypes.bool,
        /** Function to call when input value changes */
        onChange: PropTypes.func,
        /** Function to call input is blurred */
        onBlur: PropTypes.func,
        /** Value of the input. */
        value: PropTypes.string,
        /** Placeholder for path input */
        pathPlaceholder: PropTypes.string,
        /** Placeholder for text input */
        textPlaceholder: PropTypes.string,
        /** Tooltip description for the path mode. */
        pathDescription: PropTypes.string,
        /** Message to display when user selects the skip option. */
        skipMessage: PropTypes.node,
        /**
         * Value to use in order to indicate the skip option is used. This is currently used to allow
         * a hack to get around the issue with leaving the input set to undefined when it is a required
         * field.
         */
        skipValue: PropTypes.string,
        /** Text for Button of File Input mode */
        fileInputButtonText: PropTypes.string
    };
    FileTextInput.defaultProps = {
        mode: MODE.FILE.name,
        showPathMode: false,
        showFileMode: true,
        showInputMode: true,
        showSkipMode: false,
        onChange: function () { },
        onBlur: function () { },
        pathPlaceholder: i18n.t('label.enterPath.placeholder'),
        textPlaceholder: i18n.t('label.directInput.placeholder'),
        fileInputButtonText: i18n.t('label.chooseFile')
    };
    return FileTextInput;
}(React.Component));
export default FileTextInput;
var templateObject_1;
