var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
// Copyright (c) 2023 Cloudera, Inc. All rights reserved.
import React from 'react';
import FacetDropdown from './FacetDropdown';
import MultipleValueFilter from './MultipleValueFilter';
import SingleValueFilter from './SingleValueFilter';
import SelectedValuesTooltip from './SelectedValuesTooltip';
import { toLabel } from './helpers';
var findItem = function (value, items) {
    return items.find(function (item) {
        if (typeof item === 'string') {
            return value === item;
        }
        if (item.key) {
            return value === item.key;
        }
        return value === item.value;
    });
};
var getItems = function (values, facet) {
    return values.map(function (value) {
        var item = findItem(value, facet.items);
        if (item) {
            return item;
        }
        else {
            throw new Error("Selected value ".concat(JSON.stringify(value), " not found in items for facet \"").concat(facet.label, "\""));
        }
    });
};
/**
 * A list of `FacetDropdown` or `CustomFacetDropdown` components.
 */
var FacetDropdownList = function (_a) {
    var facets = _a.facets, onChange = _a.onChange;
    return (React.createElement(React.Fragment, null, facets.map(function (facetState) {
        if (!facetState.facet) {
            return null;
        }
        var facet = facetState.facet, values = facetState.values, label = facetState.label, props = __rest(facetState, ["facet", "values", "label"]);
        if ('items' in facet) {
            var items_1 = facet.items, search_1 = facet.search, multiple_1 = facet.multiple;
            var initialItems = getItems(values, facet);
            if (!multiple_1) {
                return (React.createElement(FacetDropdown, __assign({ key: label, label: label, values: initialItems, onChange: onChange, dropdownRender: function (onChange, close) { return (React.createElement(SingleValueFilter, { key: label, label: label, items: items_1, values: values, search: search_1, onChange: onChange, onClose: close })); }, onClose: !props.isFixed
                        ? function () { return onChange({ label: label, show: false, values: [], open: false }); }
                        : undefined }, props)));
            }
            // multiple is truthy
            return (React.createElement(SelectedValuesTooltip, { key: label, values: initialItems.map(toLabel) },
                React.createElement(FacetDropdown, __assign({ label: label, values: initialItems, onChange: onChange, dropdownRender: function (onChange, close) { return (React.createElement(MultipleValueFilter, { onChange: onChange, close: close, values: values, label: label, items: items_1, search: search_1, apply: typeof multiple_1 === 'object' && multiple_1.apply })); }, onClose: !props.isFixed
                        ? function () { return onChange({ label: label, show: false, values: [], open: false }); }
                        : undefined }, props))));
        }
        var dropdownRender = facet.dropdownRender, _a = facet.toDisplayValue, toDisplayValue = _a === void 0 ? String : _a;
        return (React.createElement(SelectedValuesTooltip, { key: label, values: values },
            React.createElement(FacetDropdown, __assign({ label: label, values: values.map(toDisplayValue), onChange: onChange, dropdownRender: dropdownRender, onClose: !props.isFixed
                    ? function () { return onChange({ label: label, show: false, values: [], open: false }); }
                    : undefined }, props))));
    })));
};
export default FacetDropdownList;
