import React from 'react';
import { FilterOutput, BasicFacet, CustomFacet } from './types';
export declare const SEARCH_FACET_LABEL = "search";
interface Props {
    /**
     * If truthy, a dedicated text search box will be displayed. Its value will be
     * included in the filter output passed to `onChange()` as a property named
     * `search`. If another facet has the label `search`, it will overwrite this
     * value, so you should probably avoid that. You can customize the
     * search box placeholder by passing an object with a `placeholder` property.
     */
    search?: boolean | {
        placeholder?: string;
    };
    /**
     * Facets defined here will be removable.
     */
    facets?: (BasicFacet | CustomFacet)[];
    /**
     * Facets defined here will always be shown.
     */
    fixedFacets?: (BasicFacet | CustomFacet)[];
    /**
     * If true, an Apply button will be displayed when the filter state is dirty.
     * Changes to the filter as a whole will not be applied until this button
     * is clicked.
     */
    apply?: boolean;
    onChange?: (filter: FilterOutput) => void;
    /**
     * If true, the facet selection dropdown will include a search box.
     */
    facetSearch?: boolean;
}
/**
 * A filtering component and framework for facet-based filtering. These filter
 * types are supported "out of the box":
 * - Text search - renders a text input into which any search string can be
 *   typed.
 * - Single value selection - renders a dropdown from which a single value can
 *   be selected. For this type of facet, provide an `items` array property. Set
 *   the `search` property to `true` on the facet to render a search box.
 * - Multiple value selection - renders a dropdown from which multiple values
 *   can be selected. For this type of facet, provide an `items` array prop and
 *   set `multiple` to `true`. Set the `search` property to `true` on the facet
 *   to render a search box. To render batch operation and apply/cancel
 *   controls, set the `multiple` property to `{ apply: true }`.
 * - Custom - renders whatever filter component you provide via the
 *   `dropdownRender` prop of the facet.
 *
 * Via `onChange`, it outputs an object of the form:
 * `{
 *   facetLabel1: [value1, value2, value3, ...], facetLabel2: [value1, value2,
 *   value3, ...],
 *   ...
 * }`
 */
declare const Filter: React.FC<Props>;
export default Filter;
