var __makeTemplateObject = (this && this.__makeTemplateObject) || function (cooked, raw) {
    if (Object.defineProperty) { Object.defineProperty(cooked, "raw", { value: raw }); } else { cooked.raw = raw; }
    return cooked;
};
var __read = (this && this.__read) || function (o, n) {
    var m = typeof Symbol === "function" && o[Symbol.iterator];
    if (!m) return o;
    var i = m.call(o), r, ar = [], e;
    try {
        while ((n === void 0 || n-- > 0) && !(r = i.next()).done) ar.push(r.value);
    }
    catch (error) { e = { error: error }; }
    finally {
        try {
            if (r && !r.done && (m = i["return"])) m.call(i);
        }
        finally { if (e) throw e.error; }
    }
    return ar;
};
var __spreadArray = (this && this.__spreadArray) || function (to, from, pack) {
    if (pack || arguments.length === 2) for (var i = 0, l = from.length, ar; i < l; i++) {
        if (ar || !(i in from)) {
            if (!ar) ar = Array.prototype.slice.call(from, 0, i);
            ar[i] = from[i];
        }
    }
    return to.concat(ar || Array.prototype.slice.call(from));
};
// Copyright (c) 2023 Cloudera, Inc. All rights reserved.
import React, { useCallback, useEffect, useLayoutEffect, useMemo, useState } from 'react';
import Search from './Search';
import FacetDropdownList from './FacetDropdownList';
import i18n from "cuix/dist/utils/i18n";
import { cdlSpacingXxs } from "cuix/dist/styles/variables";
import styled from 'styled-components';
import LinkButton from '../Button/LinkButton';
import CloseIcon from '@cloudera/cuix-core/icons/react/CloseIcon';
import ResetIcon from '@cloudera/cuix-core/icons/react/ResetIcon';
import CheckmarkIcon from '@cloudera/cuix-core/icons/react/CheckmarkIcon';
import { areFilterStatesEqual, getClearedFilterState, getInitialFilterState, getNewFilterState, getOutput } from './helpers';
import FacetSelector from './FacetSelector';
import { useDebouncedCallback } from '@react-hookz/web/esm/useDebouncedCallback';
export var SEARCH_FACET_LABEL = 'search';
var getSearchValue = function (filter) {
    var searchFacet = filter.find(function (facet) { return facet.label === SEARCH_FACET_LABEL; });
    if (!searchFacet) {
        return '';
    }
    return searchFacet.values[0] || '';
};
//@ts-ignore styled-components typing doesn't include `search`
var FilterLayout = styled('search')(templateObject_1 || (templateObject_1 = __makeTemplateObject(["\n  display: flex;\n  align-items: center;\n  flex-wrap: wrap;\n  gap: ", ";\n"], ["\n  display: flex;\n  align-items: center;\n  flex-wrap: wrap;\n  gap: ", ";\n"])), cdlSpacingXxs);
/**
 * A filtering component and framework for facet-based filtering. These filter
 * types are supported "out of the box":
 * - Text search - renders a text input into which any search string can be
 *   typed.
 * - Single value selection - renders a dropdown from which a single value can
 *   be selected. For this type of facet, provide an `items` array property. Set
 *   the `search` property to `true` on the facet to render a search box.
 * - Multiple value selection - renders a dropdown from which multiple values
 *   can be selected. For this type of facet, provide an `items` array prop and
 *   set `multiple` to `true`. Set the `search` property to `true` on the facet
 *   to render a search box. To render batch operation and apply/cancel
 *   controls, set the `multiple` property to `{ apply: true }`.
 * - Custom - renders whatever filter component you provide via the
 *   `dropdownRender` prop of the facet.
 *
 * Via `onChange`, it outputs an object of the form:
 * `{
 *   facetLabel1: [value1, value2, value3, ...], facetLabel2: [value1, value2,
 *   value3, ...],
 *   ...
 * }`
 */
var Filter = function (_a) {
    var search = _a.search, facets = _a.facets, fixedFacets = _a.fixedFacets, apply = _a.apply, onChange = _a.onChange, facetSearch = _a.facetSearch;
    var initialSearch = useMemo(function () {
        if (!search) {
            return undefined;
        }
        return { label: SEARCH_FACET_LABEL, show: true, values: [] };
    }, [search]);
    var initialFilterState = useCallback(function () { return getInitialFilterState(initialSearch, facets, fixedFacets); }, [initialSearch, fixedFacets, facets]);
    var _b = __read(useState(initialFilterState), 2), appliedFilter = _b[0], setAppliedFilter = _b[1];
    var _c = __read(useState(initialFilterState), 2), selectedFilter = _c[0], setSelectedFilter = _c[1];
    var clearedFilterState = useMemo(function () { return getClearedFilterState(appliedFilter); }, [appliedFilter]);
    var _d = __read(useState(false), 2), showClearButton = _d[0], setShowClearButton = _d[1];
    var _e = __read(useState(false), 2), showResetButton = _e[0], setShowResetButton = _e[1];
    var _f = __read(useState(false), 2), showApplyButton = _f[0], setShowApplyButton = _f[1];
    // Clear button logic
    useEffect(function () {
        if ((facets && facets.length > 0) || (fixedFacets && (fixedFacets === null || fixedFacets === void 0 ? void 0 : fixedFacets.length) > 0)) {
            if (showApplyButton) {
                setShowClearButton(false);
            }
            else {
                setShowClearButton(!areFilterStatesEqual(appliedFilter, clearedFilterState));
            }
        }
    }, [facets, fixedFacets, showApplyButton, appliedFilter, clearedFilterState]);
    // Reset button logic
    var isInitialStateEqualToClearedState = useMemo(function () { return areFilterStatesEqual(initialFilterState(), clearedFilterState); }, [initialFilterState, clearedFilterState]);
    useEffect(function () {
        // If the initial state is the same as the cleared state, we never need to show the reset button
        if (isInitialStateEqualToClearedState) {
            setShowResetButton(false);
        }
        else {
            setShowResetButton(!areFilterStatesEqual(appliedFilter, initialFilterState()));
        }
    }, [isInitialStateEqualToClearedState, initialFilterState, clearedFilterState, appliedFilter]);
    // Apply (and Cancel) button logic
    useEffect(function () {
        if (!apply) {
            setShowApplyButton(false);
        }
        else {
            setShowApplyButton(!areFilterStatesEqual(appliedFilter, selectedFilter));
        }
    }, [apply, appliedFilter, selectedFilter]);
    var handleChange = useCallback(function () { return onChange === null || onChange === void 0 ? void 0 : onChange(getOutput(appliedFilter)); }, [onChange, appliedFilter]);
    useLayoutEffect(function () {
        handleChange();
    }, [handleChange]);
    var facetsToShow = selectedFilter.filter(function (facet) { return facet.show || facet.isFixed; });
    var moreFacets = selectedFilter.filter(function (facet) { return !facetsToShow.includes(facet); });
    var setAppliedFilterDebounced = useDebouncedCallback(setAppliedFilter, [setAppliedFilter], 250);
    var handleSearchChange = function (search) {
        var newSearchFacetState = {
            label: SEARCH_FACET_LABEL,
            show: true,
            values: [search]
        };
        var newFilterState = getNewFilterState(selectedFilter, newSearchFacetState);
        setSelectedFilter(newFilterState);
        if (!apply) {
            setAppliedFilterDebounced(newFilterState);
        }
    };
    return (React.createElement(FilterLayout, null,
        search && (React.createElement(Search, { placeholder: typeof search === 'boolean' ? undefined : search.placeholder, value: getSearchValue(selectedFilter), onChange: handleSearchChange })),
        (facetsToShow === null || facetsToShow === void 0 ? void 0 : facetsToShow.length) > 0 && (React.createElement(FacetDropdownList, { facets: facetsToShow, onChange: function (facetOutput) {
                var newFilterState = getNewFilterState(selectedFilter, facetOutput);
                setSelectedFilter(newFilterState);
                if (!apply) {
                    setAppliedFilterDebounced(newFilterState);
                }
            } })),
        moreFacets.length > 0 && (React.createElement(FacetSelector, { search: facetSearch, items: moreFacets
                .map(function (_a) {
                var label = _a.label;
                return ({
                    key: label,
                    label: label,
                    onClick: function () {
                        var newFilterState = getNewFilterState(selectedFilter, {
                            label: label,
                            show: true,
                            values: [],
                            open: true
                        });
                        setSelectedFilter(newFilterState);
                        if (!apply) {
                            setAppliedFilterDebounced(newFilterState);
                        }
                    }
                });
            })
                .sort(function (a, b) { return a.label.localeCompare(b.label); }), label: moreFacets.length === ((facets === null || facets === void 0 ? void 0 : facets.length) || 0) + ((fixedFacets === null || fixedFacets === void 0 ? void 0 : fixedFacets.length) || 0)
                ? i18n.t('label.filterBy')
                : i18n.t('label.more') })),
        showApplyButton && (React.createElement(React.Fragment, null,
            React.createElement(LinkButton, { icon: React.createElement(CheckmarkIcon, null), "data-event": "Apply filter", onClick: function () { return setAppliedFilterDebounced(__spreadArray([], __read(selectedFilter), false)); } }, i18n.t('label.apply')),
            React.createElement(LinkButton, { icon: React.createElement(CloseIcon, null), "data-event": "Cancel filter", onClick: function () { return setSelectedFilter(__spreadArray([], __read(appliedFilter), false)); } }, i18n.t('label.cancel')))),
        showResetButton && (React.createElement(LinkButton, { icon: React.createElement(ResetIcon, null), "data-event": "Reset filter", onClick: function () {
                var newFilterState = initialFilterState();
                setSelectedFilter(newFilterState);
                if (!apply) {
                    setAppliedFilterDebounced(newFilterState);
                }
            } }, i18n.t('label.reset'))),
        showClearButton && (React.createElement(LinkButton, { icon: React.createElement(CloseIcon, null), "data-event": "Clear filter", onClick: function () {
                var newFilterState = __spreadArray([], __read(clearedFilterState), false);
                setSelectedFilter(newFilterState);
                if (!apply) {
                    setAppliedFilterDebounced(newFilterState);
                }
            } }, i18n.t('label.clear')))));
};
export default Filter;
var templateObject_1;
