var __makeTemplateObject = (this && this.__makeTemplateObject) || function (cooked, raw) {
    if (Object.defineProperty) { Object.defineProperty(cooked, "raw", { value: raw }); } else { cooked.raw = raw; }
    return cooked;
};
var __read = (this && this.__read) || function (o, n) {
    var m = typeof Symbol === "function" && o[Symbol.iterator];
    if (!m) return o;
    var i = m.call(o), r, ar = [], e;
    try {
        while ((n === void 0 || n-- > 0) && !(r = i.next()).done) ar.push(r.value);
    }
    catch (error) { e = { error: error }; }
    finally {
        try {
            if (r && !r.done && (m = i["return"])) m.call(i);
        }
        finally { if (e) throw e.error; }
    }
    return ar;
};
// Copyright (c) 2023 Cloudera, Inc. All rights reserved.
import React, { useCallback, useEffect, useState } from 'react';
import { Checkbox } from 'antd';
import i18n from "cuix/dist/utils/i18n";
import { BorderlessButton, LinkButton, PrimaryButton } from '../Button';
import styled from 'styled-components';
import { Text } from "cuix/dist/components/Typography";
import { useDebouncedCallback } from '@react-hookz/web/esm/useDebouncedCallback';
import { getMatchingItems, toValue } from './helpers';
import FacetSearch from './FacetSearch';
import { FilterEmptyMessage } from './FilterEmptyMessage';
import { StyledFilterContainer } from './styledComponents';
import { cdlSpacingS, cdlSpacingXs, cdlSpacingXxs, cdlTextSmallLineHeight } from '@cloudera/cuix-core/variables';
import { borderColor } from './MultipleValueFilter.theme';
import { defaultTheme as theme } from "cuix/dist/styles/theme";
var MultipleValueFilterContainer = styled(StyledFilterContainer)(templateObject_1 || (templateObject_1 = __makeTemplateObject(["\n  max-height: 384px;\n  overflow: hidden;\n"], ["\n  max-height: 384px;\n  overflow: hidden;\n"])));
var Actions = styled(Text)(templateObject_2 || (templateObject_2 = __makeTemplateObject(["\n  &&& {\n    display: flex;\n    justify-content: space-between;\n    width: 100%;\n    padding: ", ";\n    border-bottom: 1px solid ", ";\n    margin: 0;\n  }\n"], ["\n  &&& {\n    display: flex;\n    justify-content: space-between;\n    width: 100%;\n    padding: ", ";\n    border-bottom: 1px solid ", ";\n    margin: 0;\n  }\n"])), cdlSpacingXxs, borderColor);
Actions.defaultProps = { theme: theme };
// Max height set to fit 6 items
var CheckboxGroup = styled(Checkbox.Group)(templateObject_3 || (templateObject_3 = __makeTemplateObject(["\n  max-height: 232px;\n  overflow: auto;\n  width: 100%;\n  display: block;\n  padding-top: ", ";\n  padding-bottom: ", ";\n"], ["\n  max-height: 232px;\n  overflow: auto;\n  width: 100%;\n  display: block;\n  padding-top: ", ";\n  padding-bottom: ", ";\n"])), cdlSpacingXxs, cdlSpacingXxs);
var CheckBoxWrapper = styled('div')(templateObject_4 || (templateObject_4 = __makeTemplateObject(["\n  display: flex;\n  align-items: center;\n  padding-left: ", ";\n  padding-right: ", ";\n  height: 36px;\n"], ["\n  display: flex;\n  align-items: center;\n  padding-left: ", ";\n  padding-right: ", ";\n  height: 36px;\n"])), cdlSpacingS, cdlSpacingS);
var Footer = styled('div')(templateObject_5 || (templateObject_5 = __makeTemplateObject(["\n  display: flex;\n  padding-bottom: ", ";\n  padding-left: ", ";\n  padding-right: ", ";\n  justify-content: space-between;\n  border-top: 1px solid ", ";\n  padding-top: ", ";\n"], ["\n  display: flex;\n  padding-bottom: ", ";\n  padding-left: ", ";\n  padding-right: ", ";\n  justify-content: space-between;\n  border-top: 1px solid ", ";\n  padding-top: ", ";\n"])), cdlSpacingXxs, cdlSpacingXxs, cdlSpacingXxs, borderColor, cdlSpacingXxs);
Footer.defaultProps = { theme: theme };
var getChecked = function (visible, selected, newlyChecked) {
    // get selected values that are hidden by the current search
    var hiddenSelected = selected.filter(function (value) { return !visible.includes(value); });
    return hiddenSelected.concat(newlyChecked);
};
var invert = function (visible, selected) {
    return visible.filter(function (value) { return !selected.includes(value); });
};
/**
 * A multiple value selection filter that includes a search box, "select all",
 * "invert selection", and "select none" buttons, and apply/cancel buttons.
 */
var MultipleValueFilter = function (_a) {
    var label = _a.label, name = _a.name, items = _a.items, search = _a.search, apply = _a.apply, onChange = _a.onChange, close = _a.close, values = _a.values;
    var initialValues = useCallback(function () {
        if (!values) {
            return [];
        }
        return values.map(toValue);
    }, [values]);
    var _b = __read(useState(items), 2), matchingItems = _b[0], setMatchingItems = _b[1];
    var _c = __read(useState(''), 2), searchString = _c[0], setSearchString = _c[1];
    var _d = __read(useState(initialValues), 2), selected = _d[0], setSelected = _d[1];
    var _e = __read(useState(initialValues), 2), applied = _e[0], setApplied = _e[1];
    useEffect(function () {
        onChange === null || onChange === void 0 ? void 0 : onChange({ label: name ? name : label, values: applied });
        // Excluding `onChange` to avoid infinite loop.
        // eslint-disable-next-line react-hooks/exhaustive-deps
    }, [name, label, applied]);
    var handleSearch = useDebouncedCallback(function (value) { return setMatchingItems(getMatchingItems(items, value)); }, [], 250);
    return (React.createElement(MultipleValueFilterContainer, { onClose: function () {
            if (apply) {
                setSelected(applied);
            }
        } },
        search && (React.createElement(FacetSearch, { value: searchString, onChange: function (event) {
                setSearchString(event.target.value);
                handleSearch(event.target.value);
            } })),
        apply && (React.createElement(Actions, { size: "small" },
            React.createElement(LinkButton, { "data-event": "facet select all", onClick: function () {
                    var checked = getChecked(matchingItems.map(toValue), selected, matchingItems.map(toValue));
                    setSelected(checked);
                }, style: { margin: 0, height: cdlTextSmallLineHeight } }, i18n.t('label.selectAll')),
            React.createElement(LinkButton, { "data-event": "facet invert selection", onClick: function () {
                    return setSelected(getChecked(matchingItems.map(toValue), selected, invert(matchingItems.map(toValue), selected)));
                }, style: {
                    marginLeft: cdlSpacingXs,
                    marginRight: cdlSpacingXs,
                    marginBottom: 0,
                    height: cdlTextSmallLineHeight
                } }, i18n.t('label.invertSelection')),
            React.createElement(LinkButton, { "data-event": "facet select none", onClick: function () { return setSelected(getChecked(matchingItems.map(toValue), selected, [])); }, style: { margin: 0, height: cdlTextSmallLineHeight } }, i18n.t('label.selectNone')))),
        (matchingItems === null || matchingItems === void 0 ? void 0 : matchingItems.length) > 0 ? (React.createElement(CheckboxGroup, { value: selected, onChange: function (value) {
                var checked = getChecked(matchingItems.map(toValue), selected, value);
                setSelected(checked);
                if (!apply) {
                    setApplied(checked);
                    close === null || close === void 0 ? void 0 : close();
                }
            } }, matchingItems.map(function (item) {
            if (typeof item === 'string') {
                return (React.createElement(CheckBoxWrapper, { key: item },
                    React.createElement(Checkbox, { value: item }, item)));
            }
            return (React.createElement(CheckBoxWrapper, { key: item.value },
                React.createElement(Checkbox, { value: item.value, disabled: item === null || item === void 0 ? void 0 : item.disabled }, item.display || item.label)));
        }))) : (React.createElement(FilterEmptyMessage, null)),
        apply && (React.createElement(Footer, null,
            React.createElement(PrimaryButton, { size: "small", "data-event": "apply facet filter", onClick: function () {
                    setApplied(selected);
                    close === null || close === void 0 ? void 0 : close();
                } }, i18n.t('label.apply')),
            React.createElement(BorderlessButton, { size: "small", "data-event": "clear facet filter", onClick: function () {
                    setSelected(applied);
                    close === null || close === void 0 ? void 0 : close();
                } }, i18n.t('label.cancel'))))));
};
export default MultipleValueFilter;
var templateObject_1, templateObject_2, templateObject_3, templateObject_4, templateObject_5;
