var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __read = (this && this.__read) || function (o, n) {
    var m = typeof Symbol === "function" && o[Symbol.iterator];
    if (!m) return o;
    var i = m.call(o), r, ar = [], e;
    try {
        while ((n === void 0 || n-- > 0) && !(r = i.next()).done) ar.push(r.value);
    }
    catch (error) { e = { error: error }; }
    finally {
        try {
            if (r && !r.done && (m = i["return"])) m.call(i);
        }
        finally { if (e) throw e.error; }
    }
    return ar;
};
var __spreadArray = (this && this.__spreadArray) || function (to, from, pack) {
    if (pack || arguments.length === 2) for (var i = 0, l = from.length, ar; i < l; i++) {
        if (ar || !(i in from)) {
            if (!ar) ar = Array.prototype.slice.call(from, 0, i);
            ar[i] = from[i];
        }
    }
    return to.concat(ar || Array.prototype.slice.call(from));
};
// Copyright (c) 2023 Cloudera, Inc. All rights reserved.
import { SEARCH_FACET_LABEL } from './Filter';
export var areFilterStatesEqual = function (a, b) {
    var _loop_1 = function (i) {
        var aFacet = a[i];
        var bFacet = b.find(function (facet) { return facet.label === aFacet.label; });
        if (!bFacet) {
            return { value: false };
        }
        var areValuesEqualLength = aFacet.values.length === bFacet.values.length;
        if (!areValuesEqualLength) {
            return { value: false };
        }
        var areValuesSelectedEqual = aFacet.values.every(function (value) { return bFacet.values.includes(value); });
        if (!areValuesSelectedEqual) {
            return { value: false };
        }
    };
    for (var i = 0; i < a.length; i++) {
        var state_1 = _loop_1(i);
        if (typeof state_1 === "object")
            return state_1.value;
    }
    return true;
};
export var getInitialFilterState = function (searchFacet, facets, fixedFacets) {
    var searchFacetState = searchFacet ? [searchFacet] : [];
    var fixedFacetsState = [];
    var facetsState = [];
    if (fixedFacets) {
        fixedFacetsState = fixedFacets.map(function (facet) { return ({
            label: facet.label,
            values: facet.initialValues || [],
            isFixed: true,
            facet: facet
        }); });
    }
    if (facets) {
        facetsState = facets.map(function (facet) { return ({
            label: facet.label,
            values: facet.initialValues || [],
            show: !!facet.initialValues,
            facet: facet
        }); });
    }
    return __spreadArray(__spreadArray(__spreadArray([], __read(searchFacetState), false), __read(fixedFacetsState), false), __read(facetsState), false);
};
export var getNewFilterState = function (oldFilterState, facetStateUpdate) {
    if (!facetStateUpdate) {
        return oldFilterState;
    }
    var oldFacetStateIndex = oldFilterState.findIndex(function (facetState) { return facetState.label === facetStateUpdate.label; });
    if (oldFacetStateIndex >= 0) {
        var oldFacetState = oldFilterState[oldFacetStateIndex];
        var newFacetState = __assign(__assign({}, oldFacetState), facetStateUpdate);
        if (!oldFacetState.show && !oldFacetState.isFixed) {
            // If facet was not previously selected, move it to the last position
            oldFilterState.splice(oldFacetStateIndex, 1);
            oldFilterState.push(newFacetState);
        }
        else {
            oldFilterState[oldFacetStateIndex] = newFacetState;
        }
    }
    else {
        throw new Error("Cannot update facet \"".concat(facetStateUpdate.label, "\". Facet not found in filter.") // This should be impossible
        );
    }
    return __spreadArray([], __read(oldFilterState), false);
};
var toClearedFacetState = function (facetState) {
    var clearedFacetState = __assign(__assign({}, facetState), { show: false, values: [] });
    if (facetState.label === SEARCH_FACET_LABEL || facetState.isFixed) {
        clearedFacetState.show = true;
    }
    return clearedFacetState;
};
export var getClearedFilterState = function (filterState) {
    return filterState.map(toClearedFacetState);
};
export var getOutput = function (filterState) {
    var filtered = filterState.filter(function (facetState) {
        return (facetState.show || facetState.isFixed) && facetState.values && facetState.values.length > 0;
    });
    var reduced = filtered.reduce(function (output, facet) {
        var _a;
        var _b;
        return __assign(__assign({}, output), (_a = {}, _a[((_b = facet.facet) === null || _b === void 0 ? void 0 : _b.name) ? facet.facet.name : facet.label] = facet.values, _a));
    }, {});
    return reduced;
};
export var toValue = function (item) { return (typeof item === 'string' ? item : item.value); };
export var isMatchingItem = function (item, search) {
    return toValue(item).toLowerCase().includes(search.trim().toLowerCase()) ||
        toLabel(item).toLowerCase().includes(search.trim().toLowerCase());
};
export var getMatchingItems = function (items, search) {
    return items.filter(function (item) { return isMatchingItem(item, search); });
};
export var toLabel = function (item) { return (typeof item === 'string' ? item : item.label); };
