import React, { PureComponent, ReactNode, CSSProperties } from 'react';
import { RowInfo, Column, Resize, ResizedChangeFunction, SortingRule, SortedChangeFunction } from 'react-table-v6';
import type { CheckboxChangeEvent } from 'antd/es/checkbox';
import { SimpleMap } from '../../types/types';
import 'react-table-v6/react-table.css';
import "./FlexTable.css";
export interface FlexTableCell {
    row: number;
    column: string;
}
export type { SortingRule } from 'react-table-v6';
export declare enum ColumnType {
    DURATION = "duration",
    MEMORY = "memory",
    BYTE_SECONDS = "byteSeconds",
    NUMBER = "number",
    STRING = "string",
    DATE = "date",
    PERCENT = "percent"
}
export declare enum ColumnAlign {
    LEFT = "left",
    CENTER = "center",
    RIGHT = "right"
}
/** Shows "Display 10 - 20 of 321" */
export declare const defaultShowTotal: (total: number, range: [number, number]) => React.ReactNode;
/** Shows "Display 10 - 20" */
export declare const showPageRangeOnly: (total: number, range: [number, number]) => React.ReactNode;
export declare type SorterFunction = (a: any, b: any) => any;
export declare type OnEditCompleteFunction = (value: any) => void;
export declare enum SortOrder {
    ASCEND = "ascend",
    DESCEND = "descend"
}
export interface FlexTableColumn<T> {
    className?: string;
    key?: string;
    dataIndex?: string;
    align?: ColumnAlign;
    render?: (value: any, record: T, index: number) => any;
    title?: React.ReactNode;
    width?: number;
    minWidth?: number;
    maxWidth?: number;
    sorter?: boolean | SorterFunction;
    defaultSortOrder?: SortOrder;
    type?: ColumnType;
    resizable?: boolean;
    editor?: (value: any, record: T, cell: FlexTableCell, onComplete: OnEditCompleteFunction) => ReactNode;
    children?: FlexTableColumn<T>[];
    hidden?: boolean;
    defaultSortDesc?: boolean;
}
export interface FlexTablePagination {
    defaultPageSize: number;
    showTotal: (total: number, range: [number, number]) => React.ReactNode;
    pageSizeOptions: string[];
    showSizeChanger: boolean;
    hideOnSinglePage: boolean;
    /** If using "manual" mode e.g we take control over sorting/pagination we can send the total item count */
    itemCount?: number;
}
export interface FlexTableRowSelection {
    onChange: (selectedRowKeys: string[]) => void;
    columnWidth?: number;
    selectedRowKeys?: string[];
}
export interface FlexTableProps<T> {
    className?: string;
    rowKey?: string;
    columns: Partial<FlexTableColumn<T>>[];
    dataSource: T[];
    pagination: boolean | Partial<FlexTablePagination>;
    resized?: Resize[];
    onResizedChange?: ResizedChangeFunction;
    highlightRows?: boolean;
    rowSelection?: FlexTableRowSelection;
    onEdit?: (newValue: any, oldValue: any, column: string, row: number) => void;
    RowWrapperComponent?: React.ReactType;
    style?: CSSProperties;
    loading?: boolean;
    manual?: boolean;
    onFetchData?: (state: any, instance: any) => void;
    sorted?: SortingRule[];
    onSortedChange?: SortedChangeFunction;
    /**
     * Override content that will be shown in table when there are no rows to be shown.
     * Will not be shown while `loading: true`.
     */
    noDataText?: React.ReactNode;
}
interface FlexTableState {
    current: number;
    editedCell?: FlexTableCell;
    dirtyCache: SimpleMap;
}
export default class FlexTable<T> extends PureComponent<FlexTableProps<T>, FlexTableState> {
    static defaultProps: {
        rowKey: string;
        pagination: {
            defaultPageSize: number;
            showTotal: (total: number, range: [number, number]) => React.ReactNode;
            pageSizeOptions: string[];
            showSizeChanger: boolean;
            hideOnSinglePage: boolean;
        };
        highlightRows: boolean;
    };
    state: FlexTableState;
    getCellKey: (cell: FlexTableCell) => string;
    isDirty: (cell: FlexTableCell) => boolean;
    getDirtyValue: (cell: FlexTableCell) => any;
    normalize: (columns: Partial<FlexTableColumn<T>>[]) => Column<any>[];
    onEditComplete: (newValue: any, oldValue: any, cell: FlexTableCell) => void;
    onEditRequest: (dataIndex: string, index: number) => void;
    componentDidUpdate(prevProps: FlexTableProps<T>): void;
    getPaginationProps: () => {
        defaultPageSize: number;
        showTotal: (total: number, range: [number, number]) => React.ReactNode;
        pageSizeOptions: string[];
        showSizeChanger: boolean;
        hideOnSinglePage: boolean;
    } | {
        pageSizeOptions: never[];
    };
    getTdProps: (_: any, rowInfo?: RowInfo, column?: Column<T>) => {
        className: string;
    } | {
        className?: undefined;
    };
    onSelectionChange: (rowKeyValue: string, event: CheckboxChangeEvent) => void;
    buildColumns(): Column<any>[];
    render(): JSX.Element;
}
