// Copyright (c) 2022 Cloudera, Inc. All rights reserved.
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
var __read = (this && this.__read) || function (o, n) {
    var m = typeof Symbol === "function" && o[Symbol.iterator];
    if (!m) return o;
    var i = m.call(o), r, ar = [], e;
    try {
        while ((n === void 0 || n-- > 0) && !(r = i.next()).done) ar.push(r.value);
    }
    catch (error) { e = { error: error }; }
    finally {
        try {
            if (r && !r.done && (m = i["return"])) m.call(i);
        }
        finally { if (e) throw e.error; }
    }
    return ar;
};
import React, { useCallback, useEffect, useMemo, useState } from 'react';
import FlexTable, { defaultShowTotal, showPageRangeOnly } from './FlexTable';
var defaultPageSize = 20;
/**
 * FlexTable with external sort (server side), but with local pagination.
 * Our FlexTable when set in "manual" mode (for external sort) also then delegates the
 * pagination to the parent component.
 **/
export var FlexTableWithExternalSort = function (_a) {
    var sort = _a.sort, setSort = _a.setSort, truncated = _a.truncated, dataSource = _a.dataSource, otherProps = __rest(_a, ["sort", "setSort", "truncated", "dataSource"]);
    var _b = __read(useState({ page: 0, pageSize: defaultPageSize }), 2), pagination = _b[0], setPagination = _b[1];
    // Since our table is in "manual" mode to support server side sorting
    // we have to take care of pagination ourselves since we do that client side.
    // This mirrors the table pagination.
    useEffect(function () {
        // When data changes (e.g. new sort which means the data can be all different since we only show
        // the first 500 items), we put the user back on page zero. This mirrors the table pagination.
        setPagination(function (prevState) { return (__assign(__assign({}, prevState), { page: 0 })); });
    }, [dataSource]);
    var pagedDataSource = useMemo(function () {
        return dataSource.slice(pagination.page * pagination.pageSize, (pagination.page + 1) * pagination.pageSize);
    }, [dataSource, pagination]);
    var sorted = useMemo(function () { return (sort ? [{ id: sort.col, desc: !sort.isAscending }] : []); }, [sort]);
    var onFetchData = useCallback(function (_a) {
        var page = _a.page, pageSize = _a.pageSize;
        setPagination({ page: page, pageSize: pageSize });
    }, []);
    var onSortedChange = useCallback(function (sorted) {
        if (sorted.length) {
            setSort(sorted[0].id, !sorted[0].desc);
        }
        else {
            setSort(undefined);
        }
    }, [setSort]);
    return (React.createElement(FlexTable, __assign({}, otherProps, { dataSource: pagedDataSource, manual: true, onFetchData: onFetchData, onSortedChange: onSortedChange, sorted: sorted, pagination: {
            itemCount: dataSource.length,
            showTotal: truncated ? showPageRangeOnly : defaultShowTotal
        } })));
};
