import React from 'react';
interface Props {
    /**
     * Content of tooltip. Also see `maxWidth`.
     */
    content: React.ReactNode;
    /**
     * Controls visiblity of tooltip.
     */
    visible: boolean;
    /**
     * The point or rect that we should align/point to. This can be either given in
     * page cordinates, viewport coordinates or relative coordinates.
     */
    pointAt: {
        x: number;
        y: number;
        width?: number;
        height?: number;
    };
    /**
     * Determines which frame of reference we use to understand the `pointAt` coordinates.
     *  - "parent": renders relative to the first position parent (aka offsetParent)
     *    of the tooltip
     *  - "viewport": renders relative to the viewport e.g. what you get when using
     *    `getBoundingClientRect()`
     *  - "page": renders relative to the document.
     *
     * The relationship between viewport and page is
     * `viewport = page + window.scroll`.
     */
    relativeTo?: 'parent' | 'viewport' | 'page';
    /**
     * Max width of the tooltip
     */
    maxWidth?: number;
    /**
     * Enable pointer events. We leave this disable by default as if the tooltip follow the mouse
     * you can easily move the mouse over the tooltip, which means if you rely on dom elements events
     * you'd loose them and the tooltip would briefly disapear.
     */
    pointerEvents?: boolean;
    /**
     * Distance from `pointAt` point/rect to the tooltip
     */
    pointToTooltipDistance?: number;
}
/**
 * Displays a floating/non-clickable tooltip. This can for example be used to show information when
 * hovering over graphs or dense structures, where Antd Popover/tooltip isn't sufficient.
 */
declare const FloatingTooltip: React.FC<Props>;
export default FloatingTooltip;
