import React from 'react';
import "@ant-design/compatible/lib/form/style/index.css";
import { CommonFormProps } from '../../utils/formUtils';
import { FormConfig } from '../../types/react-types';
import "./FormContainer.css";
import type { FormLayout } from 'antd/es/form/Form';
import type { ButtonProps } from 'antd/es/button';
interface CancelButtonProps extends ButtonProps {
    'data-event'?: string;
    'data-event-category'?: string;
}
interface Props<T> extends CommonFormProps<T> {
    /** Title of the form. */
    title: React.ReactNode;
    /** Whether to warn on unload */
    warnOnExit?: boolean;
    /** A function that gets called when user clicks Cancel. Can also be a URL string. */
    onCancel?: ((event: React.MouseEvent) => void) | string;
    /** Additional props to apply on the submit button. Anything specified by submitButtonProps will overwrite the defaults */
    submitButtonProps: ButtonProps;
    /** Additional props to apply on the cancel button. Anything specified by cancelButtonProps will overwrite the defaults */
    cancelButtonProps: CancelButtonProps;
    /**disableSubmit flag is for submit button if it true then submitbutton would be disabled and vice versa*/
    disableSubmit: boolean;
}
/**
 * Container component for a basic single page form. Constructs a formConfig object that contains
 * Ant's form object, methods to get initial values and validation rules, and a default layout (which
 * can be overriden for each field)
 *
 * This formConfig object is passed to each FormField instance when creating the form.
 */
declare class UnwrappedFormContainer<T = any> extends React.Component<Props<T>> {
    formConfig: FormConfig;
    constructor(props: Props<T>);
    debug: () => boolean;
    beforeUnload: (event: {
        preventDefault: () => void;
        returnValue: any;
    }) => any;
    componentDidMount(): void;
    componentWillUnmount(): void;
    onSubmit: (e: React.FormEvent) => void;
    render(): JSX.Element;
    static defaultProps: {
        submitText: string;
        cancelText: string;
        submitting: boolean;
        warnOnExit: boolean;
        layout: FormLayout;
    };
}
/**
 * @deprecated Uses old antd 3.x forms. See antd docs for current form usage.
 */
declare const FormContainer: import("@ant-design/compatible/lib/form/interface").ConnectedComponentClass<typeof UnwrappedFormContainer, import("@ant-design/compatible/lib/_util/types").Omit<import("@ant-design/compatible/lib/form").FormComponentProps<any>, "form">>;
export default FormContainer;
/**
 * @deprecated Uses old antd 3.x forms. See antd docs for current form usage.
 */
export declare const makeFormContainer: <T extends unknown>() => import("@ant-design/compatible/lib/form/interface").ConnectedComponentClass<{
    new (props: Props<T>): {
        formConfig: FormConfig;
        debug: () => boolean;
        beforeUnload: (event: {
            preventDefault: () => void;
            returnValue: any;
        }) => any;
        componentDidMount(): void;
        componentWillUnmount(): void;
        onSubmit: (e: React.FormEvent) => void;
        render(): JSX.Element;
        context: any;
        setState<K extends never>(state: {} | ((prevState: Readonly<{}>, props: Readonly<Props<T>>) => {} | Pick<{}, K> | null) | Pick<{}, K> | null, callback?: (() => void) | undefined): void;
        forceUpdate(callback?: (() => void) | undefined): void;
        readonly props: Readonly<Props<T>> & Readonly<{
            children?: React.ReactNode;
        }>;
        state: Readonly<{}>;
        refs: {
            [key: string]: React.ReactInstance;
        };
        shouldComponentUpdate?(nextProps: Readonly<Props<T>>, nextState: Readonly<{}>, nextContext: any): boolean;
        componentDidCatch?(error: Error, errorInfo: React.ErrorInfo): void;
        getSnapshotBeforeUpdate?(prevProps: Readonly<Props<T>>, prevState: Readonly<{}>): any;
        componentDidUpdate?(prevProps: Readonly<Props<T>>, prevState: Readonly<{}>, snapshot?: any): void;
        componentWillMount?(): void;
        UNSAFE_componentWillMount?(): void;
        componentWillReceiveProps?(nextProps: Readonly<Props<T>>, nextContext: any): void;
        UNSAFE_componentWillReceiveProps?(nextProps: Readonly<Props<T>>, nextContext: any): void;
        componentWillUpdate?(nextProps: Readonly<Props<T>>, nextState: Readonly<{}>, nextContext: any): void;
        UNSAFE_componentWillUpdate?(nextProps: Readonly<Props<T>>, nextState: Readonly<{}>, nextContext: any): void;
    };
    defaultProps: {
        submitText: string;
        cancelText: string;
        submitting: boolean;
        warnOnExit: boolean;
        layout: FormLayout;
    };
    contextType?: React.Context<any> | undefined;
}, import("@ant-design/compatible/lib/_util/types").Omit<Props<T>, "form">>;
