import React from 'react';
import { GetFieldDecoratorOptions } from '@ant-design/compatible/lib/form/Form';
import "@ant-design/compatible/lib/form/style/index.css";
import "./FormField.css";
import type { ColProps } from 'antd/es/col';
import { FormConfig } from "cuix/dist/types/react-types";
interface Props {
    /** Form config object provided by the form container. See formUtils.js for more information. */
    formConfig: FormConfig;
    /** Unique field name. Supports nested field format. E.g., name="user.lastName" */
    name?: string;
    /** Label text. */
    label?: string;
    /** Label description. If set, an info icon will be added after the label. */
    description?: string;
    /** When to validate the field value. */
    validateTrigger?: string | false;
    /**
     * If set to true, a checkbox is displayed and form field is hidden until user checks the
     * checkbox. A Checkbox node can also be passed in in order to customize the checkbox.
     */
    activateWithCheckbox?: boolean | React.ReactElement<any>;
    /**
     * Layout for the form field. If not present, defaultLayout property of the formConfig
     * will be used. Can be set to false to disable layout.
     */
    layout?: {
        wrapperCol?: ColProps;
        labelCol?: ColProps;
    } | false;
    /**
     * If rendering this field depends on the value of another field, you can pass the controlling field
     * name here to show/hide current field based on the controlling field's value.
     */
    controllingFieldName?: string;
    /**
     * Method to use when checking the value of the controllingField to determine whether to show
     * or hide this field. Defaults to value == true.
     * */
    controllingFieldActivationMethod?: (value: any) => boolean;
    /** Additional class name to add to the underlying Form.Item component. */
    className?: string;
    /** Allows to pass additional Antd FieldDecoratorOptions into internal call of getFieldDecorator(id, options) */
    fieldDecoratorOptions?: GetFieldDecoratorOptions;
    /** Extra help message similar to validation message that is always visible. */
    extra?: React.ReactNode;
    /** The input element to render when rendering this form field. */
    children: React.ReactElement<any>;
}
/**
 * Renders a Form.Item for the given Input along with its configuration. Expects a formConfig object
 * that stores Ant's form object along with some additional data (initial data, validation, etc).
 *
 * This component is meant to be used from *FormContainer components where the formConfig object
 * is available to you. It mainly simplifies Ant's process of creating and configuring a field and
 * some fields can still be created using Ant's default method, if needed.
 *
 * @deprecated Uses old antd 3.x forms. See antd docs for current form usage.
 */
export default class FormField extends React.Component<Props> {
    state: {
        activatingCheckboxChecked: undefined;
        activatingCheckboxTouched: boolean;
    };
    onActivatingCheckboxClick: (event: React.ChangeEvent<HTMLInputElement>) => void;
    isActivatingCheckboxChecked: () => boolean | undefined;
    getLabel: () => JSX.Element | undefined;
    getValidationRules: () => import("@ant-design/compatible/lib/form/Form").ValidationRule[] | undefined;
    getInitialValue: () => any;
    getInput: () => React.ReactElement<any, string | React.JSXElementConstructor<any>>;
    getActivatingCheckbox(): JSX.Element | null;
    getLayout: () => false | {
        wrapperCol?: ColProps | undefined;
        labelCol?: ColProps | undefined;
    } | undefined;
    /**
     * Returns true if we can render the field. This method will return false if the rendering of
     * this field is dependent on another field's value (specified in the controllingFieldName prop.)
     */
    canRender: () => boolean;
    render(): JSX.Element | null;
}
export {};
