var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (Object.prototype.hasOwnProperty.call(b, p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        if (typeof b !== "function" && b !== null)
            throw new TypeError("Class extends value " + String(b) + " is not a constructor or null");
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
// Copyright (c) 2018 Cloudera, Inc. All rights reserved.
import React from 'react';
import { Form } from '@ant-design/compatible';
import "@ant-design/compatible/lib/form/style/index.css";
import { Checkbox, Switch } from 'antd';
import i18n from '../../utils/i18n';
import get from 'lodash/get';
import omit from 'lodash/omit';
import Label from '../Label';
import SelectInput from "cuix/dist/components/SelectInput";
import classNames from 'classnames';
import "./FormField.css";
// List of props we want to process here and not pass through to Form.Item component
var FORM_FIELD_PROPS = [
    'name',
    'children',
    'layout',
    'extra',
    'formConfig',
    'label',
    'description',
    'validateTrigger',
    'activateWithCheckbox',
    'className',
    'controllingFieldName',
    'controllingFieldActivationMethod'
];
/**
 * Renders a Form.Item for the given Input along with its configuration. Expects a formConfig object
 * that stores Ant's form object along with some additional data (initial data, validation, etc).
 *
 * This component is meant to be used from *FormContainer components where the formConfig object
 * is available to you. It mainly simplifies Ant's process of creating and configuring a field and
 * some fields can still be created using Ant's default method, if needed.
 *
 * @deprecated Uses old antd 3.x forms. See antd docs for current form usage.
 */
var FormField = /** @class */ (function (_super) {
    __extends(FormField, _super);
    function FormField() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.state = { activatingCheckboxChecked: undefined, activatingCheckboxTouched: false };
        _this.onActivatingCheckboxClick = function (event) {
            var checked = event.target && event.target.checked;
            _this.setState({ activatingCheckboxChecked: !!checked, activatingCheckboxTouched: true });
        };
        _this.isActivatingCheckboxChecked = function () {
            var _a = _this.props, formConfig = _a.formConfig, name = _a.name;
            var _b = _this.state, activatingCheckboxChecked = _b.activatingCheckboxChecked, activatingCheckboxTouched = _b.activatingCheckboxTouched;
            if (activatingCheckboxTouched) {
                return activatingCheckboxChecked;
            }
            return name ? formConfig.getFieldCurrentValue(name) !== undefined : false;
        };
        _this.getLabel = function () {
            var _a = _this.props, label = _a.label, description = _a.description;
            if (!label) {
                return undefined;
            }
            return React.createElement(Label, { info: description }, label);
        };
        // Returns the validation rules for this field
        _this.getValidationRules = function () {
            var name = _this.props.name;
            if (!name) {
                return undefined;
            }
            var validationRules = _this.props.formConfig.validationRules;
            // Single rules can be passed in as an object so we convert to array here if needed.
            var rules = get(validationRules, name);
            rules = rules === undefined || Array.isArray(rules) ? rules : [rules];
            return rules;
        };
        // Returns the initial value for this field. getInitialValues is a function to handle cases
        // where initial data comes from component state (E.g., WizardFormContainer)
        _this.getInitialValue = function () {
            return _this.props.name ? get(_this.props.formConfig.getInitialValues(), _this.props.name) : undefined;
        };
        _this.getInput = function () {
            var _a = _this.props, formConfig = _a.formConfig, children = _a.children, name = _a.name, validateTrigger = _a.validateTrigger, _b = _a.fieldDecoratorOptions, fieldDecoratorOptions = _b === void 0 ? {} : _b;
            var input = children;
            var form = formConfig.form, popupContainerRef = formConfig.popupContainerRef;
            var _fieldDecoratorOptions = __assign({ validateFirst: true, rules: _this.getValidationRules(), initialValue: _this.getInitialValue(), validateTrigger: (validateTrigger === false ? false : validateTrigger || 'onBlur'), valuePropName: input.type === Checkbox || input.type === Switch ? 'checked' : 'value' }, fieldDecoratorOptions);
            if (input.type === SelectInput && !validateTrigger) {
                // When upgrading to ant 4.x the default onBlur validation on
                // SelectInput seem to clear the value instead of keeping it (at least when marked
                // as required).
                // Setting the validate trigger to undefined still seems to do validation
                // and it works. A lot of this might go away too if we use the new form
                // APIs in 4.x
                _fieldDecoratorOptions.validateTrigger = undefined;
            }
            if (popupContainerRef && input.type === SelectInput) {
                input = React.cloneElement(input, { popupContainerRef: popupContainerRef });
            }
            // Decorate input in order to connect it to form's store when name is present. IF name is not
            // provided, we assume caller is using FormField only for layout.
            if (name) {
                input = form.getFieldDecorator(name, _fieldDecoratorOptions)(input);
            }
            // If we don't cast it here, it seems that our current version of typescript generates
            // a declaration build (during the build.sh process) that has a syntax error/issue in it
            // so we can't use our code transform script to rewrite imports. By casting it here it
            // seems to fix the issue.
            return input;
        };
        _this.getLayout = function () {
            var _a = _this.props, layout = _a.layout, formConfig = _a.formConfig;
            return layout === undefined ? formConfig.defaultLayout : layout;
        };
        /**
         * Returns true if we can render the field. This method will return false if the rendering of
         * this field is dependent on another field's value (specified in the controllingFieldName prop.)
         */
        _this.canRender = function () {
            var _a = _this.props, formConfig = _a.formConfig, controllingFieldName = _a.controllingFieldName, controllingFieldActivationMethod = _a.controllingFieldActivationMethod;
            if (!controllingFieldName) {
                return true;
            }
            var controllingFieldValue = formConfig.getFieldCurrentValue(controllingFieldName);
            return controllingFieldActivationMethod
                ? controllingFieldActivationMethod(controllingFieldValue)
                : !!controllingFieldValue;
        };
        return _this;
    }
    FormField.prototype.getActivatingCheckbox = function () {
        var _a = this.props, activateWithCheckbox = _a.activateWithCheckbox, name = _a.name;
        if (!activateWithCheckbox) {
            return null;
        }
        var checkboxProps = {
            onChange: this.onActivatingCheckboxClick,
            checked: this.isActivatingCheckboxChecked()
        };
        return React.isValidElement(activateWithCheckbox) ? (React.cloneElement(activateWithCheckbox, checkboxProps)) : (
        // @ts-expect-error props type issues
        React.createElement(Checkbox, __assign({}, checkboxProps, { id: "show-".concat(name) })));
    };
    FormField.prototype.render = function () {
        var _a = this.props, className = _a.className, extra = _a.extra;
        var extraField = typeof extra === 'string' ? i18n.t(extra) : extra;
        var otherProps = omit(this.props, FORM_FIELD_PROPS);
        var checkbox = this.getActivatingCheckbox();
        if (!this.canRender()) {
            return null;
        }
        // getInput calls getFieldDecorator, which we don't want to call until we "canRender"
        // because we don't want to eagerly register form fields if they are hidden.
        var input = this.getInput();
        if (checkbox) {
            return (React.createElement(React.Fragment, null,
                React.createElement(Form.Item, __assign({ label: this.getLabel(), extra: extraField }, this.getLayout(), otherProps), checkbox),
                this.isActivatingCheckboxChecked() && (React.createElement(Form.Item, __assign({}, this.getLayout(), { label: " ", className: classNames(className, 'checkbox-activated-form-item') }), input))));
        }
        return (React.createElement(Form.Item, __assign({}, this.getLayout(), { label: this.getLabel(), extra: extraField, className: className }, otherProps), input));
    };
    return FormField;
}(React.Component));
export default FormField;
