import { CSSProperties, ReactElement } from 'react';
import { FormItemProps } from 'antd';
import type { FormListProps as AntdFormListProps } from 'antd/es/form';
import type { FormListFieldData } from 'antd/es/form/FormList';
import type { NamePath } from 'antd/es/form/interface';
import { ValidatorRule } from 'rc-field-form/es/interface';
export declare const getRequiredRule: <T extends unknown = string>(required?: boolean, requiredMessage?: string, isItemTouched?: ((value: T) => boolean) | undefined) => ValidatorRule;
export declare const getDuplicatesRule: (allowDuplicates?: boolean, noDuplicatesMessage?: string) => ValidatorRule;
export interface FormListOperationHandler {
    /**
     * Additional logic to run when a list item is added.
     */
    onAdd?: () => void;
    /**
     * Additional logic to run when a list item is moved.
     */
    onMove?: (oldIndex: number, newIndex: number) => void;
    /**
     * Additional logic to run when a list item is removed.
     */
    onRemove?: (index: number) => void;
}
export interface FormListProps<T = string> extends Pick<AntdFormListProps, 'rules'>, Omit<FormListOperationHandler, 'onMove'> {
    name: NamePath;
    /**
     * Returns a `Form.Item` component.
     */
    renderFormItem: (formItemProps: FormListFieldData & {
        style?: CSSProperties;
    }) => ReactElement<FormItemProps>;
    addButtonLabel?: string;
    /**
     * Used for the Remove button's Tooltip text and `aria-label`.
     */
    removeButtonLabel?: string;
    disableAdd?: boolean | ((values: T[]) => boolean);
    readOnly?: boolean;
    /**
     * If true, the field will be required. Note: To display the required mark,
     * you must also set `required` on the parent `Form.Item`.
     */
    required?: boolean;
    requiredMessage?: string;
    /**
     * @default false
     */
    allowDuplicates?: boolean;
    noDuplicatesMessage?: string;
    /**
     * Used to determine whether an item in the list should be considered
     * "touched". If there are untouched items, the Add button is disabled to
     * prevent creating multiple blank list items. The default is `value => value
     * !== undefined`.
     */
    isItemTouched?: (value: T) => boolean;
}
/**
 * Base component for `FormList`, etc. By providing different `mapper`
 * components via `renderMapper`, you can embellish the `Form.Item`s in the list
 * in different ways.
 */
declare const FormList: <T extends unknown = string>({ name, renderFormItem, addButtonLabel, removeButtonLabel, disableAdd, readOnly, required, requiredMessage, allowDuplicates, noDuplicatesMessage, rules, isItemTouched, onAdd, onRemove }: FormListProps<T>) => JSX.Element;
export default FormList;
