var __read = (this && this.__read) || function (o, n) {
    var m = typeof Symbol === "function" && o[Symbol.iterator];
    if (!m) return o;
    var i = m.call(o), r, ar = [], e;
    try {
        while ((n === void 0 || n-- > 0) && !(r = i.next()).done) ar.push(r.value);
    }
    catch (error) { e = { error: error }; }
    finally {
        try {
            if (r && !r.done && (m = i["return"])) m.call(i);
        }
        finally { if (e) throw e.error; }
    }
    return ar;
};
// Copyright (c) 2023 Cloudera, Inc. All rights reserved.
import React, { useRef, useState } from 'react';
import { cdlGridColumns, cdlGridColumnGutterWidthUnitless, cdlAppLayoutWidthMinUnitless } from "cuix/dist/styles/variables";
import { useResizeObserver } from '@react-hookz/web/esm/useResizeObserver';
/**
 * Get the width of an element that spans a given number of columns, given the
 * current column width.
 */
export var getColspanWidth = function (colspan, columnWidth, gutterWidth) {
    return columnWidth * colspan + gutterWidth * (colspan - 1);
};
/**
 * Get the current column width, given the total available width and the
 * provided constraints, less the `widthAdjustment`.
 */
export var getColumnWidth = function (
/**
 * The current width of the grid.
 */
gridWidth, 
/**
 * The number of grid columns.
 */
gridColumns, 
/**
 * The space between each grid column.
 */
gutterWidth) {
    var gutters = gutterWidth * (gridColumns - 1);
    return Math.round(((gridWidth - gutters) / gridColumns) * 10) / 10;
};
export var defaultGridContext = {
    columnWidth: getColumnWidth(cdlAppLayoutWidthMinUnitless, cdlGridColumns, cdlGridColumnGutterWidthUnitless)
};
/**
 * Typically, you should use this hook when providing a value to
 * `GridContext.Provider`.
 */
export var useGridContextValue = function (
/**
 * Ref attached to the grid container that the grid columns should respond to.
 */
ref, 
/**
 * If the element that `ref` is attached to is conditionally displayed, you
 * will probably need to pass the same boolean here so that the hook is
 * activated when the element is displayed.
 */
enabled) {
    var _a = __read(useState(defaultGridContext), 2), gridContextValue = _a[0], setGridContextValue = _a[1];
    if (typeof ref === 'function') {
        throw new Error('Ref for GridContext cannot be a function.');
    }
    useResizeObserver(ref, function () {
        if (ref && typeof ref !== 'function' && ref.current) {
            var columnWidth = getColumnWidth(ref.current.offsetWidth || cdlAppLayoutWidthMinUnitless, cdlGridColumns, cdlGridColumnGutterWidthUnitless);
            setGridContextValue({ columnWidth: columnWidth });
        }
    }, enabled);
    return gridContextValue;
};
/**
 * Stores information about the state of the CDL layout grid.
 */
var GridContext = React.createContext(defaultGridContext);
/**
 * Makes its children responsive by wrapping them in a container element and
 * providing a `GridContext` to its children that responds to the container.
 */
export var GridContextProvider = function (_a) {
    var children = _a.children;
    var ref = useRef(null);
    return (React.createElement("div", { ref: ref },
        React.createElement(GridContext.Provider, { value: useGridContextValue(ref) }, children)));
};
export default GridContext;
