// Copyright (c) 2022 Cloudera, Inc. All rights reserved.
import isIp from 'is-ip';
import isCidr from 'is-cidr';
import i18n from "cuix/dist/utils/i18n";
var isValid = function (value, _a) {
    var ip = _a.ip, cidr = _a.cidr, v4 = _a.v4, v6 = _a.v6;
    var isValidIp = false;
    var isValidCidr = false;
    if (ip) {
        if (v4 && v6) {
            isValidIp = isIp(value);
        }
        else if (v4) {
            isValidIp = isIp.v4(value);
        }
        else {
            // v6 === true
            isValidIp = isIp.v6(value);
        }
    }
    if (cidr) {
        if (v4 && v6) {
            isValidCidr = isCidr(value) ? true : false;
        }
        else if (v4) {
            isValidCidr = isCidr.v4(value);
        }
        else {
            // v6 === true
            isValidCidr = isCidr.v6(value);
        }
    }
    if (ip && cidr) {
        return isValidIp || isValidCidr;
    }
    if (ip) {
        return isValidIp;
    }
    // cidr === true
    return isValidCidr;
};
var getValidationError = function (_a) {
    var ip = _a.ip, cidr = _a.cidr, v4 = _a.v4, v6 = _a.v6;
    if (ip && cidr) {
        if (v4 && v6) {
            return i18n.t('error.ipCidrFormItem.ipCidr', ['IP']);
        }
        else if (v4) {
            return i18n.t('error.ipCidrFormItem.ipCidr', ['IPv4']);
        }
        // v6 === true
        return i18n.t('error.ipCidrFormItem.ipCidr', ['IPv6']);
    }
    if (ip) {
        if (v4 && v6) {
            return i18n.t('error.ipCidrFormItem.ip', ['IP']);
        }
        else if (v4) {
            return i18n.t('error.ipCidrFormItem.ip', ['IPv4']);
        }
        // v6 === true
        return i18n.t('error.ipCidrFormItem.ip', ['IPv6']);
    }
    /// cidr === true
    if (v4 && v6) {
        return i18n.t('error.ipCidrFormItem.cidr', ['CIDR']);
    }
    else if (v4) {
        return i18n.t('error.ipCidrFormItem.cidr', ['IPv4 CIDR']);
    }
    // v6 === true
    return i18n.t('error.ipCidrFormItem.cidr', ['IPv6 CIDR']);
};
var getIpCidrValidator = function (options) {
    if (options === void 0) { options = { ip: true, cidr: false, v4: true, v6: false }; }
    var ip = options.ip, cidr = options.cidr, v4 = options.v4, v6 = options.v6;
    if (!ip && !cidr) {
        throw new Error(i18n.t('error.ipCidrFormItem.ipCidrBothFalse'));
    }
    if (!v4 && !v6) {
        throw new Error(i18n.t('error.ipCidrFormItem.v4v6BothFalse'));
    }
    var validator = function (_rule, value) {
        if (!value) {
            return Promise.resolve();
        }
        return isValid(value, options)
            ? Promise.resolve()
            : Promise.reject(new Error(getValidationError(options)));
    };
    return validator;
};
export default getIpCidrValidator;
