import React, { PropsWithChildren, ReactNode } from 'react';
import { FormInstance, ModalProps } from 'antd';
interface Props<ValueType, ModalFormValuesType> extends Omit<ModalProps, 'visible' | 'onOk' | 'onCancel'> {
    /**
     * If you need access to the `FormInstance` used by the modal, you can provide
     * one; otherwise, a `FormInstance` will be created internally.
     */
    form?: FormInstance<ModalFormValuesType>;
    /**
     * A function that renders a component to represent the value of the
     * `ModalEditable` field.
     * @param showModal - a function that displays the modal
     * @param value - the current value of the field
     */
    displayContent: (showModal: () => void, value?: ValueType) => ReactNode;
    /**
     * A function that renders the content of the form that will be opened in a
     * modal to let you edit the field's value.
     * @param form - the `FormInstance` bound to the form that wraps the component
     * returned from this function
     */
    editFormContent: (form?: FormInstance) => ReactNode;
    /**
     * Called when the modal is opened. It will receive the value from the parent
     * form so that it can be modified before being used to populate the field
     * values in the modal form.
     */
    transformInputValuesForEdit?: (value?: ValueType) => ModalFormValuesType;
    /**
     * Called when the OK button of the modal is clicked. It will receive the
     * values from the modal form so that they can be modified before being passed
     * back to the parent form via `onChange`.
     */
    transformOutputValuesForDisplay?: (value: ModalFormValuesType) => ValueType;
    value?: ValueType;
    onChange?: (value: ValueType) => void;
}
/**
 * This component can be used when you want to render a value independently of
 * the control(s) used to edit it. When used in a form, `ModalEditable` should
 * be wrapped in a `Form.Item`. The value is editable via a form in a modal;
 * therefore, this component should not itself be used in a modal because CDL
 * does not support modals in a modal.
 */
declare const ModalEditable: <ValueType extends unknown, ModalFormValuesType extends unknown>({ form, displayContent, editFormContent, transformInputValuesForEdit, transformOutputValuesForDisplay, value, onChange, ...modalProps }: React.PropsWithChildren<Props<ValueType, ModalFormValuesType>>) => JSX.Element;
export default ModalEditable;
