import React from 'react';
import { ModalProps } from 'antd';
import type { FormLayout } from 'antd/es/form/Form';
export declare const DEFAULT_MODAL_FORM_HORIZONTAL_LAYOUT: {
    labelCol: {
        xs: {
            span: number;
        };
        sm: {
            span: number;
        };
    };
    wrapperCol: {
        xs: {
            span: number;
        };
        sm: {
            span: number;
        };
    };
};
/** This helper function can be called when a form is implemented so that the default formlayout and
 * the horizontal form layout render a proper display of the form
 * ```js
 *  <Form form={form}> layout={getModalFormLayout() .... </Form/>
 * ```
 */
export declare const getModalFormLayout: (layout?: FormLayout) => "vertical" | {
    labelCol: {
        xs: {
            span: number;
        };
        sm: {
            span: number;
        };
    };
    wrapperCol: {
        xs: {
            span: number;
        };
        sm: {
            span: number;
        };
    };
};
interface Props extends ModalProps {
    /** okButtonProps is overriden in order to make it easier to transform the components
     * which use the deprecated ModalFormContainer.
     */
    okButtonProps?: Record<string, any>;
    disableOkButton?: boolean;
    submitting?: boolean;
}
/** A lightweight form component that is as close to Ant's own form as possible,
 * offering some additional settings on top of it.
 * When you implement a form with this Modal wrapper, note a couple things:
 * 1. Initialize the form itself with const [form] = Form.useForm();
 * 2. Field validation should happen when submitting the form: https://ant.design/components/form/#validateFields-return-sample
 *
 * Example:
 *
 * ```js
 * const [form] = Form.useForm();
 * const onOk = () => {
 *   form.validateFields().then(values => {
 *     submitForm()
 *   });
 * };
 *
 * <ModalForm ... onOk={onOk}>
 *   <Form form={form}> .... </Form/>
 * </ModalForm>
 * ```
 */
declare const ModalForm: React.FC<Props>;
export default ModalForm;
