var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
// Copyright (c) 2022 Cloudera, Inc. All rights reserved.
import React from 'react';
import { Modal } from 'antd';
import i18n from '../../utils/i18n';
import Loading from '../Loading';
export var DEFAULT_MODAL_FORM_HORIZONTAL_LAYOUT = {
    labelCol: {
        xs: { span: 24 },
        sm: { span: 8 }
    },
    wrapperCol: {
        xs: { span: 24 },
        sm: { span: 16 }
    }
};
/** This helper function can be called when a form is implemented so that the default formlayout and
 * the horizontal form layout render a proper display of the form
 * ```js
 *  <Form form={form}> layout={getModalFormLayout() .... </Form/>
 * ```
 */
export var getModalFormLayout = function (layout) {
    if (!layout || layout === 'horizontal') {
        return DEFAULT_MODAL_FORM_HORIZONTAL_LAYOUT;
    }
    else {
        return 'vertical';
    }
};
/** A lightweight form component that is as close to Ant's own form as possible,
 * offering some additional settings on top of it.
 * When you implement a form with this Modal wrapper, note a couple things:
 * 1. Initialize the form itself with const [form] = Form.useForm();
 * 2. Field validation should happen when submitting the form: https://ant.design/components/form/#validateFields-return-sample
 *
 * Example:
 *
 * ```js
 * const [form] = Form.useForm();
 * const onOk = () => {
 *   form.validateFields().then(values => {
 *     submitForm()
 *   });
 * };
 *
 * <ModalForm ... onOk={onOk}>
 *   <Form form={form}> .... </Form/>
 * </ModalForm>
 * ```
 */
var ModalForm = function (_a) {
    var children = _a.children, okButtonProps = _a.okButtonProps, disableOkButton = _a.disableOkButton, submitting = _a.submitting, otherProps = __rest(_a, ["children", "okButtonProps", "disableOkButton", "submitting"]);
    return (React.createElement(Modal, __assign({ okButtonProps: okButtonProps ? okButtonProps : disableOkButton ? { disabled: true } : undefined, 
        // We disallow closing by clicking on mask to avoid the user accidentally closing the modal with input entered
        maskClosable: false, 
        // setting destroyOnClose to true means we don't need to deal with resetting the form or other states after closing it
        destroyOnClose: true, okText: i18n.t('label.save'), cancelText: i18n.t('label.cancel') }, otherProps, { "data-test": "ModalForm" }),
        submitting && React.createElement(Loading, { delay: 0 }),
        children));
};
export default ModalForm;
