import React from 'react';
import "@ant-design/compatible/lib/form/style/index.css";
import { CommonFormProps } from '../../utils/formUtils';
import { FormConfig } from '../../types/react-types';
import type { FormLayout } from 'antd/es/form/Form';
interface Props<T> extends CommonFormProps<T> {
    /**
     * children is used as a trigger the show to modal if provided. If not, modal is visible on
     * initial render.
     */
    children?: React.ReactNode;
    /** Title of the modal. */
    title: React.ReactNode;
    /** Disables Submit form button if form is not touched by user */
    disableOkIfNotTouched?: boolean;
    /** Whether to hide the form on submit. */
    hideOnSubmit?: boolean;
    /** Width of the modal. */
    width?: number;
    /** Custom footer for the modal. See Ant's documentation for more info. */
    footer?: React.ReactNode;
    /** Whether modal is visible. */
    visible?: boolean;
    /** A function that gets called when user clicks Cancel. */
    onCancel?: () => void;
    /** To disable submit button on Modal */
    disable?: boolean;
    okButtonProps?: Record<string, any>;
    /** To pass custom properties for Modal Form Cancel button */
    cancelButtonProps?: Record<string, any>;
}
/**
 * Container component for a modal form. Props are very similar to FormContainer.
 * @deprecated Uses old antd 3.x forms. See antd docs for current form usage.
 */
export declare class UnwrappedModalFormContainer<T> extends React.Component<Props<T>> {
    formConfig: FormConfig;
    constructor(props: Props<T>);
    onSubmit: (e: React.FormEvent) => void;
    isOkDisabled: () => boolean | undefined;
    render(): JSX.Element;
    static defaultProps: {
        submitText: string;
        cancelText: string;
        hideOnSubmit: boolean;
        submitting: boolean;
        disableOkIfNotTouched: boolean;
        layout: FormLayout;
        disable: boolean;
    };
}
/**
 * @deprecated Uses old antd 3.x forms. See antd docs for current form usage.
 */
declare const ModalFormContainer: import("@ant-design/compatible/lib/form/interface").ConnectedComponentClass<typeof UnwrappedModalFormContainer, import("@ant-design/compatible/lib/_util/types").Omit<Props<any>, "form">>;
export default ModalFormContainer;
