import React from 'react';
import { HierarchyPointLink, HierarchyPointNode } from '@visx/hierarchy/lib/types';
import { Extents } from '../types';
export interface FlexNode<Datum> extends HierarchyPointNode<Datum> {
    numChildren: number;
    hasChildren: boolean;
    noChildren: boolean;
    /** The number of nodes in this subtree. */
    length: number;
    /** The size of this node (the values fetched by the nodeSize accessor) as a two-element array. */
    size: number;
    xSize: number;
    ySize: number;
    top: number;
    bottom: number;
    left: number;
    right: number;
    /** The minimum top and left, and the maximum bottom and right values for all of the nodes in this subtree. */
    extents: Extents;
}
declare type NodeComponentProps<Datum> = {
    node: HierarchyPointNode<Datum>;
};
declare type LinkComponentProps<Datum> = {
    link: HierarchyPointLink<Datum>;
};
export declare type FlexTreeProps<Datum> = {
    /** The root hierarchy node from which to derive the tree layout. */
    data: Datum;
    /** Render override function which is passed the computed cluster layout data. */
    children?: (tree: FlexNode<Datum>) => React.ReactNode;
    /** top offset applied to the g element container. */
    top?: number;
    /** left offset applied to the g element container. */
    left?: number;
    /** className applied to the g element container. */
    className?: string;
    /** Function used to sort to the data before layout. */
    compareFunction?: (a: FlexNode<Datum>, b: FlexNode<Datum>) => number | undefined;
    /**
     * https://github.com/klortho/d3-flextree#children
     */
    childData?: (node: Datum) => null | Datum[];
    /**
     * https://github.com/klortho/d3-flextree#nodeSize
     */
    nodeSize?: [number, number] | ((node: FlexNode<Datum>) => [number, number]);
    /**
     * https://github.com/klortho/d3-flextree#spacing
     */
    spacing?: number | ((a: FlexNode<Datum>, b: FlexNode<Datum>) => number);
    /** Component which renders a single cluster link, passed the link object. */
    LinkComponent?: React.FC<LinkComponentProps<Datum>>;
    /** Component which renders a single cluster node, passed the node object. */
    NodeComponent?: React.FC<NodeComponentProps<Datum>>;
};
export default function FlexTree<Datum>({ top, left, className, data, compareFunction, childData, nodeSize, spacing, children, LinkComponent, NodeComponent }: FlexTreeProps<Datum>): JSX.Element;
export {};
