/*
 *    CLOUDERA Cloudera Data Platform
 *
 *    (C) Cloudera, Inc. 2021
 *    All rights reserved.
 *
 *    Applicable Open Source License: AGPLv3
 *
 *    NOTE: Cloudera open source products are modular software products
 *    made up of hundreds of individual components, each of which was
 *    individually copyrighted.  Each Cloudera open source product is a
 *    collective work under U.S. Copyright Law. Your license to use the
 *    collective work is as provided in your written agreement with
 *    Cloudera.  Used apart from the collective work, this file is
 *    licensed for your use pursuant to the open source license
 *    identified above.
 *
 *    This code is provided to you pursuant a written agreement with
 *    (i) Cloudera, Inc. or (ii) a third-party authorized to distribute
 *    this code. If you do not have a written agreement with Cloudera nor
 *    with an authorized and properly licensed third party, you do not
 *    have any rights to access nor to use this code.
 *
 *    Absent a written agreement with Cloudera, Inc. (“Cloudera”) to the
 *    contrary, A) CLOUDERA PROVIDES THIS CODE TO YOU WITHOUT WARRANTIES OF ANY
 *    KIND; (B) CLOUDERA DISCLAIMS ANY AND ALL EXPRESS AND IMPLIED
 *    WARRANTIES WITH RESPECT TO THIS CODE, INCLUDING BUT NOT LIMITED TO
 *    IMPLIED WARRANTIES OF TITLE, NON-INFRINGEMENT, MERCHANTABILITY AND
 *    FITNESS FOR A PARTICULAR PURPOSE; (C) CLOUDERA IS NOT LIABLE TO YOU,
 *    AND WILL NOT DEFEND, INDEMNIFY, NOR HOLD YOU HARMLESS FOR ANY CLAIMS
 *    ARISING FROM OR RELATED TO THE CODE; AND (D)WITH RESPECT TO YOUR EXERCISE
 *    OF ANY RIGHTS GRANTED TO YOU FOR THE CODE, CLOUDERA IS NOT LIABLE FOR ANY
 *    DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, PUNITIVE OR
 *    CONSEQUENTIAL DAMAGES INCLUDING, BUT NOT LIMITED TO, DAMAGES
 *    RELATED TO LOST REVENUE, LOST PROFITS, LOSS OF INCOME, LOSS OF
 *    BUSINESS ADVANTAGE OR UNAVAILABILITY, OR LOSS OR CORRUPTION OF
 *    DATA.
 */
import React from 'react';
import { Group } from '@visx/group';
import { HierarchyDefaultLink, HierarchyDefaultNode } from '@visx/hierarchy';
import cx from 'classnames';
import * as d3flextree from 'd3-flextree';
export default function FlexTree(_a) {
    var top = _a.top, left = _a.left, className = _a.className, data = _a.data, compareFunction = _a.compareFunction, childData = _a.childData, nodeSize = _a.nodeSize, spacing = _a.spacing, children = _a.children, _b = _a.LinkComponent, LinkComponent = _b === void 0 ? HierarchyDefaultLink : _b, _c = _a.NodeComponent, NodeComponent = _c === void 0 ? HierarchyDefaultNode : _c;
    var layout = d3flextree.flextree();
    layout.nodeSize(nodeSize || [0, 0]);
    if (childData) {
        layout.children(childData);
    }
    if (spacing) {
        layout.spacing(spacing);
    }
    var tree = layout(layout.hierarchy(data).sort(compareFunction));
    if (children) {
        return React.createElement(React.Fragment, null, children(tree));
    }
    return (React.createElement(Group, { top: top, left: left, className: cx('visx-tree', className) },
        LinkComponent &&
            tree.links().map(function (link, i) {
                return (React.createElement(Group, { key: "tree-link-".concat(i) },
                    React.createElement(LinkComponent, { link: link })));
            }),
        NodeComponent &&
            tree.descendants().map(function (node, i) {
                return (React.createElement(Group, { key: "tree-node-".concat(i) },
                    React.createElement(NodeComponent, { node: node })));
            })));
}
