/*
 *    CLOUDERA Cloudera Data Platform
 *
 *    (C) Cloudera, Inc. 2021
 *    All rights reserved.
 *
 *    Applicable Open Source License: AGPLv3
 *
 *    NOTE: Cloudera open source products are modular software products
 *    made up of hundreds of individual components, each of which was
 *    individually copyrighted.  Each Cloudera open source product is a
 *    collective work under U.S. Copyright Law. Your license to use the
 *    collective work is as provided in your written agreement with
 *    Cloudera.  Used apart from the collective work, this file is
 *    licensed for your use pursuant to the open source license
 *    identified above.
 *
 *    This code is provided to you pursuant a written agreement with
 *    (i) Cloudera, Inc. or (ii) a third-party authorized to distribute
 *    this code. If you do not have a written agreement with Cloudera nor
 *    with an authorized and properly licensed third party, you do not
 *    have any rights to access nor to use this code.
 *
 *    Absent a written agreement with Cloudera, Inc. (“Cloudera”) to the
 *    contrary, A) CLOUDERA PROVIDES THIS CODE TO YOU WITHOUT WARRANTIES OF ANY
 *    KIND; (B) CLOUDERA DISCLAIMS ANY AND ALL EXPRESS AND IMPLIED
 *    WARRANTIES WITH RESPECT TO THIS CODE, INCLUDING BUT NOT LIMITED TO
 *    IMPLIED WARRANTIES OF TITLE, NON-INFRINGEMENT, MERCHANTABILITY AND
 *    FITNESS FOR A PARTICULAR PURPOSE; (C) CLOUDERA IS NOT LIABLE TO YOU,
 *    AND WILL NOT DEFEND, INDEMNIFY, NOR HOLD YOU HARMLESS FOR ANY CLAIMS
 *    ARISING FROM OR RELATED TO THE CODE; AND (D)WITH RESPECT TO YOUR EXERCISE
 *    OF ANY RIGHTS GRANTED TO YOU FOR THE CODE, CLOUDERA IS NOT LIABLE FOR ANY
 *    DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, PUNITIVE OR
 *    CONSEQUENTIAL DAMAGES INCLUDING, BUT NOT LIMITED TO, DAMAGES
 *    RELATED TO LOST REVENUE, LOST PROFITS, LOSS OF INCOME, LOSS OF
 *    BUSINESS ADVANTAGE OR UNAVAILABILITY, OR LOSS OR CORRUPTION OF
 *    DATA.
 */
var __read = (this && this.__read) || function (o, n) {
    var m = typeof Symbol === "function" && o[Symbol.iterator];
    if (!m) return o;
    var i = m.call(o), r, ar = [], e;
    try {
        while ((n === void 0 || n-- > 0) && !(r = i.next()).done) ar.push(r.value);
    }
    catch (error) { e = { error: error }; }
    finally {
        try {
            if (r && !r.done && (m = i["return"])) m.call(i);
        }
        finally { if (e) throw e.error; }
    }
    return ar;
};
import React, { useState } from 'react';
import RectClipPath from '@visx/clip-path/lib/clip-paths/RectClipPath';
import { Group } from '@visx/group';
import { createMatrix } from '@visx/zoom';
import { Button } from 'antd';
import CollapseViewIcon from '@cloudera/cuix-core/icons/react/CollapseViewIcon';
import ExpandViewIcon from '@cloudera/cuix-core/icons/react/ExpandViewIcon';
import { DEPTH_SPACE, ICON_BUTTON_SIZE, MAX_NODE_HEIGHT, MIN_NODE_HEIGHT, NODE_WIDTH, TREE_PADDING } from '../utils/constants';
import { getNodeHeight } from '../utils/nodeHelpers';
import FlexTree from './FlexTree';
var MINIMAP_WIDTH = 360;
var MINIMAP_HEIGHT = 270;
var CORNER_RADIUS = 3;
var getMinimapScaleFactor = function (treeWidth, treeHeight) {
    return Math.min(MINIMAP_WIDTH / (treeWidth + TREE_PADDING + NODE_WIDTH / 2), MINIMAP_HEIGHT / (treeHeight + MAX_NODE_HEIGHT * 2));
};
var matrixToString = function (_a) {
    var scaleX = _a.scaleX, skewX = _a.skewX, skewY = _a.skewY, scaleY = _a.scaleY, translateX = _a.translateX, translateY = _a.translateY;
    return "matrix(".concat(scaleX, ", ").concat(skewY, ", ").concat(skewX, ", ").concat(scaleY, ", ").concat(translateX, ", ").concat(translateY, ")");
};
// Transform is expected to be of the form `matrix(${scaleX}, ${skewY}, ${skewX}, ${scaleY}, ${translateX}, ${translateY})`
var stringToMatrix = function (transform) {
    var values = transform.split(',').map(function (value) { return value.trim(); });
    return {
        scaleX: Number(values[0].split('(')[1]),
        skewY: Number(values[1]),
        skewX: Number(values[2]),
        scaleY: Number(values[3]),
        translateX: Number(values[4]),
        translateY: Number(values[5].split(')')[0])
    };
};
/**
 * Minimap view of the entire tree view to drag/view through
 */
var MiniMap = function (_a) {
    var data = _a.data, renderNode = _a.renderNode, renderLink = _a.renderLink, viewportWidth = _a.viewportWidth, viewportHeight = _a.viewportHeight, bbox = _a.bbox, compareFunction = _a.compareFunction, zoom = _a.zoom;
    var _b = __read(useState(true), 2), isMiniMapVisible = _b[0], setIsMiniMapVisible = _b[1];
    var zoomMatrix = stringToMatrix(zoom.toString());
    return (React.createElement(React.Fragment, null,
        isMiniMapVisible && (React.createElement(Group, { className: "minimap", transform: "translate(\n            ".concat(viewportWidth - 12 - MINIMAP_WIDTH, ",\n            ").concat(viewportHeight - 12 - MINIMAP_HEIGHT, "\n          )"), filter: "url(#drop-shadow)", "aria-label": "minimap" },
            React.createElement("filter", { id: "drop-shadow" },
                React.createElement("feDropShadow", { dy: "8", stdDeviation: "16", floodOpacity: "0.35" })),
            React.createElement(Group, { clipPath: "url(#zoom-clip)" },
                React.createElement(RectClipPath, { id: "zoom-clip", width: MINIMAP_WIDTH, height: MINIMAP_HEIGHT, rx: CORNER_RADIUS }),
                React.createElement("rect", { className: "minimap-bg", width: MINIMAP_WIDTH, height: MINIMAP_HEIGHT, rx: CORNER_RADIUS }),
                React.createElement(FlexTree, { data: data, compareFunction: compareFunction, nodeSize: function (node) { return [
                        getNodeHeight(node.data) + MIN_NODE_HEIGHT,
                        NODE_WIDTH + DEPTH_SPACE
                    ]; }, spacing: function (a, b) { return (a.parent === b.parent ? MIN_NODE_HEIGHT / 4 : MIN_NODE_HEIGHT); } }, function (tree) {
                    var scaleFactor = getMinimapScaleFactor(bbox.width, bbox.height);
                    var minimapTransform = createMatrix({
                        scaleX: scaleFactor,
                        scaleY: scaleFactor,
                        translateX: (TREE_PADDING + NODE_WIDTH / 2) * scaleFactor,
                        translateY: MINIMAP_HEIGHT / 2
                    });
                    return (React.createElement(Group, { transform: "".concat(matrixToString(minimapTransform)) },
                        (viewportWidth < (bbox.width + TREE_PADDING) * zoomMatrix.scaleX ||
                            viewportHeight < (bbox.height + TREE_PADDING) * zoomMatrix.scaleY) && (React.createElement("rect", { className: "minimap-viewbox-bg", width: viewportWidth, height: viewportHeight, transform: zoom.toStringInvert() })),
                        tree.links().map(function (link, i) { return renderLink({ key: "link-".concat(i), link: link }); }),
                        tree.descendants().map(function (node, i) {
                            return renderNode({
                                key: "node-".concat(i),
                                node: node,
                                isThumbnail: true,
                                showMenuButton: false
                            });
                        }),
                        (viewportWidth < (bbox.width + TREE_PADDING) * zoomMatrix.scaleX ||
                            viewportHeight < (bbox.height + TREE_PADDING) * zoomMatrix.scaleY) && (React.createElement("rect", { className: "minimap-viewbox-border", vectorEffect: "non-scaling-stroke", width: viewportWidth, height: viewportHeight, transform: zoom.toStringInvert() }))));
                })))),
        React.createElement("foreignObject", { width: ICON_BUTTON_SIZE, height: ICON_BUTTON_SIZE, transform: "\n          translate(\n            ".concat(viewportWidth - 12 - ICON_BUTTON_SIZE, ",\n            ").concat(viewportHeight - 12 - ICON_BUTTON_SIZE, "\n          )\n        ") },
            React.createElement(Button, { type: "text", style: {
                    width: ICON_BUTTON_SIZE,
                    height: ICON_BUTTON_SIZE,
                    padding: 0,
                    background: 'transparent',
                    position: 'fixed'
                }, onClick: function () { return setIsMiniMapVisible(!isMiniMapVisible); }, title: "".concat(isMiniMapVisible ? 'Hide' : 'Show', " MiniMap") },
                React.createElement("div", { style: { width: ICON_BUTTON_SIZE, height: ICON_BUTTON_SIZE, transform: 'scale(-1,1)' } }, isMiniMapVisible ? (React.createElement(CollapseViewIcon, { style: {
                        width: ICON_BUTTON_SIZE - 4,
                        height: ICON_BUTTON_SIZE - 4,
                        position: 'static'
                    } })) : (React.createElement(ExpandViewIcon, { style: {
                        width: ICON_BUTTON_SIZE - 4,
                        height: ICON_BUTTON_SIZE - 4,
                        position: 'static'
                    } })))))));
};
export default MiniMap;
