/*
 *    CLOUDERA Cloudera Data Platform
 *
 *    (C) Cloudera, Inc. 2021
 *    All rights reserved.
 *
 *    Applicable Open Source License: AGPLv3
 *
 *    NOTE: Cloudera open source products are modular software products
 *    made up of hundreds of individual components, each of which was
 *    individually copyrighted.  Each Cloudera open source product is a
 *    collective work under U.S. Copyright Law. Your license to use the
 *    collective work is as provided in your written agreement with
 *    Cloudera.  Used apart from the collective work, this file is
 *    licensed for your use pursuant to the open source license
 *    identified above.
 *
 *    This code is provided to you pursuant a written agreement with
 *    (i) Cloudera, Inc. or (ii) a third-party authorized to distribute
 *    this code. If you do not have a written agreement with Cloudera nor
 *    with an authorized and properly licensed third party, you do not
 *    have any rights to access nor to use this code.
 *
 *    Absent a written agreement with Cloudera, Inc. (“Cloudera”) to the
 *    contrary, A) CLOUDERA PROVIDES THIS CODE TO YOU WITHOUT WARRANTIES OF ANY
 *    KIND; (B) CLOUDERA DISCLAIMS ANY AND ALL EXPRESS AND IMPLIED
 *    WARRANTIES WITH RESPECT TO THIS CODE, INCLUDING BUT NOT LIMITED TO
 *    IMPLIED WARRANTIES OF TITLE, NON-INFRINGEMENT, MERCHANTABILITY AND
 *    FITNESS FOR A PARTICULAR PURPOSE; (C) CLOUDERA IS NOT LIABLE TO YOU,
 *    AND WILL NOT DEFEND, INDEMNIFY, NOR HOLD YOU HARMLESS FOR ANY CLAIMS
 *    ARISING FROM OR RELATED TO THE CODE; AND (D)WITH RESPECT TO YOUR EXERCISE
 *    OF ANY RIGHTS GRANTED TO YOU FOR THE CODE, CLOUDERA IS NOT LIABLE FOR ANY
 *    DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, PUNITIVE OR
 *    CONSEQUENTIAL DAMAGES INCLUDING, BUT NOT LIMITED TO, DAMAGES
 *    RELATED TO LOST REVENUE, LOST PROFITS, LOSS OF INCOME, LOSS OF
 *    BUSINESS ADVANTAGE OR UNAVAILABILITY, OR LOSS OR CORRUPTION OF
 *    DATA.
 */
var __values = (this && this.__values) || function(o) {
    var s = typeof Symbol === "function" && Symbol.iterator, m = s && o[s], i = 0;
    if (m) return m.call(o);
    if (o && typeof o.length === "number") return {
        next: function () {
            if (o && i >= o.length) o = void 0;
            return { value: o && o[i++], done: !o };
        }
    };
    throw new TypeError(s ? "Object is not iterable." : "Symbol.iterator is not defined.");
};
var __read = (this && this.__read) || function (o, n) {
    var m = typeof Symbol === "function" && o[Symbol.iterator];
    if (!m) return o;
    var i = m.call(o), r, ar = [], e;
    try {
        while ((n === void 0 || n-- > 0) && !(r = i.next()).done) ar.push(r.value);
    }
    catch (error) { e = { error: error }; }
    finally {
        try {
            if (r && !r.done && (m = i["return"])) m.call(i);
        }
        finally { if (e) throw e.error; }
    }
    return ar;
};
import "../styles/index.css";
import React, { useCallback, useEffect, useRef, useState } from 'react';
import RefreshIcon from '@cloudera/cuix-core/icons/react/RefreshIcon';
import { localPoint } from '@visx/event';
import { LinearGradient } from '@visx/gradient';
import { Group } from '@visx/group';
import { Button } from 'antd';
import { layoutHeaderHeight, fluidxGreen500, fluidxGreen050, cuixWarning5, cuixWarning0, cuixError5, cuixError0, fontSizeXl } from "cuix/dist/styles/variables";
import MenuPortal from '../../Portal/MenuPortal';
import { DEPTH_SPACE, DRAG_TOLERANCE, ICON_BUTTON_SIZE, MIN_NODE_HEIGHT, NODE_WIDTH, TREE_VIEW_CONTAINER_ID } from '../utils/constants';
import { getTreeViewContainer } from '../utils/helpers';
import { getNodeHeight, isNodeInTree } from '../utils/nodeHelpers';
import { nodeSort } from '../utils/sortHelpers';
import ControlBar from './ControlBar';
import FlexTree from './FlexTree';
import { LevelBars, LevelTitles } from './Levels';
import MiniMap from './MiniMap';
import NodeTree from './NodeTree';
import SvgZoomContainer from './SvgZoomContainer';
var onNodeClick = function (clickedNode, clickedElement, onMenuButtonClick, onToolTipButtonClick) {
    var clickedMenuButton = clickedElement.closest('.menu-button');
    onMenuButtonClick(clickedMenuButton ? clickedNode : null, clickedMenuButton);
    var clickedToolTipButton = clickedElement.closest('.tooltip-button');
    onToolTipButtonClick(clickedToolTipButton);
};
var getElementUnderZoomOverlay = function (x, y) {
    var firstElement = document.elementFromPoint(x, y);
    var targetElement;
    if ((firstElement === null || firstElement === void 0 ? void 0 : firstElement.id) === 'zoomOverlay') {
        var _display = firstElement.style.display;
        firstElement.style.display = 'none';
        targetElement = document.elementFromPoint(x, y);
        firstElement.style.display = _display;
    }
    else {
        targetElement = firstElement;
    }
    return targetElement;
};
var dragDistance = function (startPoint, endPoint) {
    if (!startPoint || !endPoint) {
        return 0;
    }
    var dx = Math.abs(startPoint.x - endPoint.x);
    var dy = Math.abs(startPoint.y - endPoint.y);
    return Math.max(dx, dy);
};
/**
 * Find the tree node associated with the HTML element having the given id.
 **/
var getTreeNode = function (node, id) {
    var e_1, _a;
    if (node.data.nodeData.path === id) {
        return node;
    }
    if (Array.isArray(node.children)) {
        try {
            for (var _b = __values(node.children), _c = _b.next(); !_c.done; _c = _b.next()) {
                var child = _c.value;
                var clickedTreeNode = getTreeNode(child, id);
                if (clickedTreeNode) {
                    return clickedTreeNode;
                }
            }
        }
        catch (e_1_1) { e_1 = { error: e_1_1 }; }
        finally {
            try {
                if (_c && !_c.done && (_a = _b.return)) _a.call(_b);
            }
            finally { if (e_1) throw e_1.error; }
        }
    }
    return undefined;
};
var getNodeSize = function (node) { return [
    getNodeHeight(node.data) + MIN_NODE_HEIGHT,
    NODE_WIDTH + DEPTH_SPACE
]; };
var getNodeSpacing = function (a, b) { return (a.parent === b.parent ? MIN_NODE_HEIGHT / 4 : MIN_NODE_HEIGHT); };
var NodeTreeView = function (_a) {
    var data = _a.data, renderNode = _a.renderNode, renderLink = _a.renderLink, renderMenu = _a.renderMenu, renderNodeThumbnail = _a.renderNodeThumbnail, renderLinkThumbnail = _a.renderLinkThumbnail, isReadOnly = _a.isReadOnly, sortOptions = _a.sortOptions, defaultSortOption = _a.defaultSortOption, onRefresh = _a.onRefresh, setNodeHeights = _a.setNodeHeights, customControl = _a.customControl;
    var _b = __read(useState(''), 2), searchText = _b[0], setSearchText = _b[1];
    var _c = __read(useState(defaultSortOption), 2), sortOption = _c[0], setSortOption = _c[1];
    var svgRef = useRef(null);
    var dragged = useRef(false);
    var dragStartPoint = useRef(null);
    var _d = __read(useState(), 2), activeNode = _d[0], setActiveNode = _d[1];
    var _e = __read(useState(), 2), menuSettings = _e[0], setMenuSettings = _e[1];
    var _f = __read(useState(), 2), tooltipSettings = _f[0], setTooltipSettings = _f[1];
    var clearPortals = useCallback(function () {
        setTooltipSettings(undefined);
        setMenuSettings(undefined);
    }, []);
    var clearAll = useCallback(function () {
        clearPortals();
        setActiveNode(undefined);
        setSearchText('');
    }, [clearPortals]);
    var mouseMoveTimer = useRef();
    var clearMouseMoveTimer = useCallback(function () {
        if (mouseMoveTimer.current) {
            mouseMoveTimer.current = window.clearTimeout(mouseMoveTimer.current);
        }
    }, []);
    useEffect(function () {
        var keyboardEventHandler = function (event) {
            if (event.key === 'Escape') {
                clearAll();
            }
        };
        document.addEventListener('keydown', keyboardEventHandler);
        return function () { return document.removeEventListener('keydown', keyboardEventHandler); };
    }, [clearAll]);
    // Clear the active node when there is a search.
    useEffect(function () {
        if (searchText) {
            setActiveNode(undefined);
        }
    }, [searchText]);
    // Clear the active node if it has been deleted.
    useEffect(function () {
        if (activeNode && !isNodeInTree(data, activeNode.path)) {
            setActiveNode(undefined);
        }
    }, [data, activeNode]);
    var onMenuButtonClick = function (node, menuButton) {
        if (node && menuButton) {
            menuButton.focus();
            clearMouseMoveTimer();
            setMenuSettings({ node: node, menuButton: menuButton });
        }
    };
    var onTooltipButtonClick = function (tooltipButton) {
        var nodeElement = tooltipButton === null || tooltipButton === void 0 ? void 0 : tooltipButton.closest('.node');
        if (nodeElement && tooltipButton) {
            tooltipButton.focus();
            clearMouseMoveTimer();
            setTooltipSettings({
                element: nodeElement,
                left: tooltipButton.getBoundingClientRect().left + 20,
                top: tooltipButton.getBoundingClientRect().top + 20
            });
        }
    };
    var compareFunction = useCallback(function (a, b) {
        return nodeSort(a.data.nodeData, b.data.nodeData, sortOption === null || sortOption === void 0 ? void 0 : sortOption.value);
    }, [sortOption]);
    return (React.createElement("div", { id: TREE_VIEW_CONTAINER_ID, style: { height: '100%' } },
        React.createElement(ControlBar, { searchText: searchText, onSearch: setSearchText, sortOptions: sortOptions, sortOption: sortOption, onSort: setSortOption, customControl: customControl }),
        React.createElement("div", { style: { width: '100%', height: "calc(100% - ".concat(layoutHeaderHeight, ")") } },
            React.createElement(SvgZoomContainer, { data: data, svgRef: svgRef }, function (zoom, width, height, bbox) { return (React.createElement("svg", { className: "tree", style: {
                    cursor: zoom ? (zoom.isDragging ? 'grabbing' : 'grab') : 'default'
                } },
                React.createElement(LinearGradient, { id: "linkFillGradient", from: fluidxGreen500, to: fluidxGreen050, x2: "1", y2: "0" }),
                React.createElement(LinearGradient, { id: "linkFillWarningGradient", from: cuixWarning5, to: cuixWarning0, x2: "1", y2: "0" }),
                React.createElement(LinearGradient, { id: "linkFillDangerGradient", from: cuixError5, to: cuixError0, x2: "1", y2: "0" }),
                React.createElement(FlexTree, { data: data, childData: function (data) { return data.children || null; }, compareFunction: compareFunction, nodeSize: getNodeSize, spacing: getNodeSpacing }, function (data) {
                    if (setNodeHeights) {
                        setNodeHeights(data);
                    }
                    return (React.createElement("g", null,
                        renderMenu && menuSettings && (React.createElement(MenuPortal, { data: menuSettings.node, menuTrigger: menuSettings.menuButton, onClick: clearPortals, onClickOutside: clearPortals, getParentElement: getTreeViewContainer, renderMenu: renderMenu })),
                        React.createElement(LevelBars, { levels: data.height, height: height, zoom: zoom }),
                        React.createElement(Group, { id: "tree", innerRef: svgRef, transform: zoom === null || zoom === void 0 ? void 0 : zoom.toString() },
                            React.createElement(NodeTree, { data: data, renderNode: renderNode, renderLink: renderLink, showMenuButton: !!renderMenu, isReadOnly: isReadOnly, searchText: searchText, activeNode: activeNode, menuSettings: menuSettings, tooltipSettings: tooltipSettings })),
                        zoom && (React.createElement("rect", { id: "zoomOverlay", "data-test": "zoomOverlay", width: width, height: height, fill: "transparent", onWheel: clearPortals, onMouseDown: function (event) {
                                dragStartPoint.current = localPoint(event);
                                zoom.dragStart(event);
                            }, onMouseMove: function (event) {
                                // `event.persist()` is supposedly not needed if using React >= 17, since event pooling is no longer used.
                                // (see https://reactjs.org/blog/2020/08/10/react-v17-rc.html#no-event-pooling)
                                event.persist();
                                if (zoom.isDragging &&
                                    dragDistance(dragStartPoint.current, localPoint(event)) >
                                        DRAG_TOLERANCE) {
                                    clearPortals();
                                    dragged.current = true;
                                    zoom.dragMove(event);
                                }
                                // Hide any visible tooltip if mouse moved outside its node.
                                if (tooltipSettings) {
                                    var hoveredElement = getElementUnderZoomOverlay(event.clientX, event.clientY);
                                    var hoveredNodeElement = hoveredElement === null || hoveredElement === void 0 ? void 0 : hoveredElement.closest('.node');
                                    if (hoveredNodeElement !== tooltipSettings.element) {
                                        window.setTimeout(function () {
                                            setTooltipSettings(undefined);
                                        }, 200);
                                    }
                                }
                                // Detect when mouse doesn't move for long enough to trigger a tooltip.
                                clearMouseMoveTimer();
                                mouseMoveTimer.current = window.setTimeout(function () {
                                    var hoveredElement = getElementUnderZoomOverlay(event.clientX, event.clientY);
                                    var hoveredNodeElement = hoveredElement === null || hoveredElement === void 0 ? void 0 : hoveredElement.closest('.node');
                                    if (hoveredNodeElement && !menuSettings) {
                                        setTooltipSettings({
                                            element: hoveredNodeElement,
                                            left: event.clientX,
                                            top: event.clientY
                                        });
                                    }
                                }, 1000);
                            }, onMouseUp: function () {
                                zoom.dragEnd();
                                dragStartPoint.current = null;
                            }, onClick: function (event) {
                                if (dragged.current === true) {
                                    dragged.current = false;
                                }
                                else {
                                    var clickedElement = getElementUnderZoomOverlay(event.clientX, event.clientY);
                                    var clickedNodeElement = clickedElement === null || clickedElement === void 0 ? void 0 : clickedElement.closest('.node');
                                    clearPortals();
                                    if (clickedNodeElement) {
                                        var clickedTreeNode = getTreeNode(data, clickedNodeElement.id);
                                        if (clickedTreeNode) {
                                            setSearchText('');
                                            setActiveNode(clickedTreeNode.data.nodeData);
                                            onNodeClick(clickedTreeNode, clickedElement, onMenuButtonClick, onTooltipButtonClick);
                                        }
                                    }
                                    else {
                                        setActiveNode(undefined);
                                    }
                                }
                            }, onDoubleClick: function (event) {
                                var point = localPoint(event) || {
                                    x: 0,
                                    y: 0
                                };
                                zoom.scale({ scaleX: 1.1, scaleY: 1.1, point: point });
                            } })),
                        React.createElement(LevelTitles, { levels: data.height, width: width, zoom: zoom })));
                }),
                React.createElement("foreignObject", { width: ICON_BUTTON_SIZE, height: ICON_BUTTON_SIZE, transform: "translate(".concat(width ? width - 32 : 32, ", 32)") },
                    React.createElement(Button, { type: "text", style: {
                            padding: 0,
                            width: ICON_BUTTON_SIZE,
                            height: ICON_BUTTON_SIZE,
                            background: 'transparent',
                            position: 'fixed'
                        }, onClick: onRefresh, icon: React.createElement(RefreshIcon, { style: { fontSize: fontSizeXl } }), title: "Refresh" })),
                zoom && bbox && width && height && (React.createElement(MiniMap, { data: data, renderNode: renderNodeThumbnail || renderNode, renderLink: renderLinkThumbnail || renderLink, viewportWidth: width, viewportHeight: height, bbox: bbox, compareFunction: compareFunction, zoom: zoom })))); }))));
};
export default NodeTreeView;
