/*
 *    CLOUDERA Cloudera Data Platform
 *
 *    (C) Cloudera, Inc. 2021
 *    All rights reserved.
 *
 *    Applicable Open Source License: AGPLv3
 *
 *    NOTE: Cloudera open source products are modular software products
 *    made up of hundreds of individual components, each of which was
 *    individually copyrighted.  Each Cloudera open source product is a
 *    collective work under U.S. Copyright Law. Your license to use the
 *    collective work is as provided in your written agreement with
 *    Cloudera.  Used apart from the collective work, this file is
 *    licensed for your use pursuant to the open source license
 *    identified above.
 *
 *    This code is provided to you pursuant a written agreement with
 *    (i) Cloudera, Inc. or (ii) a third-party authorized to distribute
 *    this code. If you do not have a written agreement with Cloudera nor
 *    with an authorized and properly licensed third party, you do not
 *    have any rights to access nor to use this code.
 *
 *    Absent a written agreement with Cloudera, Inc. (“Cloudera”) to the
 *    contrary, A) CLOUDERA PROVIDES THIS CODE TO YOU WITHOUT WARRANTIES OF ANY
 *    KIND; (B) CLOUDERA DISCLAIMS ANY AND ALL EXPRESS AND IMPLIED
 *    WARRANTIES WITH RESPECT TO THIS CODE, INCLUDING BUT NOT LIMITED TO
 *    IMPLIED WARRANTIES OF TITLE, NON-INFRINGEMENT, MERCHANTABILITY AND
 *    FITNESS FOR A PARTICULAR PURPOSE; (C) CLOUDERA IS NOT LIABLE TO YOU,
 *    AND WILL NOT DEFEND, INDEMNIFY, NOR HOLD YOU HARMLESS FOR ANY CLAIMS
 *    ARISING FROM OR RELATED TO THE CODE; AND (D)WITH RESPECT TO YOUR EXERCISE
 *    OF ANY RIGHTS GRANTED TO YOU FOR THE CODE, CLOUDERA IS NOT LIABLE FOR ANY
 *    DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, PUNITIVE OR
 *    CONSEQUENTIAL DAMAGES INCLUDING, BUT NOT LIMITED TO, DAMAGES
 *    RELATED TO LOST REVENUE, LOST PROFITS, LOSS OF INCOME, LOSS OF
 *    BUSINESS ADVANTAGE OR UNAVAILABILITY, OR LOSS OR CORRUPTION OF
 *    DATA.
 */
var __read = (this && this.__read) || function (o, n) {
    var m = typeof Symbol === "function" && o[Symbol.iterator];
    if (!m) return o;
    var i = m.call(o), r, ar = [], e;
    try {
        while ((n === void 0 || n-- > 0) && !(r = i.next()).done) ar.push(r.value);
    }
    catch (error) { e = { error: error }; }
    finally {
        try {
            if (r && !r.done && (m = i["return"])) m.call(i);
        }
        finally { if (e) throw e.error; }
    }
    return ar;
};
import React, { useEffect, useState } from 'react';
import { withParentSize } from '@visx/responsive';
import { createMatrix, Zoom } from '@visx/zoom';
import { HEADER_HEIGHT, NODE_WIDTH, TREE_PADDING } from '../utils/constants';
var getSvgBbox = function (svg) {
    var _a;
    return ((_a = svg === null || svg === void 0 ? void 0 : svg.getBBox) === null || _a === void 0 ? void 0 : _a.call(svg)) || {
        width: 0,
        height: 0,
        x: 0,
        y: 0
    };
};
var SvgZoomContainer = function (_a) {
    var data = _a.data, svgRef = _a.svgRef, parentWidth = _a.parentWidth, parentHeight = _a.parentHeight, children = _a.children;
    var _b = __read(useState(getSvgBbox(svgRef.current)), 2), bbox = _b[0], setBbox = _b[1];
    useEffect(function () { return setBbox(getSvgBbox(svgRef.current)); }, [data, svgRef]);
    if (!parentWidth || !parentHeight) {
        return null;
    }
    var initialTranslateX = TREE_PADDING + NODE_WIDTH / 2;
    var initialTranslateY = (parentHeight + HEADER_HEIGHT) / 2;
    var initialTransform = createMatrix({
        translateX: initialTranslateX,
        translateY: initialTranslateY
    });
    var constrain = function (transformMatrix, prevTransformMatrix) {
        // This is the default visx logic.
        var scaleXMin = 0.25;
        var scaleXMax = 1;
        var scaleYMin = 0.25;
        var scaleYMax = 1;
        var scaleX = transformMatrix.scaleX, scaleY = transformMatrix.scaleY;
        var shouldConstrainScaleX = scaleX > scaleXMax || scaleX < scaleXMin;
        var shouldConstrainScaleY = scaleY > scaleYMax || scaleY < scaleYMin;
        if (shouldConstrainScaleX || shouldConstrainScaleY) {
            return prevTransformMatrix;
        }
        // Additional logic starts here.
        // Ensure that if we are close to 1:1, we actually get there.
        if (scaleX > 0.95) {
            transformMatrix.scaleX = 1;
        }
        if (scaleY > 0.95) {
            transformMatrix.scaleY = 1;
        }
        // Constrain the panning area.
        // Calculate how much the content can be panned horizontally.
        var translateXMax = initialTranslateX * transformMatrix.scaleX;
        var rightOverflow = Math.max((bbox.width + TREE_PADDING) * transformMatrix.scaleX - parentWidth, 0);
        var translateXMin = translateXMax - rightOverflow;
        transformMatrix.translateX = Math.max(translateXMin, Math.min(transformMatrix.translateX, translateXMax));
        // Calculate how much the content can be panned vertically in either direction.
        var topHalfHeight = Math.abs(bbox.y);
        var topOverflow = Math.max(topHalfHeight * transformMatrix.scaleY - parentHeight / 2, 0);
        var bottomHalfHeight = bbox.height - topHalfHeight;
        var bottomOverflow = Math.max(bottomHalfHeight * transformMatrix.scaleY - parentHeight / 2, 0);
        var translateYMin = initialTranslateY - (bottomOverflow + TREE_PADDING * transformMatrix.scaleY);
        var translateYMax = initialTranslateY + topOverflow + TREE_PADDING * transformMatrix.scaleY;
        transformMatrix.translateY = Math.max(translateYMin, Math.min(transformMatrix.translateY, translateYMax));
        return transformMatrix;
    };
    return (React.createElement(Zoom, { className: "zoom", width: parentWidth, height: parentHeight, transformMatrix: initialTransform, constrain: constrain }, function (zoom) { return children(zoom, parentWidth, parentHeight, bbox); }));
};
// Used the withParentSize HOC instead of the hook because the hook
// was not updating the width and height properly. Maybe a visx bug?
var responsiveSvgZoomContainer = function () {
    return withParentSize(SvgZoomContainer);
};
export default responsiveSvgZoomContainer();
