import React from 'react';
import { HierarchyPointLink, HierarchyPointNode } from '@visx/hierarchy/lib/types';
import { Point, ProvidedZoom, TransformMatrix } from '@visx/zoom/lib/types';
interface ZoomState {
    isDragging: boolean;
    transformMatrix: TransformMatrix;
}
export declare type ZoomProvider = ProvidedZoom & ZoomState;
export interface Bbox {
    width: number;
    height: number;
    x: number;
    y: number;
}
export interface MenuSettings<T extends NodeData> {
    node: TreeLayoutNode<T>;
    menuButton: HTMLElement;
}
export interface TooltipSettings {
    element: HTMLElement;
    left: number;
    top: number;
}
export interface NodeSortOrder {
    id: string;
    valueType: 'string' | 'number';
    getValue: Function;
    invert?: boolean;
}
export interface NodeSortOption {
    value: NodeSortOrder;
    label: string;
}
export interface Extents {
    top: number;
    bottom: number;
    left: number;
    right: number;
}
export interface CornerPoints {
    topLeft: Point;
    bottomLeft: Point;
    topRight: Point;
    bottomRight: Point;
}
export interface NodeData {
    path: string;
    name: string;
    parentPath?: string;
    tags?: any[];
}
export interface TreeVisualNode<T extends NodeData> {
    nodeData: T;
    children: this[];
    height?: number;
    width?: number;
    isPending?: boolean;
    isDimmed?: boolean;
    isActive?: boolean;
}
export declare type TreeLayoutNode<T extends NodeData> = HierarchyPointNode<TreeVisualNode<T>>;
export declare type TreeLayoutLink<T extends NodeData> = HierarchyPointLink<TreeVisualNode<T>>;
export interface MenuItemHandlers<T extends NodeData> {
    [key: number]: (nodeData: T) => void;
}
export interface NodeProviderProps<T extends NodeData> {
    key: React.Key;
    node: TreeLayoutNode<T>;
    isPending?: boolean;
    isMuted?: boolean;
    isActive?: boolean;
    isSearched?: boolean;
    isReadOnly?: boolean;
    showMenuButton?: boolean;
    tooltipSettings?: TooltipSettings;
    isThumbnail?: boolean;
    warningThreshold?: number;
    dangerThreshold?: number;
}
export declare type NodeProvider<T extends NodeData> = (props: NodeProviderProps<T>) => React.ReactNode;
export interface LinkProviderProps<T extends NodeData> {
    key: React.Key;
    link: TreeLayoutLink<T>;
    activeNode?: NodeData;
    searchText?: string;
}
export declare type LinkProvider<T extends NodeData> = (props: LinkProviderProps<T>) => React.ReactNode;
interface MenuProviderProps<T = any> {
    data: T;
    menuTrigger: HTMLElement;
}
export declare type MenuProvider<T> = (props: MenuProviderProps<T>) => React.ReactNode;
export {};
