/*
 *    CLOUDERA Cloudera Data Platform
 *
 *    (C) Cloudera, Inc. 2021
 *    All rights reserved.
 *
 *    Applicable Open Source License: AGPLv3
 *
 *    NOTE: Cloudera open source products are modular software products
 *    made up of hundreds of individual components, each of which was
 *    individually copyrighted.  Each Cloudera open source product is a
 *    collective work under U.S. Copyright Law. Your license to use the
 *    collective work is as provided in your written agreement with
 *    Cloudera.  Used apart from the collective work, this file is
 *    licensed for your use pursuant to the open source license
 *    identified above.
 *
 *    This code is provided to you pursuant a written agreement with
 *    (i) Cloudera, Inc. or (ii) a third-party authorized to distribute
 *    this code. If you do not have a written agreement with Cloudera nor
 *    with an authorized and properly licensed third party, you do not
 *    have any rights to access nor to use this code.
 *
 *    Absent a written agreement with Cloudera, Inc. (“Cloudera”) to the
 *    contrary, A) CLOUDERA PROVIDES THIS CODE TO YOU WITHOUT WARRANTIES OF ANY
 *    KIND; (B) CLOUDERA DISCLAIMS ANY AND ALL EXPRESS AND IMPLIED
 *    WARRANTIES WITH RESPECT TO THIS CODE, INCLUDING BUT NOT LIMITED TO
 *    IMPLIED WARRANTIES OF TITLE, NON-INFRINGEMENT, MERCHANTABILITY AND
 *    FITNESS FOR A PARTICULAR PURPOSE; (C) CLOUDERA IS NOT LIABLE TO YOU,
 *    AND WILL NOT DEFEND, INDEMNIFY, NOR HOLD YOU HARMLESS FOR ANY CLAIMS
 *    ARISING FROM OR RELATED TO THE CODE; AND (D)WITH RESPECT TO YOUR EXERCISE
 *    OF ANY RIGHTS GRANTED TO YOU FOR THE CODE, CLOUDERA IS NOT LIABLE FOR ANY
 *    DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, PUNITIVE OR
 *    CONSEQUENTIAL DAMAGES INCLUDING, BUT NOT LIMITED TO, DAMAGES
 *    RELATED TO LOST REVENUE, LOST PROFITS, LOSS OF INCOME, LOSS OF
 *    BUSINESS ADVANTAGE OR UNAVAILABILITY, OR LOSS OR CORRUPTION OF
 *    DATA.
 */
import { TREE_VIEW_CONTAINER_ID } from './constants';
export var getTreeViewContainer = function () { return document.getElementById(TREE_VIEW_CONTAINER_ID); };
/**
 * Repositions element so that it is entirely inside the container.
 * Makes element visible after repositioning to avoid the repositioning being visible.
 * @param [tolerance=24] - Minimum distance in pixels between element and container edge. Default is 24.
 */
export var repositionInContainer = function (element, container, tolerance) {
    if (tolerance === void 0) { tolerance = 24; }
    if (!element || !container) {
        return;
    }
    var elementRect = element.getBoundingClientRect();
    var containerRect = container.getBoundingClientRect();
    var top = Number.parseInt(element.style.top);
    var bottom = top + elementRect.height;
    var left = Number.parseInt(element.style.left);
    var right = left + elementRect.width;
    var maxRight = containerRect.width - tolerance;
    var maxBottom = containerRect.height - tolerance;
    var maxTop = tolerance;
    var maxLeft = tolerance;
    if (bottom > maxBottom) {
        top -= bottom - maxBottom;
    }
    if (top < maxTop) {
        top = maxTop;
    }
    if (right > maxRight) {
        left -= right - maxRight;
    }
    if (left < maxLeft) {
        left = maxLeft;
    }
    element.style.top = "".concat(top, "px");
    element.style.left = "".concat(left, "px");
    element.style.visibility = 'visible';
};
