/*
 *    CLOUDERA Cloudera Data Platform
 *
 *    (C) Cloudera, Inc. 2021
 *    All rights reserved.
 *
 *    Applicable Open Source License: AGPLv3
 *
 *    NOTE: Cloudera open source products are modular software products
 *    made up of hundreds of individual components, each of which was
 *    individually copyrighted.  Each Cloudera open source product is a
 *    collective work under U.S. Copyright Law. Your license to use the
 *    collective work is as provided in your written agreement with
 *    Cloudera.  Used apart from the collective work, this file is
 *    licensed for your use pursuant to the open source license
 *    identified above.
 *
 *    This code is provided to you pursuant a written agreement with
 *    (i) Cloudera, Inc. or (ii) a third-party authorized to distribute
 *    this code. If you do not have a written agreement with Cloudera nor
 *    with an authorized and properly licensed third party, you do not
 *    have any rights to access nor to use this code.
 *
 *    Absent a written agreement with Cloudera, Inc. (“Cloudera”) to the
 *    contrary, A) CLOUDERA PROVIDES THIS CODE TO YOU WITHOUT WARRANTIES OF ANY
 *    KIND; (B) CLOUDERA DISCLAIMS ANY AND ALL EXPRESS AND IMPLIED
 *    WARRANTIES WITH RESPECT TO THIS CODE, INCLUDING BUT NOT LIMITED TO
 *    IMPLIED WARRANTIES OF TITLE, NON-INFRINGEMENT, MERCHANTABILITY AND
 *    FITNESS FOR A PARTICULAR PURPOSE; (C) CLOUDERA IS NOT LIABLE TO YOU,
 *    AND WILL NOT DEFEND, INDEMNIFY, NOR HOLD YOU HARMLESS FOR ANY CLAIMS
 *    ARISING FROM OR RELATED TO THE CODE; AND (D)WITH RESPECT TO YOUR EXERCISE
 *    OF ANY RIGHTS GRANTED TO YOU FOR THE CODE, CLOUDERA IS NOT LIABLE FOR ANY
 *    DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, PUNITIVE OR
 *    CONSEQUENTIAL DAMAGES INCLUDING, BUT NOT LIMITED TO, DAMAGES
 *    RELATED TO LOST REVENUE, LOST PROFITS, LOSS OF INCOME, LOSS OF
 *    BUSINESS ADVANTAGE OR UNAVAILABILITY, OR LOSS OR CORRUPTION OF
 *    DATA.
 */
import { successColor, warningColor, errorColor, fluidxGreen500, cuixWarning5, cuixError5 } from "cuix/dist/styles/variables";
import { LINK_MARGIN } from './constants';
import { getNodeHeight, getNodeWidth, isNodeMuted } from './nodeHelpers';
//#region Style variables and functions
export var linkStroke = successColor;
export var linkStrokeWarning = warningColor;
export var linkStrokeDanger = errorColor;
export var linkStrokeMuted = fluidxGreen500;
export var linkStrokeWarningMuted = cuixWarning5;
export var linkStrokeDangerMuted = cuixError5;
export var linkFill = 'url(#linkFillGradient)';
export var linkFillWarning = 'url(#linkFillWarningGradient)';
export var linkFillDanger = 'url(#linkFillDangerGradient)';
export var isLinkMuted = function (link, activeNode, searchText) { return isNodeMuted(link.target.data, activeNode, searchText); };
//#endregion
export var getChildIndex = function (parent, child) {
    if (!Array.isArray(parent.children)) {
        return 0;
    }
    var index = parent.children.indexOf(child);
    return index === -1 ? 0 : index;
};
export var getNodeExtents = function (node, vertical) {
    var sideAdjustment = 3;
    var width = getNodeWidth(node.data);
    var height = getNodeHeight(node.data);
    // Swap x and y to get horizontal links
    var x = vertical ? node.x : node.y;
    var y = vertical ? node.y : node.x;
    return {
        // Use sideAdjustment to hide left/right edges of link shape behind node
        left: x - width / 2 + sideAdjustment,
        right: x + width / 2 - sideAdjustment,
        // Adjust top and bottom extents to leave a margin above/below links
        top: y - height / 2 + LINK_MARGIN,
        bottom: y + height / 2 - LINK_MARGIN
    };
};
export var getPathData = function (link) {
    if (!link) {
        return '';
    }
    var linkWidth = link.topRight.x - link.topLeft.x;
    var linkHeight = link.bottomRight.y;
    var curveAmount = linkWidth / 4;
    var startPoint = link.topLeft;
    var topEndPoint = link.topRight;
    var topControlPoint = {
        x: link.topLeft.x + curveAmount,
        y: link.topLeft.y
    };
    var bottomEndPoint = link.bottomLeft;
    var bottomControlPoint = {
        x: link.bottomRight.x - curveAmount,
        y: link.bottomRight.y
    };
    var pathData = '';
    if (
    // Left node above right node
    link.topLeft.y >= link.topRight.y &&
        link.bottomLeft.y > link.bottomRight.y) {
        {
            // Draw top line of link
            var curveHeight = link.topLeft.y - link.topRight.y;
            var midPoint = {
                x: link.topLeft.x + linkWidth / 2,
                y: link.topLeft.y - curveHeight / 2
            };
            pathData = "\n        M ".concat(startPoint.x, ",").concat(startPoint.y, "\n        Q ").concat(topControlPoint.x, ",").concat(topControlPoint.y, " ").concat(midPoint.x, ",").concat(midPoint.y, "\n        T ").concat(topEndPoint.x, ",").concat(topEndPoint.y, "\n      ");
        }
        {
            // Draw bottom line of link
            var curveHeight = link.bottomLeft.y - link.bottomRight.y;
            var midPoint = {
                x: link.bottomRight.x - linkWidth / 2,
                y: link.bottomRight.y + curveHeight / 2
            };
            pathData += "\n        V".concat(linkHeight, "\n        Q").concat(bottomControlPoint.x, ",").concat(bottomControlPoint.y, " ").concat(midPoint.x, ",").concat(midPoint.y, "\n        T").concat(bottomEndPoint.x, ",").concat(bottomEndPoint.y, "\n        Z\n      ");
        }
    }
    else if (
    // Left node bigger than right node
    link.topLeft.y < link.topRight.y &&
        link.bottomLeft.y >= link.bottomRight.y) {
        {
            // Draw top line of link
            var curveHeight = link.topRight.y - link.topLeft.y;
            var midPoint = {
                x: link.topLeft.x + linkWidth / 2,
                y: link.topLeft.y + curveHeight / 2
            };
            pathData = "\n        M ".concat(startPoint.x, ",").concat(startPoint.y, "\n        Q ").concat(topControlPoint.x, ",").concat(topControlPoint.y, " ").concat(midPoint.x, ",").concat(midPoint.y, "\n        T ").concat(topEndPoint.x, ",").concat(topEndPoint.y, "\n      ");
        }
        {
            // Draw bottom line of link
            var curveHeight = link.bottomLeft.y - link.bottomRight.y;
            var midPoint = {
                x: link.bottomRight.x - linkWidth / 2,
                y: link.bottomRight.y + curveHeight / 2
            };
            pathData += "\n        V ".concat(linkHeight, "\n        Q ").concat(bottomControlPoint.x, ",").concat(bottomControlPoint.y, " ").concat(midPoint.x, ",").concat(midPoint.y, "\n        T ").concat(bottomEndPoint.x, ",").concat(bottomEndPoint.y, "\n        Z\n      ");
        }
    }
    else if (
    // Left node below right node
    link.topLeft.y < link.topRight.y &&
        link.bottomLeft.y <= link.bottomRight.y) {
        {
            // Draw top line of link
            var curveHeight = link.topRight.y - link.topLeft.y;
            var midPoint = {
                x: link.topLeft.x + linkWidth / 2,
                y: link.topLeft.y + curveHeight / 2
            };
            pathData = "\n        M ".concat(startPoint.x, ",").concat(startPoint.y, "\n        Q ").concat(topControlPoint.x, ",").concat(topControlPoint.y, " ").concat(midPoint.x, ",").concat(midPoint.y, "\n        T ").concat(topEndPoint.x, ",").concat(topEndPoint.y, "\n      ");
        }
        {
            // Draw bottom line of link
            var curveHeight = link.bottomRight.y - link.bottomLeft.y;
            var midPoint = {
                x: link.bottomRight.x - linkWidth / 2,
                y: link.bottomRight.y - curveHeight / 2
            };
            pathData += "\n        V ".concat(linkHeight, "\n        Q ").concat(bottomControlPoint.x, ",").concat(bottomControlPoint.y, " ").concat(midPoint.x, ",").concat(midPoint.y, "\n        T ").concat(bottomEndPoint.x, ",").concat(bottomEndPoint.y, "\n        Z\n      ");
        }
    }
    else if (
    // Left node smaller than right node
    link.topLeft.y >= link.topRight.y &&
        link.bottomLeft.y < link.bottomRight.y) {
        {
            // Draw top line of link
            var curveHeight = link.topLeft.y - link.topRight.y;
            var midPoint = {
                x: link.topLeft.x + linkWidth / 2,
                y: link.topLeft.y - curveHeight / 2
            };
            pathData = "\n        M ".concat(startPoint.x, ",").concat(startPoint.y, "\n        Q ").concat(topControlPoint.x, ",").concat(topControlPoint.y, " ").concat(midPoint.x, ",").concat(midPoint.y, "\n        T ").concat(topEndPoint.x, ",").concat(topEndPoint.y, "\n      ");
        }
        {
            // Draw bottom line of link
            var curveHeight = link.bottomRight.y - link.bottomLeft.y;
            var midPoint = {
                x: link.bottomRight.x - linkWidth / 2,
                y: link.bottomRight.y - curveHeight / 2
            };
            pathData += "\n        V ".concat(linkHeight, "\n        Q ").concat(bottomControlPoint.x, ",").concat(bottomControlPoint.y, " ").concat(midPoint.x, ",").concat(midPoint.y, "\n        T ").concat(bottomEndPoint.x, ",").concat(bottomEndPoint.y, "\n        Z\n      ");
        }
    }
    else {
        // Left node same size and vertical position as right node
        pathData = "\n      M ".concat(link.topLeft.x, ",").concat(link.topLeft.y, "\n      L ").concat(link.topRight.x, ",").concat(link.topRight.y, "\n      V ").concat(linkHeight, "\n      L ").concat(link.bottomLeft.x, ",").concat(link.bottomLeft.y, "\n      Z\n    ");
    }
    return pathData;
};
