/*
 *    CLOUDERA Cloudera Data Platform
 *
 *    (C) Cloudera, Inc. 2021
 *    All rights reserved.
 *
 *    Applicable Open Source License: AGPLv3
 *
 *    NOTE: Cloudera open source products are modular software products
 *    made up of hundreds of individual components, each of which was
 *    individually copyrighted.  Each Cloudera open source product is a
 *    collective work under U.S. Copyright Law. Your license to use the
 *    collective work is as provided in your written agreement with
 *    Cloudera.  Used apart from the collective work, this file is
 *    licensed for your use pursuant to the open source license
 *    identified above.
 *
 *    This code is provided to you pursuant a written agreement with
 *    (i) Cloudera, Inc. or (ii) a third-party authorized to distribute
 *    this code. If you do not have a written agreement with Cloudera nor
 *    with an authorized and properly licensed third party, you do not
 *    have any rights to access nor to use this code.
 *
 *    Absent a written agreement with Cloudera, Inc. (“Cloudera”) to the
 *    contrary, A) CLOUDERA PROVIDES THIS CODE TO YOU WITHOUT WARRANTIES OF ANY
 *    KIND; (B) CLOUDERA DISCLAIMS ANY AND ALL EXPRESS AND IMPLIED
 *    WARRANTIES WITH RESPECT TO THIS CODE, INCLUDING BUT NOT LIMITED TO
 *    IMPLIED WARRANTIES OF TITLE, NON-INFRINGEMENT, MERCHANTABILITY AND
 *    FITNESS FOR A PARTICULAR PURPOSE; (C) CLOUDERA IS NOT LIABLE TO YOU,
 *    AND WILL NOT DEFEND, INDEMNIFY, NOR HOLD YOU HARMLESS FOR ANY CLAIMS
 *    ARISING FROM OR RELATED TO THE CODE; AND (D)WITH RESPECT TO YOUR EXERCISE
 *    OF ANY RIGHTS GRANTED TO YOU FOR THE CODE, CLOUDERA IS NOT LIABLE FOR ANY
 *    DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, PUNITIVE OR
 *    CONSEQUENTIAL DAMAGES INCLUDING, BUT NOT LIMITED TO, DAMAGES
 *    RELATED TO LOST REVENUE, LOST PROFITS, LOSS OF INCOME, LOSS OF
 *    BUSINESS ADVANTAGE OR UNAVAILABILITY, OR LOSS OR CORRUPTION OF
 *    DATA.
 */
var __values = (this && this.__values) || function(o) {
    var s = typeof Symbol === "function" && Symbol.iterator, m = s && o[s], i = 0;
    if (m) return m.call(o);
    if (o && typeof o.length === "number") return {
        next: function () {
            if (o && i >= o.length) o = void 0;
            return { value: o && o[i++], done: !o };
        }
    };
    throw new TypeError(s ? "Object is not iterable." : "Symbol.iterator is not defined.");
};
import { MAX_NODE_HEIGHT, MIN_NODE_HEIGHT, NODE_WIDTH } from './constants';
export var getNodeWidth = function (node) { return node.width || NODE_WIDTH; };
export var getNodeHeight = function (node) {
    return node.height ? Math.max(Math.min(node.height, MAX_NODE_HEIGHT), MIN_NODE_HEIGHT) : MIN_NODE_HEIGHT;
};
export var isRootNode = function (nodeData) { return !nodeData.parentPath; };
export var hasChildren = function (node) {
    return Array.isArray(node.children) && node.children.length > 0;
};
export var isParentNode = function (node) {
    return !isRootNode(node.nodeData) && hasChildren(node);
};
export var isNodeInTree = function (node, path) {
    var e_1, _a;
    if (node.nodeData.path === path) {
        return true;
    }
    if (Array.isArray(node.children)) {
        try {
            for (var _b = __values(node.children), _c = _b.next(); !_c.done; _c = _b.next()) {
                var child = _c.value;
                if (isNodeInTree(child, path)) {
                    return true;
                }
            }
        }
        catch (e_1_1) { e_1 = { error: e_1_1 }; }
        finally {
            try {
                if (_c && !_c.done && (_a = _b.return)) _a.call(_b);
            }
            finally { if (e_1) throw e_1.error; }
        }
    }
    return false;
};
export var isNodeActive = function (path, activeNode, searchText) {
    return searchText ? false : path === (activeNode === null || activeNode === void 0 ? void 0 : activeNode.path);
}; // There is never an active node if there is searchText.
export var isNodeAncestorActive = function (path, activeNode, searchText) {
    if (!path) {
        return false;
    }
    if (isNodeActive(path, activeNode, searchText)) {
        return true;
    }
    var parentPath = path.split('.').slice(0, -1).join('.');
    if (!parentPath) {
        return false;
    }
    return isNodeAncestorActive(parentPath, activeNode, searchText);
};
export var isNodeChildActive = function (node, activeNode, searchText) {
    var e_2, _a;
    if (Array.isArray(node.children)) {
        try {
            for (var _b = __values(node.children), _c = _b.next(); !_c.done; _c = _b.next()) {
                var child = _c.value;
                var isActive = isNodeActive(child.nodeData.path, activeNode, searchText);
                if (isActive) {
                    return true;
                }
            }
        }
        catch (e_2_1) { e_2 = { error: e_2_1 }; }
        finally {
            try {
                if (_c && !_c.done && (_a = _b.return)) _a.call(_b);
            }
            finally { if (e_2) throw e_2.error; }
        }
    }
    return false;
};
export var isNodeDescendantActive = function (node, activeNode, searchText) {
    var e_3, _a;
    if (isNodeChildActive(node, activeNode, searchText)) {
        return true;
    }
    if (Array.isArray(node.children)) {
        try {
            for (var _b = __values(node.children), _c = _b.next(); !_c.done; _c = _b.next()) {
                var child = _c.value;
                if (isNodeDescendantActive(child, activeNode, searchText)) {
                    return true;
                }
            }
        }
        catch (e_3_1) { e_3 = { error: e_3_1 }; }
        finally {
            try {
                if (_c && !_c.done && (_a = _b.return)) _a.call(_b);
            }
            finally { if (e_3) throw e_3.error; }
        }
    }
    return false;
};
export var isNodeSearched = function (nodeName, searchText) {
    return searchText ? nodeName === null || nodeName === void 0 ? void 0 : nodeName.toLowerCase().includes(searchText.toLowerCase()) : false;
};
export var isNodeChildSearched = function (node, searchText) {
    var e_4, _a;
    if (Array.isArray(node.children)) {
        try {
            for (var _b = __values(node.children), _c = _b.next(); !_c.done; _c = _b.next()) {
                var child = _c.value;
                if (isNodeSearched(child.nodeData.name, searchText)) {
                    return true;
                }
            }
        }
        catch (e_4_1) { e_4 = { error: e_4_1 }; }
        finally {
            try {
                if (_c && !_c.done && (_a = _b.return)) _a.call(_b);
            }
            finally { if (e_4) throw e_4.error; }
        }
    }
    return false;
};
export var isNodeDescendantSearched = function (node, searchText) {
    var e_5, _a;
    if (isNodeChildSearched(node, searchText)) {
        return true;
    }
    if (Array.isArray(node.children)) {
        try {
            for (var _b = __values(node.children), _c = _b.next(); !_c.done; _c = _b.next()) {
                var child = _c.value;
                if (isNodeDescendantSearched(child, searchText)) {
                    return true;
                }
            }
        }
        catch (e_5_1) { e_5 = { error: e_5_1 }; }
        finally {
            try {
                if (_c && !_c.done && (_a = _b.return)) _a.call(_b);
            }
            finally { if (e_5) throw e_5.error; }
        }
    }
    return false;
};
export var isNodeMuted = function (node, activeNode, searchText) {
    return (!!activeNode || !!searchText) && // Don't mute any nodes unless there's an active node or search text
        !isNodeActive(node.nodeData.path, activeNode, searchText) &&
        !isNodeAncestorActive(node.nodeData.parentPath, activeNode, searchText) &&
        !isNodeDescendantActive(node, activeNode, searchText) &&
        !isNodeSearched(node.nodeData.name, searchText) &&
        !isNodeDescendantSearched(node, searchText);
};
