/*
 *    CLOUDERA Cloudera Data Platform
 *
 *    (C) Cloudera, Inc. 2021
 *    All rights reserved.
 *
 *    Applicable Open Source License: AGPLv3
 *
 *    NOTE: Cloudera open source products are modular software products
 *    made up of hundreds of individual components, each of which was
 *    individually copyrighted.  Each Cloudera open source product is a
 *    collective work under U.S. Copyright Law. Your license to use the
 *    collective work is as provided in your written agreement with
 *    Cloudera.  Used apart from the collective work, this file is
 *    licensed for your use pursuant to the open source license
 *    identified above.
 *
 *    This code is provided to you pursuant a written agreement with
 *    (i) Cloudera, Inc. or (ii) a third-party authorized to distribute
 *    this code. If you do not have a written agreement with Cloudera nor
 *    with an authorized and properly licensed third party, you do not
 *    have any rights to access nor to use this code.
 *
 *    Absent a written agreement with Cloudera, Inc. (“Cloudera”) to the
 *    contrary, A) CLOUDERA PROVIDES THIS CODE TO YOU WITHOUT WARRANTIES OF ANY
 *    KIND; (B) CLOUDERA DISCLAIMS ANY AND ALL EXPRESS AND IMPLIED
 *    WARRANTIES WITH RESPECT TO THIS CODE, INCLUDING BUT NOT LIMITED TO
 *    IMPLIED WARRANTIES OF TITLE, NON-INFRINGEMENT, MERCHANTABILITY AND
 *    FITNESS FOR A PARTICULAR PURPOSE; (C) CLOUDERA IS NOT LIABLE TO YOU,
 *    AND WILL NOT DEFEND, INDEMNIFY, NOR HOLD YOU HARMLESS FOR ANY CLAIMS
 *    ARISING FROM OR RELATED TO THE CODE; AND (D)WITH RESPECT TO YOUR EXERCISE
 *    OF ANY RIGHTS GRANTED TO YOU FOR THE CODE, CLOUDERA IS NOT LIABLE FOR ANY
 *    DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, PUNITIVE OR
 *    CONSEQUENTIAL DAMAGES INCLUDING, BUT NOT LIMITED TO, DAMAGES
 *    RELATED TO LOST REVENUE, LOST PROFITS, LOSS OF INCOME, LOSS OF
 *    BUSINESS ADVANTAGE OR UNAVAILABILITY, OR LOSS OR CORRUPTION OF
 *    DATA.
 */
export var nodeSortOptions = [
    {
        value: {
            id: 'NAME_ASC',
            valueType: 'string',
            getValue: function (nodeData) { return nodeData.name; }
        },
        label: 'Name - A to Z'
    },
    {
        value: {
            id: 'NAME_DESC',
            valueType: 'string',
            getValue: function (nodeData) { return nodeData.name; },
            invert: true
        },
        label: 'Name - Z to A'
    }
];
/* Convert inputs to numbers. If conversion results in NaN, use 0 for comparison. */
export var compareNumber = function (a, b) { return (+a || 0) - (+b || 0); };
export var compareString = function (a, b) {
    return a.toString().toLowerCase().localeCompare(b.toString().toLowerCase());
};
export var invertComparison = function (comparison) { return (comparison ? comparison * -1 : comparison); };
export var nodeSort = function (n1, n2, sortOrder) {
    if (!sortOrder) {
        return 0;
    }
    if (sortOrder.valueType === 'string') {
        var compare = function (q1, q2) {
            return compareString(sortOrder.getValue(q1), sortOrder.getValue(q2));
        };
        return sortOrder.invert ? invertComparison(compare(n1, n2)) : compare(n1, n2);
    }
    if (sortOrder.valueType === 'number') {
        var compare = function (q1, q2) {
            return compareNumber(sortOrder.getValue(q1), sortOrder.getValue(q2));
        };
        var result = sortOrder.invert ? invertComparison(compare(n1, n2)) : compare(n1, n2);
        // if numbers are equal, compare names as a fallback to ensure deterministic results
        return result === 0 ? compareString(n1.name, n2.name) : result;
    }
    return 0;
};
