import React from 'react';
import { Props as PageTitleProps } from '../PageTitle/PageTitle';
import { BreadcrumbsProps } from '../Breadcrumbs/Breadcrumbs';
interface Props extends PageTitleProps, Partial<BreadcrumbsProps> {
    /**
     * Style for the header area.
     */
    headerStyle?: React.CSSProperties;
    /**
     * Style for the content area.
     */
    contentStyle?: React.CSSProperties;
    /**
     * Additional space that must be reserved for elements outside the grid, such
     * as the navigation bar.
     */
    widthAdjustment?: number;
    /**
     * If true, the page content will use the entire available viewport width;
     * otherwise, the page content will be centered in viewports larger than the
     * maximum supported width.
     *
     * @default false
     */
    fullWidth?: boolean;
    isAdmin?: boolean;
}
/**
 * Lays out a CDL page, including the title, breadcrumbs, and content (children)
 * in a 12-column grid. It provides a columnWidth value to its children via
 * React Context that they can use to size themselves correctly, given the
 * number of columns they want to span.
 *
 * Children placed directly inside this component will stack with the correct
 * gap between them. The children should be other, more specific layout
 * components, or Cards.
 *
 * Cards have a `size` prop that dictates their width in grid columns. By
 * placing them inside this component, they will responsively resize themselves
 * within the limits defined by CDL.
 */
declare const PageLayout: React.FC<Props>;
export default PageLayout;
