var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
// Copyright (c) 2021 Cloudera, Inc. All rights reserved.
import React, { useEffect, useRef } from 'react';
import { useDispatch, useSelector } from 'react-redux';
import { actions as preferenceActions, getPreference } from "cuix/dist/reducers/preferenceReducer";
import { actions as routerActions, getNumberSearchParam, getSearchParam } from "cuix/dist/reducers/routerReducer";
import Table from "cuix/dist/components/Table";
import { strings, defaults } from "cuix/dist/utils/constants";
import i18n from "cuix/dist/utils/i18n";
export var getPage = function (state) { return getNumberSearchParam(state, strings.PAGE, 1); };
var getTotalRangeLabel = function (fetchedAllData) { return function (total, range) {
    return fetchedAllData
        ? i18n.t('ko.components.pagination.displayXtoY.known', range[0], range[1], total)
        : i18n.t('ko.components.pagination.displayXtoY.unknown', range[0], range[1]);
}; };
var PagedTable = function (_a) {
    var _b = _a.pagination, pagination = _b === void 0 ? {
        pageSize: defaults.PAGE_SIZE,
        showSizeChanger: true,
        hideOnSinglePage: false
    } : _b, _c = _a.dataSource, dataSource = _c === void 0 ? [] : _c, _d = _a.fetchedAllData, fetchedAllData = _d === void 0 ? true : _d, columns = _a.columns, otherProps = __rest(_a, ["pagination", "dataSource", "fetchedAllData", "columns"]);
    var defaultPageSize = defaults.PAGE_SIZE;
    if (typeof pagination !== 'boolean' && pagination.pageSize) {
        defaultPageSize = pagination.pageSize;
    }
    var pageSize = useSelector(function (state) {
        return getPreference(state, strings.PAGE_SIZE, defaultPageSize);
    });
    var page = useSelector(getPage);
    var sortColumn = useSelector(function (state) { return getSearchParam(state, strings.SORT_COLUMN); });
    var sortOrder = useSelector(function (state) { return getSearchParam(state, strings.SORT_ORDER); });
    var hasNonDefaultSort = useRef(false);
    var dispatch = useDispatch();
    var adjustedColumns = columns;
    // If sort info is provided in the url, update the columns to use that sort info. If sort info
    // is not provided, we'll use the default values specified in column definitions.
    if (hasNonDefaultSort.current || sortColumn) {
        hasNonDefaultSort.current = true;
        adjustedColumns = columns.map(function (column) {
            var key = column.key || column.dataIndex;
            // note that we need to specify a falsy value here in order to override any
            // previous sort settings that was applied.
            // TODO: [future] perhaps the right solution is to always go to a default sort if you "deselect" and other sort
            // and also make it so that you can not deselect the default sort itself (only change it's direction or click a different
            // sort column) (arne)
            var colSortOrder = column.sorter && key === sortColumn ? sortOrder : false;
            return __assign(__assign({}, column), { sortOrder: colSortOrder });
        });
    }
    /**
     * If the length of the data doesn't last until the current page (usually because it has been filtered),
     * jump to the last page still containing data.
     */
    useEffect(function () {
        /**
         * this effect only applies to PagedTable when the UI does all the filtering.
         * In the case that the UI does all the filtering, dataSource.length is the total length.
         * If the PagedTable is serving server-side data, we should just trust what the dataSource has.
         * and not try to be smart about what the current page is, since that is in the URL.
         */
        if (!fetchedAllData) {
            return;
        }
        var lastPageContainingData = Math.max(Math.ceil(dataSource.length / pageSize), 1);
        if (page > lastPageContainingData) {
            dispatch(routerActions.updateSearchParams({ page: lastPageContainingData.toString() }));
        }
    }, [dataSource, page, pageSize, dispatch, fetchedAllData]);
    var onPageChange = function (page) {
        dispatch(routerActions.updateSearchParams({ page: page }));
    };
    var onShowSizeChange = function (_page, pageSize) {
        dispatch(preferenceActions.savePreference(strings.PAGE_SIZE, pageSize));
        dispatch(routerActions.updateSearchParams({ page: '1' }));
    };
    /**
     * Handles any changes to table. We are only interested in sorting changes so we check for that
     * and update the url when sort column or order is changed.
     */
    var onTableChange = function (_pagination, _filters, sorter) {
        var _a, _b;
        if (sortColumn !== sorter.columnKey || sortOrder !== sorter.order) {
            hasNonDefaultSort.current = true;
            var columnKey = sorter.columnKey, order = sorter.order;
            var sortColumn_1 = columnKey ? columnKey.toString() : (_b = (_a = sorter.column) === null || _a === void 0 ? void 0 : _a.dataIndex) !== null && _b !== void 0 ? _b : undefined;
            var sortOrder_1 = order !== null && order !== void 0 ? order : undefined;
            dispatch(routerActions.updateSearchParams({ sortColumn: sortColumn_1, sortOrder: sortOrder_1 }));
        }
    };
    var paginationProps = __assign(__assign({ pageSizeOptions: defaults.PAGE_SIZE_OPTIONS, current: page, onChange: onPageChange, onShowSizeChange: onShowSizeChange, total: fetchedAllData ? dataSource.length : dataSource.length + pageSize, size: 'small', showTotal: getTotalRangeLabel(fetchedAllData) }, pagination), { pageSize: pageSize });
    return (React.createElement(Table, __assign({ columns: adjustedColumns, dataSource: dataSource, onChange: onTableChange, pagination: paginationProps }, otherProps)));
};
export default PagedTable;
