// Copyright (c) 2021 Cloudera, Inc. All rights reserved.
/**
 * Match a subset of urls
 */
var urlRegexp = /(?<!['"])https?:\/\/([\w-.]+)\.[\w]+\/[^ <>\n\t'"]*/g;
/**
 * Common characters that are used for sentence structure
 */
var lastCharRegexp = /[.,;:?!]$/;
/**
 * Find (subset) of links in text/partial-html and turn them into <a> links
 * WARNING: Only use with trusted data (e.g. not third-party/user provided)
 */
export var linkifyHtml = function (text) {
    var htmlText = text.replace(urlRegexp, function (subString) {
        // As period, comma, semi-colon, etc, are typical used for sentence structure, we'll
        // assume they are not part of the URL, if they are the last char.
        // e.g " my url is http://cloudera.com. What is yours http://cloudera.com/test?"
        // should not use the period or the question mark as part of the url
        var endsWithSentenceStructure = subString.match(lastCharRegexp);
        if (endsWithSentenceStructure) {
            subString = subString.replace(lastCharRegexp, '');
        }
        return "<a href=\"".concat(encodeURI(subString), "\">").concat(subString, "</a>").concat(endsWithSentenceStructure ? endsWithSentenceStructure[0] : '');
    });
    return htmlText;
};
