var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (Object.prototype.hasOwnProperty.call(b, p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        if (typeof b !== "function" && b !== null)
            throw new TypeError("Class extends value " + String(b) + " is not a constructor or null");
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
var __read = (this && this.__read) || function (o, n) {
    var m = typeof Symbol === "function" && o[Symbol.iterator];
    if (!m) return o;
    var i = m.call(o), r, ar = [], e;
    try {
        while ((n === void 0 || n-- > 0) && !(r = i.next()).done) ar.push(r.value);
    }
    catch (error) { e = { error: error }; }
    finally {
        try {
            if (r && !r.done && (m = i["return"])) m.call(i);
        }
        finally { if (e) throw e.error; }
    }
    return ar;
};
var __spreadArray = (this && this.__spreadArray) || function (to, from, pack) {
    if (pack || arguments.length === 2) for (var i = 0, l = from.length, ar; i < l; i++) {
        if (ar || !(i in from)) {
            if (!ar) ar = Array.prototype.slice.call(from, 0, i);
            ar[i] = from[i];
        }
    }
    return to.concat(ar || Array.prototype.slice.call(from));
};
// Copyright (c) 2018 Cloudera, Inc. All rights reserved.
import React from 'react';
import PropTypes from 'prop-types';
import { Select } from 'antd';
import differenceWith from 'lodash/differenceWith';
import get from 'lodash/get';
import i18n from '../../utils/i18n';
import sortBy from 'lodash/sortBy';
import { lowercasedSelectorByKey } from '../../utils/sortUtils';
var Option = Select.Option, OptGroup = Select.OptGroup;
var EMTPY_OPTION_VALUE = 'EMTPY_OPTION';
export var DEFAULT_FILTER_FUNCTION = function (input, option) {
    if (input === void 0) { input = ''; }
    var label = option.props.label || '';
    return label.toLowerCase().indexOf(input.toLowerCase()) > -1;
};
var DEFAULT_OPTION_RENDERER = function (option, nameField, labelField) { return (React.createElement(Option, { key: option[nameField], "data-test-key": option[nameField], value: option[nameField], label: option[labelField] }, option[labelField])); };
var DEFAULT_OPTION_CONFIG = {
    ONLY: 'only',
    FIRST: 'first',
    LAST: 'last'
};
var verifyValue = function (value) { return (value === EMTPY_OPTION_VALUE ? undefined : value); };
var verifyValueAndRunCallback = function (showEmptyOption, callback) {
    return !showEmptyOption ? callback : callback ? function (value) { return callback(verifyValue(value)); } : function () { };
};
var SelectInput = /** @class */ (function (_super) {
    __extends(SelectInput, _super);
    function SelectInput() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.getPopupContainer = function () {
            return get(_this.props, 'popupContainerRef.current', document.body);
        };
        return _this;
    }
    SelectInput.prototype.componentDidMount = function () {
        this.setDefaultValue();
        this.clearInvalidValue();
    };
    SelectInput.prototype.componentDidUpdate = function () {
        this.clearInvalidValue();
    };
    SelectInput.prototype.setDefaultValue = function () {
        var _a = this.props, nameField = _a.nameField, value = _a.value, defaultOptionConfig = _a.defaultOptionConfig, onChange = _a.onChange;
        if (value === undefined && defaultOptionConfig) {
            var optionsToRender = this.getVisibleOptions();
            var optionsAmount = optionsToRender.length;
            var defaultValue = void 0;
            if (optionsAmount > 0) {
                switch (defaultOptionConfig) {
                    case 'only':
                        if (optionsAmount === 1) {
                            defaultValue = optionsToRender[0][nameField];
                        }
                        break;
                    case 'first':
                        defaultValue = optionsToRender[0][nameField];
                        break;
                    case 'last':
                        defaultValue = optionsToRender[optionsAmount - 1][nameField];
                        break;
                }
            }
            if (defaultValue && onChange) {
                onChange(defaultValue);
            }
        }
    };
    SelectInput.prototype.clearValue = function () {
        this.props.onChange(undefined);
    };
    SelectInput.prototype.clearInvalidValue = function () {
        if (this._clearedInvalidValue && this.props.onChange) {
            this.clearValue();
        }
        this._clearedInvalidValue = false;
    };
    SelectInput.prototype.renderOption = function (option) {
        var _a = this.props, nameField = _a.nameField, labelField = _a.labelField, optionRenderer = _a.optionRenderer;
        return option.key === EMTPY_OPTION_VALUE
            ? DEFAULT_OPTION_RENDERER(option, nameField, labelField)
            : optionRenderer(option, nameField, labelField);
    };
    SelectInput.prototype.renderOptions = function (options) {
        var _this = this;
        return options.map(function (option) { return _this.renderOption(option); });
    };
    SelectInput.prototype.renderGroup = function (label, options) {
        return (React.createElement(OptGroup, { key: label, label: label }, this.renderOptions(options)));
    };
    SelectInput.prototype.renderOptionsAsGroups = function (options) {
        var _this = this;
        var categoryField = this.props.categoryField;
        var emptyGroup = [];
        var groupsByName = {};
        options.forEach(function (option) {
            var categoryName = option[categoryField];
            if (!categoryName) {
                emptyGroup.push(option);
            }
            else {
                var group = groupsByName[categoryName] || [];
                group.push(option);
                groupsByName[categoryName] = group;
            }
        });
        var noCategoryOptions = this.renderOptions(emptyGroup);
        var optGroups = Object.entries(groupsByName).map(function (_a) {
            var _b = __read(_a, 2), categoryName = _b[0], options = _b[1];
            return _this.renderGroup(categoryName, options);
        });
        return __spreadArray(__spreadArray([], __read(noCategoryOptions), false), __read(optGroups), false);
    };
    SelectInput.prototype.getVisibleOptions = function () {
        var _a = this.props, visibleOption = _a.visibleOption, sortField = _a.sortField, items = _a.options;
        var filteredItems = visibleOption ? items.filter(visibleOption) : __spreadArray([], __read(items), false);
        // Sort visible options if a sort field or function is provided
        return sortField === undefined
            ? filteredItems
            : typeof sortField === 'function'
                ? filteredItems.sort(sortField)
                : sortBy(filteredItems, lowercasedSelectorByKey(sortField));
    };
    SelectInput.prototype.render = function () {
        var _a;
        var _b = this.props, options = _b.options, nameField = _b.nameField, labelField = _b.labelField, sortField = _b.sortField, visibleOption = _b.visibleOption, value = _b.value, allowClear = _b.allowClear, showEmptyOption = _b.showEmptyOption, emptyOptionLabel = _b.emptyOptionLabel, onSelect = _b.onSelect, onChange = _b.onChange, useCategories = _b.useCategories, defaultOptionConfig = _b.defaultOptionConfig, mode = _b.mode, categoryField = _b.categoryField, optionRenderer = _b.optionRenderer, otherProps = __rest(_b, ["options", "nameField", "labelField", "sortField", "visibleOption", "value", "allowClear", "showEmptyOption", "emptyOptionLabel", "onSelect", "onChange", "useCategories", "defaultOptionConfig", "mode", "categoryField", "optionRenderer"]);
        var optionsToRender = this.getVisibleOptions();
        // Check if value is still valid. If not, we'll set a flag that indicates the value needs to be
        // cleared. We can't directly clear it here since we are in the middle of a render.
        if (mode === 'tags') {
            this._clearedInvalidValue = false;
        }
        else {
            var arrayValue = value;
            if (arrayValue && !Array.isArray(arrayValue)) {
                arrayValue = [arrayValue];
            }
            // clear the value if any of the array items is not present in the option list
            if (Array.isArray(arrayValue) &&
                differenceWith(arrayValue, optionsToRender, function (value, opt) { return opt[nameField] === value; }).length) {
                this._clearedInvalidValue = true;
            }
        }
        if (showEmptyOption) {
            optionsToRender.unshift((_a = {},
                _a[labelField] = emptyOptionLabel || i18n.t('All'),
                _a[nameField] = EMTPY_OPTION_VALUE,
                _a.key = EMTPY_OPTION_VALUE,
                _a));
        }
        var optionsContent = useCategories
            ? this.renderOptionsAsGroups(optionsToRender)
            : this.renderOptions(optionsToRender);
        return (React.createElement(Select, __assign({ mode: mode, value: value, getPopupContainer: this.getPopupContainer }, otherProps, { onChange: verifyValueAndRunCallback(showEmptyOption, onChange), onSelect: verifyValueAndRunCallback(showEmptyOption, onSelect), allowClear: allowClear }), optionsContent));
    };
    SelectInput.DEFAULT_OPTION_CONFIG = DEFAULT_OPTION_CONFIG;
    SelectInput.propTypes = {
        /** Ant Select modes */
        mode: PropTypes.oneOf(['default', 'multiple', 'tags']),
        /** Array of options objects for the select input. */
        options: PropTypes.array.isRequired,
        /** The field that is used as the value when an option is selected. */
        nameField: PropTypes.string,
        /** The field that is used as the label when an option is selected. */
        labelField: PropTypes.string,
        /** That field that is used to categorize options. */
        categoryField: PropTypes.string,
        /** The field that is used for sorting options or a custom sort method that is used to sort
         options. */
        sortField: PropTypes.oneOfType([PropTypes.string, PropTypes.func]),
        /**  Whether to use categories */
        useCategories: PropTypes.bool,
        value: PropTypes.any,
        onChange: PropTypes.func,
        onSelect: PropTypes.func,
        /** Function that is used to render each option. See the default value for the signature. */
        optionRenderer: PropTypes.func,
        /**
         * filterOption method is used when user types in a search query into this input. See antd docs
         * for more info.
         */
        filterOption: PropTypes.func,
        /**
         * visibleOption method is used to decide which options to display in the dropdown.
         * This prop is used when options for this component can be limited by another component.
         */
        visibleOption: PropTypes.func,
        /**
         * Used for dictating where the select's dropdown is rendered. If you pass in a ref, that
         * container will be used as the parent.
         */
        popupContainerRef: PropTypes.object,
        allowClear: PropTypes.bool,
        showSearch: PropTypes.bool,
        dropdownMatchSelectWidth: PropTypes.bool,
        showEmptyOption: PropTypes.bool,
        emptyOptionLabel: PropTypes.string,
        /**
         * if provided specifies how default value will be selected in case if value is not yet set.
         * only: If SelectInput has only one option select that one by default (Usefull then field is required)
         * first: Select the first option
         * last: Select the last option
         */
        defaultOptionConfig: PropTypes.oneOf(Object.values(DEFAULT_OPTION_CONFIG))
    };
    SelectInput.defaultProps = {
        mode: 'default',
        nameField: 'name',
        labelField: 'label',
        categoryField: 'category',
        useCategories: false,
        optionRenderer: DEFAULT_OPTION_RENDERER,
        filterOption: DEFAULT_FILTER_FUNCTION,
        allowClear: true,
        showSearch: true,
        dropdownMatchSelectWidth: false,
        showEmptyOption: false
    };
    return SelectInput;
}(React.Component));
export default SelectInput;
