import { FormProps } from 'antd';
import React, { ComponentProps } from 'react';
import { ButtonFooter } from '../ButtonFooter';
import { Heading } from '../Typography';
/**
 * Convenience wrapper `Heading` used for an optional title for the form
 */
export declare const ShortPageFormHeading: typeof Heading;
/**
 * Form footer that can display three buttons. For customization use the
 * wrapped components directly instead of this convenience wrapper
 */
export declare const ShortPageFormFooter: React.FC<ComponentProps<typeof ButtonFooter>>;
export declare const ShortPageFormLayout: React.FC;
/**
 * A "Card" (e.g. white container) used to wrap a Short Page Form
 * with custom styling to match specs.
 */
export declare const ShortPageFormCard: import("styled-components").StyledComponent<"div", any, {}, never>;
/**
 * A `<Form>` with included layout and card to simplify creating a "Short Page
 * Form". This is intended to be used on Pages only (e.g. not in Modals etc).
 * See design.cloudera.com for more details on Form usage. This convenience
 * component should handle most cases. For uncommon cases, then re-use the
 * underlying building blocks instead of this.
 *
 * Example:
 *
 * ```jsx
 * <ShortPageForm onFinish={onFinish}>
 *   // Optional header
 *   <ShortPageFormHeader>Database Overview</ShortPageFormHeader>
 *   <Form.Item label="Environment" name="env">
 *     <Input />
 *   </Form.Item>
 *   <ShortPageFormFooter
 *     primaryButton={
 *       <PrimaryButton htmlType="submit" data-event="Create database">
 *         Create Database
 *       </PrimaryButton>
 *     }
 *     cancelButton={
 *       <BorderlessButton data-event="Cancel create database" onClick={onCancel}>
 *         Cancel
 *       </BorderlessButton>
 *     }
 *   />
 *  </ShortPageForm>
 * ```
 *
 */
export declare const ShortPageForm: React.FC<FormProps>;
