import React from 'react';
import { type TabsProps } from 'antd';
interface Props extends TabsProps {
    /**
     * By default, the URL queryString will be maintained with the current tab ID
     * using the client-side routing format, which means that the queryString
     * actually comes AFTER the hash, i.e.
     * `https://hostname/path/#/route?key=value`. This is, technically, a
     * malformed URL. Standard URLs have the hash last, i.e.
     * `http://hostname/path?queryString#hash`. To have `Tabs` work with standard
     * URLs, set to "serverSearchParam". Note that, in this case, the queryString
     * is actually sent to the server, but that has no bearing on how this
     * component uses it. Set to `null` to disable this behavior entirely.
     * @default searchParam
     */
    updateUrlWith?: 'searchParam' | 'serverSearchParam' | 'null';
    /**
     * Specify the queryString key to use for the current tab ID. Useful if there
     * is more than one `Tabs` component on a page.
     * @default tab
     */
    searchParamKey?: string;
}
/**
 * A Tabs component that has the options to synchronize the url queryString with
 * the current tab ID.
 */
export declare const Tabs: React.FC<Props>;
export {};
