import React from 'react';
import { Color } from "cuix/dist/types/types";
export interface TagInputValue {
    value: string;
    color: Color;
}
export interface Props {
    label?: string;
    value?: (string | TagInputValue)[];
    onChange?: (values: (string | TagInputValue)[]) => void;
    onAdded?: (added: TagInputValue, values: (string | TagInputValue)[]) => void;
    onRemoved?: (removed: TagInputValue, values: (string | TagInputValue)[]) => void;
    /**
     * If provided, these values will be available to add as tags via a dropdown
     * menu, rather than needing to type them. This can be used in various ways,
     * such as "suggestions", "recents", etc.
     */
    presets?: (string | TagInputValue)[];
    /**
     * If `presets` are provided, this will be the label for the menu. The default
     * is "Suggestions" or, if `presetOnly === true`, "Select".
     */
    presetsMenuLabel?: string;
    /**
     * The color to make the tags. If set to "select", the user can select the color.
     * @default Color.Gray
     */
    color?: Color | 'select';
    /**
     * @default "Add"
     */
    addButtonLabel?: string;
    /**
     * If specified, a counter will be displayed to track the number of characters
     * typed in the input field. If it exceeds this value, the tag will not be
     * able to be added.
     */
    maxTagLength?: number;
    /**
     * If true and presets are provided, the text input and color selector will
     * not be shown.
     */
    presetsOnly?: boolean;
    placeholder?: string;
}
/**
 * A component for adding tags. May also be used as a generic multiple-value input.
 */
declare const TagInput: React.FC<Props>;
export default TagInput;
