var __makeTemplateObject = (this && this.__makeTemplateObject) || function (cooked, raw) {
    if (Object.defineProperty) { Object.defineProperty(cooked, "raw", { value: raw }); } else { cooked.raw = raw; }
    return cooked;
};
var __read = (this && this.__read) || function (o, n) {
    var m = typeof Symbol === "function" && o[Symbol.iterator];
    if (!m) return o;
    var i = m.call(o), r, ar = [], e;
    try {
        while ((n === void 0 || n-- > 0) && !(r = i.next()).done) ar.push(r.value);
    }
    catch (error) { e = { error: error }; }
    finally {
        try {
            if (r && !r.done && (m = i["return"])) m.call(i);
        }
        finally { if (e) throw e.error; }
    }
    return ar;
};
var __spreadArray = (this && this.__spreadArray) || function (to, from, pack) {
    if (pack || arguments.length === 2) for (var i = 0, l = from.length, ar; i < l; i++) {
        if (ar || !(i in from)) {
            if (!ar) ar = Array.prototype.slice.call(from, 0, i);
            ar[i] = from[i];
        }
    }
    return to.concat(ar || Array.prototype.slice.call(from));
};
// Copyright (c) 2023 Cloudera, Inc. All rights reserved.
import React, { useEffect, useState } from 'react';
import { Form } from 'antd';
import i18n from "cuix/dist/utils/i18n";
import { Color } from "cuix/dist/types/types";
import DropdownIcon from '@cloudera/cuix-core/icons/preact/DropdownIcon.preact';
import Button from '../Button';
import Dropdown from '../Dropdown';
import { backgroundColor, borderColor } from './TagInput.theme';
import { cdlSpacingTiny, cdlSpacingMUnitless, cdlSpacingXs, cdlSpacingXxs } from '@cloudera/cuix-core/variables';
import { styled } from 'styled-components';
import { defaultTheme as theme } from "cuix/dist/styles/theme";
import Tooltip from '../Tooltip';
import Tag from '../Tag';
import Counter from '../Counter/Counter';
import Input from '../Input';
import PresetsDropdownButton from './PresetsDropdownButton';
var Swatch = styled.div(templateObject_1 || (templateObject_1 = __makeTemplateObject(["\n  width: ", ";\n  height: ", ";\n  border: 1px solid ", ";\n  border-radius: 50%;\n  background-color: ", ";\n"], ["\n  width: ", ";\n  height: ", ";\n  border: 1px solid ", ";\n  border-radius: 50%;\n  background-color: ", ";\n"])), cdlSpacingXs, cdlSpacingXs, borderColor, backgroundColor);
Swatch.defaultProps = { theme: theme };
var LeftSplitButton = styled(Button)(templateObject_2 || (templateObject_2 = __makeTemplateObject(["\n  display: flex;\n  align-items: center;\n  gap: ", ";\n  margin-right: -1px;\n  margin-left: ", ";\n  border-top-right-radius: 0;\n  border-bottom-right-radius: 0;\n  padding-right: 10px;\n  padding-left: ", ";\n\n  &:hover,\n  &:active,\n  &:focus {\n    z-index: 2;\n  }\n"], ["\n  display: flex;\n  align-items: center;\n  gap: ", ";\n  margin-right: -1px;\n  margin-left: ", ";\n  border-top-right-radius: 0;\n  border-bottom-right-radius: 0;\n  padding-right: 10px;\n  padding-left: ", ";\n\n  &:hover,\n  &:active,\n  &:focus {\n    z-index: 2;\n  }\n"])), cdlSpacingTiny, cdlSpacingXxs, cdlSpacingXs);
var RightSplitButton = styled(Button)(templateObject_3 || (templateObject_3 = __makeTemplateObject(["\n  border-top-left-radius: 0;\n  border-bottom-left-radius: 0;\n"], ["\n  border-top-left-radius: 0;\n  border-bottom-left-radius: 0;\n"])));
var getTag = function (value, fallbackColor) {
    if (typeof value === 'string') {
        return {
            value: value,
            color: fallbackColor
        };
    }
    return {
        value: value.value,
        color: value.color || fallbackColor
    };
};
var getTags = function (values, fallbackColor) {
    return values.map(function (value) { return getTag(value, fallbackColor); });
};
var getPresetMenuItems = function (tags, presets) {
    return presets
        .filter(function (preset) { return !tags.find(function (tag) { return tag.value === preset.value; }); })
        .map(function (preset) { return ({
        key: preset.value,
        label: React.createElement(Tag, { label: preset.value, color: preset.color }),
        color: preset.color
    }); });
};
var colorMenuItems = [
    Color.Gray,
    Color.Pink,
    Color.Red,
    Color.Orange,
    Color.Amber,
    Color.Pear,
    Color.Green,
    Color.Spearmint,
    Color.Blue,
    Color.Indigo,
    Color.Purple
].map(function (color) { return ({
    label: (React.createElement("div", { style: { display: 'flex', gap: 8, alignItems: 'center' } },
        React.createElement(Swatch, { backgroundColor: color, borderColor: color }),
        color === Color.Gray ? i18n.t("label.default") : i18n.t("label.color.".concat(color)))),
    key: color
}); });
/**
 * A component for adding tags. May also be used as a generic multiple-value input.
 */
var TagInput = function (_a) {
    var label = _a.label, values = _a.value, onChange = _a.onChange, onAdded = _a.onAdded, onRemoved = _a.onRemoved, presets = _a.presets, presetsMenuLabel = _a.presetsMenuLabel, colorMode = _a.color, _b = _a.addButtonLabel, addButtonLabel = _b === void 0 ? i18n.t('label.add') : _b, maxTagLength = _a.maxTagLength, presetsOnly = _a.presetsOnly, placeholder = _a.placeholder;
    var color = colorMode === 'select' ? undefined : colorMode;
    var initialColor = color || Color.Gray;
    var tags = getTags(values || [], initialColor);
    var presetTags = getTags(presets || [], initialColor);
    var presetMenuItems = getPresetMenuItems(tags, presetTags);
    var presetsMenuDefaultLabel = presetsOnly && presets ? i18n.t('label.select') : i18n.t('label.suggestions');
    var _c = __read(useState(false), 2), isInvalid = _c[0], setIsInvalid = _c[1];
    var _d = __read(useState(''), 2), validationMessage = _d[0], setValidationMessage = _d[1];
    var _e = __read(useState(false), 2), maxExceeded = _e[0], setMaxExceeded = _e[1];
    var _f = __read(useState(false), 2), duplicateInput = _f[0], setDuplicateInput = _f[1];
    var _g = __read(useState(''), 2), inputValue = _g[0], setInputValue = _g[1];
    var _h = __read(useState(initialColor), 2), currentColor = _h[0], setCurrentColor = _h[1];
    useEffect(function () {
        var isInvalid = false;
        var validationMessage = '';
        if (maxExceeded) {
            isInvalid = true;
        }
        if (duplicateInput) {
            isInvalid = true;
            validationMessage = i18n.t('label.valuesMustBeUnique');
        }
        setIsInvalid(isInvalid);
        setValidationMessage(validationMessage);
    }, [duplicateInput, maxExceeded]);
    var addTag = function (value, color) {
        var trimmedValue = value.trim();
        if (trimmedValue === '') {
            return false;
        }
        var duplicate = tags.find(function (tag) { return tag.value === trimmedValue; });
        if (duplicate) {
            setDuplicateInput(true);
            return false;
        }
        var newTag = getTag(trimmedValue, color);
        var newValues = __spreadArray(__spreadArray([], __read((values || [])), false), [newTag], false);
        onAdded === null || onAdded === void 0 ? void 0 : onAdded(newTag, newValues);
        onChange === null || onChange === void 0 ? void 0 : onChange(newValues);
        return true;
    };
    var addTagFromInput = function (color) {
        if (addTag(inputValue, color || currentColor)) {
            setInputValue('');
        }
    };
    var removeTag = function (tagToRemove) {
        var newValues = (values || []).filter(function (value) {
            if (typeof value === 'string') {
                return value !== tagToRemove.value;
            }
            return value.value !== tagToRemove.value;
        });
        onRemoved === null || onRemoved === void 0 ? void 0 : onRemoved(tagToRemove, newValues);
        if (tagToRemove.value === inputValue) {
            setDuplicateInput(false);
        }
        return newValues;
    };
    var output = (React.createElement("div", { style: { display: 'flex', flexWrap: 'wrap', gap: cdlSpacingXxs } },
        tags.map(function (tag) { return (React.createElement(Tag, { key: tag.value, value: tag.value, color: tag.color, onClose: function () { return onChange === null || onChange === void 0 ? void 0 : onChange(removeTag(tag)); } })); }),
        presetMenuItems.length > 0 && (React.createElement(PresetsDropdownButton, { type: "pill", label: presetsMenuLabel || presetsMenuDefaultLabel, menu: {
                items: presetMenuItems,
                onClick: function (_a) {
                    var key = _a.key;
                    var presetMenuItem = presetMenuItems.find(function (item) { return item.key === key; });
                    if (presetMenuItem) {
                        addTag(presetMenuItem.key, presetMenuItem.color);
                    }
                }
            } }))));
    return (React.createElement("div", { className: "ant-form-vertical" }, presetsOnly && presets ? (React.createElement(Form.Item, { label: label, style: { marginBottom: 0 } }, output)) : (React.createElement(React.Fragment, null,
        React.createElement(Form.Item, { label: label, validateStatus: isInvalid ? 'error' : '', help: isInvalid ? validationMessage : undefined, style: { marginBottom: 0 } },
            React.createElement("div", { style: { display: 'flex', alignItems: 'flex-end' } },
                React.createElement("div", { style: {
                        display: 'flex',
                        flexDirection: 'column',
                        alignItems: 'flex-end',
                        flexGrow: 1,
                        gap: cdlSpacingTiny,
                        marginTop: -cdlSpacingMUnitless
                    } },
                    maxTagLength && (React.createElement(Counter, { max: maxTagLength, value: inputValue.length, onChange: setMaxExceeded })),
                    React.createElement(Input, { placeholder: placeholder, value: inputValue, onChange: function (event) {
                            setInputValue(event.target.value);
                            setDuplicateInput(false);
                        }, onPressEnter: function (event) {
                            event.preventDefault();
                            addTagFromInput(currentColor);
                        } })),
                colorMode === 'select' ? (React.createElement(React.Fragment, null,
                    React.createElement(Dropdown, { menu: {
                            items: colorMenuItems,
                            selectable: true,
                            defaultSelectedKeys: [Color.Gray],
                            onClick: function (_a) {
                                var key = _a.key;
                                return setCurrentColor(key);
                            }
                        } },
                        React.createElement(LeftSplitButton, { "aria-label": i18n.t('label.selectColor') },
                            React.createElement(Tooltip, { title: i18n.t("label.color.".concat(currentColor)) },
                                React.createElement(Swatch, { backgroundColor: currentColor, borderColor: currentColor })),
                            React.createElement(DropdownIcon, null))),
                    React.createElement(RightSplitButton, { onClick: function () { return addTagFromInput(currentColor); } }, addButtonLabel))) : (React.createElement(Button, { style: { marginLeft: cdlSpacingXxs }, onClick: function () {
                        if (!isInvalid) {
                            addTagFromInput(currentColor);
                        }
                    } }, addButtonLabel)))),
        (presetMenuItems.length > 0 || tags.length > 0) && (React.createElement("div", { style: { marginTop: cdlSpacingXxs } }, output))))));
};
export default TagInput;
var templateObject_1, templateObject_2, templateObject_3;
