var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
// Copyright (c) 2019 Cloudera, Inc. All rights reserved.
import React from 'react';
import PropTypes from 'prop-types';
import { Row, Col } from 'antd';
import "./TilesLayout.css";
import classNames from 'classnames';
var gridMapper = {
    // prefer 2 columns for medium/small, prefer 3 xxl
    two_cols: {
        xs: 24,
        sm: 24,
        md: 12,
        lg: 12,
        xl: 12,
        xxl: 12
    },
    medium: {
        xs: 24,
        sm: 24,
        md: 12,
        lg: 12,
        xl: 8,
        xxl: 6
    },
    // prefer 3 columns, then 2 for small
    small: {
        xs: 24,
        sm: 12,
        md: 12,
        lg: 8,
        xl: 8,
        xxl: 6
    },
    // prefer 1 column for smaller sizes, 3 for large
    narrow: {
        xs: 24,
        sm: 24,
        md: 24,
        lg: 8,
        xl: 8,
        xxl: 8
    }
};
export var SIZES = {
    SMALL: 'small',
    MEDIUM: 'medium',
    NARROW: 'narrow',
    TWO_COLS: 'two_cols'
};
export default function TilesLayout(props) {
    var children = props.children, rowGutter = props.rowGutter, size = props.size, justify = props.justify, className = props.className;
    var gridProps = gridMapper[size];
    return (React.createElement(Row, { className: classNames('tile-column', className), gutter: rowGutter, justify: justify }, React.Children.map(children, function (tile, i) {
        return tile && (React.createElement(Col, __assign({ key: tile.key || i }, gridProps), tile));
    })));
}
TilesLayout.propTypes = {
    /** Elements to layout in columns and rows */
    children: PropTypes.node.isRequired,
    /** Size of gutter between columns in pixels */
    rowGutter: PropTypes.number,
    /** Column width presets for different screen sizes. */
    size: PropTypes.string,
    /** Horizontal arrangement of the flex layout: start, end, center, space-around, space-between */
    justify: PropTypes.string,
    /** css class name  */
    className: PropTypes.string
};
TilesLayout.defaultProps = {
    rowGutter: 32,
    justify: 'start',
    size: 'medium'
};
