import React, { CSSProperties, MouseEventHandler, ReactNode } from 'react';
import { TooltipProps } from 'antd';
export declare const lineClampStyle: {
    display: string;
    overflow: string;
    textOverflow: string;
    WebkitBoxOrient: any;
    margin: number;
};
export declare const codeWrapperStyle: {
    padding: string;
    border: string;
    borderRadius: string;
    backgroundColor: string;
    zoom: number;
};
export declare const codeLineClampStyle: {
    margin: number;
    padding: number;
    border: string;
    fontSize: string;
};
declare type LineClampPosition = 'bottom' | 'right' | 'left' | 'top' | Pick<CSSProperties, 'bottom' | 'right' | 'left' | 'top'>;
interface LineClampPropsBase {
    /**
     * Where to position the expand/collapse symbol. If you omit this property, it
     * will be positioned inline, following the ellipsis. If you pass an object,
     * it will be used to absolutely position the symbol relative to the content.
     */
    position?: LineClampPosition;
}
export interface LineClampConfig extends LineClampPropsBase {
    lines: number;
    tooltip?: string | TooltipProps;
    expandable?: boolean;
    /**
     * A custom collapse button. It must have an onClick prop that will enable it
     * to collapse the content when clicked.
     */
    collapseButton?: React.ComponentType<{
        onClick: MouseEventHandler<HTMLElement>;
    }>;
    /**
     * A custom expand button. It must have an onClick prop that will enable it
     * to expandButton the content when clicked.
     */
    expandButton?: React.ComponentType<{
        onClick: MouseEventHandler<HTMLElement>;
    }>;
    /**
     * An additional event handler that will be called when the content is
     * collapsed.
     */
    onCollapse?: MouseEventHandler<HTMLElement>;
    /**
     * An additional event handler that will be called when the content is
     * expanded.
     */
    onExpand?: MouseEventHandler<HTMLElement>;
}
interface LineClampProps extends LineClampPropsBase {
    isTruncated: boolean;
    isCollapsed: boolean;
    tooltip?: string | TooltipProps;
    collapseButton?: ReactNode;
    expandButton?: ReactNode;
}
/**
 * Works in tandem with the Paragraph component, which uses CSS line-clamp to
 * provide "More"/"Less" functionality for text blocks.
 *
 * Improves on the antd "ellipsis" feature by providing a way to toggle the
 * collapsed state of the content and by supporting different display styles,
 * like preformatted text.
 */
export declare const LineClamp: React.FC<LineClampProps>;
export default LineClamp;
