// Copyright (c) 2022 Cloudera, Inc. All rights reserved.
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __generator = (this && this.__generator) || function (thisArg, body) {
    var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
    return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function() { return this; }), g;
    function verb(n) { return function (v) { return step([n, v]); }; }
    function step(op) {
        if (f) throw new TypeError("Generator is already executing.");
        while (_) try {
            if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done) return t;
            if (y = 0, t) op = [op[0] & 2, t.value];
            switch (op[0]) {
                case 0: case 1: t = op; break;
                case 4: _.label++; return { value: op[1], done: false };
                case 5: _.label++; y = op[1]; op = [0]; continue;
                case 7: op = _.ops.pop(); _.trys.pop(); continue;
                default:
                    if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                    if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                    if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                    if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                    if (t[2]) _.ops.pop();
                    _.trys.pop(); continue;
            }
            op = body.call(thisArg, _);
        } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
        if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
    }
};
var __read = (this && this.__read) || function (o, n) {
    var m = typeof Symbol === "function" && o[Symbol.iterator];
    if (!m) return o;
    var i = m.call(o), r, ar = [], e;
    try {
        while ((n === void 0 || n-- > 0) && !(r = i.next()).done) ar.push(r.value);
    }
    catch (error) { e = { error: error }; }
    finally {
        try {
            if (r && !r.done && (m = i["return"])) m.call(i);
        }
        finally { if (e) throw e.error; }
    }
    return ar;
};
import React, { useState } from 'react';
import Button, { BorderlessButton, DangerButton, PrimaryButton } from "cuix/dist/components/Button";
import { Row, Col, Layout } from 'antd';
import BackIcon from '@cloudera/cuix-core/icons/react/BackIcon';
import NextIcon from '@cloudera/cuix-core/icons/react/NextIcon';
import { componentBackground, fluidxSpacingM, fluidxSpacingXs, fluidxSpacingXxs, fluidxMinContentWidth, fluidxSpacingMUnitless } from "cuix/dist/styles/variables";
import i18n from "cuix/dist/utils/i18n";
import { StepButtons, StepContent, StepHeading } from './styledComponents';
import Steps from '../Steps';
var Content = Layout.Content;
var getButtonContent = function (defaultLabel, defaultIcon, customLabel, customIcon, iconOnRight) {
    var icon = customIcon || defaultIcon || null;
    var label = customLabel || defaultLabel;
    if (!icon) {
        return label;
    }
    if (iconOnRight) {
        return (React.createElement(React.Fragment, null,
            React.createElement("span", { style: { marginRight: fluidxSpacingXxs } }, label),
            icon));
    }
    return (React.createElement(React.Fragment, null,
        icon,
        React.createElement("span", { style: { marginLeft: fluidxSpacingXxs } }, label)));
};
var getPreviousButtonContent = function (label, icon) {
    return getButtonContent(i18n.t('label.previous'), React.createElement(BackIcon, null), label, icon);
};
var getNextButtonContent = function (label, icon) {
    if (icon) {
        return getButtonContent(i18n.t('label.next'), React.createElement(NextIcon, null), label, icon);
    }
    return getButtonContent(i18n.t('label.next'), React.createElement(NextIcon, null), label, icon, true);
};
var getFinishButtonContent = function (label, icon) {
    return getButtonContent(i18n.t('label.finish'), null, label, icon);
};
var getCancelButtonContent = function (label, icon) {
    return getButtonContent(i18n.t('label.cancel'), null, label, icon);
};
/**
 * Implements a wizard in Cloudera Design Language. Wizards should always take
 * up the entire main content area of a view; they should not be part of a
 * larger interface and should not be used inside containers such as modals.
 */
var Wizard = function (_a) {
    var data = _a.data, steps = _a.steps, cancelLabel = _a.cancelLabel, cancelIcon = _a.cancelIcon, onCancel = _a.onCancel;
    var _b = __read(useState(0), 2), currentStep = _b[0], setCurrentStep = _b[1];
    var previous = function () {
        if (currentStep > 0) {
            setCurrentStep(currentStep - 1);
        }
    };
    var next = function () {
        if (currentStep < steps.length - 1) {
            setCurrentStep(function (currentStep) { return ++currentStep; });
        }
    };
    var wizardSteps = steps.map(function (step) {
        return typeof step === 'function' ? step(data, previous, next) : step;
    });
    var finishStep = function () { return __awaiter(void 0, void 0, void 0, function () {
        var shouldGoNext;
        return __generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    if (!wizardSteps[currentStep].finishStep) return [3 /*break*/, 2];
                    return [4 /*yield*/, wizardSteps[currentStep].finishStep(data)];
                case 1:
                    shouldGoNext = _a.sent();
                    if (shouldGoNext === false) {
                        return [2 /*return*/];
                    }
                    _a.label = 2;
                case 2:
                    next();
                    return [2 /*return*/];
            }
        });
    }); };
    var handleNext = function () { return __awaiter(void 0, void 0, void 0, function () {
        var canFinishStep;
        return __generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    if (!!wizardSteps[currentStep].checkCanFinishStep) return [3 /*break*/, 1];
                    finishStep();
                    return [3 /*break*/, 3];
                case 1: return [4 /*yield*/, wizardSteps[currentStep].checkCanFinishStep(data)];
                case 2:
                    canFinishStep = _a.sent();
                    if (canFinishStep) {
                        finishStep();
                    }
                    _a.label = 3;
                case 3: return [2 /*return*/];
            }
        });
    }); };
    var handleKeyDown = function (event) {
        if (event.key === 'Enter') {
            handleNext();
        }
    };
    var showPrevious = !wizardSteps[currentStep].hidePrevious && currentStep > 0;
    return (React.createElement(Layout, { className: "cuix-wizard", style: { height: '100%', minWidth: fluidxMinContentWidth }, onKeyDown: handleKeyDown },
        React.createElement(Layout, null,
            React.createElement(Content, { style: { position: 'relative', margin: fluidxSpacingM } },
                React.createElement(Row, { gutter: fluidxSpacingMUnitless, style: { height: '100%' } },
                    React.createElement(Col, { span: 4, style: { maxHeight: '100%', overflow: 'auto' } },
                        React.createElement(Steps, { current: currentStep, items: wizardSteps.map(function (step) { return ({
                                title: step.shortTitle || step.title,
                                description: step.description
                            }); }) })),
                    wizardSteps[currentStep].customLayout !== true ? (React.createElement(React.Fragment, null,
                        React.createElement(Col, { span: wizardSteps[currentStep].renderSummary ? 14 : 16, style: { height: '100%' } },
                            React.createElement(StepHeading, null, wizardSteps[currentStep].title),
                            React.createElement(StepContent, null, wizardSteps[currentStep].render(data, previous, next)),
                            React.createElement("div", { style: { height: fluidxSpacingM, backgroundColor: componentBackground } }),
                            React.createElement(StepButtons, null,
                                showPrevious && (React.createElement(Button, { "data-event": "Wizard Previous", onClick: previous, style: { marginRight: fluidxSpacingXs } }, getPreviousButtonContent(wizardSteps[currentStep].previousLabel, wizardSteps[currentStep].previousIcon))),
                                wizardSteps[currentStep].finishButtonType === 'danger' ? (React.createElement(DangerButton, { "data-event": "Wizard Next (Finish)", onClick: handleNext }, currentStep === wizardSteps.length - 1
                                    ? getFinishButtonContent(wizardSteps[currentStep].finishLabel, wizardSteps[currentStep].finishIcon)
                                    : getNextButtonContent(wizardSteps[currentStep].finishLabel, wizardSteps[currentStep].finishIcon))) : (React.createElement(PrimaryButton, { "data-event": "Wizard Next (Finish)", onClick: handleNext }, currentStep === wizardSteps.length - 1
                                    ? getFinishButtonContent(wizardSteps[currentStep].finishLabel, wizardSteps[currentStep].finishIcon)
                                    : getNextButtonContent(wizardSteps[currentStep].finishLabel, wizardSteps[currentStep].finishIcon))),
                                wizardSteps[currentStep].actions && (React.createElement(React.Fragment, null, wizardSteps[currentStep].actions.map(function (action, index) {
                                    var _a, _b;
                                    if ((_a = action.shouldHide) === null || _a === void 0 ? void 0 : _a.call(action, data)) {
                                        return null;
                                    }
                                    var ActionButton = action.type === 'danger' ? DangerButton : BorderlessButton;
                                    return (React.createElement(ActionButton, { "data-event": "Wizard ".concat(action.label), key: "".concat(action.label.split(' ').join(), "-").concat(index), style: { marginLeft: fluidxSpacingXs }, onClick: function () { return action.handler(data, previous, next); }, disabled: (_b = action.shouldDisable) === null || _b === void 0 ? void 0 : _b.call(action, data) }, getButtonContent(action.label, action.icon)));
                                }))),
                                !wizardSteps[currentStep].hideCancel && onCancel && (React.createElement(BorderlessButton, { "data-event": "Cancel Wizard", style: { marginLeft: 'auto' }, onClick: onCancel }, getCancelButtonContent(cancelLabel, cancelIcon))),
                                ' ')),
                        wizardSteps[currentStep].renderSummary ? (React.createElement(Col, { span: 6, style: { maxHeight: '100%', overflow: 'auto' } }, wizardSteps[currentStep].renderSummary(data))) : (React.createElement(Col, { span: 4 })))) : (React.createElement(Col, { span: 20 }, wizardSteps[currentStep].render(data, previous, next))))))));
};
export default Wizard;
