import { ReactNode } from 'react';
export interface WizardStepAction<T> {
    label: string;
    icon?: ReactNode;
    /**
     * If set to 'danger', a `DangerButton` will be rendered for the action
     * button; otherwise, a `BorderlessButton` will be used.
     */
    type?: 'danger';
    shouldHide?: (data: T) => boolean;
    shouldDisable?: (data: T) => boolean;
    /**
     * Actions can navigate to the previous and next wizard steps by calling
     * `previous()` and `next()`, respectively.
     */
    handler: (data: T, previous: () => void, next: () => void) => unknown;
}
export interface WizardStep<T> {
    title: string;
    /**
     * Step title shown in the stepper if provided; otherwise, `title` will be
     * used.
     */
    shortTitle?: string;
    /**
     * Step description used in the stepper.
     */
    description?: string;
    previousLabel?: string;
    previousIcon?: ReactNode;
    hidePrevious?: boolean;
    finishLabel?: string;
    finishIcon?: ReactNode;
    /**
     * If set to 'danger', a `DangerButton` will be rendered for the "finish"
     * button; otherwise, a `PrimaryButton` will be used.
     */
    finishButtonType?: 'danger';
    hideCancel?: boolean;
    /**
     * If `true`, the entire width of the content area will be used to render the
     * step content; otherwise, space will be reserved on the right for the wizard
     * summary area.
     */
    customLayout?: boolean;
    render: (data: T, previous: () => void, next: () => void) => ReactNode;
    renderSummary?: (data: T) => ReactNode;
    /**
     * Defines actions that can be performed other than "previous" and "finish".
     * These will be rendered as additional buttons in the step footer.
     */
    actions?: WizardStepAction<T>[];
    /**
     * Additional logic to run before navigating to the next step. Return `false`
     * to prevent navigation.
     */
    finishStep?: (data: T) => void | boolean | Promise<void> | Promise<boolean>;
    /**
     * A function that determines whether the step can be finished. This is where you
     * would put form validation, for example. If no function is provided, the
     * step will always be allowed to finish.
     */
    checkCanFinishStep?: (data: T) => boolean | Promise<boolean>;
}
