// Copyright (c) 2022 Cloudera, Inc. All rights reserved.
import React, { useRef } from 'react';
import { Col, Row } from 'antd';
import * as jsdiff from 'diff';
import { cdlSpacingMUnitless } from "cuix/dist/styles/variables";
/**
 * Side by side diff e.g showing two views with the (line) differences highlighted
 */
export var SideBySideDiff = function (_a) {
    var a = _a.a, b = _a.b, aBackgroundColor = _a.aBackgroundColor, bBackgroundColor = _a.bBackgroundColor, aHeader = _a.aHeader, bHeader = _a.bHeader;
    var diffARef = useRef(null);
    var diffBRef = useRef(null);
    var diff = jsdiff.diffLines(a, b);
    var handleScrollSync = function (sourceRef, targetRef) {
        if (sourceRef.current && targetRef.current) {
            targetRef.current.scrollLeft = sourceRef.current.scrollLeft;
        }
    };
    var handleDiffAScroll = function () {
        handleScrollSync(diffARef, diffBRef);
    };
    var handleDiffBScroll = function () {
        handleScrollSync(diffBRef, diffARef);
    };
    return (React.createElement(Row, { gutter: cdlSpacingMUnitless },
        React.createElement(Col, { lg: 12, md: 12 },
            aHeader,
            React.createElement("pre", { "data-test": "SideBySideDiffA", ref: diffARef, onScroll: handleDiffAScroll }, diff
                .filter(function (chunk) { return !chunk.added; })
                .map(function (chunk, index) {
                var backgroundColor;
                var changed = false;
                if (chunk.removed) {
                    backgroundColor = aBackgroundColor;
                    changed = true;
                }
                return (React.createElement("span", { style: { backgroundColor: backgroundColor }, "data-changed": changed, key: index }, chunk.value));
            }))),
        React.createElement(Col, { lg: 12, md: 12 },
            bHeader,
            React.createElement("pre", { "data-test": "SideBySideDiffB", ref: diffBRef, onScroll: handleDiffBScroll }, diff
                .filter(function (chunk) { return !chunk.removed; })
                .map(function (chunk, index) {
                var backgroundColor;
                var changed = false;
                if (chunk.added) {
                    backgroundColor = bBackgroundColor;
                    changed = true;
                }
                return (React.createElement("span", { style: { backgroundColor: backgroundColor }, "data-changed": changed, key: index }, chunk.value));
            })))));
};
