import React from 'react';
export interface GenericData {
    [key: string]: any;
}
interface LineData<NodeData> {
    nodes: NodeData[];
    label: string;
    shortLabel?: string;
}
export interface HoverArg<NodeData> {
    entry: NodeData;
    dim: {
        x: number;
        y: number;
        height: number;
        width: number;
    };
}
export interface Props<NodeData extends GenericData> {
    /**
     * Data for each line of nodes
     */
    lines: LineData<NodeData>[];
    /**
     * Height of a single line of nodes
     */
    lineHeight?: number;
    /**
     * Label width. Labels longer than the width will be truncated using ellipis.
     */
    labelWidth?: number;
    /**
     * margin between each node box.
     */
    nodeSpacing?: number;
    /**
     * Function to return the node value into a color
     */
    colorScaleFn?: (value: any) => string;
    /**
     * Optional xAxis to render through a fn call. It will provide the layout where to render, but
     * it's up to the calling Component to provide the x-axis itself.
     */
    xAxis?: (arg: {
        width: number;
        labelWidth: number;
        lineWidth: number;
    }) => React.ReactNode;
    /**
     * Called when hovering over a node with data, and called with false when leaving said node
     */
    onHover?: (arg: HoverArg<NodeData> | false) => any;
    /**
     * Custom legend. This will render it the right edge aligns with the right edge of the last node in a line.
     * Since nodes are rendered in whole pixels, the full width of the chart will be like a step function,
     * so you can't just right align in the parent component.
     */
    legend?: React.ReactNode;
    /**
     * Which property of the node object is fed to the value function.
     */
    valueProperty?: keyof NodeData;
    /**
     * Set if you need to limit the chart height. This will limit the Node graph but not legend/x-axis, so
     * the total height can be bigger than this. If node graph exceeds the max height it will introduce
     * scollbars.
     */
    chartMaxHeight?: number;
}
declare const _default: React.MemoExoticComponent<(<NodeData extends GenericData>({ lines, xAxis, onHover, legend, lineHeight, labelWidth, nodeSpacing, colorScaleFn, valueProperty, chartMaxHeight }: Props<NodeData>) => JSX.Element)>;
export default _default;
