// Copyright (c) 2021 Cloudera, Inc. All rights reserved.
var __makeTemplateObject = (this && this.__makeTemplateObject) || function (cooked, raw) {
    if (Object.defineProperty) { Object.defineProperty(cooked, "raw", { value: raw }); } else { cooked.raw = raw; }
    return cooked;
};
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
import React, { useCallback } from 'react';
import { useResizeDetector } from 'react-resize-detector';
import { fontSizeSm, animationDurationBase, fluidxBlue, warningColor } from "cuix/dist/styles/variables";
import styled from 'styled-components';
import i18n from "cuix/dist/utils/i18n";
var LineLabel = styled.div(templateObject_1 || (templateObject_1 = __makeTemplateObject(["\n  position: absolute;\n  left: 0;\n  overflow: hidden;\n  text-overflow: ellipsis;\n  white-space: nowrap;\n  font-size: ", ";\n  line-height: 1; // otherwise, can cause scrolling since label box becomes big\n  text-align: right;\n"], ["\n  position: absolute;\n  left: 0;\n  overflow: hidden;\n  text-overflow: ellipsis;\n  white-space: nowrap;\n  font-size: ", ";\n  line-height: 1; // otherwise, can cause scrolling since label box becomes big\n  text-align: right;\n"])), fontSizeSm);
var Node = styled.rect(templateObject_2 || (templateObject_2 = __makeTemplateObject(["\n  transition: fill ", ";\n  &:hover {\n    stroke: ", ";\n  }\n"], ["\n  transition: fill ", ";\n  &:hover {\n    stroke: ", ";\n  }\n"])), animationDurationBase, fluidxBlue);
/**
 * Default grayscale color function used
 */
var defaultColorScaleFn = function (val) {
    if (val === null || val === undefined) {
        return warningColor;
    }
    return "rgba(0,0,0,".concat(val, ")");
};
/**
 * The "expensive" rendering part of NodeChart component. This is not meant to be used directly, use
 * `<NodeChart>` instead.
 */
var BaseNodeChart = function (_a) {
    var lines = _a.lines, xAxis = _a.xAxis, onHover = _a.onHover, legend = _a.legend, _b = _a.lineHeight, lineHeight = _b === void 0 ? 12 : _b, _c = _a.labelWidth, labelWidth = _c === void 0 ? 100 : _c, _d = _a.nodeSpacing, nodeSpacing = _d === void 0 ? 1 : _d, _e = _a.colorScaleFn, colorScaleFn = _e === void 0 ? defaultColorScaleFn : _e, _f = _a.valueProperty, valueProperty = _f === void 0 ? 'value' : _f, chartMaxHeight = _a.chartMaxHeight;
    var _g = useResizeDetector({
        handleHeight: false
    }), width = _g.width, ref = _g.ref;
    var onMouseEnter = useCallback(function (event, entry) {
        var node = event.target;
        // Note: getBoundingClientRect returns a DOMRect which doesn't quite
        // behave like a normal object. For example
        //    const newObject = { ...DOMRect, a: 1}
        // would not work as expected, and only leave you with { a: 1 }
        // so we'll construct a regular object here before passing it along.
        var _a = node.getBoundingClientRect(), height = _a.height, width = _a.width, x = _a.x, y = _a.y;
        onHover && onHover({ entry: entry, dim: { x: x, y: y, height: height, width: width } });
    }, [onHover]);
    if (!lines[0]) {
        return React.createElement(React.Fragment, null, i18n.t('label.na'));
    }
    var nodesPerLine = lines[0].nodes.length;
    if (!width) {
        return React.createElement("div", { ref: ref });
    }
    var spacingBetweenLabelAndNode = 8;
    var height = (lineHeight + nodeSpacing) * lines.length;
    var nodeWidth = Math.floor((width - labelWidth - spacingBetweenLabelAndNode) / nodesPerLine) - nodeSpacing;
    var realWidth = nodesPerLine * (nodeWidth + nodeSpacing) + labelWidth + spacingBetweenLabelAndNode;
    return (React.createElement("div", { ref: ref, style: { position: 'relative' } },
        !!legend && (React.createElement("div", { style: { width: realWidth - nodeSpacing, display: 'flex', justifyContent: 'flex-end' } }, legend)),
        React.createElement("div", { style: { position: 'relative', maxHeight: chartMaxHeight, overflow: 'hidden auto' } },
            React.createElement("div", null, lines.map(function (line, lineIndex) {
                return (React.createElement(LineLabel, { key: line.label, className: "cuix-discrete-node-chart-line-label", style: {
                        width: labelWidth,
                        top: lineIndex * (lineHeight + nodeSpacing),
                        lineHeight: "".concat(lineHeight, "px")
                    }, title: line.label }, line.shortLabel || line.label));
            })),
            React.createElement("svg", { viewBox: "0 0 ".concat(width, " ").concat(height), width: width, height: height, style: { display: 'block' } }, lines.map(function (line, lineIndex) {
                return line.nodes.map(function (entry, entryIndex) {
                    var key = "".concat(lineIndex, "-").concat(entryIndex);
                    var dimensionalProps = {
                        x: entryIndex * (nodeWidth + nodeSpacing) + labelWidth + spacingBetweenLabelAndNode,
                        y: lineIndex * (lineHeight + nodeSpacing),
                        width: nodeWidth,
                        height: lineHeight
                    };
                    return (React.createElement(Node, __assign({ key: key, className: "cuix-discrete-node-chart-box" }, dimensionalProps, { fill: colorScaleFn(entry[valueProperty]), onMouseEnter: function (event) { return onMouseEnter(event, entry); }, onMouseLeave: onHover && (function () { return onHover(false); }) })));
                });
            }))),
        xAxis && (React.createElement("div", { style: { position: 'relative' } }, xAxis({
            width: width,
            labelWidth: labelWidth + spacingBetweenLabelAndNode,
            lineWidth: nodesPerLine * (nodeWidth + nodeSpacing) - nodeSpacing
        })))));
};
export default React.memo(BaseNodeChart);
var templateObject_1, templateObject_2;
