// Copyright (c) 2021 Cloudera, Inc. All rights reserved.
var __makeTemplateObject = (this && this.__makeTemplateObject) || function (cooked, raw) {
    if (Object.defineProperty) { Object.defineProperty(cooked, "raw", { value: raw }); } else { cooked.raw = raw; }
    return cooked;
};
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
import React, { useCallback } from 'react';
import { useResizeDetector } from 'react-resize-detector';
import { fontSizeSm, animationDurationBase, cdlBlue, warningColor, cdlBlue300, cdlSpacingXxs } from "cuix/dist/styles/variables";
import styled from 'styled-components';
import i18n from "cuix/dist/utils/i18n";
var LineLabel = styled.div(templateObject_1 || (templateObject_1 = __makeTemplateObject(["\n  position: absolute;\n  left: 0;\n  overflow: hidden;\n  text-overflow: ellipsis;\n  white-space: nowrap;\n  font-size: ", ";\n  line-height: 1; // otherwise, can cause scrolling since label box becomes big\n  text-align: right;\n"], ["\n  position: absolute;\n  left: 0;\n  overflow: hidden;\n  text-overflow: ellipsis;\n  white-space: nowrap;\n  font-size: ", ";\n  line-height: 1; // otherwise, can cause scrolling since label box becomes big\n  text-align: right;\n"])), fontSizeSm);
var Node = styled.rect(templateObject_2 || (templateObject_2 = __makeTemplateObject(["\n  transition: fill ", ";\n"], ["\n  transition: fill ", ";\n"])), animationDurationBase);
var Group = styled.g(templateObject_3 || (templateObject_3 = __makeTemplateObject(["\n  &:hover {\n    stroke: ", ";\n    cursor: pointer;\n    stroke: ", ";\n    stroke-width: 4;\n    stroke-opacity: 0.9;\n    filter: opacity(0.9);\n  }\n  &:active {\n    stroke: ", ";\n    stroke-width: 4;\n    stroke-opacity: 1;\n    filter: opacity(1);\n  }\n"], ["\n  &:hover {\n    stroke: ", ";\n    cursor: pointer;\n    stroke: ", ";\n    stroke-width: 4;\n    stroke-opacity: 0.9;\n    filter: opacity(0.9);\n  }\n  &:active {\n    stroke: ", ";\n    stroke-width: 4;\n    stroke-opacity: 1;\n    filter: opacity(1);\n  }\n"])), cdlBlue, cdlBlue300, cdlBlue300);
var TextContainer = styled.div(templateObject_4 || (templateObject_4 = __makeTemplateObject(["\n  height: 100%;\n  width: 100%;\n  display: flex;\n  align-items: center;\n  justify-content: center;\n  padding: ", ";\n"], ["\n  height: 100%;\n  width: 100%;\n  display: flex;\n  align-items: center;\n  justify-content: center;\n  padding: ", ";\n"])), cdlSpacingXxs);
var Text = styled.div(templateObject_5 || (templateObject_5 = __makeTemplateObject(["\n  text-overflow: ellipsis;\n  overflow: hidden;\n  white-space: nowrap;\n"], ["\n  text-overflow: ellipsis;\n  overflow: hidden;\n  white-space: nowrap;\n"])));
/**
 * Default grayscale color function used
 */
var defaultColorScaleFn = function (val) {
    if (val === null || val === undefined) {
        return warningColor;
    }
    return "rgba(0,0,0,".concat(val, ")");
};
/**
 * The "expensive" rendering part of NodeChart component. This is not meant to be used directly, use
 * `<NodeChart>` instead.
 */
var BaseNodeChart = function (_a) {
    var _b, _c;
    var lines = _a.lines, xAxis = _a.xAxis, onHover = _a.onHover, legend = _a.legend, _d = _a.lineHeight, lineHeight = _d === void 0 ? 12 : _d, _e = _a.labelWidth, labelWidth = _e === void 0 ? 100 : _e, _f = _a.nodeSpacing, nodeSpacing = _f === void 0 ? 1 : _f, _g = _a.colorScaleFn, colorScaleFn = _g === void 0 ? defaultColorScaleFn : _g, _h = _a.valueProperty, valueProperty = _h === void 0 ? 'value' : _h, chartMaxHeight = _a.chartMaxHeight, _j = _a.numNodeInRow, numNodeInRow = _j === void 0 ? 5 : _j, onClick = _a.onClick, _k = _a.showLabel, showLabel = _k === void 0 ? false : _k, _l = _a.label, label = _l === void 0 ? '' : _l, _m = _a.dataTest, dataTest = _m === void 0 ? 'Node' : _m;
    var _o = useResizeDetector({
        handleHeight: false
    }), width = _o.width, ref = _o.ref;
    var onMouseEnter = useCallback(function (event, entry) {
        var node = event.target;
        // Note: getBoundingClientRect returns a DOMRect which doesn't quite
        // behave like a normal object. For example
        //    const newObject = { ...DOMRect, a: 1}
        // would not work as expected, and only leave you with { a: 1 }
        // so we'll construct a regular object here before passing it along.
        var _a = node.getBoundingClientRect(), height = _a.height, width = _a.width, x = _a.x, y = _a.y;
        onHover && onHover({ entry: entry, dim: { x: x, y: y, height: height, width: width } });
    }, [onHover]);
    if (!lines[0]) {
        return React.createElement(React.Fragment, null, i18n.t('label.na'));
    }
    var nodesPerLine = lines[0].nodes.length;
    if (!width) {
        return React.createElement("div", { ref: ref });
    }
    var spacingBetweenLabelAndNode = xAxis ? 8 : 0;
    var height = (lineHeight + nodeSpacing) * lines.length;
    var nodeWidth = ((_c = (_b = lines === null || lines === void 0 ? void 0 : lines[0]) === null || _b === void 0 ? void 0 : _b.nodes) === null || _c === void 0 ? void 0 : _c.length) < numNodeInRow // Don't want to stretch the node width if less than min number of nodes in rows.
        ? 89
        : Math.floor((width - labelWidth - spacingBetweenLabelAndNode) / nodesPerLine) - nodeSpacing;
    return (React.createElement("div", { ref: ref, style: { position: 'relative' } },
        !!legend && (React.createElement("div", { style: { width: '100%', display: 'flex', justifyContent: 'flex-end' } }, legend)),
        React.createElement("div", { style: {
                position: 'relative',
                maxHeight: chartMaxHeight,
                overflow: 'hidden auto',
                padding: "".concat(cdlSpacingXxs, " 0")
            } },
            React.createElement("div", null, lines.map(function (line, lineIndex) {
                return (React.createElement(LineLabel, { key: line.label, className: "cuix-discrete-node-chart-line-label", style: {
                        width: labelWidth,
                        top: lineIndex * (lineHeight + nodeSpacing),
                        lineHeight: "".concat(lineHeight, "px")
                    }, title: line.label }, line.shortLabel || line.label));
            })),
            React.createElement("svg", { viewBox: "0 0 ".concat(width, " ").concat(height), width: width, height: height, style: { display: 'block' } }, lines.map(function (line, lineIndex) {
                return line.nodes.map(function (entry, entryIndex) {
                    var key = "".concat(lineIndex, "-").concat(entryIndex);
                    var dimensionalProps = {
                        x: entryIndex * (nodeWidth + nodeSpacing) + labelWidth + spacingBetweenLabelAndNode,
                        y: lineIndex * (lineHeight + nodeSpacing),
                        width: nodeWidth,
                        height: lineHeight
                    };
                    var textDimensionalProps = __assign(__assign({}, dimensionalProps), { width: dimensionalProps.width, height: dimensionalProps.height });
                    return (React.createElement(Group, { key: key, "data-test": "".concat(dataTest, "-").concat(entryIndex, "-").concat(lineIndex), onMouseEnter: function (event) {
                            return onMouseEnter(event, entry);
                        }, onMouseLeave: onHover && (function () { return onHover(false); }), onClick: function (event) { return onClick === null || onClick === void 0 ? void 0 : onClick(event, entry); } },
                        React.createElement(Node, __assign({ key: key, className: "cuix-discrete-node-chart-box" }, dimensionalProps, { fill: colorScaleFn(entry[valueProperty]) })),
                        showLabel && (React.createElement("foreignObject", __assign({}, textDimensionalProps),
                            React.createElement(TextContainer, null,
                                React.createElement(Text, null, entry === null || entry === void 0 ? void 0 : entry[label]))))));
                });
            }))),
        xAxis && (React.createElement("div", { style: { position: 'relative' } }, xAxis({
            width: width,
            labelWidth: labelWidth + spacingBetweenLabelAndNode,
            lineWidth: nodesPerLine * (nodeWidth + nodeSpacing) - nodeSpacing
        })))));
};
export default React.memo(BaseNodeChart);
var templateObject_1, templateObject_2, templateObject_3, templateObject_4, templateObject_5;
