// Copyright (c) 2018 Cloudera, Inc. All rights reserved.
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (Object.prototype.hasOwnProperty.call(b, p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        if (typeof b !== "function" && b !== null)
            throw new TypeError("Class extends value " + String(b) + " is not a constructor or null");
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
import React, { Component } from 'react';
import { connect } from 'react-redux';
import PropTypes from 'prop-types';
import { getError } from '../reducers/apiBusReducer';
import { actions as modalActions, commonModals } from '../reducers/modalReducer';
/**
 * Connects error dialogs to a component.
 * Any strings passed to withErrorDialog are channel names that you wish to show errors for.
 * We require you to be explicit about which APIs you want to show errors in a popup to users.
 * @param {string|string[]} infoErrorChannels. Configures withErrorDialog to listen on apiBus channels for errors.
 * @return {React.Component}
 */
var withErrorDialog = function (infoErrorChannels) { return function (WrappedComponent) {
    var ErrorListener = /** @class */ (function (_super) {
        __extends(ErrorListener, _super);
        function ErrorListener() {
            var _this = _super !== null && _super.apply(this, arguments) || this;
            _this.render = function () { return React.createElement(WrappedComponent, __assign({}, _this.props, { infoError: undefined })); };
            return _this;
        }
        ErrorListener.prototype.showAnyError = function () {
            var _a = this.props, infoError = _a.infoError, showModal = _a.showModal;
            if (infoError) {
                showModal(commonModals.REQUEST_ERROR_MODAL, { error: infoError });
            }
        };
        ErrorListener.prototype.componentDidMount = function () {
            this.showAnyError();
        };
        ErrorListener.prototype.componentDidUpdate = function (prevProps) {
            var infoError = this.props.infoError;
            if (infoError !== prevProps.infoError) {
                this.showAnyError();
            }
        };
        ErrorListener.propTypes = {
            infoError: PropTypes.object,
            showModal: PropTypes.func.isRequired
        };
        return ErrorListener;
    }(Component));
    var ConnectedErrorListener = connect(function (state) { return ({
        infoError: getError(state, infoErrorChannels)
    }); }, {
        showModal: modalActions.showModal
    })(ErrorListener);
    // if the component is already wrapped, for tests, we want the wrapped.wrapped component
    ConnectedErrorListener.WrappedComponent = WrappedComponent.WrappedComponent || WrappedComponent;
    return ConnectedErrorListener;
}; };
export default withErrorDialog;
