// Copyright (c) 2022 Cloudera, Inc. All rights reserved.
import React from 'react';
import { RadialBarChart, PolarAngleAxis, RadialBar } from 'recharts';
import { Text } from "cuix/dist/components/Typography";
import i18n from "cuix/dist/utils/i18n";
import { cdlGray, cdlGreen400, cdlGreen500, cdlGreen600, cdlLineHeightLg, cdlSpacingSUnitless, fontSizeBase, fontSizeXl } from "cuix/dist/styles/variables";
var circleRadius = 220;
var circleHeight = 150;
var AutoScalingDisplay = function (_a) {
    var runningNodes = _a.runningNodes, minimumNodes = _a.minimumNodes, maximumNodes = _a.maximumNodes;
    var data = [{ name: '1', value: runningNodes || 0 }];
    var baseLineSize = {
        x: circleRadius / 2,
        y: circleRadius / 2
    };
    return (React.createElement(RadialBarChart, { width: circleRadius, height: circleHeight, cx: circleRadius / 2, cy: circleRadius / 2, innerRadius: 100, outerRadius: 200, barSize: 10, data: data, startAngle: 200, endAngle: -20 },
        React.createElement(PolarAngleAxis, { type: "number", domain: [0, maximumNodes], angleAxisId: 0, tick: false }),
        React.createElement(RadialBar, { background: true, dataKey: "value", cornerRadius: circleRadius / 2, fill: cdlGreen400, isAnimationActive: false }),
        React.createElement("text", { x: baseLineSize.x, y: baseLineSize.y - Number.parseInt(cdlLineHeightLg), textAnchor: "middle", dominantBaseline: "middle", className: "progress-label", fill: cdlGreen600, fontSize: fontSizeXl }, runningNodes !== null && runningNodes !== void 0 ? runningNodes : i18n.t('label.unknown')),
        React.createElement("text", { x: baseLineSize.x, y: baseLineSize.y, textAnchor: "middle", dominantBaseline: "middle", className: "progress-label", fontSize: fontSizeBase },
            i18n.t('compute.label.autoScalesBetween'),
            React.createElement("tspan", { x: baseLineSize.x, y: baseLineSize.y + cdlSpacingSUnitless }, i18n.t('compute.label.autoScalingMinAndMax', [minimumNodes, maximumNodes])))));
};
var NodeCountDisplay = function (_a) {
    var nodeStates = _a.nodeStates, configuredNodes = _a.configuredNodes;
    return (React.createElement("div", { style: { display: 'flex', flexDirection: 'column' } },
        React.createElement("div", { style: {
                display: 'flex',
                alignItems: 'baseline',
                justifyContent: 'center',
                fontWeight: 'lighter'
            } },
            React.createElement("span", { style: { color: cdlGreen500, fontSize: 70, lineHeight: 1 } }, nodeStates.running !== undefined ? nodeStates.running : '?'),
            React.createElement("span", { style: { fontSize: 50, lineHeight: 1 } }, "/"),
            React.createElement("span", { style: { fontSize: 50, lineHeight: 1 } }, configuredNodes)),
        React.createElement(Text, { style: { textAlign: 'center', color: cdlGray } }, i18n.t('compute.status.RUNNING').toUpperCase())));
};
var NodeStatus = function (_a) {
    var nodeStates = _a.nodeStates, configuredNodes = _a.configuredNodes, minimumNodes = _a.minimumNodes, maximumNodes = _a.maximumNodes;
    return (React.createElement("div", { style: { display: 'flex' } }, minimumNodes !== undefined && maximumNodes !== undefined && minimumNodes !== maximumNodes ? (React.createElement(AutoScalingDisplay, { runningNodes: nodeStates.running, minimumNodes: minimumNodes, maximumNodes: maximumNodes })) : (React.createElement(NodeCountDisplay, { nodeStates: nodeStates, configuredNodes: configuredNodes }))));
};
export default NodeStatus;
