var __read = (this && this.__read) || function (o, n) {
    var m = typeof Symbol === "function" && o[Symbol.iterator];
    if (!m) return o;
    var i = m.call(o), r, ar = [], e;
    try {
        while ((n === void 0 || n-- > 0) && !(r = i.next()).done) ar.push(r.value);
    }
    catch (error) { e = { error: error }; }
    finally {
        try {
            if (r && !r.done && (m = i["return"])) m.call(i);
        }
        finally { if (e) throw e.error; }
    }
    return ar;
};
// Copyright (c) 2022 Cloudera, Inc. All rights reserved.
import React, { useEffect, useState } from 'react';
import { Form, Select } from 'antd';
import Modal from "cuix/dist/components/Modal";
import i18n from "cuix/dist/utils/i18n";
import useSubmissionApi from "cuix/dist/hooks/useSubmissionApi";
import compute from "cdp-js/dist/api/compute";
import { Heading, Text } from "cuix/dist/components/Typography";
import apiErrorNotification from "cuix/dist/utils/apiErrorNotification";
import apiSuccessNotification from "cuix/dist/utils/apiSuccessNotification";
import I18nHtml from "cuix/dist/components/I18nHtml/I18nHtml";
/**
 * Modal shown when the user chooses to upgrade deployment in a compute cluster.
 */
var DeploymentUpgradeModal = function (_a) {
    var clusterCrn = _a.clusterCrn, name = _a.name, namespace = _a.namespace, versions = _a.versions, recommendedVersion = _a.recommendedVersion, isModalVisible = _a.isModalVisible, setIsModalVisible = _a.setIsModalVisible, onSuccess = _a.onSuccess, showAdvanced = _a.showAdvanced, confirmMessage = _a.confirmMessage;
    var _b = __read(Form.useForm(), 1), form = _b[0];
    var _c = __read(useSubmissionApi(compute.upgradeDeployment), 2), upgradeDeploymentResponse = _c[0], upgradeDeployment = _c[1];
    var _d = __read(useState(false), 2), isAdvancedMode = _d[0], setIsAdvancedMode = _d[1];
    // TODO: [future] Use this when implementing the full "advanced" flow. (@jgolieb)
    // const advancedConfirm = () =>
    //   apiDangerConfirm(
    //     i18n.t('label.areYouSure'),
    //     confirmed => {
    //       if (confirmed) {
    //         const values = form.getFieldsValue();
    //         upgradeDeployment({
    //           clusterCrn,
    //           name,
    //           namespace,
    //           chartVersion: values['version']
    //         });
    //         handleCancel();
    //       }
    //     },
    //     { title: i18n.t('compute.label.deployment.upgradeDeployment') }
    //   );
    var handleCancel = function () {
        setIsModalVisible(false);
        setIsAdvancedMode(false);
    };
    var handleOk = function () {
        upgradeDeployment({
            clusterCrn: clusterCrn,
            name: name,
            namespace: namespace,
            chartVersion: recommendedVersion
        });
        handleCancel();
    };
    useEffect(function () {
        if (upgradeDeploymentResponse.data) {
            onSuccess === null || onSuccess === void 0 ? void 0 : onSuccess();
            apiSuccessNotification(i18n.t('compute.label.deployment.upgradeDeploymentRequestSuccess', [name]));
        }
    }, [upgradeDeploymentResponse.data, onSuccess, name]);
    useEffect(function () {
        if (upgradeDeploymentResponse.error) {
            apiErrorNotification(upgradeDeploymentResponse.error);
        }
    }, [upgradeDeploymentResponse.error]);
    var defaultConfirmMessage = (React.createElement(React.Fragment, null,
        React.createElement(I18nHtml, { messageKey: "compute.label.deployment.upgradeDeploymentToVersion", params: [name, recommendedVersion] }),
        ' ',
        React.createElement(Text, null, i18n.t('label.areYouSure'))));
    return (React.createElement(Modal, { title: React.createElement(Heading, { level: 2 }, i18n.t('compute.label.deployment.upgradeDeployment')), open: isModalVisible, onOk: handleOk, onCancel: handleCancel, destroyOnClose: true, secondaryButtonText: showAdvanced ? i18n.t('compute.label.advanced') : undefined, onSecondary: function () { return setIsAdvancedMode(true); } }, isAdvancedMode ? (React.createElement(Form, { form: form, layout: "vertical", autoComplete: "off", initialValues: { version: recommendedVersion }, preserve: false },
        React.createElement(Form.Item, { name: "version", label: i18n.t('label.version') },
            React.createElement(Select, { options: versions.map(function (version) { return ({
                    label: version === recommendedVersion
                        ? "".concat(version, " (").concat(i18n.t('compute.label.recommendedSelection'), ")")
                        : version,
                    value: version
                }); }) })))) : (confirmMessage || defaultConfirmMessage)));
};
export default DeploymentUpgradeModal;
