var __read = (this && this.__read) || function (o, n) {
    var m = typeof Symbol === "function" && o[Symbol.iterator];
    if (!m) return o;
    var i = m.call(o), r, ar = [], e;
    try {
        while ((n === void 0 || n-- > 0) && !(r = i.next()).done) ar.push(r.value);
    }
    catch (error) { e = { error: error }; }
    finally {
        try {
            if (r && !r.done && (m = i["return"])) m.call(i);
        }
        finally { if (e) throw e.error; }
    }
    return ar;
};
// Copyright (c) 2022 Cloudera, Inc. All rights reserved.
import React, { useEffect, useState } from 'react';
import { Form, Select } from 'antd';
import Modal from "cuix/dist/components/Modal";
import i18n from "cuix/dist/utils/i18n";
import useSubmissionApi from "cuix/dist/hooks/useSubmissionApi";
import compute from "cdp-js/dist/api/compute";
import apiDangerConfirm from "cuix/dist/utils/apiDangerConfirm";
import { Heading } from "cuix/dist/components/Typography";
import apiErrorNotification from "cuix/dist/utils/apiErrorNotification";
import apiSuccessNotification from "cuix/dist/utils/apiSuccessNotification";
import ValidationResultsModal from '../ValidationResultModal/ValidationResultModal';
/**
 * Modal shown when the user chooses to upgrade kubernetes in a compute cluster.
 */
var KubernetesUpgradeModal = function (_a) {
    var clusterCrn = _a.clusterCrn, clusterStateVersion = _a.clusterStateVersion, versions = _a.versions, recommendedVersion = _a.recommendedVersion, isModalVisible = _a.isModalVisible, setIsModalVisible = _a.setIsModalVisible, onSuccess = _a.onSuccess;
    var _b = __read(Form.useForm(), 1), form = _b[0];
    var _c = __read(useSubmissionApi(compute.upgradeCluster), 2), upgradeKubernetesResponse = _c[0], upgradeKubernetes = _c[1];
    var _d = __read(useState(), 2), validationResponse = _d[0], setValidationResponse = _d[1];
    var handleOk = function () {
        apiDangerConfirm(i18n.t('label.areYouSure'), function (confirmed) {
            if (confirmed) {
                var values = form.getFieldsValue();
                upgradeKubernetes({
                    clusterCrn: clusterCrn,
                    clusterStateVersion: clusterStateVersion,
                    kubernetesVersion: values['version']
                });
                setIsModalVisible(false);
            }
        }, { title: i18n.t('compute.label.upgradeKubernetes') });
    };
    useEffect(function () {
        if (upgradeKubernetesResponse.data) {
            if (upgradeKubernetesResponse.data.validationResponse) {
                setValidationResponse(upgradeKubernetesResponse.data.validationResponse);
            }
            else {
                onSuccess === null || onSuccess === void 0 ? void 0 : onSuccess();
                apiSuccessNotification(i18n.t('compute.label.upgradeKubernetesRequestSuccess'));
            }
        }
    }, [upgradeKubernetesResponse.data, onSuccess]);
    useEffect(function () {
        if (upgradeKubernetesResponse.error) {
            apiErrorNotification(upgradeKubernetesResponse.error);
        }
    }, [upgradeKubernetesResponse.error]);
    return (React.createElement(React.Fragment, null,
        React.createElement(Modal, { title: React.createElement(Heading, { level: 2 }, i18n.t('compute.label.upgradeKubernetes')), open: isModalVisible, onOk: handleOk, onCancel: function () { return setIsModalVisible(false); }, destroyOnClose: true },
            React.createElement(Form, { form: form, layout: "vertical", autoComplete: "off", initialValues: { version: recommendedVersion }, preserve: false },
                React.createElement(Form.Item, { name: "version", label: i18n.t('label.version') },
                    React.createElement(Select, { options: versions.map(function (version) { return ({
                            label: version === recommendedVersion
                                ? "".concat(version, " (").concat(i18n.t('compute.label.recommendedSelection'), ")")
                                : version,
                            value: version
                        }); }) })))),
        React.createElement(ValidationResultsModal, { description: i18n.t('compute.label.upgradeValidationModalText'), validationResponse: validationResponse, isVisible: validationResponse !== undefined, setIsVisible: function () { return setValidationResponse(undefined); } })));
};
export default KubernetesUpgradeModal;
