var __read = (this && this.__read) || function (o, n) {
    var m = typeof Symbol === "function" && o[Symbol.iterator];
    if (!m) return o;
    var i = m.call(o), r, ar = [], e;
    try {
        while ((n === void 0 || n-- > 0) && !(r = i.next()).done) ar.push(r.value);
    }
    catch (error) { e = { error: error }; }
    finally {
        try {
            if (r && !r.done && (m = i["return"])) m.call(i);
        }
        finally { if (e) throw e.error; }
    }
    return ar;
};
// Copyright (c) 2022 Cloudera, Inc. All rights reserved.
import React, { useEffect, useState } from 'react';
import { Card } from 'antd';
import { cdlSpacingS } from "cuix/dist/styles/variables";
import DeleteIcon from '@cloudera/cuix-core/icons/react/DeleteIcon';
import UpgradeIcon from '@cloudera/cuix-core/icons/react/UpgradeIcon';
import SettingsIcon from '@cloudera/cuix-core/icons/react/SettingsIcon';
import { Heading } from "cuix/dist/components/Typography";
import i18n from "cuix/dist/utils/i18n";
import { IconButton } from "cuix/dist/components/Button";
import DeploymentUpgradeModal from './DeploymentUpgradeModal';
import apiDangerConfirm from "cuix/dist/utils/apiDangerConfirm";
import useSubmissionApi from "cuix/dist/hooks/useSubmissionApi/useSubmissionApi";
import compute from "cdp-js/dist/api/compute";
import apiSuccessNotification from "cuix/dist/utils/apiSuccessNotification";
import I18nHtml from "cuix/dist/components/I18nHtml/I18nHtml";
import useApiData, { NO_FETCH } from "cuix/dist/hooks/useApiData";
import Loading from "cuix/dist/components/Loading";
import { DeploymentStatus } from '../types';
var deploymentPendingStatusTypes = [
    DeploymentStatus.PendingInstall,
    DeploymentStatus.PendingUpgrade,
    DeploymentStatus.PendingRollback
];
var isDeploymentPending = function (status) {
    return deploymentPendingStatusTypes.includes(status);
};
var PlatformServiceCard = function (_a) {
    var _b;
    var cluster = _a.cluster, name = _a.name, namespace = _a.namespace, version = _a.version, onConfigure = _a.onConfigure, canUpgrade = _a.canUpgrade, onUpgrade = _a.onUpgrade, onUpgradeSuccess = _a.onUpgradeSuccess, canRemove = _a.canRemove, recommendedUpgrade = _a.recommendedUpgrade, availableUpgrades = _a.availableUpgrades, showAdvanced = _a.showAdvanced, upgradeConfirmMessage = _a.upgradeConfirmMessage;
    var _c = useApiData({
        api: compute.describeDeployment,
        fetchParams: namespace
            ? {
                clusterCrn: cluster.clusterCrn,
                namespace: namespace,
                name: name
            }
            : NO_FETCH,
        initialRefreshDelay: 1000,
        shouldRefresh: function (data) {
            var _a;
            if (!((_a = data === null || data === void 0 ? void 0 : data.deployment) === null || _a === void 0 ? void 0 : _a.status)) {
                return false;
            }
            return isDeploymentPending(data.deployment.status);
        }
    }), data = _c.data, refresh = _c.refresh;
    var _d = __read(useState(false), 2), isDeploymentUpgradeModalVisible = _d[0], setIsDeploymentUpgradeModalVisible = _d[1];
    var _e = __read(useSubmissionApi(compute.deleteDeployment), 2), deleteDeploymentResponse = _e[0], deleteDeployment = _e[1];
    var defaultUpgradeHandler = function () { return setIsDeploymentUpgradeModalVisible(true); };
    useEffect(function () {
        if (deleteDeploymentResponse.data) {
            apiSuccessNotification(React.createElement(I18nHtml, { messageKey: "compute.label.deployment.deleted", params: [name] }));
        }
    }, [deleteDeploymentResponse.data, name]);
    return (React.createElement(Card, { style: { width: 220 }, bodyStyle: { padding: cdlSpacingS } },
        isDeploymentPending((_b = data === null || data === void 0 ? void 0 : data.deployment) === null || _b === void 0 ? void 0 : _b.status) && React.createElement(Loading, null),
        React.createElement("div", { style: { display: 'flex', justifyContent: 'space-between' } },
            React.createElement("div", { className: "spaced-4" },
                canUpgrade && recommendedUpgrade && (React.createElement(IconButton, { icon: React.createElement(UpgradeIcon, null), onClick: onUpgrade || defaultUpgradeHandler, "aria-label": i18n.t('label.upgrade'), "data-event": "Upgrade Platform Service" })),
                onConfigure && (React.createElement(IconButton, { icon: React.createElement(SettingsIcon, null), onClick: onConfigure, "aria-label": i18n.t('label.configure'), "data-event": "Configure Platform Service" })),
                canRemove && (React.createElement(IconButton, { icon: React.createElement(DeleteIcon, null), onClick: function () {
                        apiDangerConfirm(i18n.t('compute.label.deleteConfirmMessageWithName', [name]), function (confirmed) {
                            if (confirmed) {
                                deleteDeployment({
                                    name: name,
                                    namespace: namespace,
                                    clusterCrn: cluster.clusterCrn
                                });
                            }
                        });
                    }, "aria-label": i18n.t('label.remove'), "data-event": "Remove Platform Service" })))),
        React.createElement(Heading, { style: { fontWeight: 'bold', fontSize: 'large', marginBottom: 0 }, ellipsis: {
                tooltip: {
                    overlayInnerStyle: {
                        minHeight: 0
                    }
                },
                rows: 1,
                expandable: false
            } }, name),
        version && React.createElement(React.Fragment, null, "".concat(i18n.t('label.version'), " ").concat(version)),
        recommendedUpgrade && (React.createElement(DeploymentUpgradeModal, { name: name, namespace: namespace, isModalVisible: isDeploymentUpgradeModalVisible, setIsModalVisible: setIsDeploymentUpgradeModalVisible, clusterCrn: cluster === null || cluster === void 0 ? void 0 : cluster.clusterCrn, versions: availableUpgrades, recommendedVersion: recommendedUpgrade, onSuccess: function () {
                onUpgradeSuccess === null || onUpgradeSuccess === void 0 ? void 0 : onUpgradeSuccess();
                refresh();
            }, showAdvanced: showAdvanced, confirmMessage: upgradeConfirmMessage }))));
};
export default PlatformServiceCard;
