// Copyright (c) 2022 Cloudera, Inc. All rights reserved.
var __makeTemplateObject = (this && this.__makeTemplateObject) || function (cooked, raw) {
    if (Object.defineProperty) { Object.defineProperty(cooked, "raw", { value: raw }); } else { cooked.raw = raw; }
    return cooked;
};
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var _a;
import React from 'react';
import ErrorIcon from '@cloudera/cuix-core/icons/react/ErrorIcon';
import WarningIcon from '@cloudera/cuix-core/icons/react/WarningIcon';
import Modal from "cuix/dist/components/Modal";
import { Paragraph } from "cuix/dist/components/Typography";
import { alertErrorIconColor, alertWarningIconColor, cdlDefaultBorderColor, cdlSpacingS, cdlSpacingXxs, fontSizeLg } from "cuix/dist/styles/variables";
import i18n from "cuix/dist/utils/i18n";
import { ValidationStatusType } from '../types';
import styled from 'styled-components';
var iconStyle = { height: 24, width: 24, marginRight: cdlSpacingXxs };
var iconMap = (_a = {},
    _a[ValidationStatusType.Failed] = React.createElement(ErrorIcon, { style: __assign({ color: alertErrorIconColor }, iconStyle) }),
    _a[ValidationStatusType.Warning] = (React.createElement(WarningIcon, { style: __assign({ color: alertWarningIconColor }, iconStyle) })),
    _a);
var ValidationItemContainer = styled.div(templateObject_1 || (templateObject_1 = __makeTemplateObject(["\n  display: flex;\n  flex-direction: row;\n  padding: ", ";\n\n  &:not(:last-child) {\n    border-bottom-width: 1px;\n    border-bottom-style: solid;\n    border-bottom-color: ", ";\n  }\n"], ["\n  display: flex;\n  flex-direction: row;\n  padding: ", ";\n\n  &:not(:last-child) {\n    border-bottom-width: 1px;\n    border-bottom-style: solid;\n    border-bottom-color: ", ";\n  }\n"])), cdlSpacingS, cdlDefaultBorderColor);
/**
 * A single validation result, which can be either a warning or a failure.
 */
var ValidationItem = function (_a) {
    var validation = _a.validation;
    var status = validation.status;
    return (React.createElement(ValidationItemContainer, null,
        iconMap[status],
        React.createElement("div", null,
            React.createElement(Paragraph, { style: { fontSize: fontSizeLg, fontWeight: 500, marginBottom: cdlSpacingXxs } }, validation.name),
            React.createElement(Paragraph, { style: { marginBottom: 0 } }, validation.description))));
};
var ValidationSummary = styled.ul(templateObject_2 || (templateObject_2 = __makeTemplateObject(["\n  padding: 0;\n  list-style: none;\n\n  li {\n    display: inline;\n    font-weight: 500;\n\n    &:not(:last-child) {\n      margin-right: ", ";\n    }\n  }\n"], ["\n  padding: 0;\n  list-style: none;\n\n  li {\n    display: inline;\n    font-weight: 500;\n\n    &:not(:last-child) {\n      margin-right: ", ";\n    }\n  }\n"])), cdlSpacingXxs);
/**
 * List of validation results. Used to display the results of various operations
 * which are validated on the back end.
 */
export var ValidationResults = function (_a) {
    var failures = _a.failures, warnings = _a.warnings, validations = _a.validations;
    return (React.createElement(React.Fragment, null,
        React.createElement(ValidationSummary, null,
            React.createElement("li", null, "".concat(i18n.t('label.failure'), "s: ").concat(failures)),
            React.createElement("li", null, "".concat(i18n.t('label.warning'), "s: ").concat(warnings))),
        validations.map(function (validation) {
            if (![ValidationStatusType.Warning, ValidationStatusType.Failed].includes(validation.status)) {
                return null;
            }
            return React.createElement(ValidationItem, { validation: validation, key: validation.name });
        })));
};
/**
 * Modal that shows cluster creation validation results.
 */
var ValidationResultsModal = function (_a) {
    var _b, _c;
    var description = _a.description, validationResponse = _a.validationResponse, isVisible = _a.isVisible, setIsVisible = _a.setIsVisible;
    var handleClose = function () {
        setIsVisible(false);
    };
    return (React.createElement(Modal, { title: i18n.t('compute.label.problemsFound'), open: isVisible, okText: i18n.t('label.close'), onOk: handleClose, onCancel: handleClose, cancelButtonProps: { style: { display: 'none' } } },
        React.createElement(Paragraph, null, description),
        React.createElement(ValidationResults, { failures: ((_b = validationResponse === null || validationResponse === void 0 ? void 0 : validationResponse.summary) === null || _b === void 0 ? void 0 : _b.failed) || 0, warnings: ((_c = validationResponse === null || validationResponse === void 0 ? void 0 : validationResponse.summary) === null || _c === void 0 ? void 0 : _c.warning) || 0, validations: validationResponse === null || validationResponse === void 0 ? void 0 : validationResponse.validations })));
};
export default ValidationResultsModal;
var templateObject_1, templateObject_2;
