var __read = (this && this.__read) || function (o, n) {
    var m = typeof Symbol === "function" && o[Symbol.iterator];
    if (!m) return o;
    var i = m.call(o), r, ar = [], e;
    try {
        while ((n === void 0 || n-- > 0) && !(r = i.next()).done) ar.push(r.value);
    }
    catch (error) { e = { error: error }; }
    finally {
        try {
            if (r && !r.done && (m = i["return"])) m.call(i);
        }
        finally { if (e) throw e.error; }
    }
    return ar;
};
// Copyright (c) 2023 Cloudera, Inc. All rights reserved.
import React from 'react';
import { compareVersions } from 'compare-versions';
import { ComputePlatform, EnvCloudProvider } from "cdp-js/dist/api/compute/types";
import i18n from "cuix/dist/utils/i18n";
import { ClusterStatusType } from './ClusterStatus';
import { NodeGroupStatusType } from './NodeGroups/NodeGroupStatus';
import KubernetesIcon from '@cloudera/cuix-core/icons/react/KubernetesIcon';
import { InstanceTierType } from './types';
export var KUBERNETES = 'kubernetes';
export var none = "(".concat(i18n.t('label.none').toLocaleLowerCase(), ")");
export var keyValuePairsToObject = function (pairs) {
    return pairs.reduce(function (obj, pair) {
        obj[pair.key] = pair.val;
        return obj;
    }, {});
};
/**
 * Compares "DSP" chart versions, which have a semver portion followed by an
 * optional "DSP" version. For example:
 *
 * 1.0.0-dsp.1
 *
 * The delimiter between the two portions is the string '-dsp.'. Unlike standard
 * semver, which considers any version that contains a '-' to be a pre-release
 * and, therefore, a lower version than the same version without the '-', DSP
 * versions should be considered higher than their non-DSP counterparts.
 */
export var compareDspChartVersions = function (a, b) {
    var _a = __read(a.split('-dsp.'), 2), Asemver = _a[0], Adspver = _a[1];
    var _b = __read(b.split('-dsp.'), 2), Bsemver = _b[0], Bdspver = _b[1];
    // if niether has a dsp version, we can compare as standard semver
    if (Adspver === undefined && Bdspver === undefined) {
        return compareVersions(a, b);
    }
    // otherwise, we first compare the semver portion
    var semverComparison = compareVersions(Asemver, Bsemver);
    if (semverComparison === 0) {
        // if the semver portions are the same, then whichever one has a dsp version
        // is considered greater
        if (Adspver === undefined && Bdspver !== undefined) {
            return -1;
        }
        if (Adspver !== undefined && Bdspver === undefined) {
            return 1;
        }
        // if they both have dsp versions, then we must compare them
        return compareVersions(Adspver, Bdspver);
    }
    // if the semver portions were different, then the dsp version doesn't matter
    // and we can just return the semver comparison
    return semverComparison;
};
/**
 * TODO: [future] This is placeholder logic for how to determine the recommended
 * version. In the future, we should replace this with a real algorithm or with
 * a call to a "recommendation" API. (@jgolieb)
 */
export var getRecommendedDeploymentUpgrade = function (currentVersion, upgrades) {
    var recommendedVersion;
    if (!upgrades || upgrades.length === 0) {
        return undefined;
    }
    if (upgrades.length === 1) {
        recommendedVersion = upgrades[0];
    }
    var sorted = upgrades.sort(compareDspChartVersions);
    recommendedVersion = sorted[sorted.length - 1];
    if (!currentVersion) {
        return recommendedVersion;
    }
    // make sure that the recommended version is greater than the current version
    if (compareDspChartVersions(currentVersion, recommendedVersion) < 0) {
        return recommendedVersion;
    }
    return undefined;
};
var clusterPendingStatusTypes = [
    ClusterStatusType.Creating,
    ClusterStatusType.Updating,
    ClusterStatusType.DeployingServices,
    ClusterStatusType.Deleting,
    ClusterStatusType.Registering,
    ClusterStatusType.Unregistering,
    ClusterStatusType.Upgrading
];
export var isClusterPending = function (cluster) {
    return clusterPendingStatusTypes.includes(cluster.status);
};
var nodeGroupPendingStatusTypes = [NodeGroupStatusType.NodeAcquisitionInProgress];
// TODO: [future] Uncomment AksInstanceGroup when instanceGroupStatus gets added (jgolieb)
export var isInstanceGroupPending = function (instanceGroup) {
    return nodeGroupPendingStatusTypes.includes(instanceGroup.instanceGroupStatus);
};
export var isAnyClusterPending = function (clusters) {
    return clusters === null || clusters === void 0 ? void 0 : clusters.some(function (cluster) { return isClusterPending(cluster); });
};
export var isAnyInstanceGroupPending = function (cluster) {
    var _a;
    switch (cluster.computePlatform) {
        case ComputePlatform.EKS:
            if ((_a = cluster.eks) === null || _a === void 0 ? void 0 : _a.instanceGroups) {
                return Object.values(cluster.eks.instanceGroups).some(isInstanceGroupPending);
            }
            return false;
        case ComputePlatform.AKS:
            // TODO: [future] Uncomment this when AKS gets instanceGroupStatus added (jgolieb)
            // if (cluster.aks?.instanceGroups) {
            //   Object.values(cluster.aks.instanceGroups).some(isInstanceGroupPending);
            // }
            return false;
        default:
            return false;
    }
};
export var getIsClusterDisabled = function (cluster) {
    var clusterDisabledTypes = [
        ClusterStatusType.Deleted,
        ClusterStatusType.Deleting
    ];
    return clusterDisabledTypes.includes(cluster.status);
};
export var isBootstrapScriptAvailable = function (environmentProvider) {
    return (environmentProvider !== EnvCloudProvider.AZURE &&
        environmentProvider !== EnvCloudProvider.OPENSHIFT);
};
/**
 * Determines whether the cluster node images can be upgraded.
 */
export var canUpgradeImage = function (cluster) {
    if (!cluster.nodeImageUpgradeAvailable) {
        return false;
    }
    if (cluster.aks) {
        if (!cluster.aks.instanceGroups) {
            return false;
        }
        return Object.entries(cluster.aks.instanceGroups).length !== 0;
    }
    if (cluster.eks) {
        if (!cluster.eks.instanceGroups) {
            return false;
        }
        return Object.entries(cluster.eks.instanceGroups).length !== 0;
    }
    return false;
};
export var canUpgradeKubernetes = function (cluster) {
    if (cluster.availableUpgrades &&
        cluster.availableUpgrades.length > 0 &&
        !isClusterPending(cluster)) {
        return true;
    }
    return false;
};
// TODO: [future] Implement this when we know what the logic should be (manojayyanavara)
export var getAlerts = function () {
    return false;
};
// TODO: [future] Implement this when we know what the logic should be (jgolieb)
var getHasGpu = function (_instanceGroup) {
    return false;
};
export var getNodeGroups = function (cluster) {
    var _a, _b;
    var instanceGroups;
    switch (cluster.computePlatform) {
        case ComputePlatform.AKS:
            instanceGroups = ((_a = cluster.aks) === null || _a === void 0 ? void 0 : _a.instanceGroups) || {};
            break;
        case ComputePlatform.EKS:
            instanceGroups = ((_b = cluster.eks) === null || _b === void 0 ? void 0 : _b.instanceGroups) || {};
            break;
        default:
            instanceGroups = {};
            break;
    }
    return Object.values(instanceGroups).map(function (instanceGroup) {
        var nodeGroup = {
            name: instanceGroup.instanceGroupName,
            labels: instanceGroup.labels,
            taints: instanceGroup.taints,
            minimumNodes: instanceGroup.minInstance,
            maximumNodes: instanceGroup.maxInstance,
            configuredNodes: instanceGroup.instanceCount || 0,
            nodeStates: instanceGroup.instanceStates,
            rootVolume: instanceGroup.nodeVolumeSize,
            isOnDemand: instanceGroup.instanceTier === InstanceTierType.OnDemand,
            isSingleZone: instanceGroup.singleZone || false,
            hasGpu: getHasGpu(instanceGroup)
        };
        switch (cluster.computePlatform) {
            case ComputePlatform.AKS:
                var aksInstanceGroup = instanceGroup;
                nodeGroup.nodeTypes = [aksInstanceGroup.instanceType];
                // TODO: [future] Uncomment if/when these items are added to AKS instance groups. (manojayyanavara)
                // nodeGroup.status = aksInstanceGroup.instanceGroupStatus;
                // nodeGroup.image = eksInstanceGroup.ami; // or vmImage or whatever AKS calls it
                break;
            case ComputePlatform.EKS:
                var eksInstanceGroup = instanceGroup;
                nodeGroup.nodeTypes = eksInstanceGroup.instanceTypes;
                nodeGroup.status = eksInstanceGroup.instanceGroupStatus;
                nodeGroup.image = eksInstanceGroup.ami;
                break;
            default:
                break;
        }
        return nodeGroup;
    });
};
export var getPlatformServices = function (cluster, listDeploymentsResponse, includeKubernetes) {
    var _a;
    var platformServices = [];
    if (includeKubernetes) {
        platformServices.push({
            icon: React.createElement(KubernetesIcon, null),
            name: KUBERNETES,
            namespace: '',
            cluster: cluster,
            version: cluster.kubernetesVersion,
            availableUpgrades: cluster.availableUpgrades,
            liftieManaged: true
        });
    }
    (_a = listDeploymentsResponse === null || listDeploymentsResponse === void 0 ? void 0 : listDeploymentsResponse.installedDeployments) === null || _a === void 0 ? void 0 : _a.map(function (deployment) {
        var _a, _b;
        platformServices.push({
            name: deployment.name,
            namespace: deployment.namespace,
            cluster: cluster,
            version: (_a = deployment.chart) === null || _a === void 0 ? void 0 : _a.deploymentVersion,
            icon: React.createElement(KubernetesIcon, null),
            availableUpgrades: (_b = deployment.upgrades) === null || _b === void 0 ? void 0 : _b.map(function (upgrade) { return upgrade === null || upgrade === void 0 ? void 0 : upgrade.deploymentVersion; }),
            // TODO: [future] Run additional logic to determine whether individual
            // services are removable when we know what that logic should be.
            // (jgolieb)
            canRemove: true,
            liftieManaged: deployment.liftieManaged
        });
    });
    return platformServices;
};
/**
 * TODO: [future] This is placeholder logic for how to determine the recommended
 * version. In the future, we should replace this with a real algorithm or with
 * a call to a "recommendation" API. (@jgolieb)
 */
export var getRecommendedKubernetesUpgrade = function (currentVersion, upgrades) {
    var recommendedVersion;
    if (!upgrades || upgrades.length === 0) {
        return undefined;
    }
    if (upgrades.length === 1) {
        recommendedVersion = upgrades[0];
    }
    var sorted = upgrades.sort(compareVersions);
    recommendedVersion = sorted[sorted.length - 1];
    if (!currentVersion) {
        return recommendedVersion;
    }
    // make sure that the recommended version is greater than the current version
    if (compareVersions(currentVersion, recommendedVersion) < 0) {
        return recommendedVersion;
    }
    return undefined;
};
