var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (Object.prototype.hasOwnProperty.call(b, p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        if (typeof b !== "function" && b !== null)
            throw new TypeError("Class extends value " + String(b) + " is not a constructor or null");
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
// Copyright (c) 2017 Cloudera, Inc. All rights reserved.
import React, { PureComponent, Suspense } from 'react';
import { connect } from 'react-redux';
import { commonModals, actions as modalActions } from '../reducers/modalReducer';
import { Modal } from 'antd';
import i18n from '../utils/i18n';
import ApiErrorMessageBody from '../components/ApiErrorMessageBody';
import Loading from "cuix/dist/components/Loading";
var mapState = function (state) { return (__assign({}, state.modal)); };
var mapDispatch = {
    hideModal: modalActions.hideModal
};
var ModalContainer = /** @class */ (function (_super) {
    __extends(ModalContainer, _super);
    function ModalContainer() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    Object.defineProperty(ModalContainer.prototype, "commonModalAntMap", {
        get: function () {
            var _a;
            return _a = {},
                _a[commonModals.INFO_MODAL] = {
                    method: Modal.info,
                    defaultSettings: {
                        title: i18n.t('label.info')
                    }
                },
                _a[commonModals.SUCCESS_MODAL] = {
                    method: Modal.success,
                    defaultSettings: {
                        title: i18n.t('label.success')
                    }
                },
                _a[commonModals.ERROR_MODAL] = {
                    method: Modal.error,
                    defaultSettings: {
                        title: i18n.t('label.error')
                    }
                },
                _a[commonModals.WARNING_MODAL] = {
                    method: Modal.warning,
                    defaultSettings: {
                        title: i18n.t('label.warning')
                    }
                },
                _a[commonModals.CONFIRM_MODAL] = {
                    method: Modal.confirm,
                    defaultSettings: {
                        title: i18n.t('label.confirm')
                    }
                },
                _a;
        },
        enumerable: false,
        configurable: true
    });
    ModalContainer.prototype.showCommonModal = function (method, settings) {
        var _this = this;
        method(__assign({ okText: i18n.t('label.ok'), onOk: function (close) {
                // remove the dom node antd creates
                close();
                // signal to modalContainer to cleanup this modal
                _this.props.hideModal();
            } }, settings));
    };
    /**
     * We handle common modals in the componentDidUpdate since we use the Modal.info/success/error ...
     * methods to render these modals. Custom modals are rendered as reqular react components so they
     * are handled in the render method.
     */
    ModalContainer.prototype.componentDidUpdate = function () {
        var _a = this.props, modalType = _a.modalType, modalParams = _a.modalParams, visible = _a.visible;
        if (!modalType || !visible) {
            return;
        }
        var modalInfo = this.commonModalAntMap[modalType];
        if (modalInfo) {
            return this.showCommonModal(modalInfo.method, __assign(__assign({}, modalInfo.defaultSettings), modalParams));
        }
        if (modalType === commonModals.REQUEST_ERROR_MODAL) {
            var error = modalParams.error;
            this.showCommonModal(Modal.error, {
                title: error.title,
                content: React.createElement(ApiErrorMessageBody, { error: error })
            });
        }
    };
    ModalContainer.prototype.render = function () {
        var _a = this.props, modalType = _a.modalType, modalParams = _a.modalParams, visible = _a.visible, hideModal = _a.hideModal, _b = _a.modalComponents, modalComponents = _b === void 0 ? {} : _b;
        var ModalComponent = modalType && modalComponents[modalType];
        if (!ModalComponent) {
            return null;
        }
        return (React.createElement(Suspense, { fallback: React.createElement(Loading, null) },
            React.createElement(DelayedRemove, { remove: !visible },
                React.createElement(ModalComponent, __assign({}, modalParams, { hideModal: hideModal, visible: visible })))));
    };
    return ModalContainer;
}(PureComponent));
export default connect(mapState, mapDispatch)(ModalContainer);
var DelayedRemove = /** @class */ (function (_super) {
    __extends(DelayedRemove, _super);
    function DelayedRemove() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.state = { remove: false };
        return _this;
    }
    /**
     * If remove flag is set to false we should update state immediately so that the chilren is rendered.
     */
    DelayedRemove.getDerivedStateFromProps = function (props) {
        return props.remove ? null : { remove: false };
    };
    /**
     * Sets a timer for removing chilren when remove is set to true.
     */
    DelayedRemove.prototype.componentDidUpdate = function () {
        var _this = this;
        if (this.removeTimer) {
            clearTimeout(this.removeTimer);
            this.removeTimer = undefined;
        }
        if (this.props.remove) {
            this.removeTimer = window.setTimeout(function () { return _this.setState({ remove: true }); }, this.props.delay);
        }
    };
    DelayedRemove.prototype.render = function () {
        return this.state.remove ? null : this.props.children;
    };
    DelayedRemove.defaultProps = {
        delay: 300
    };
    return DelayedRemove;
}(React.PureComponent));
