var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (Object.prototype.hasOwnProperty.call(b, p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        if (typeof b !== "function" && b !== null)
            throw new TypeError("Class extends value " + String(b) + " is not a constructor or null");
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
// Copyright (c) 2019 Cloudera, Inc. All rights reserved.
import React from 'react';
import Loading from "cuix/dist/components/Loading";
import PageError from "cuix/dist/components/PageError";
import { API_ERROR_CODES } from "cuix/dist/utils/getErrorInfo";
import { FetchStatus } from "cuix/dist/reducers/apiBusReducer";
import InlineError from "cuix/dist/components/InlineError";
/**
 * HOC for handling common states for components. Handles following states:
 *
 * ERROR: If error prop is defined it is considered a fatal error and an error component is
 * rendered. UI for NOT_FOUND errors can be customized with the getNotFoundState configuration.
 *
 * FETCHING: If fetching prop is true the Loading component is rendered. Fetching state is determined
 * by either the boolean fetching flag or the fetchStatus value. See apiBusReducer.FetchStatus for
 * more info.
 *
 * EMPTY: If isEmpty prop is true a custom empty state component is rendered. There is no default UI
 * for empty state so getEmptyState configuration option is required if isEmpty is provided.
 *
 * All these props are optional so you can opt out of handling a specific state while still handling
 * other by not providing the corresponding prop.
 *
 * @param {object} config Configuration object
 * @param {props => ReactNode} config.getEmptyState Function that returns a ReactNode to render when
 * component is in empty state
 * @param {props => ReactNode} config.getNotFoundState Function that returns a ReactNode to render
 * when component has a NOT_FOUND error
 */
// TODO: [future] switch over to use new FETCH_INITIAL vs FETCH_FOLLOWING and refactor usage.
// Should we use "refresh" naming at this level, or move it further down? We could include
// fetching=true/false isInitalFetch=true/false to the child component if we wanted to leave that
// semantic out? (arne)
var withStateHandling = function (config) {
    if (config === void 0) { config = {}; }
    return function (WrappedComponent) {
        var _a;
        return _a = /** @class */ (function (_super) {
                __extends(class_1, _super);
                function class_1() {
                    var _this = _super !== null && _super.apply(this, arguments) || this;
                    _this.isFetching = function () {
                        return _this.props.fetching || _this.props.fetchStatus === FetchStatus.FETCHING;
                    };
                    return _this;
                }
                class_1.prototype.render = function () {
                    var _a = this.props, error = _a.error, infoError = _a.infoError, fetching = _a.fetching, fetchStatus = _a.fetchStatus, isEmpty = _a.isEmpty, useInlineLoader = _a.useInlineLoader, otherProps = __rest(_a, ["error", "infoError", "fetching", "fetchStatus", "isEmpty", "useInlineLoader"]);
                    // If isEmpty is provided getEmptyState needs to be provided as well.
                    if (isEmpty !== undefined && config.getEmptyState === undefined) {
                        throw new Error('Invalid configuration. isEmpty is provided without getEmptyState config');
                    }
                    if (error) {
                        if (error.code === API_ERROR_CODES.NOT_FOUND && config.getNotFoundState) {
                            return config.getNotFoundState(this.props);
                        }
                        else {
                            return config.getErrorState ? (config.getErrorState(this.props)) : (React.createElement(PageError, __assign({}, error)));
                        }
                    }
                    if (this.isFetching()) {
                        if (config.getFetchingState) {
                            return config.getFetchingState(this.props);
                        }
                        else {
                            return React.createElement(Loading, { inline: useInlineLoader, size: config.loadingIndicatorSize });
                        }
                    }
                    if (isEmpty && config.getEmptyState) {
                        return config.getEmptyState(this.props);
                    }
                    return (React.createElement(React.Fragment, null,
                        infoError && (React.createElement(React.Fragment, null,
                            React.createElement(InlineError, { error: infoError, closable: true, showIcon: true }),
                            React.createElement("br", null))),
                        React.createElement(WrappedComponent, __assign({}, otherProps, { fetching: this.isFetching(), refreshing: fetchStatus === FetchStatus.REFRESHING }))));
                };
                return class_1;
            }(React.Component)),
            _a.WrappedComponent = WrappedComponent,
            _a;
    };
};
export default withStateHandling;
