import { ApiError } from "cuix/dist/types/types";
import React from 'react';
interface RequestLikeType {
    error?: ApiError;
    fetching: boolean;
}
interface Props {
    /**
     * Request. This is for example the object you'd get when using `useApiData` hook.
     * You can pass in several as an array. If multiple errors, only the first one will
     * be shown.
     */
    request: RequestLikeType | RequestLikeType[];
    /**
     * Use `<PageError>` instead of `<InlineError>` to display errors
     */
    usePageError?: boolean;
    /**
     * Use <Loading inline /> during fetching
     */
    inlineLoading?: boolean;
}
/**
 * Convenince component to handle both loading and error states from a request object
 * such as what you get when using `useApiData` hook.
 *
 * Typically you'd want to use this in combination with the `isSuccessfullyCompleted`
 * type predicate helper.
 *
 * If you pass in multiple requests with errors, only the first error will be shown.
 *
 * Example:
 *
 * ```tsx
 * const req = useApiData(...);
 *
 * if (!isSuccessfullyCompleted(req)) {
 *   return <LoadingAndErrorHandler request={req} />;
 * }
 *
 * return <span>name: {req.data.name}</span>
 * ```
 *
 */
declare const LoadingAndErrorHandler: React.FC<Props>;
export default LoadingAndErrorHandler;
