var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
import React from 'react';
import InlineError from "cuix/dist/components/InlineError";
import Loading from "cuix/dist/components/Loading";
import PageError from "cuix/dist/components/PageError";
/**
 * Convenince component to handle both loading and error states from a request object
 * such as what you get when using `useApiData` hook.
 *
 * Typically you'd want to use this in combination with the `isSuccessfullyCompleted`
 * type predicate helper.
 *
 * If you pass in multiple requests with errors, only the first error will be shown.
 *
 * Example:
 *
 * ```tsx
 * const req = useApiData(...);
 *
 * if (!isSuccessfullyCompleted(req)) {
 *   return <LoadingAndErrorHandler request={req} />;
 * }
 *
 * return <span>name: {req.data.name}</span>
 * ```
 *
 */
var LoadingAndErrorHandler = function (_a) {
    var _b;
    var request = _a.request, usePageError = _a.usePageError, inlineLoading = _a.inlineLoading;
    var requestList = Array.isArray(request) ? request : [request];
    var error = (_b = requestList.find(function (req) { return req.error; })) === null || _b === void 0 ? void 0 : _b.error;
    var fetching = requestList.some(function (req) { return req.fetching; });
    if (error) {
        if (usePageError) {
            return React.createElement(PageError, __assign({}, error));
        }
        else {
            return React.createElement(InlineError, { error: error });
        }
    }
    else if (fetching) {
        return React.createElement(Loading, { inline: inlineLoading });
    }
    return null;
};
export default LoadingAndErrorHandler;
