import { HooksConfig } from './useInternalApiData';
/**
 * Hook for retrieving API data. Fetches when callback is called.
 *
 * **NOTE**: Consider using `useApiData` instead as that now also supports on-demand fetching.
 * That would be preferred unless that does not meet your requirements.
 *
 * startFetchFn can take 'force' param to force new request instead of reusing
 * existing data if available.
 *
 * Example:
 *
 * ```js
 * const [{ data, error, fetching }, startFetchFn] = useOnDemandApiData({
 *   api: wa.getOperationExecutionDetails,
 *   fetchParams: {
 *     id: 'xyz',
 *   }
 * });
 *
 * startFetchFn(); // fetch data (or reuse existing if available)
 * ```
 */
export default function useOnDemandApiData<ApiParams, ResponseType>(apiConfig: HooksConfig<ResponseType, ApiParams>): readonly [{
    fetching: boolean;
    fetchingInitial: boolean;
    data: ResponseType | undefined;
    listData: any[];
    error: import("../../types/types").ApiError | undefined;
    unstarted: boolean;
}, (config?: {
    force?: boolean | undefined;
    onlyIfInvalid?: boolean | undefined;
} | undefined) => void];
