// Copyright (c) 2020 Cloudera, Inc. All rights reserved.
import useInternalApiData from './useInternalApiData';
/**
 * Hook for retrieving API data. Fetches when callback is called.
 *
 * **NOTE**: Consider using `useApiData` instead as that now also supports on-demand fetching.
 * That would be preferred unless that does not meet your requirements.
 *
 * startFetchFn can take 'force' param to force new request instead of reusing
 * existing data if available.
 *
 * Example:
 *
 * ```js
 * const [{ data, error, fetching }, startFetchFn] = useOnDemandApiData({
 *   api: wa.getOperationExecutionDetails,
 *   fetchParams: {
 *     id: 'xyz',
 *   }
 * });
 *
 * startFetchFn(); // fetch data (or reuse existing if available)
 * ```
 */
export default function useOnDemandApiData(apiConfig) {
    var _a = useInternalApiData(apiConfig), fetching = _a.fetching, fetchingInitial = _a.fetchingInitial, data = _a.data, listData = _a.listData, error = _a.error, unstarted = _a.unstarted, startFetchIfNeeded = _a.startFetchIfNeeded;
    var obj = {
        fetching: fetching,
        fetchingInitial: fetchingInitial,
        data: data,
        listData: listData,
        error: error,
        unstarted: unstarted
    };
    return [obj, startFetchIfNeeded];
}
