/**
 * Debounced a setState value/setter.
 * This could be used in a child component if you don't want to update the parent component for
 * example while typing, because that would be expensive and cause UI delays.
 *
 * Usage:
 *
 * ```js
 * // Child input debouncing within component
 * const ChildFilter = ({ value, setValue }) => {
 *   const [internalValue, setInternalValue] = useDebouncedProxyState(value, setValue);
 *   return <Input value={internalValue} onChange(e => setInternalValue(e.target.value)) />;
 * }
 *
 * // search param debouncing
 * const SearchFilter = () => {
 *   const [searchTerm, setSearchTerm] = useSearchParamState('searchTerm', '');
 *   const [internalSearchTerm, setInternalSearchTerm] = useDebouncedProxyState(
 *     searchTerm,
 *     setSearchTerm
 *   );
 *   return <Input value={internalSearchTerm} onChange(e => setInternalSearchTerm(e.target.value)) />;
 * }
 * ```
 */
export declare const useDebouncedProxyState: <T extends unknown>(externalValue: T, setExternalValue: (val: T) => any, debounceDelayMs?: number) => readonly [T, (val: T) => void];
export default useDebouncedProxyState;
