/**
 * Similar to useState, but also outputs a debounced value (e.g. a value that updates less often)
 * This can be used to limit re-renders and/or expensive processing
 *
 * Typically you'd use this with `React.memo(Child)` to reduce children rendering or `useMemo` etc
 * to reduce internal calculations.
 *
 * Another option is move the source of the changes to it's own component and use
 * `useDebouncedProxyState` instead.
 *
 * The default debounce time (a.k.a delay between updates) is 200ms.
 *
 * Usage:
 *
 * ```js
 * const [value, debouncedValue, setValue] = useDebouncedState('initial value');
 * ```
 */
declare const useDebouncedState: <T extends {}>(initialValue: T, debounceDelayMs?: number) => readonly [T, T, (val: T) => void];
export default useDebouncedState;
