var __read = (this && this.__read) || function (o, n) {
    var m = typeof Symbol === "function" && o[Symbol.iterator];
    if (!m) return o;
    var i = m.call(o), r, ar = [], e;
    try {
        while ((n === void 0 || n-- > 0) && !(r = i.next()).done) ar.push(r.value);
    }
    catch (error) { e = { error: error }; }
    finally {
        try {
            if (r && !r.done && (m = i["return"])) m.call(i);
        }
        finally { if (e) throw e.error; }
    }
    return ar;
};
// Copyright (c) 2021 Cloudera, Inc. All rights reserved.
import { useState, useMemo, useCallback, useLayoutEffect } from 'react';
import debounce from 'lodash/debounce';
/**
 * Similar to useState, but also outputs a debounced value (e.g. a value that updates less often)
 * This can be used to limit re-renders and/or expensive processing
 *
 * Typically you'd use this with `React.memo(Child)` to reduce children rendering or `useMemo` etc
 * to reduce internal calculations.
 *
 * Another option is move the source of the changes to it's own component and use
 * `useDebouncedProxyState` instead.
 *
 * The default debounce time (a.k.a delay between updates) is 200ms.
 *
 * Usage:
 *
 * ```js
 * const [value, debouncedValue, setValue] = useDebouncedState('initial value');
 * ```
 */
var useDebouncedState = function (initialValue, debounceDelayMs) {
    if (debounceDelayMs === void 0) { debounceDelayMs = 200; }
    var _a = __read(useState(initialValue), 2), value = _a[0], setValue = _a[1];
    var _b = __read(useState(initialValue), 2), debouncedValue = _b[0], setDebouncedValue = _b[1];
    var debouncedCallback = useMemo(function () {
        return debounce(setDebouncedValue, debounceDelayMs);
    }, [debounceDelayMs]);
    var set = useCallback(function (val) {
        setValue(val);
        debouncedCallback(val);
    }, [debouncedCallback]);
    useLayoutEffect(function () {
        return function () {
            // calling setDebouncedValue after unmount is a no-op technically
            // so there might not be any harm in it. However, there will be a
            // warning printed so we'll cancel any outstanding debounces after
            // the component has been unmounted.
            debouncedCallback.cancel();
        };
    }, [debouncedCallback]);
    return [value, debouncedValue, set];
};
export default useDebouncedState;
