/**
 * Hook to interact with our preference state, which is backed by localStorage, which will persist
 * between sessions. The `storageKey` is the key suffix used by localStorage to store the value.
 *
 * Works similarly to `React.useState`.
 *
 * ```tsx
 * // sets up a state stored under the 'sigma.showNotice' key and with
 * // default value of `true`.
 * const [value, setValue] = usePreferenceState('sigma.showNotice', true)
 *
 * // setting direct value
 * setValue(false);
 *
 * // setting via fn
 * setValue(oldState => !oldState);
 * ```
 *
 * See `preferenceReducer` and `storageSaga` for more details.
 */
export declare const usePreferenceState: <T extends unknown>(storageKey: string, defaultValue?: T | undefined) => readonly [T, (valueOrFn: T | ((val: T) => T)) => void];
