// Copyright (c) 2021 Cloudera, Inc. All rights reserved.
import { useCallback } from 'react';
import { getSearchParams, actions as routerActions } from "cuix/dist/reducers/routerReducer";
import { useDispatch, useSelector } from 'react-redux';
/**
 * Instead of dealing with searchParams/routerReducer directly, this hook is to
 * access and edit all search params. See `useSearchParamState` for single value
 * state edit that behaves more like `React.useState`.
 *
 * Note that the set call does behave differently than `React.useState` here in
 * that it will only update the keys given and leave other keys alone. This is
 * the same behavior routerActions.updateSearchParams has.
 */
export var useAllSearchParamsState = function () {
    var searchParams = useSelector(getSearchParams);
    var dispatch = useDispatch();
    var setValue = useCallback(function (value) {
        dispatch(routerActions.updateSearchParams(value));
    }, [dispatch]);
    return [searchParams, setValue];
};
