/**
 * Instead of dealing with searchParams/routerReducer directly, this is hook similar to React.useState
 * that will store the state as a search parameter. This can be useful for storing state that should
 * survive reload/be part of url e.g. such as which tab you're on.
 */
declare const useSearchParamState: (searchParamKey: string, defaultValue?: string | string[]) => readonly [string | string[] | undefined, (value: string | string[] | undefined) => void];
export default useSearchParamState;
/**
 * Same as `useSearchParamState` except it will never return `string[]` as value, only
 * `string` or `undefined`. If it encounters `string[]` then it will return first element.
 */
export declare const useSimpleSearchParamState: (searchParamKey: string, defaultValue?: string) => readonly [string | undefined, (value: string | string[] | undefined) => void];
