// Copyright (c) 2021 Cloudera, Inc. All rights reserved.
var __read = (this && this.__read) || function (o, n) {
    var m = typeof Symbol === "function" && o[Symbol.iterator];
    if (!m) return o;
    var i = m.call(o), r, ar = [], e;
    try {
        while ((n === void 0 || n-- > 0) && !(r = i.next()).done) ar.push(r.value);
    }
    catch (error) { e = { error: error }; }
    finally {
        try {
            if (r && !r.done && (m = i["return"])) m.call(i);
        }
        finally { if (e) throw e.error; }
    }
    return ar;
};
import { useCallback } from 'react';
import { getSearchParams, actions as routerActions } from "cuix/dist/reducers/routerReducer";
import { useDispatch, useSelector } from 'react-redux';
/**
 * Instead of dealing with searchParams/routerReducer directly, this is hook similar to React.useState
 * that will store the state as a search parameter. This can be useful for storing state that should
 * survive reload/be part of url e.g. such as which tab you're on.
 */
var useSearchParamState = function (searchParamKey, defaultValue) {
    var searchParams = useSelector(getSearchParams);
    var value = searchParams[searchParamKey] || defaultValue;
    var dispatch = useDispatch();
    var setValue = useCallback(function (value) {
        var _a;
        var stateUpdate = (_a = {},
            _a[searchParamKey] = !!value && value !== defaultValue ? value : undefined,
            _a);
        dispatch(routerActions.updateSearchParams(stateUpdate));
    }, [defaultValue, dispatch, searchParamKey]);
    return [value, setValue];
};
export default useSearchParamState;
/**
 * Same as `useSearchParamState` except it will never return `string[]` as value, only
 * `string` or `undefined`. If it encounters `string[]` then it will return first element.
 */
export var useSimpleSearchParamState = function (searchParamKey, defaultValue) {
    var _a = __read(useSearchParamState(searchParamKey, defaultValue), 2), value = _a[0], setValue = _a[1];
    var simpleValue = Array.isArray(value) ? value[0] : value;
    return [simpleValue, setValue];
};
