var __makeTemplateObject = (this && this.__makeTemplateObject) || function (cooked, raw) {
    if (Object.defineProperty) { Object.defineProperty(cooked, "raw", { value: raw }); } else { cooked.raw = raw; }
    return cooked;
};
var __read = (this && this.__read) || function (o, n) {
    var m = typeof Symbol === "function" && o[Symbol.iterator];
    if (!m) return o;
    var i = m.call(o), r, ar = [], e;
    try {
        while ((n === void 0 || n-- > 0) && !(r = i.next()).done) ar.push(r.value);
    }
    catch (error) { e = { error: error }; }
    finally {
        try {
            if (r && !r.done && (m = i["return"])) m.call(i);
        }
        finally { if (e) throw e.error; }
    }
    return ar;
};
// Copyright (c) 2023 Cloudera, Inc. All rights reserved.
import React, { useContext, useState } from 'react';
import NotificationsIcon from '@cloudera/cuix-core/icons/react/NotificationsIcon';
import { Drawer, Menu } from 'antd';
import CloseIcon from '@cloudera/cuix-core/icons/react/CloseIcon';
import ActionsDropdown from "cuix/dist/components/ActionsDropdown";
import useApiData from "cuix/dist/hooks/useApiData";
import notification from "cdp-js/dist/api/notification";
import Notification from './Notification';
import SettingsIcon from '@cloudera/cuix-core/icons/react/SettingsIcon';
import { createIsEntitledSelector } from "../../../cloud-common/src/react/reducers/authReducer";
import { useSelector } from 'react-redux';
import styled from 'styled-components';
import i18n from "cuix/dist/utils/i18n";
import { NotificationContext } from "cuix/dist/utils/NotificationContext";
import { IconButton, LinkButton } from "cuix/dist/components/Button";
import { cdlIconSizeDefault, cdlSpacingM, cdlSpacingS, cdlSpacingXs, cdlSpacingXxs } from "cuix/dist/styles/variables";
import { Text } from "cuix/dist/components/Typography";
import Loading from "cuix/dist/components/Loading";
import PageError from "cuix/dist/components/PageError";
import { defaultTheme as theme } from "cuix/dist/styles/theme";
import { bodyColor, iconColor, panelBackgroundColor, panelBorderColor } from './Notifications.theme';
var NOTIFICATION_ENTITLEMENT_NAME = 'CDP_NOTIFICATION_SERVICE';
var pageSize = 10;
var getIsEntitledToNotificationFlow = createIsEntitledSelector(NOTIFICATION_ENTITLEMENT_NAME);
var StyledNotificationPanel = styled(Drawer)(templateObject_1 || (templateObject_1 = __makeTemplateObject(["\n  .ant-drawer-wrapper-body {\n    background-color: ", ";\n  }\n  .ant-drawer-header {\n    border-bottom: 1px solid ", ";\n  }\n  .ant-drawer-footer {\n    border-top: 1px solid ", ";\n  }\n"], ["\n  .ant-drawer-wrapper-body {\n    background-color: ", ";\n  }\n  .ant-drawer-header {\n    border-bottom: 1px solid ", ";\n  }\n  .ant-drawer-footer {\n    border-top: 1px solid ", ";\n  }\n"])), panelBackgroundColor, panelBorderColor, panelBorderColor);
StyledNotificationPanel.defaultProps = { theme: theme };
var StyledNotificationsIcon = styled(NotificationsIcon)(templateObject_2 || (templateObject_2 = __makeTemplateObject(["\n  margin-left: ", ";\n  font-size: ", ";\n  line-height: 0;\n  color: ", ";\n"], ["\n  margin-left: ", ";\n  font-size: ", ";\n  line-height: 0;\n  color: ", ";\n"])), cdlSpacingS, cdlIconSizeDefault, iconColor);
StyledNotificationsIcon.defaultProps = { theme: theme };
var StyledCloseIcon = styled(IconButton)(templateObject_3 || (templateObject_3 = __makeTemplateObject(["\n  margin-left: ", ";\n  color: ", ";\n  &:hover {\n    color: ", ";\n  }\n"], ["\n  margin-left: ", ";\n  color: ", ";\n  &:hover {\n    color: ", ";\n  }\n"])), cdlSpacingXxs, bodyColor, iconColor);
StyledCloseIcon.defaultProps = { theme: theme };
var Notifications = function () {
    var _a, _b, _c, _d;
    var _e = __read(useState(false), 2), open = _e[0], setOpen = _e[1];
    var setActiveTab = useContext(NotificationContext);
    var isEntitledToNotificationFlow = useSelector(getIsEntitledToNotificationFlow);
    var broadcastNotificationMessages = useApiData({
        api: notification.listNotificationMessages,
        fetchParams: {
            pageSize: pageSize,
            pageToken: ''
        }
    });
    var onClose = function () {
        setOpen(false);
    };
    var showNotificationPanel = function () {
        setOpen(true);
    };
    var navigate = function (key) {
        if (setActiveTab) {
            setActiveTab(key);
            onClose();
        }
        else {
            window.location.href = "".concat(window.location.protocol, "//").concat(window.location.host, "/notification/#/?tab=").concat(key);
        }
    };
    var items = [
        {
            key: 'notifications',
            label: i18n.t('label.showAllNotifications'),
            icon: React.createElement(NotificationsIcon, { style: { fontSize: cdlIconSizeDefault } }),
            onClick: function () { return navigate('notifications'); }
        },
        {
            key: 'subscriptions',
            label: i18n.t('label.subscriptions'),
            icon: React.createElement(SettingsIcon, { style: { fontSize: cdlIconSizeDefault } }),
            onClick: function () { return navigate('subscriptions'); }
        }
    ];
    if (!isEntitledToNotificationFlow || !broadcastNotificationMessages) {
        return null;
    }
    return (React.createElement(React.Fragment, null,
        React.createElement(StyledNotificationsIcon, { onClick: showNotificationPanel }),
        React.createElement(StyledNotificationPanel, { title: React.createElement(Text, { bold: true, size: "large" }, i18n.t('label.notifications')), headerStyle: { height: 57, flexBasis: 'auto' }, footerStyle: {
                paddingTop: cdlSpacingXs,
                paddingBottom: cdlSpacingXs,
                paddingLeft: cdlSpacingM,
                paddingRight: cdlSpacingM,
                display: 'flex',
                justifyContent: 'right',
                alignItems: 'center'
            }, placement: "right", width: 500, onClose: onClose, open: open, closable: false, footer: React.createElement(LinkButton, { "data-event": "Show All Notifications", onClick: function () { return navigate('notifications'); } }, i18n.t('label.showAllNotifications')), extra: React.createElement(React.Fragment, null,
                React.createElement(ActionsDropdown, { dots: true },
                    React.createElement(Menu, { items: items, onClick: function (event) { return navigate(event.key); } })),
                React.createElement(StyledCloseIcon, { "aria-label": "Close notification drawer", icon: React.createElement(CloseIcon, null), onClick: onClose })) }, broadcastNotificationMessages.error ? (React.createElement(PageError, { title: i18n.t('label.error'), message: i18n.t('label.unexpectedError.title') })) : broadcastNotificationMessages.fetching ? (React.createElement(Loading, null)) : ((_b = (_a = broadcastNotificationMessages === null || broadcastNotificationMessages === void 0 ? void 0 : broadcastNotificationMessages.data) === null || _a === void 0 ? void 0 : _a.notifications) === null || _b === void 0 ? void 0 : _b.length) ? ((_d = (_c = broadcastNotificationMessages === null || broadcastNotificationMessages === void 0 ? void 0 : broadcastNotificationMessages.data) === null || _c === void 0 ? void 0 : _c.notifications) === null || _d === void 0 ? void 0 : _d.map(function (data, index) { return (React.createElement(Notification, { key: "broadcast-card-".concat(index), broadcastNotification: data })); })) : (React.createElement(Text, null, i18n.t('label.noNotifications'))))));
};
export default Notifications;
var templateObject_1, templateObject_2, templateObject_3;
