var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __read = (this && this.__read) || function (o, n) {
    var m = typeof Symbol === "function" && o[Symbol.iterator];
    if (!m) return o;
    var i = m.call(o), r, ar = [], e;
    try {
        while ((n === void 0 || n-- > 0) && !(r = i.next()).done) ar.push(r.value);
    }
    catch (error) { e = { error: error }; }
    finally {
        try {
            if (r && !r.done && (m = i["return"])) m.call(i);
        }
        finally { if (e) throw e.error; }
    }
    return ar;
};
var _a;
import get from 'lodash/get';
import omit from 'lodash/omit';
export var types = {
    SUBMIT_REQUEST: 'SUBMIT_REQUEST',
    REQUEST_SUCCESS: 'REQUEST_SUCCESS',
    REQUEST_FAILURE: 'REQUEST_FAILURE',
    PREPARE_CHANNEL: 'PREPARE_CHANNEL',
    REQUEST_FLUSH: 'REQUEST_FLUSH',
    IS_CONFIRMED: 'IS_CONFIRMED'
};
/**
 * Maps message configuration value provided by the user to a proper message configuration object.
 * @param {Function:Promise} requestMethod The request method for the API call.
 * @param {string|array|object} userMessageConfig User provided message configuration value. Can be
 * a string, array of strings, or a message config object.
 *
 * @return Returns a message configuration object in this format:
 * { confirmKey, confirmParams, notifyKey, notifyParams }
 */
export var getMessageConfig = function (requestMethod, userMessageConfig) {
    var serviceName = requestMethod.serviceName, methodName = requestMethod.methodName;
    var defaultMessageConfig = {
        confirmKey: "".concat(serviceName, ".api.").concat(methodName, ".confirm"),
        confirmParams: [],
        notifyKey: "".concat(serviceName, ".api.").concat(methodName, ".notify"),
        notifyParams: []
    };
    if (!userMessageConfig ||
        (typeof userMessageConfig === 'object' && !Array.isArray(userMessageConfig))) {
        return __assign(__assign({}, defaultMessageConfig), userMessageConfig);
    }
    if (typeof userMessageConfig === 'string') {
        userMessageConfig = [userMessageConfig];
    }
    return __assign(__assign({}, defaultMessageConfig), { confirmParams: userMessageConfig, notifyParams: userMessageConfig });
};
export var actions = {
    /**
     * @param {Function:Promise} requestMethod An async function that returns cdp-js/ApiResponse when await finishes.
     * @param {object} requestParams Any parameters to send in the body of the request.
     * @param {string} channel Optional. This defaults to the requestMethod methodName. It specifies the bucket to put the most recent invokation of the request.
     */
    submitRequest: function (requestMethod, requestParams, channel, args) {
        if (args === void 0) { args = {}; }
        channel = channel || requestMethod.methodName;
        if (!channel) {
            throw new Error('Missing channel. Channel is required.');
        }
        if (args.messageConfig) {
            args.messageConfig = getMessageConfig(requestMethod, args.messageConfig);
        }
        return {
            type: types.SUBMIT_REQUEST,
            requestMethod: requestMethod,
            requestParams: requestParams,
            channel: channel,
            args: args
        };
    },
    /**
     * Creates a SUBMIT_REQUEST action with listAll argument set to true by default.
     * If listAll is set to true for a listing API, apiBusSaga will fetch all pages.
     */
    submitListRequest: function (requestMethod, requestParams, channel, args) {
        if (args === void 0) { args = {}; }
        return actions.submitRequest(requestMethod, requestParams, channel, __assign(__assign({}, args), { listAll: true }));
    },
    /**
     * @param {Function:Promise} requestMethod An async function that returns cdp-js/ApiResponse when await finishes.
     * @param {object} requestParams Any parameters to send in the body of the request.
     * @param {string} channel Required. This defaults to the requestMethod methodName. It specifies the bucket to put the most recent invokation of the request.
     * @param {string|array|object} messageConfig Required. Configuration for the confirm and notify
     * messages. Accepts a single paremeter string, and array of parameters, or the full configuration
     * object with keys and params.
     */
    submitConfirmedRequest: function (requestMethod, requestParams, channel, messageConfig, args) {
        if (args === void 0) { args = {}; }
        return actions.submitRequest(requestMethod, requestParams, channel, __assign(__assign({ notify: true }, args), { messageConfig: messageConfig, confirm: true }));
    },
    requestSuccess: function (submitAction, response, lastFetched) { return ({
        type: types.REQUEST_SUCCESS,
        channel: submitAction.channel,
        response: response,
        lastFetched: lastFetched,
        args: submitAction.args
    }); },
    requestFailure: function (submitAction, error) { return ({
        type: types.REQUEST_FAILURE,
        channel: submitAction.channel,
        error: error,
        args: submitAction.args
    }); },
    /**
     * Sets fetching to true for given channel. Can be used when a requets depends on another request
     * to finish but you want the UI to think the request is in progress.
     * @param {string|function} channel. Name of the channel or the API method
     */
    prepareChannel: function (channel) {
        var realChannel = typeof channel === 'string' ? channel : channel.methodName;
        if (realChannel === undefined) {
            throw new Error('Cannot find a channel name.');
        }
        return {
            type: types.PREPARE_CHANNEL,
            channel: realChannel
        };
    },
    /**
     * Flushes the state.
     * Can be used to flush a specific api request state.
     * @param {string} Optional channel. If no channel is provided, all state is flushed.
     */
    flush: function (channel) { return ({ type: types.REQUEST_FLUSH, channel: channel }); },
    /**
     * Marks the request as confirmed, used by confirmedRequests.
     * Indicates that the user confirmed the request, and we have entered the fetching state.
     * @param channel
     */
    isConfirmed: function (channel) { return ({ type: types.IS_CONFIRMED, channel: channel }); }
};
/**
 * The state of this reducer is to store an object with keys being the request name.
 * The values for the request object contain the following:
 * fetching: true/false,
 * requestMethod: the async api callback which returns cdp-js/ApiResponse
 * requestParams: the params to pass to the api call.
 * response: A successful cdp-js/ApiResponse
 * error: An cdp-js/ErrorResponse
 *
 * To clear out the store, a flush event is invoked
 * Flush events can be used to clear out specific request data, if necessary.
 */
var actionMap = (_a = {},
    _a[types.SUBMIT_REQUEST] = function (state, action) {
        var _a;
        var channel = action.channel, requestParams = action.requestParams, requestMethod = action.requestMethod;
        return __assign(__assign({}, state), (_a = {}, _a[channel] = __assign(__assign({}, state[channel]), { error: undefined, fetching: true, requestParams: requestParams, preserve: action.args.preserve, invalidated: false, unconfirmed: action.args.confirm, invalidateOn: action.args.invalidateOn, requestMethod: requestMethod
                ? { methodName: requestMethod.methodName, serviceName: requestMethod.serviceName }
                : undefined }), _a));
    },
    _a[types.REQUEST_SUCCESS] = function (state, action) {
        var _a;
        var _b;
        var requestMethod = (_b = state[action.channel]) === null || _b === void 0 ? void 0 : _b.requestMethod;
        // Find all channels that will be invalidated by this call, and mark them.
        var invalidatedChannels = Object.entries(state).reduce(function (someState, _a) {
            var _b;
            var _c = __read(_a, 2), channelName = _c[0], channel = _c[1];
            if ((_b = channel === null || channel === void 0 ? void 0 : channel.invalidateOn) === null || _b === void 0 ? void 0 : _b.find(function (signature) {
                return signature.methodName === (requestMethod === null || requestMethod === void 0 ? void 0 : requestMethod.methodName) &&
                    signature.serviceName === (requestMethod === null || requestMethod === void 0 ? void 0 : requestMethod.serviceName);
            })) {
                someState[channelName] = __assign(__assign({}, channel), { invalidated: true });
            }
            return someState;
        }, {});
        return __assign(__assign(__assign({}, state), (_a = {}, _a[action.channel] = __assign(__assign({}, state[action.channel]), { response: action.response, lastFetched: action.lastFetched, fetching: false, args: action.args }), _a)), invalidatedChannels);
    },
    _a[types.REQUEST_FAILURE] = function (state, action) {
        var _a;
        return (__assign(__assign({}, state), (_a = {}, _a[action.channel] = __assign(__assign({}, state[action.channel]), { error: action.error, response: undefined, fetching: false, args: action.args }), _a)));
    },
    _a[types.PREPARE_CHANNEL] = function (state, action) {
        var _a;
        return (__assign(__assign({}, state), (_a = {}, _a[action.channel] = {
            fetching: true
        }, _a)));
    },
    _a[types.REQUEST_FLUSH] = function (state, action) {
        if (action.channel) {
            return omit(state, action.channel);
        }
        return Object.keys(state).reduce(function (acc, channeName) {
            var _a;
            if ((_a = state[channeName]) === null || _a === void 0 ? void 0 : _a.preserve) {
                acc[channeName] = state[channeName];
            }
            return acc;
        }, {});
    },
    _a[types.IS_CONFIRMED] = function (state, action) {
        var _a;
        return __assign(__assign({}, state), (_a = {}, _a[action.channel] = __assign(__assign({}, state[action.channel]), { unconfirmed: false }), _a));
    },
    _a);
export default function apiBusReducer(state, action) {
    if (state === void 0) { state = {}; }
    var callback = actionMap[action.type] || (function (state) { return state; });
    return callback(state, action);
}
export var DEFAULT_CHANNEL_STATE = {
    fetching: false,
    lastFetched: undefined,
    response: undefined,
    error: undefined
};
export function requestState(state, channel) {
    return get(state.apiBus, channel, DEFAULT_CHANNEL_STATE);
}
/**
 * Returns true if any of the channels provided is still in fetching state.
 *
 * @param {object} state Store state
 * @param {array|string} channels List of channels to check
 */
export function getFetching(state, channels) {
    channels = Array.isArray(channels) ? channels : [channels];
    return channels.some(function (c) { return requestState(state, c).fetching; });
}
/**
 *
 * @param state store state
 * @param channels  List of channels to check
 * @returns true if any of the channels provided are in unconfirmed state
 */
export function getIsUnconfirmed(state, channels) {
    channels = Array.isArray(channels) ? channels : [channels];
    return channels.some(function (c) { return requestState(state, c).unconfirmed; });
}
/**
 * Returns the error object from the first failed channel.
 *
 * @param {object} state Store state
 * @param {array|string} channels List of channels to check
 */
export function getError(state, channels) {
    channels = Array.isArray(channels) ? channels : [channels];
    var errors = channels.map(function (c) { return requestState(state, c).error; });
    return errors.find(function (error) { return error !== undefined; });
}
/**
 * Returns true if a fetch has been attempted or finished (regardless of outcome) on a
 * channel.
 *
 * @param {object} state Store state
 * @param {array|string} channels List of channels to check
 */
export function getFetchHasBeenAttempted(state, channels) {
    channels = Array.isArray(channels) ? channels : [channels];
    return channels.some(function (channel) { return state.apiBus[channel] !== undefined; });
}
/**
 *
 * @param {object} state Store state
 * @param {string} channel Channel to get items from
 * @param {function} mapMethod Used for transforming items. If provided, items will be mapped to a
 * new array using this method.
 * T: Return type for the items in the array
 * Y: The intermediate type used if mapMethod is provided. The first argument to the mapMethod
 * will have type Y.
 */
export var getItems = function (state, channel, mapMethod) {
    var items = get(requestState(state, channel), 'response.items', []);
    if (mapMethod) {
        return items.map(function (item) { return mapMethod(item); });
    }
    return items;
};
/**
 *
 * @param {object} state Store state
 * @param {string} channel Channel to get items from
 * @param {function} mapMethod Used for transforming items. If provided, items will be mapped to a
 * new array using this method.
 * T: Return type for the items in the array
 * Y: The intermediate type used if mapMethod is provided. The first argument to the mapMethod
 * will have type Y.
 */
export var getItem = function (state, channel, itemPath, mapMethod) {
    var path = itemPath ? "response.".concat(itemPath) : 'response';
    var item = get(requestState(state, channel), path);
    if (item) {
        return mapMethod ? mapMethod(item) : item;
    }
    return undefined;
};
export var getLastFetched = function (state, channel) {
    return requestState(state, channel).lastFetched;
};
export var getRequestParams = function (state, channel) {
    return requestState(state, channel).requestParams;
};
export var getNextToken = function (state, channel) {
    var channelState = requestState(state, channel);
    return channelState.response ? channelState.response.nextToken : undefined;
};
export var FetchStatus = {
    FETCHING: 'FETCHING',
    REFRESHING: 'REFRESHING',
    READY: 'READY'
};
/**
 * Returns a fetch status that is calculated by looking at given channels and trying to
 * differentiate between the initial fetch and a subsequent fetch for refreshing data.
 * If all channels have a lastFetched value and none of them are refreshing this method returns READY.
 * If at least one channel does not have a lastFetched value, we return FETCHING.
 * If all channels have a lastFetched value and one of them is in fetching state we return REFRESHING.
 *
 * @param {object} state Store state
 * @param {array|string} channels Channels that store required data for our component
 */
// TODO: [future] deprecate over `getStatus` (arne)
export var getFetchStatus = function (state, channels) {
    channels = Array.isArray(channels) ? channels : [channels];
    var fetching = getFetching(state, channels);
    var empty = channels.some(function (c) { return getLastFetched(state, c) === undefined && getError(state, c) === undefined; });
    if (!fetching && !empty) {
        return FetchStatus.READY;
    }
    if (!empty) {
        return FetchStatus.REFRESHING;
    }
    return FetchStatus.FETCHING;
};
// TODO: [future] This and getFetchStatus above feels a bit odd. I think it is because of the perceived
// conflict with `getFetching` which has a very different behavior than these e.g. these treat an
// empty non-fetching channel as fetching - arguably what we want in most cases (?). Maybe we
// should come up with a differnt concept (ready/not_ready) or just make getFetching return true
// if fetched hasn't started yet for an empty channel :/ ?? Maybe `FETCHING` -> `FETCHING_OR_UNSTARTED`
//
// And `refreshing` should maybe be an opt in instead of being the default (it seems primarily
// useful for non-user started fetches) (arne)
// TODO: [future] clean this up (arne)
export var Status;
(function (Status) {
    Status["UNSTARTED"] = "UNSTARTED";
    Status["FETCHING_INITIAL"] = "FETCHING_INITIAL";
    Status["FETCHING_FOLLOWING"] = "FETCHING_FOLLOWING";
    Status["DONE"] = "DONE";
})(Status || (Status = {}));
export var selectors = {
    getItem: getItem,
    getItems: getItems,
    getError: getError,
    getRequestState: requestState,
    getStatus: function (state, channels) {
        channels = Array.isArray(channels) ? channels : [channels];
        var fetching = getFetching(state, channels);
        var empty = channels.some(function (c) { return getLastFetched(state, c) === undefined && getError(state, c) === undefined; });
        if (fetching) {
            if (empty) {
                return Status.FETCHING_INITIAL;
            }
            else {
                return Status.FETCHING_FOLLOWING;
            }
        }
        else if (empty) {
            return Status.UNSTARTED;
        }
        return Status.DONE;
    },
    isUnstarted: function (state, channels) {
        var status = selectors.getStatus(state, channels);
        return status === Status.UNSTARTED;
    },
    isFetchingOrUnstarted: function (state, channels) {
        var status = selectors.getStatus(state, channels);
        return [Status.FETCHING_INITIAL, Status.FETCHING_FOLLOWING, Status.UNSTARTED].includes(status);
    },
    isFetchingOrCompleted: function (state, channels) {
        var status = selectors.getStatus(state, channels);
        return [Status.FETCHING_INITIAL, Status.FETCHING_FOLLOWING, Status.DONE].includes(status);
    },
    isFetching: getFetching,
    hasNextToken: function (state, channel) { return !!getNextToken(state, channel); },
    getLastFetched: getLastFetched,
    getIsInvalidated: function (state, channel) {
        return selectors.getRequestState(state, channel).invalidated;
    }
};
