import { Action } from 'redux';
/** Interface for the props passed to modal components when they are rendered via the modal reducer. */
export interface ShowModalProps {
    visible: boolean;
    hideModal: typeof actions.hideModal;
}
export interface ShowModalAction extends Action {
    type: typeof types['SHOW_MODAL'];
    modalType: string;
    modalParams: any;
}
declare type ModalAction = ShowModalAction | Action;
export interface ModalState {
    /**  A unique identifier for the modal */
    modalType: string | null;
    /** Any props to pass to the modal */
    modalParams: {
        [key: string]: any;
    };
    /** Whether modal is visible */
    visible: boolean;
}
export declare const types: {
    readonly SHOW_MODAL: "SHOW_MODAL";
    readonly HIDE_MODAL: "HIDE_MODAL";
};
export declare const commonModals: {
    INFO_MODAL: string;
    SUCCESS_MODAL: string;
    ERROR_MODAL: string;
    REQUEST_ERROR_MODAL: string;
    WARNING_MODAL: string;
    CONFIRM_MODAL: string;
};
export declare const actions: {
    showModal: (modalType: string, modalParams?: {}) => ShowModalAction;
    hideModal: () => Action;
};
export declare const actionSelectors: {
    showModal: (modalType: string) => (action: ShowModalAction) => boolean;
};
declare const modalReducer: (state: ModalState | undefined, action: ModalAction) => ModalState;
export default modalReducer;
