import { Action } from 'redux';
import { DecoratedRoutesMap } from '../sagas/routerSaga';
interface RootState {
    routing: RouterState;
}
export interface Params {
    [key: string]: string | undefined;
}
export interface SearchParams {
    [key: string]: string | string[] | undefined;
}
export interface NavigateAction extends Action {
    type: string;
    id: string;
    params: Params;
    searchParams: SearchParams;
    opts: {
        [key: string]: string | number | boolean;
    };
    path: string;
}
export interface UpdateSearchParamsAction extends Action {
    type: typeof types.UPDATE_SEARCH_PARAMS | typeof types.SET_SEARCH_PARAMS;
    searchParams: SearchParams;
    opts: {
        [key: string]: string | number | boolean;
    };
}
export declare type RouterAction = NavigateAction | UpdateSearchParamsAction | Action;
export interface RouterState {
    ready: boolean;
    id?: string;
    params: Params;
    searchParams: SearchParams;
    opts: {
        [key: string]: string | number | boolean;
    };
    route: any;
    path: string;
}
export declare const types: {
    readonly NAVIGATE: "router/NAVIGATE";
    readonly NAVIGATE_SUCCESS: "router/NAVIGATE_SUCCESS";
    readonly UPDATE_SEARCH_PARAMS: "router/UPDATE_SEARCH_PARAMS";
    readonly SET_SEARCH_PARAMS: "router/SET_SEARCH_PARAMS";
};
export declare const actions: {
    navigate: (id: string, params: {} | undefined, searchParams: {} | undefined, opts: {} | undefined, path: string) => NavigateAction;
    navigateSuccess: () => Action;
    updateSearchParams: (searchParams: SearchParams) => UpdateSearchParamsAction;
    setSearchParams: (searchParams: SearchParams) => UpdateSearchParamsAction;
};
export declare const initialState: RouterState;
export default function getRouterReducer(routesMap: DecoratedRoutesMap): (state: RouterState | undefined, action: RouterAction) => RouterState;
export declare const getRoutingId: (state: RootState) => string | undefined;
export declare const getRoutingPath: (state: RootState) => string;
/**
 *  * Returns the router parameter value for the given parameter name.
 */
export declare const getRoutingParam: (state: RootState, paramName: string, defaultValue?: string) => string | undefined;
/**
 * Returns the searchParams object from the route state. If paramNames is provided, only the keys
 * listed in the array are returned.
 */
export declare const getSearchParams: (state: RootState, paramNames?: string[]) => SearchParams;
/**
 * Returns the search parameter value for the given parameter name.
 * Use a bit of magic TS to make it return `string` type if defaultValue
 * is specified as opposed to `string | undefined`.
 */
export declare const getSearchParam: <T extends string | undefined>(state: RootState, paramName: string, defaultValue?: T | undefined) => string | string[] | T;
/**
 * Narrow SearchParam value by removing `string[]` which is rarely used.
 * If used, then pick the first value in the array.
 */
export declare const convertToSimpleValue: (value: SearchParams[string]) => string | undefined;
/**
 * Returns the search parameter value for the given parameter name. If search param is an
 * array, will return the first value.
 */
export declare const getSimpleSearchParam: <T extends string | undefined>(state: RootState, paramName: string, defaultValue?: T | undefined) => string | T;
/**
 * Returns the search parameter value for the given parameter name in number format. Default value
 * is returned if the value is not a number.
 */
export declare const getNumberSearchParam: (state: RootState, paramName: string, defaultValue?: any) => any;
/**
 * Given a current path and a new path, resolve the path.
 * - if the new path is absolute, return that
 * - if the new path is relative, combine the paths and if necessary travel upwards
 *
 * Should follow nodeJS path.resolve method
 *
 */
export declare const resolvePath: (base: string, newPath: string) => string;
export {};
