import { SagaIterator } from 'redux-saga';
import { SubmitRequestAction, RequestSuccessAction, RequestFailureAction } from '../reducers/apiBusReducer';
import ErrorResponse from '../utils/ErrorResponse';
import ApiResponse from "cdp-js/dist/lib/ApiResponse";
/**
 * This saga listens for SUBMIT_REQUEST actions. When that happens, it calls the api method
 * Then it publishes success or failure.
 */
export declare function apiSaga(action: SubmitRequestAction): SagaIterator;
/**
 * Performs the API call and fires a REQUEST_SUCCESS action with the fetched data.
 */
export declare function submitRequest(action: SubmitRequestAction): Generator<import("redux-saga/effects").CallEffect<unknown> | import("redux-saga/effects").PutEffect<RequestSuccessAction<import("../reducers/apiBusReducer").ApiBusResponse>>, void, ApiResponse<any>>;
/**
 * Fires a SHOW_CONFIRMATION action for the given action.
 */
export declare function confirmRequest(action: SubmitRequestAction): Generator<import("redux-saga/effects").RaceEffect<import("redux-saga/effects").TakeEffect> | import("redux-saga/effects").PutEffect<import("../reducers/confirmationReducer").ShowConfirmationAction | import("redux").Action<any>>, any, {
    yes: any;
}>;
/**
 * Fires a SHOW_NOTIFICATION action for the given action.
 */
export declare function notifyRequest(action: SubmitRequestAction): any;
/**
 * Handles errors that are caught during api operations. If API call fails due to 401, we redirect
 * user to home page.
 */
export declare function handleError(action: SubmitRequestAction, error: ErrorResponse | Error): Generator<import("redux-saga/effects").GetContextEffect | import("redux-saga/effects").PutEffect<RequestFailureAction>, void, ((error: any) => any) | undefined>;
export default function apiBusSaga(): SagaIterator;
export declare function takeChannelAction(channel: string | SubmitRequestAction['requestMethod'], actionType: string): any;
export declare function takeSuccess(channel: string | SubmitRequestAction['requestMethod']): any;
export declare function takeFailure(channel: string | SubmitRequestAction['requestMethod']): Generator<any, import("../types/types").ApiError, RequestFailureAction>;
/**
 * If you need to wait for a request completion in a saga (e.g. either success or fail)
 */
export declare function takeSuccessOrFailure(channel: string): any;
