import { EventChannel, SagaIterator } from 'redux-saga';
import pathToRegexp from 'path-to-regexp';
import { NavigateAction } from '../reducers/routerReducer';
import { History } from 'history';
export interface Right {
    name: string;
    rightName: string;
    required?: boolean;
    isUserRight?: boolean;
}
export interface Route {
    path: string | RegExp;
    title: string;
    pageImportWrapper?: () => Promise<any>;
    saga?: any;
    sidebarComponent?: any;
    rights?: Right[];
    entitlements?: string[];
    someEntitlements?: string[];
    hideSidebar?: boolean;
    sidebarProps?: any;
    componentProps?: object;
}
export interface DecoratedRoute extends Route {
    id: string;
    matcher: RegExp;
    keys: pathToRegexp.Key[];
    toPath: pathToRegexp.PathFunction;
}
export interface RoutesMap {
    [key: string]: Route;
}
export interface DecoratedRoutesMap {
    [key: string]: DecoratedRoute;
}
/**
 *
 * @param {object} routes Routes object
 * Returns a copy of the routes object where each route is decorated with following additional fields:
 * matcher: A regular expression that matches a url path to a route path.
 * keys: Key information returned by the pathToRegexp library. See https://github.com/pillarjs/path-to-regexp
 * for more info.
 * toPath: A function that returns a url path given a parameters object.
 */
export declare function buildRoutesMap(routes: RoutesMap): DecoratedRoutesMap;
export declare function actionToPath(routesMap: DecoratedRoutesMap, action: NavigateAction): string;
export declare function pathToAction(routesMap: DecoratedRoutesMap, path: string, search: string): NavigateAction;
/**
 * Intended to be able to get the route object **before** routing is started, to help
 * us do some UX loading optimization such as showing an empty sidebar.
 */
export declare function getPreloadingActiveRoute(routesMap: DecoratedRoutesMap): DecoratedRoute | undefined;
export declare function createHistoryChannel(history: History): EventChannel<unknown>;
export declare function historyToStore(routesMap: DecoratedRoutesMap, historyChannel: EventChannel<any>): Generator<import("redux-saga/effects").ChannelTakeEffect<any> | import("redux-saga/effects").PutEffect<NavigateAction> | import("redux-saga/effects").PutEffect<import("../reducers/routerReducer").UpdateSearchParamsAction>, void, {
    location: any;
    action: any;
}>;
export declare function storeToHistory(routesMap: DecoratedRoutesMap, history: History): SagaIterator;
export declare function onNavigate(routesMap: DecoratedRoutesMap, beforeNavigate: any, action: NavigateAction): Generator<import("redux-saga/effects").CallEffect<any> | import("redux-saga/effects").ForkEffect<unknown> | import("redux-saga/effects").PutEffect<import("redux").Action<any>>, void, {
    canNavigate: any;
    canRunSaga: any;
    routeProps: any;
}>;
export declare function routeSaga(routesMap: DecoratedRoutesMap, beforeNavigate: any): Generator<import("redux-saga/effects").ForkEffect<never>, void, unknown>;
/**
 *
 * @param {object} routesMap Route definition map
 * @param {*} history History object
 * @param {*} beforeNavigate A saga that will be run before navigating to a new path. Can be
 * used to perform pre-navigation checks and cancel navigation if needed. (E.g., Altus uses this
 * hook for checking entitlements and rights associated with the new route.)
 * This saga needs to return an object that contains following fields:
 * canNavigate: Whether user can navigate to the new route. If false, navigation is cancelled.
 * canRunSaga: Whether we can run the saga for the new route. If false, navigation happens but
 * the saga associated with the route isn't run. This flag is used when you want to render the
 * UI with an error message and don't want to kick of the API calls from the page saga. (E.g., user
 * failed the authorization checks so you know the API calls will fail.)
 * routeProps: Additional props/arguments passed to the route saga. This will passed as the second
 * parameter to the route saga.
 *
 * See the defaultBeforeNavigate method above for the response format.
 */
export default function routerSaga(routesMap: DecoratedRoutesMap, history: History | undefined, beforeNavigate?: unknown): Generator<import("redux-saga/effects").TakeEffect | import("redux-saga/effects").PutEffect<NavigateAction> | import("redux-saga/effects").ForkEffect<any> | import("redux-saga/effects").CallEffect<EventChannel<unknown>>, void, EventChannel<any>>;
