// Copyright (c) 2018 Cloudera, Inc. All rights reserved.
var __read = (this && this.__read) || function (o, n) {
    var m = typeof Symbol === "function" && o[Symbol.iterator];
    if (!m) return o;
    var i = m.call(o), r, ar = [], e;
    try {
        while ((n === void 0 || n-- > 0) && !(r = i.next()).done) ar.push(r.value);
    }
    catch (error) { e = { error: error }; }
    finally {
        try {
            if (r && !r.done && (m = i["return"])) m.call(i);
        }
        finally { if (e) throw e.error; }
    }
    return ar;
};
import fs from 'fs';
import path from 'path';
import camelCase from 'lodash/camelCase';
import * as cuixCoreVars from '@cloudera/cuix-core/src/variables.cjs';
var getTsNameFromLessName = function (lessVariableName) {
    lessVariableName = lessVariableName.replace(/^@/, '');
    return camelCase(lessVariableName);
};
var containsLessVariable = function (lessValue) {
    // might not technically be 100% accurate, but good enough
    return lessValue === null || lessValue === void 0 ? void 0 : lessValue.includes('@');
};
/**
 * This code mimics npm less-vars-to-js which is out of date and broken.
 *
 * It will also fetch our cuix-core variables and use those to try to resolve variable values,
 * since this script does not follow less imports.
 */
export default function extractLessVars(lessFiles) {
    if (lessFiles === void 0) { lessFiles = [path.join(__dirname, 'variables.less')]; }
    var lessContent = lessFiles.map(function (colorPath) { return fs.readFileSync(colorPath, 'utf8'); }).join('\n');
    var content = lessContent.match(/^\s*(@[^:\n]+):\s*([^;\n]+)/gm) || [];
    var lessVars = {};
    // parse less src (vars still unresolved)
    content.map(function (line) {
        var _a = __read(line.split(/:\s*/)), rawName = _a[0], valueParts = _a.slice(1);
        var value = valueParts.join(':').trim();
        var name = rawName.trim();
        if (lessVars[name]) {
            throw new Error("Found duplicate less var ".concat(name));
        }
        lessVars[name] = value;
    });
    /** Check both TS and less to find variables */
    var doLookup = function (lessVarNameOrValue) {
        var tsName = getTsNameFromLessName(lessVarNameOrValue);
        // @ts-ignore: trying to fight TS on this one doesn't seem worth it
        var tsValue = cuixCoreVars[tsName];
        var lessValue = lessVars[lessVarNameOrValue];
        if (tsValue && lessValue) {
            throw new Error("Variable \"".concat(lessVarNameOrValue, "\" exists in cuix-core and is also specified in our less file. We should avoid duplication and not duplicate it."));
        }
        if (containsLessVariable(lessValue) && !doLookup(lessValue)) {
            // we have a value with what appears to contain a less variable, but it is not resolving to anything.
            // we'll assume it's a composite value (e.g. it has multiple parts)
            var resolvedVal = lessValue.replace(/@[\w-_]+/g, function (match) {
                return doLookup(match) || match;
            });
            lessValue = resolvedVal;
        }
        return tsValue || lessValue;
    };
    Object.keys(lessVars).forEach(function (key) {
        var lookup = key;
        var resolved;
        // recursively traverse variables
        // in  case @a => @b and @b => @c, etc.
        while ((resolved = doLookup(lookup))) {
            lookup = resolved;
        }
        lessVars[key] = lookup;
    });
    return Object.keys(lessVars).reduce(function (prev, key) {
        var value = lessVars[key];
        if (Number.isFinite(+value)) {
            value = +value;
        }
        // remove the @
        prev[key.replace(/^@/, '')] = value;
        return prev;
    }, {});
}
