import type { ItemType } from 'antd/es/menu/hooks/useItems';
export interface SimpleMap<T = any> {
    [key: string]: T;
}
export interface Error {
    [key: string]: any;
}
export interface ApiError {
    code: string;
    title: string;
    message: string;
    requestId?: string;
}
export interface StringMap {
    [key: string]: string | undefined;
}
/**
 * Converts a type for a static object to StaticMap type which allows lookups for keys that don't
 * exist and type them as undefined.
 * E.g. const X = {foo:'123'}; // X.bar is an invalid lookup since type of X is {foo:string}
 * S, this helper type returns a more flexible type definition that says typeof X.bar is undefined.
 */
declare type StaticMap<T extends object> = {
    readonly [key in keyof T]: T[keyof T];
} & {
    readonly [key: string]: undefined;
} & {
    readonly [key: number]: undefined;
};
/**
 * Helper that converts a given object to StaticMap.
 * @param map Object to convert to a StaticMap
 */
export declare function makeStaticMap<T extends object>(map: T): StaticMap<T>;
/**
 * Omit for union types since regular Omit helper does not work properly on union types.  E.g.:
 * type A = {type: string; name: string}
 * type B = {type: number; name: string}
 * type C = A | B;
 *
 * Omit<C, 'type'> does not return what you'd expect but OmitFromUnion<C, 'type'> works as expected.
 */
export declare type OmitFromUnion<T, K extends keyof any> = T extends any ? Omit<T, K> : never;
export * from "cdp-js/dist/lib/utilityTypes";
/**
 * Type for antd menu items which has props and typing requirement of
 * official antd ItemType but allows us to add data-event tracking possibilities.
 *
 * Antd expects us to define menu items as ItemType: https://ant.design/components/menu/#ItemType
 * However, this type doesn't allow us to add data-event related props
 * which are useful for event tracking in google analytics, that's why we added
 * this new type.
 */
export declare type CuixMenuItem = ItemType & {
    'data-event-category'?: string;
    'data-event'?: string;
    'data-event-label'?: string;
};
export declare enum Cloud {
    AmazonWebServices = "AWS",
    GoogleCloudPlatform = "GCP",
    MicrosoftAzure = "AZURE",
    RedHatOpenShift = "OPENSHIFT",
    Cloudera = "CLOUDERA",
    ClassicClusters = "CLASSICCLUSTERS",
    CloudMigration = "CLOUDMIGRATION",
    DataLake = "DATALAKE"
}
