// Copyright (c) 2016 Guy Benron, released under the MIT License.
// This saga test helper is copied from https://github.com/wix/redux-saga-tester in order to apply
// fixes that are required for redux-saga 1.0. The original package is unmaintained so we copied it
// here in order to fix it and extend it as necessary.
var __read = (this && this.__read) || function (o, n) {
    var m = typeof Symbol === "function" && o[Symbol.iterator];
    if (!m) return o;
    var i = m.call(o), r, ar = [], e;
    try {
        while ((n === void 0 || n-- > 0) && !(r = i.next()).done) ar.push(r.value);
    }
    catch (error) { e = { error: error }; }
    finally {
        try {
            if (r && !r.done && (m = i["return"])) m.call(i);
        }
        finally { if (e) throw e.error; }
    }
    return ar;
};
var __spreadArray = (this && this.__spreadArray) || function (to, from, pack) {
    if (pack || arguments.length === 2) for (var i = 0, l = from.length, ar; i < l; i++) {
        if (ar || !(i in from)) {
            if (!ar) ar = Array.prototype.slice.call(from, 0, i);
            ar[i] = from[i];
        }
    }
    return to.concat(ar || Array.prototype.slice.call(from));
};
import { combineReducers as reduxCombineReducers, createStore, applyMiddleware } from 'redux';
import createSagaMiddleware from 'redux-saga';
var RESET_TESTER_ACTION_TYPE = '@@RESET_TESTER';
var SET_STATE_TYPE = '@@SET_TESTER_STATE';
var UPDATE_STATE_TYPE = '@@UPDATE_TESTER_STATE';
export var resetAction = { type: RESET_TESTER_ACTION_TYPE };
var SagaIntegrationTester = /** @class */ (function () {
    function SagaIntegrationTester(_a) {
        var _b = _a.initialState, initialState = _b === void 0 ? {} : _b, reducers = _a.reducers, _c = _a.middlewares, middlewares = _c === void 0 ? [] : _c, _d = _a.combineReducers, combineReducers = _d === void 0 ? reduxCombineReducers : _d, _e = _a.ignoreReduxActions, ignoreReduxActions = _e === void 0 ? true : _e, sagaMiddleware = _a.sagaMiddleware;
        var _this = this;
        this.calledActions = [];
        this.actionLookups = {};
        this.sagaMiddleware = sagaMiddleware || createSagaMiddleware({});
        var reducerFn = typeof reducers === 'object' ? combineReducers(wrapReducers(reducers)) : reducers;
        var finalReducer = function (state, action) {
            // reset state if requested
            if (action.type === RESET_TESTER_ACTION_TYPE) {
                return initialState;
            }
            // supply identity reducer as default
            if (!reducerFn) {
                var stateUpdate = {};
                if ([SET_STATE_TYPE, UPDATE_STATE_TYPE].indexOf(action.type) > -1) {
                    stateUpdate = action.payload;
                }
                // TODO: [future] update this to use `.isImmutable()` as soon as v4 is released.
                // http://facebook.github.io/immutable-js/docs/#/isImmutable (hayro)
                if (initialState.toJS) {
                    return initialState.mergeDeep(stateUpdate);
                }
                return Object.assign({}, initialState, stateUpdate);
            }
            // otherwise use the provided reducer
            return reducerFn(state, action);
        };
        // Middleware to store the actions and create promises
        var testerMiddleware = function () { return function (next) { return function (action) {
            if ((ignoreReduxActions && action.type.startsWith('@@redux/')) ||
                action.type === UPDATE_STATE_TYPE) {
                // Don't monitor redux actions
            }
            else {
                _this.calledActions.push(action);
                var actionObj = _this._addAction(action.type);
                actionObj.count++;
                actionObj.callback(action);
            }
            return next(action);
        }; }; };
        var allMiddlewares = __spreadArray(__spreadArray([], __read(middlewares), false), [testerMiddleware, this.sagaMiddleware], false);
        this.store = createStore(finalReducer, initialState, applyMiddleware.apply(void 0, __spreadArray([], __read(allMiddlewares), false)));
    }
    SagaIntegrationTester.prototype._handleRootSagaException = function (e) {
        var _this = this;
        Object.keys(this.actionLookups).forEach(function (key) { return _this.actionLookups[key].reject(e); });
    };
    SagaIntegrationTester.prototype._addAction = function (actionType, futureOnly) {
        if (futureOnly === void 0) { futureOnly = false; }
        var action = this.actionLookups[actionType];
        if (!action || futureOnly) {
            action = { count: 0 };
            action.promise = new Promise(function (resolve, reject) {
                action.callback = resolve;
                action.reject = reject;
            });
            this.actionLookups[actionType] = action;
        }
        return action;
    };
    SagaIntegrationTester.prototype._verifyAwaitedActionsCalled = function () {
        var _this = this;
        Object.keys(this.actionLookups).forEach(function (actionType) {
            var action = _this.actionLookups[actionType];
            if (action.count === 0 && action.reject) {
                action.reject(new Error(actionType + ' was waited for but never called'));
            }
        });
    };
    SagaIntegrationTester.prototype.run = function (sagas) {
        if (sagas === void 0) { sagas = []; }
        var args = [];
        for (var _i = 1; _i < arguments.length; _i++) {
            args[_i - 1] = arguments[_i];
        }
        var task = this.start.apply(this, __spreadArray([sagas], __read(args), false));
        if (task.done === undefined) {
            return task.done;
        }
        else {
            return task.toPromise();
        }
    };
    SagaIntegrationTester.prototype.start = function (sagas) {
        var _a;
        var _this = this;
        if (sagas === void 0) { sagas = []; }
        var args = [];
        for (var _i = 1; _i < arguments.length; _i++) {
            args[_i - 1] = arguments[_i];
        }
        var task = (_a = this.sagaMiddleware).run.apply(_a, __spreadArray([sagas], __read(args), false));
        var onDone = function () { return _this._verifyAwaitedActionsCalled(); };
        var onCatch = function (e) { return _this._handleRootSagaException(e); };
        if (task.done !== undefined) {
            task.done.then(onDone);
            task.done.catch(onCatch);
        }
        else {
            var taskPromise = task.toPromise();
            taskPromise.then(onDone);
            taskPromise.catch(onCatch);
        }
        return task;
    };
    SagaIntegrationTester.prototype.reset = function (clearActionList) {
        var _this = this;
        if (clearActionList === void 0) { clearActionList = false; }
        this.store.dispatch(resetAction);
        if (clearActionList) {
            // Clear existing array in case there are other references to it
            this.calledActions.length = 0;
            // Delete object keys in case there are other references to it
            Object.keys(this.actionLookups).forEach(function (key) { return delete _this.actionLookups[key]; });
        }
    };
    SagaIntegrationTester.prototype.dispatch = function (action) {
        this.store.dispatch(action);
    };
    SagaIntegrationTester.prototype.getState = function () {
        return this.store.getState();
    };
    SagaIntegrationTester.prototype.setState = function (newState) {
        deprecate('setState has been deprecated. Please use updateState.');
        this.store.dispatch({ type: SET_STATE_TYPE, payload: newState });
    };
    SagaIntegrationTester.prototype.updateState = function (newState) {
        this.store.dispatch({ type: UPDATE_STATE_TYPE, payload: newState });
    };
    SagaIntegrationTester.prototype.getCalledActions = function () {
        return this.calledActions;
    };
    SagaIntegrationTester.prototype.getLatestCalledAction = function () {
        return this.calledActions[this.calledActions.length - 1];
    };
    SagaIntegrationTester.prototype.getLatestCalledActions = function (num) {
        if (num === void 0) { num = 1; }
        return this.calledActions.slice(-1 * num);
    };
    SagaIntegrationTester.prototype.wasCalled = function (actionType) {
        var action = this.actionLookups[actionType];
        return action ? action.count > 0 : false;
    };
    SagaIntegrationTester.prototype.numCalled = function (actionType) {
        var action = this.actionLookups[actionType];
        return (action && action.count) || 0;
    };
    SagaIntegrationTester.prototype.waitFor = function (actionType, futureOnly) {
        if (futureOnly === void 0) { futureOnly = false; }
        return this._addAction(actionType, futureOnly).promise;
    };
    SagaIntegrationTester.prototype.getActionsCalled = function () {
        deprecate('getActionsCalled has been deprecated. Please use getCalledActions.');
        return this.calledActions;
    };
    SagaIntegrationTester.prototype.getLastActionCalled = function (num) {
        if (num === void 0) { num = 1; }
        deprecate('getLastActionCalled has been deprecated. Please use getLatestCalledAction or getLatestCalledActions.');
        return this.calledActions.slice(-1 * num);
    };
    return SagaIntegrationTester;
}());
export default SagaIntegrationTester;
function wrapReducers(reducerList) {
    return Object.keys(reducerList).reduce(function (result, name) {
        result[name] = function (state, action) {
            var reducer = reducerList[name];
            var payload = action.payload, type = action.type;
            var newState = reducer(state, action);
            if ([SET_STATE_TYPE, UPDATE_STATE_TYPE].indexOf(type) > -1 && payload[name]) {
                newState = Object.assign({}, state, payload[name]);
            }
            return newState;
        };
        return result;
    }, {});
}
function deprecate(txt) {
    if (txt === void 0) { txt = ''; }
    console.warn("[redux-saga-tester] Warning: ".concat(txt));
}
