declare global {
    interface Window {
        ga: any;
        GoogleAnalyticsObject: any;
    }
}
declare const analytics: {
    ga(...args: any): void;
    /**
     * This function sets up all anlytics.
     * We specify a user so we can filter out cloudera usage.
     * analyticsToken and prefix are allowed so that non-webpack usage is supported.
     * @param {string} accountId The tenant id of the current user.
       @param {string} consoleName The public cloud console name or product name.
     * @param {string} analyticsToken The analytics token to send GA data.
     * @param {boolean} isEnabled If analytics should be turned on.
     * Can be overridden by localStorage['debug-ga-to-console']
     */
    init({ accountId, analyticsToken, consoleName, isEnabled }: {
        accountId: string;
        analyticsToken: string;
        consoleName: string;
        isEnabled: boolean;
    }): void;
    setTrialUser(): void;
    setCdpOneTrialUser(): void;
    /**
     * For Single Page Apps, identify the current "page"
     * @param {string} pageName
     */
    page(pageName: string): void;
    /**
     * @param {string} category The toplevel event grouping.
     * @param {string} action The action performed under the category grouping.
     * @param {string} label Metadata for the action.
     * @param {string} value Metric for the label
     */
    trackEvent(category: string, action: string, label?: string, value?: number | string): void;
    /**
     * Tracks an exception that occurs.
     */
    exception(error: string | Error, fatal?: boolean): void;
    /**
     * Tracks the timing of an event or series of events.
     * @param category The category of the variable.
     * @param variable The variable name for the timer.
     * @param value A moment.range object representing to elapsed time or undefined
     * to use the elapsed time since load.
     * @param label An optional string to associate with the variable.
     */
    timing(category: string, variable: string, value: number, label?: string): void;
    /**
     * A helper function to create an object that will collect the elapsed time
     * when "record" method is called.
     */
    createTimer(): {
        record: (category: string, variable: string, label?: string) => void;
    };
    /**
     * Handler for page error events.
     */
    trackErrorEvent(event: ErrorEvent): void;
    /**
     * For promises that have errors (rejections) that are not handled they don't
     * bubble up to a page "error" event but they will generate an  "unhandledrejection"
     * event if you use Bluebird and/or newer versions of Chrome.
     */
    trackUnhandledPromiseErrorEvent(event: any): void;
    /**
     * Internal method to setup tracking of JS page error to GA
     */
    setupPageErrorTracking(): void;
};
export default analytics;
