// Copyright (c) 2016 Cloudera, Inc. All rights reserved.
var __read = (this && this.__read) || function (o, n) {
    var m = typeof Symbol === "function" && o[Symbol.iterator];
    if (!m) return o;
    var i = m.call(o), r, ar = [], e;
    try {
        while ((n === void 0 || n-- > 0) && !(r = i.next()).done) ar.push(r.value);
    }
    catch (error) { e = { error: error }; }
    finally {
        try {
            if (r && !r.done && (m = i["return"])) m.call(i);
        }
        finally { if (e) throw e.error; }
    }
    return ar;
};
var __spreadArray = (this && this.__spreadArray) || function (to, from, pack) {
    if (pack || arguments.length === 2) for (var i = 0, l = from.length, ar; i < l; i++) {
        if (ar || !(i in from)) {
            if (!ar) ar = Array.prototype.slice.call(from, 0, i);
            ar[i] = from[i];
        }
    }
    return to.concat(ar || Array.prototype.slice.call(from));
};
import appConfig from "cdp-js/dist/lib/appConfig";
var PREFIX;
/**
 * If you want to debug GA by printing out all the GA calls to console, but not
 * actually send them to GA. Enable this by
 * localStorage.setItem('debug-ga-to-console', "true");
 * Disable by clearing or setting to "false"
 */
function isDebugLogEnabled() {
    var result;
    try {
        var debug = localStorage.getItem('debug-ga-to-console');
        result = debug ? !!JSON.parse(debug) : false;
    }
    catch (err) {
        result = false;
    }
    return result;
}
var DEBUG_LOG = isDebugLogEnabled();
function loadAnalytics(analyticsToken) {
    if (!window.ga) {
        // For the tracker tag to register correctly, the "create"
        // command must be enqueued before Google's analytics.js loads
        window.GoogleAnalyticsObject = 'ga';
        window.ga = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            window.ga.q = window.ga.q || [];
            window.ga.q.push(args);
        };
        window.ga.l = Number(new Date());
        window.ga('create', analyticsToken, 'auto');
    }
    var node = document.getElementsByTagName('script')[0];
    var lib = document.createElement('script');
    lib.async = true;
    lib.src = 'https://www.google-analytics.com/analytics.js';
    node.parentNode.insertBefore(lib, node);
    // Register any HTML tags with data-event attribute.
    if (document.body.dataset !== undefined) {
        document.addEventListener('click', onDOMElementClick);
    }
}
/**
 * Listen to click events on the document and if the clicked element has analytics attached log those.
 * We are registering the click event to document and can't do filtering like jquery ('[data-event]')
 * so we need to traverse event's target's parents for cases like
 * <a data-event="x"><span>Click me</span></a> where the span is the target.
 */
function onDOMElementClick(event) {
    var target = (event.target || event.srcElement);
    while (target && target.parentNode) {
        var data = target.dataset;
        if (data && data.event && data.eventCategory) {
            analytics.trackEvent(data.eventCategory, data.event, data.eventLabel, data.eventValue);
            break;
        }
        target = target.parentNode;
    }
}
function unloadAnalytics() {
    delete window.ga;
    delete window.GoogleAnalyticsObject;
}
var ignoredAccountIds = [
    '59888298-38ae-44f6-9df2-003dacda8a3f',
    'd494ee13-f0f3-4069-9754-b6eaf35c6bc6',
    'd178f5a9-56a0-415f-914f-d3d985c6612e',
    '9992c4f9-9bcf-4120-8592-90fff18b531f',
    '3c9fb850-4200-4dd6-b8d2-adb263c4221b',
    '3e7bdb14-cc7f-4d13-a153-faadc8829203',
    '45a51de4-46fe-4985-ae23-f47cf8460a08' // algwtus-123-test@grr.la
];
var analytics = {
    ga: function () {
        var args = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            args[_i] = arguments[_i];
        }
        if (DEBUG_LOG) {
            console.log.apply(console, __spreadArray([], __read(args), false));
            return;
        }
        if (window.ga) {
            window.ga.apply(window, __spreadArray([], __read(args), false));
        }
    },
    /**
     * This function sets up all anlytics.
     * We specify a user so we can filter out cloudera usage.
     * analyticsToken and prefix are allowed so that non-webpack usage is supported.
     * @param {string} accountId The tenant id of the current user.
       @param {string} consoleName The public cloud console name or product name.
     * @param {string} analyticsToken The analytics token to send GA data.
     * @param {boolean} isEnabled If analytics should be turned on.
     * Can be overridden by localStorage['debug-ga-to-console']
     */
    init: function (_a) {
        var accountId = _a.accountId, analyticsToken = _a.analyticsToken, consoleName = _a.consoleName, isEnabled = _a.isEnabled;
        if (appConfig.isGovCloud()) {
            return;
        }
        PREFIX = "".concat(consoleName, ".");
        var isRealCustomer = !ignoredAccountIds.includes(accountId);
        if (DEBUG_LOG || (isRealCustomer && isEnabled)) {
            loadAnalytics(analyticsToken);
            this.ga('set', 'dimension1', accountId);
            this.ga('set', 'anonymizeIp', true);
            this.ga('set', 'transport', 'beacon');
            this.setupPageErrorTracking();
        }
        else {
            unloadAnalytics();
        }
    },
    setTrialUser: function () {
        this.ga('set', 'dimension2', 'trial');
    },
    setCdpOneTrialUser: function () {
        this.ga('set', 'dimension2', 'cdp-one-trial');
    },
    /**
     * For Single Page Apps, identify the current "page"
     * @param {string} pageName
     */
    page: function (pageName) {
        pageName = PREFIX + (pageName || 'Unknown');
        this.ga('set', 'page', pageName);
        this.ga('send', 'pageview');
    },
    /**
     * @param {string} category The toplevel event grouping.
     * @param {string} action The action performed under the category grouping.
     * @param {string} label Metadata for the action.
     * @param {string} value Metric for the label
     */
    trackEvent: function (category, action, label, value) {
        var event = ['send', 'event', PREFIX + category, action];
        if (label) {
            event.push(label);
        }
        if (value !== undefined) {
            if (typeof value === 'string') {
                value = parseInt(value, 10);
            }
            if (label && !isNaN(value)) {
                event.push(value);
            }
        }
        this.ga.apply(this, __spreadArray([], __read(event), false));
    },
    /**
     * Tracks an exception that occurs.
     */
    exception: function (error, fatal) {
        var description = error instanceof Error ? error.message : error;
        this.ga('send', 'exception', {
            exDescription: description,
            exFatal: !!fatal
        });
    },
    /**
     * Tracks the timing of an event or series of events.
     * @param category The category of the variable.
     * @param variable The variable name for the timer.
     * @param value A moment.range object representing to elapsed time or undefined
     * to use the elapsed time since load.
     * @param label An optional string to associate with the variable.
     */
    timing: function (category, variable, value, label) {
        if (Math.random() > 0.05) {
            // GA samples timings pretty aggressively, so not point of sending many of these to them
            // this limits to 5% sample rate.
            return;
        }
        this.ga('send', 'timing', PREFIX + category, variable, value, label);
    },
    /**
     * A helper function to create an object that will collect the elapsed time
     * when "record" method is called.
     */
    createTimer: function () {
        var _this = this;
        var start = Date.now();
        return {
            // Note: might be called multiple times
            record: function (category, variable, label) {
                return _this.timing(category, variable, Date.now() - start, label);
            }
        };
    },
    /**
     * Handler for page error events.
     */
    trackErrorEvent: function (event) {
        var errorMsg;
        try {
            var filename = event.filename;
            // strip domain name to make it more readable for us
            filename = filename.replace(/^https?:\/\/[^\/]*/, '');
            errorMsg = "".concat(event.message, " at ").concat(filename, ":").concat(event.lineno, ":").concat(event.colno);
            var error = event.error;
            if (error && error.stack) {
                errorMsg = errorMsg + '\nStack: ' + error.stack;
            }
        }
        catch (err) {
            errorMsg = "Error in error handler. ".concat(err.message, " at ").concat(err.stack);
        }
        errorMsg = "JS Client Error: ".concat(errorMsg);
        this.exception(errorMsg);
    },
    /**
     * For promises that have errors (rejections) that are not handled they don't
     * bubble up to a page "error" event but they will generate an  "unhandledrejection"
     * event if you use Bluebird and/or newer versions of Chrome.
     */
    trackUnhandledPromiseErrorEvent: function (event) {
        var errorMsg = '';
        try {
            var reason = void 0;
            if (event.reason) {
                // native Chrome events should report this
                reason = event.reason;
            }
            else if (event.detail && event.detail.reason) {
                // Bluebird event should report this
                reason = event.detail.reason;
            }
            else {
                // try a bunch of fallbacks
                // no easy way to test this, but the GA reports show events that
                // doesn't seem to match either of the two above approaches.
                reason = event.error || event.detail || event;
            }
            if (reason) {
                // in most cases, the reason will be an Error, but it is not guaranteed
                // as you can reject/throw any object you'd like, not just errors.
                errorMsg = reason.stack || reason.message || reason;
            }
            if ("".concat(errorMsg) === '[object Object]') {
                // sometimes we're not dealing with error objects,
                // so we'll try to serialize it so we can capture it
                errorMsg = "json: ".concat(JSON.stringify(errorMsg));
            }
        }
        catch (err) {
            errorMsg = "Error in error handler. ".concat(err.message, " at ").concat(err.stack);
        }
        errorMsg = "JS Client Unhandled Promise Error:\n".concat(errorMsg);
        this.exception(errorMsg);
    },
    /**
     * Internal method to setup tracking of JS page error to GA
     */
    setupPageErrorTracking: function () {
        var _this = this;
        window.addEventListener('error', function (event) { return _this.trackErrorEvent(event); });
        window.addEventListener('unhandledrejection', function (event) {
            return _this.trackUnhandledPromiseErrorEvent(event);
        });
    }
};
export default analytics;
