import { Entitlement } from "cdp-js/dist/api/iam/types";
import { Options as CuixInitAnalyticsOptions } from './cuixInitAnalytics';
declare type SimpifiedEntitlement = Pick<Entitlement, 'entitlementName'>;
interface Options {
    /**
     * When set to `auto`, the user will be fetched via iam calls
     */
    user?: 'auto' | CuixInitAnalyticsOptions['user'];
    /**
     * When set to `auto`, full story config will be set via appConfig checks
     */
    fullStory?: 'auto' | CuixInitAnalyticsOptions['fullStory'];
    /**
     * When set to `auto`, the entitlement will be fetched via iam calls.
     */
    entitlements?: 'auto' | SimpifiedEntitlement[] | Promise<SimpifiedEntitlement[]>;
    /**
     * When set to `auto`, full story config will be set via appConfig checks
     */
    isLocalDev?: 'auto' | boolean;
    delay?: number;
}
/**
 * **NOTE**: This method might not be settled yet.
 *
 * Analytics setup for CDP projects (tested with Public Control Plane).
 *
 * By default it will "self-configure", but can be overridden. If this is not suitable for
 * your project, consider using the underlying `cuixInitAnalytics` directly. If you think
 * it's a common use-case then reach out to the `cuix` team to see if we can handle it better
 * here.
 *
 * By default this will fetch user/entitlements when run.
 *
 * See description of `cuixInitAnalytics` as well.
 */
export declare const cdpInitAnalytics: ({ user, fullStory, entitlements, isLocalDev, delay }: Options) => false | Promise<boolean>;
export {};
