export declare const hasRunCuixInitAnalytics: () => boolean;
interface AnalyticsUser {
    crn: string;
    /**
     * Additional data about the user we want to send to the analytics services
     */
    userData?: object;
}
interface FullStoryOptions {
    /**
     * Fullstory organization id. See `fullstoryOrgIds.ts` for regular ids.
     * This determines which fullstory "property" we send the data to.
     */
    orgId: string;
}
export interface Options {
    /**
     * User information that will be sent to analytics to identify the user
     */
    user: null | AnalyticsUser | Promise<AnalyticsUser | null>;
    /**
     * FullStory analytics configuration
     */
    fullStory: null | FullStoryOptions | Promise<FullStoryOptions | null>;
    /**
     * Indicate that it is being used locally and generally that analytics data should not be sent.
     */
    isLocalDev?: boolean;
    /**
     * Exposed for testing and might be removed in the future.
     * Time to wait before starting to init FS.
     */
    delay?: number;
}
/**
 * **NOTE**: This method might not be settled yet.
 *
 * Low-level setup for cuix analytics that tries to be generic enough to be used
 * outside of CDP.
 * For CDP projects, use `cdpInitAnalytics` instead.
 *
 * Certain argument supports promises so that the function can be called early, before
 * certain things are known (e.g. user crn).
 */
export declare const cuixInitAnalytics: ({ user, fullStory, isLocalDev, delay }: Options) => Promise<boolean>;
export {};
