/**
 * From several domains, find any common domain e.g.
 *
 * - test.cloudera.com, help.cloudera.com, cloudera.com
 *      => common domain: cloudera.com
 * - example.com, cloudera.com, test.cloudera.com
 *      => common domain: false
 *
 * Expects an array of items, and and accessor to get the domain from the item.
 * This is done so we can iterate over existing complex objects.
 *
 * Example:
 *
 * ```js
 * const list = [{ name: 'test', domain: 'x.y.z', ...}, { name: 'other, domain: 'y.y.z', ...}, ...];
 * const accessor = (listItem) => listItem.domain;
 * const common = findCommonDomain(list, accessor);
 * ```
 *
 * If you have an plain domain array, you can pass in identify fn to accessor ( item => item ).
 */
export declare const findCommonDomain: <T extends {}>(list: T[], accessor: (item: T) => string) => string | false;
