/**
 * Convenience method to create a rectangle object.
 */
export var getRect = function (x, y, width, height) {
    return {
        x: x,
        y: y,
        width: width,
        height: height
    };
};
/**
 * Get intersection between two rectangles. If they don't intersect (no overlap)
 * then returns null;
 */
export var getRectIntersection = function (rect1, rect2) {
    if (rect1.x + rect1.width < rect2.x) {
        return null;
    }
    if (rect1.x > rect2.x + rect2.width) {
        return null;
    }
    if (rect1.y + rect1.height < rect2.y) {
        return null;
    }
    if (rect1.y > rect2.y + rect2.height) {
        return null;
    }
    var x = Math.max(rect1.x, rect2.x);
    var y = Math.max(rect1.y, rect2.y);
    return {
        x: x,
        y: y,
        width: Math.min(rect1.x + rect1.width, rect2.x + rect2.width) - x,
        height: Math.min(rect1.y + rect1.height, rect2.y + rect2.height) - y
    };
};
/**
 * Convert a Rectangle to css style (top, left, height, width).
 */
export var rectToCssStyle = function (rect) {
    var x = rect.x, y = rect.y, width = rect.width, height = rect.height;
    return {
        left: x,
        top: y,
        height: height,
        width: width
    };
};
