/**
 * Generator to create exponentially increasing delay. This can be used if you are polling an API
 * and waiting for something to finish. The longer it waits the longer the delay will become. This
 * is useful because if the operation you're waiting for is done quick you'll catch it quickly
 * (since the inital delays are small) and if it is long running the delays will increase such
 * as to not overload with API requests.
 *
 * Usage:
 *   const delayGenerator = getDelayGenerator();
 *   while (true) {
 *     const status = await api.checkStatus();
 *     if (status.ok) {
 *       break;
 *     }
 *     await sleep(delayGenerator.next().value)
 *   }
 *
 * NOTE: In the example above the actual time between the calls is "duration of status API call + delay", otherwise
 * you might find yourself making a second call before the first finishes.
 *
 * Default delays with 500 and 1.1:
 *
 * 500, 550, 605, 666, 732, 805, 886, 974, 1072, 1179, 1297, 1427,
 * 1569, 1726, 1899, 2089, 2297, 2527, 2780, 3058,...
 */
export declare function getDelayGenerator(startDelay?: number, expFactor?: number): Generator<number, number, unknown>;
/**
 * Helper to use the above generator. This makes it easy to get the delay value without
 * increasing it each time it's called. See `getDelayGenerator` for params explanation.
 */
export declare function getDelayHelper(startDelay?: number, expFactor?: number): {
    getDelay(): number;
    next(): number;
    reset(): void;
};
