// Copyright (c) 2019 Cloudera, Inc. All rights reserved.
var __generator = (this && this.__generator) || function (thisArg, body) {
    var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
    return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function() { return this; }), g;
    function verb(n) { return function (v) { return step([n, v]); }; }
    function step(op) {
        if (f) throw new TypeError("Generator is already executing.");
        while (_) try {
            if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done) return t;
            if (y = 0, t) op = [op[0] & 2, t.value];
            switch (op[0]) {
                case 0: case 1: t = op; break;
                case 4: _.label++; return { value: op[1], done: false };
                case 5: _.label++; y = op[1]; op = [0]; continue;
                case 7: op = _.ops.pop(); _.trys.pop(); continue;
                default:
                    if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                    if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                    if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                    if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                    if (t[2]) _.ops.pop();
                    _.trys.pop(); continue;
            }
            op = body.call(thisArg, _);
        } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
        if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
    }
};
var START_DELAY_MS = 500;
var EXP_FACTOR = 1.1;
/**
 * Generator to create exponentially increasing delay. This can be used if you are polling an API
 * and waiting for something to finish. The longer it waits the longer the delay will become. This
 * is useful because if the operation you're waiting for is done quick you'll catch it quickly
 * (since the inital delays are small) and if it is long running the delays will increase such
 * as to not overload with API requests.
 *
 * Usage:
 *   const delayGenerator = getDelayGenerator();
 *   while (true) {
 *     const status = await api.checkStatus();
 *     if (status.ok) {
 *       break;
 *     }
 *     await sleep(delayGenerator.next().value)
 *   }
 *
 * NOTE: In the example above the actual time between the calls is "duration of status API call + delay", otherwise
 * you might find yourself making a second call before the first finishes.
 *
 * Default delays with 500 and 1.1:
 *
 * 500, 550, 605, 666, 732, 805, 886, 974, 1072, 1179, 1297, 1427,
 * 1569, 1726, 1899, 2089, 2297, 2527, 2780, 3058,...
 */
export function getDelayGenerator(startDelay, expFactor) {
    var step, delay;
    if (startDelay === void 0) { startDelay = START_DELAY_MS; }
    if (expFactor === void 0) { expFactor = EXP_FACTOR; }
    return __generator(this, function (_a) {
        switch (_a.label) {
            case 0:
                step = 0;
                _a.label = 1;
            case 1:
                if (!true) return [3 /*break*/, 3];
                delay = startDelay * Math.pow(expFactor, step);
                delay = Math.round(delay);
                return [4 /*yield*/, delay];
            case 2:
                _a.sent();
                step += 1;
                return [3 /*break*/, 1];
            case 3: return [2 /*return*/, Infinity]; // we never get to this point, but make TS type interference happy
        }
    });
}
/**
 * Helper to use the above generator. This makes it easy to get the delay value without
 * increasing it each time it's called. See `getDelayGenerator` for params explanation.
 */
export function getDelayHelper(startDelay, expFactor) {
    if (startDelay === void 0) { startDelay = START_DELAY_MS; }
    if (expFactor === void 0) { expFactor = EXP_FACTOR; }
    var generator = getDelayGenerator(startDelay, expFactor);
    var currentValue = generator.next().value;
    return {
        getDelay: function () {
            return currentValue;
        },
        next: function () {
            currentValue = generator.next().value;
            return currentValue;
        },
        reset: function () {
            generator = getDelayGenerator(startDelay, expFactor);
            currentValue = generator.next().value;
        }
    };
}
