// Copyright (c) 2020 Cloudera, Inc. All rights reserved.
import { v4 } from 'uuid';
import { useRef } from 'react';
/**
 * Generate unique DOM ids.
 */
export var getUniqueDomId = function (prefix) {
    prefix = prefix || 'id';
    // TODO: [future] v4() generates rather ugly and log ids. Would be nice to use something shorter
    // similar to what styled-components (arne)
    return "".concat(prefix, "-").concat(v4());
};
/**
 * Generate unique DOM ids as hook.
 * This is for example useful inside an svg where certain features like clip-path
 * are often done with <defs> utilizing DOM ids.
 *
 * Sample usage:
 *
 * ```js
 * const myId = useUniqueDomId('my-clip-mask');
 * ```
 *
 */
export var useUniqueDomId = function (prefix) {
    var ref = useRef(getUniqueDomId(prefix));
    return ref.current;
};
