// Copyright (c) 2018 Cloudera, Inc. All rights reserved.
var __read = (this && this.__read) || function (o, n) {
    var m = typeof Symbol === "function" && o[Symbol.iterator];
    if (!m) return o;
    var i = m.call(o), r, ar = [], e;
    try {
        while ((n === void 0 || n-- > 0) && !(r = i.next()).done) ar.push(r.value);
    }
    catch (error) { e = { error: error }; }
    finally {
        try {
            if (r && !r.done && (m = i["return"])) m.call(i);
        }
        finally { if (e) throw e.error; }
    }
    return ar;
};
import moment from 'moment';
import 'moment-duration-format';
var ms = 1;
var s = ms * 1000;
var m = s * 60;
var h = m * 60;
var d = h * 24;
var w = d * 7;
var units = {
    ms: ms,
    s: s,
    m: m,
    h: h,
    d: d,
    w: w
};
var fragmentRegex = /^(0|[1-9][0-9]*)(ms|s|m|h|d|w)$/i;
var unitRegex = /(ms|s|m|h|d|w)/i;
export var parse = function (input) {
    try {
        var fragments = input.split(' ').filter(Boolean);
        if (!fragments.length) {
            throw new Error('input string is empty');
        }
        var lastUnit_1;
        return fragments.reduce(function (acc, fragment) {
            if (!fragmentRegex.test(fragment)) {
                throw new Error("invalid duration string fragment \"".concat(fragment, "\""));
            }
            var _a = __read(fragment.split(unitRegex), 2), stringValue = _a[0], unit = _a[1];
            var value = Number(stringValue);
            unit = unit.toLowerCase();
            // validate duplicate units and fragments order (e.g. "1ms 2s", "2s 3s" are invalid duration strings)
            var lastUnitFactor = units[lastUnit_1];
            var unitFactor = units[unit];
            if (lastUnitFactor <= unitFactor) {
                throw new Error("wrong fragments order or duplicate unit ".concat(fragment));
            }
            lastUnit_1 = unit;
            return acc + unitFactor * value;
        }, 0);
    }
    catch (err) {
        console.warn('Parse error:', err.message);
        throw new Error("Invalid duration \"".concat(input, "\""));
    }
};
/**
 * Given the number of milliseconds, formats the value to the string 'h[h] m[m] s[s]' if it is greater than 1 munute,
 * and 's[s] S[ms]' otherwise.
 * TODO: Current version of moment-duration-format doesn't properly format durations having empty fragments.
 * For example, 600000 would be formatted as "10m 0s". Consider upgrading the module after resolving the version
 * conflict between sigma and cui.
 * @param {Number} millis
 */
var defaultFormat = function (millis) {
    var dur = moment.duration(millis);
    var fragments = [];
    if (millis >= 60000) {
        fragments.push([Math.floor(dur.asHours()), 'h'], [dur.minutes(), 'm'], [dur.seconds(), 's']);
    }
    else {
        fragments.push([dur.seconds(), 's'], [dur.milliseconds(), 'ms']);
    }
    return fragments
        .reduce(function (acc, fragment) {
        var _a = __read(fragment, 1), value = _a[0];
        if (value) {
            acc.push(fragment.join(''));
        }
        return acc;
    }, [])
        .join(' ');
};
/**
 * For a given duration in milliseconds, returns its formatted string value.
 * @param value The duration in milliseconds.
 * @param format The format supported by moment-duration-format.
 * @oaram options The moment-duration-format options.
 * @returns {string}
 */
export var format = function (value, format, options) {
    if (options === void 0) { options = {}; }
    if (!value) {
        return '0s';
    }
    if (!format) {
        return defaultFormat(value);
    }
    // TODO: [future] fix ts for format e.g. 'moment-duration-format' (arne)
    // @ts-expect-error no typing for .format
    return moment.duration(value).format(format, options);
};
