// Copyright (c) 2018 Cloudera, Inc. All rights reserved.
import round from 'lodash/round';
import moment from 'moment-timezone';
import humanize from './humanize';
import { truncateEnd } from './textUtils';
import { format } from './duration';
export var DATETIME_FORMAT = 'YYYY-MM-DDTHH:mm:ss.SSSZ';
var LONG_STRING_MAX_LENGTH = 200;
/**
 * Transforms a date object to a common format.
 * @param {Date|moment} date The date to format.
 * @param {string} timezone A timezone for the formatted date. Defaults to use moment to guess our timezone.
 * @param {string} format The expected output value.
 * @return {string}
 */
export function formatDateTime(date, timezone, format) {
    if (timezone === void 0) { timezone = moment.tz.guess(); }
    if (format === void 0) { format = DATETIME_FORMAT; }
    return moment(date).tz(timezone).format(format);
}
export var formatLongString = function (str, maxLength) {
    if (maxLength === void 0) { maxLength = LONG_STRING_MAX_LENGTH; }
    return truncateEnd(str, maxLength);
};
export var formatDuration = function (value) { return format(value); };
export var formatNumber = function (value) { return value && humanize.humanizeCount(value); };
export var formatMemory = function (value) {
    return Number.isFinite(value) ? humanize.humanizeBytes(value) : '';
};
export var formatByteSeconds = function (value) { return value && "".concat(formatMemory(value), " \u00D7 s"); };
export var formatPercent = function (value, precision) {
    if (precision === void 0) { precision = 0; }
    return typeof value === 'number' && Number.isFinite(value) ? round(value * 100, precision) + '%' : '';
};
