// Licensed to Cloudera, Inc. under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  Cloudera, Inc. licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
/*jslint regexp: true */
// Find {string} or {numeric} placeholders
var expression = /\{(?:(\d*)|([^\}]*))\}/g;
/*jslint regexp: false */
/**
 * Replaces all instances of {property} or {index} with
 * with the equivalent properties of the params object or value from the params array.
 * @param {string} str The template string to formatString.
 * @param {object|array} params The params to formatString the string with.
 * @param {boolean} encode A truthy value will cause the injected values to be encodeURIComponent encoded.
 * @return {string}
 */
var formatString = function (str, params, encode) {
    var result = '', lastMatch = 0, currentMatch, currentValue, loop = true;
    while (loop) {
        currentMatch = expression.exec(str);
        if (!currentMatch) {
            if (lastMatch !== str.length) {
                result += str.substring(lastMatch);
            }
            loop = false;
            return result;
        }
        result += str.substring(lastMatch, currentMatch.index);
        if (currentMatch[1]) {
            currentValue = params[parseInt(currentMatch[1], 10)];
        }
        else {
            currentValue = params[currentMatch[2]];
        }
        if (currentValue !== undefined) {
            result += encode ? encodeURIComponent(currentValue).replace(/ /g, '+') : currentValue;
        }
        lastMatch = currentMatch.index + currentMatch[0].length;
    }
    return result;
};
export default formatString;
