// Copyright (c) 2018 Cloudera, Inc. All rights reserved.
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
import i18n from './i18n';
import { makeStaticMap } from "cuix/dist/types/types";
export var API_ERROR_CODES = makeStaticMap({
    UNKNOWN: 'UNKNOWN',
    INVALID_ARGUMENT: 'INVALID_ARGUMENT',
    REQUEST_NOT_IN_ACCEPTANCE_WINDOW: 'REQUEST_NOT_IN_ACCEPTANCE_WINDOW',
    AUTHENTICATION_FAILURE: 'AUTHENTICATION_FAILURE',
    MALFORMED_REQUEST: 'MALFORMED_REQUEST',
    NOT_FOUND: 'NOT_FOUND',
    ALREADY_EXISTS: 'ALREADY_EXISTS',
    THROTTLED: 'THROTTLED',
    RESOURCE_EXHAUSTED: 'RESOURCE_EXHAUSTED',
    INVALID_DIRECTOR_STATE: 'INVALID_DIRECTOR_STATE',
    PERMISSION_DENIED: 'PERMISSION_DENIED',
    COMMUNICATION_ERROR: 'COMMUNICATION_ERROR',
    GATEWAY_TIMEOUT: 'GATEWAY_TIMEOUT',
    TERMS_ACCEPTANCE_EXPIRED: 'TERMS_ACCEPTANCE_EXPIRED',
    CDPONE_TRIAL_INACTIVE: 'CDPONE_TRIAL_INACTIVE'
});
var STATUS_ERROR_CODE_MAP = makeStaticMap({
    0: API_ERROR_CODES.COMMUNICATION_ERROR,
    400: API_ERROR_CODES.MALFORMED_REQUEST,
    403: API_ERROR_CODES.PERMISSION_DENIED,
    404: API_ERROR_CODES.NOT_FOUND,
    504: API_ERROR_CODES.GATEWAY_TIMEOUT
});
/**
 * Returns the title and message for the given failed response.
 * @param {object} response The api response.
 */
export default function getErrorInfo(response) {
    // If API returns an error code use that.
    var code = response && response.obj && response.obj.code;
    var message = response && response.obj && response.obj.message;
    if (!API_ERROR_CODES[code]) {
        // API didn't return a code. Map HTTP status to an error code.
        var status_1 = response && response.status;
        code = STATUS_ERROR_CODE_MAP[status_1] || API_ERROR_CODES.UNKNOWN;
    }
    return {
        code: code,
        title: i18n.t('error.api.code.' + code + '.title'),
        message: message || i18n.t('error.api.code.' + code + '.message')
    };
}
var isJqueryResponse = function (error) {
    return (error.getResponseHeader &&
        typeof error.getResponseHeader === 'function' &&
        error.then &&
        typeof error.then === 'function');
};
var isAWSSDKError = function (error) {
    return ['requestId', 'statusCode', 'time'].every(function (key) { return error[key] !== undefined; });
};
export function getErrorObj(error) {
    if (error.response) {
        return __assign(__assign({}, getErrorInfo(error.response)), { requestId: error.response.requestId });
    }
    if (isJqueryResponse(error)) {
        var responseText = error.responseText, status_2 = error.status;
        var obj = { code: status_2, message: responseText };
        try {
            obj = JSON.parse(responseText);
        }
        catch (error) {
            // ignore
        }
        var requestId = error.getResponseHeader('x-altus-request-id');
        return __assign(__assign({}, getErrorInfo({ obj: obj })), { requestId: requestId });
    }
    if (isAWSSDKError(error)) {
        var status_3 = error.statusCode;
        var message = error.message;
        if (status_3 === 403) {
            var code = API_ERROR_CODES.AUTHENTICATION_FAILURE;
            return {
                code: code,
                title: i18n.t('error.api.code.' + code + '.title'),
                message: message
            };
        }
        return getErrorInfo({
            status: status_3,
            obj: {
                message: message
            }
        });
    }
    return {
        code: API_ERROR_CODES.UNKNOWN,
        title: i18n.t('label.unexpectedError.title'),
        message: error.message
    };
}
