declare let i18n: {
    /**
     * Retrieves a localized string from the string table and formats it if necessary.
     * @param {string} key The key associated with the string in the string table.
     * @return {string}
     * @see module:formatString
     * @example
     * assume label.properties contains:
     * message.key1=Hello World
     * message.key2=Hello {0}, {1}?
     *
     * var msg1 = i18n.t('message.key1');
     * // msg1 now returns Hello World
     *
     * var msg2 = i18n.t('message.key2', ['Joe', 'How are you?');
     * // msg2 now returns Hello Joe, How are you?
     */
    t<T>(key: T, ...args: any): string | T;
    hasKey: (key: any) => boolean;
    /**
     * Extends the common-ui locale with your own product specific locale.
     * Caution, can override common-ui locale keys.
     * @param {object} extendedLocale The locale that we want to add.  Basic string key / string value.
     */
    extend(extendedLocale: {
        [key: string]: string;
    }): void;
    /**
     * Low-level method to get the underlying data object. Generally, this should not be used.
     */
    getData(): {
        [key: string]: string;
    };
};
export default i18n;
export declare const t: <T>(key: T, ...args: any) => string | T;
