// Licensed to Cloudera, Inc. under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  Cloudera, Inc. licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
var __read = (this && this.__read) || function (o, n) {
    var m = typeof Symbol === "function" && o[Symbol.iterator];
    if (!m) return o;
    var i = m.call(o), r, ar = [], e;
    try {
        while ((n === void 0 || n-- > 0) && !(r = i.next()).done) ar.push(r.value);
    }
    catch (error) { e = { error: error }; }
    finally {
        try {
            if (r && !r.done && (m = i["return"])) m.call(i);
        }
        finally { if (e) throw e.error; }
    }
    return ar;
};
var __spreadArray = (this && this.__spreadArray) || function (to, from, pack) {
    if (pack || arguments.length === 2) for (var i = 0, l = from.length, ar; i < l; i++) {
        if (ar || !(i in from)) {
            if (!ar) ar = Array.prototype.slice.call(from, 0, i);
            ar[i] = from[i];
        }
    }
    return to.concat(ar || Array.prototype.slice.call(from));
};
/**
 * @module utils/i18n
 * @description This module provides internationalization related functionality.
 * The resources available to this module are controlled by the i18n/client.label.txt and i18n/client.message.txt
 * files and the ClientResources component.
 */
import formatString from './formatString';
var language = {};
var _i18n = {
    /**
     * Retrieves a localized string from the string table and formats it if necessary.
     * @param {string} key The key associated with the string in the string table.
     * @return {string}
     * @see module:formatString
     * @example
     * assume label.properties contains:
     * message.key1=Hello World
     * message.key2=Hello {0}, {1}?
     *
     * var msg1 = i18n.t('message.key1');
     * // msg1 now returns Hello World
     *
     * var msg2 = i18n.t('message.key2', ['Joe', 'How are you?');
     * // msg2 now returns Hello Joe, How are you?
     */
    t: function (key) {
        var args = [];
        for (var _i = 1; _i < arguments.length; _i++) {
            args[_i - 1] = arguments[_i];
        }
        // If key isn't a string, we might be passing in react nodes, or other objects. Just return the
        // input as is.
        if (typeof key !== 'string') {
            return key;
        }
        if (args.length > 0) {
            // If there are more than 2 arguments or argument one is not an object, treat it as a vararg.
            if (args.length > 1 || typeof args[0] !== 'object') {
                // Replace the key with its associated string.
                var message = language[key] || key;
                args = [message, args];
            }
            else {
                // Replace the key with its associated string.
                args.unshift(language[key] || key);
            }
            // @ts-expect-error typing trouble with the rest parm
            return formatString.apply(void 0, __spreadArray([], __read(args), false));
        }
        return language[key] || key;
    },
    hasKey: function (key) { return typeof key === 'string' && !!language[key]; },
    /**
     * Extends the common-ui locale with your own product specific locale.
     * Caution, can override common-ui locale keys.
     * @param {object} extendedLocale The locale that we want to add.  Basic string key / string value.
     */
    extend: function (extendedLocale) {
        Object.assign(language, extendedLocale);
    },
    /**
     * Low-level method to get the underlying data object. Generally, this should not be used.
     */
    getData: function () {
        return language;
    }
};
// Guard against i18n getting loaded multiple times from different locations
// (E.g., cuix/utils vs cuix/dist/utils)
var i18n = _i18n;
if (typeof window === 'object') {
    if (!window._i18n) {
        window._i18n = _i18n;
    }
    i18n = window._i18n;
}
export default i18n;
export var t = i18n.t;
