// Copyright (c) 2020 Cloudera, Inc. All rights reserved.
var METRIC_PREFIX = ['', 'K', 'M', 'G', 'T', 'P', 'E', 'Z', 'Y'];
var BINARY_PREFIX = ['', 'KI', 'MI', 'GI', 'TI', 'PI', 'EI', 'ZI', 'YI'];
// Billion maps to metric giga in the short scale (used by the US). In some
// other countries (like lot of Europe) it can map differently.
var SHORT_SCALE_TO_METRIC = {
    B: 'G'
};
var countRe = /^(-?)\s*([\d.]+)\s*(\D{1,2})*$/;
var parseCount = function (countText, allowShortScale) {
    countText = countText.trim();
    var match = countText.match(countRe);
    if (!match) {
        return null;
    }
    var unit = match[3];
    var value = Number.parseFloat(match[2]);
    var sign = match[1];
    if (unit) {
        unit = (allowShortScale && SHORT_SCALE_TO_METRIC[unit]) || unit;
        var index = void 0;
        if ((index = BINARY_PREFIX.indexOf(unit.toUpperCase())) !== -1) {
            value = value * Math.pow(2, 10 * index);
        }
        else if ((index = METRIC_PREFIX.indexOf(unit.toUpperCase())) !== -1) {
            value = value * Math.pow(10, 3 * index);
        }
        else {
            return null;
        }
    }
    if (sign === '-') {
        value = -value;
    }
    return value;
};
/**
 * Parses metric strings such as "10k" / "100G" / "1.23 T" into numbers.
 * Returns null if not parsable.
 */
export default (function (countText) { return parseCount(countText); });
/**
 * Mainly to handle numbers that use B suffix for billion. Billion has different meaning in different
 * parts of the world. With the US using the "short scale".
 */
export var parseCountWithShortScale = function (countText) { return parseCount(countText, true); };
