// Copyright (c) 2020 Cloudera, Inc. All rights reserved.
var ns = 1e-6;
var us = 1e-3;
var ms = 1;
var s = ms * 1000;
var m = s * 60;
var h = m * 60;
var d = h * 24;
var w = d * 7;
var DURATION_UNIT_TO_MS = {
    ns: ns,
    us: us,
    μs: us,
    ms: ms,
    s: s,
    m: m,
    h: h,
    d: d,
    w: w
};
/**
 * Overall expected format.
 * I don't think JS supports arbitrary amount of groups so need multiple regexps.
 */
var durationRe = /^([\d.]+\s*[A-Za-zμ]*\s*)+$/;
/** a global search, to find each segment (e.g. "10h"). */
var durationFragmentRe = /[\d.]+\s*[A-Za-zμ]*\s*/g;
/** split up each fragment into num + unit */
var durationFragmentPartsRe = /^([\d.]+)\s*([A-Za-zμ]*)\s*$/;
/**
 * Parse duration strings such as "10h 2m 10s" to ms.
 * Returns null for when unable to parse.
 */
var parseDuration = function (durationText) {
    durationText = durationText.trim();
    if (!durationText.match(durationRe)) {
        return null;
    }
    var fragments = durationText.match(durationFragmentRe);
    if (!fragments) {
        return null;
    }
    var duration = 0;
    var invalid = false;
    var lastUnitValue = Infinity;
    fragments.forEach(function (fragment) {
        var match = fragment.trim().match(durationFragmentPartsRe);
        if (!match) {
            invalid = true;
            return;
        }
        var value = Number.parseFloat(match[1]);
        var unit = match[2];
        var unitValue = DURATION_UNIT_TO_MS[unit];
        if (!unitValue) {
            invalid = true;
            return;
        }
        if (unitValue >= lastUnitValue) {
            // prevent out-of-order units
            // prevent repetition of units
            invalid = true;
            return;
        }
        lastUnitValue = unitValue;
        duration += unitValue * value;
    });
    if (invalid) {
        return null;
    }
    return duration;
};
export default parseDuration;
