/// <reference types="segment-analytics" />
declare global {
    interface Window {
        analytics: SegmentAnalytics.AnalyticsJS | undefined;
    }
}
import { ContextData } from './segmentPersistence';
/**
 * Initializes Segment Analytics
 * @param analyticsToken Segment API Write Key for Dev or Prod Segment Source.
 * @param applicationContext Information about web-application like { consoleName: 'iam', isProd: true,  ... }
 */
export declare const initAnalytics: (analyticsToken: string, applicationContext: ContextData) => void;
export declare const emailToUserId: (email: string) => string;
export interface UserTraits extends Object {
    email: string;
    firstName: string;
    lastName: string;
    userId?: string;
}
/**
 * Identifies CDP user and generates unique userId from user email for Segment Analytics.
 * All provided user info is stored in a secure way on a Segment side.
 * If some user props are too sensitive, please don't provide them.
 * Feel free to use lodash/omit function to remove any sensitive props.
 * @param user
 * @returns
 */
export declare function setUser(user: UserTraits): void;
/**
 * Sends pageView event information into Segment analytics.
 * @param pageName - Optional page name.
 * @param data - Optional page properties.
 * @returns
 */
export declare function trackPage(pageName?: string, data?: ContextData): void;
/**
 * Sends any event into Segment analytics.
 * @param {string} eventName
 * @param {Object} data
 */
export declare function trackEvent(eventName: string, data?: ContextData): void;
/**
 * Sends exception event into Segment along with provided error message and isFatal status;
 * @param message Error message
 * @param isFatal Does Error cause application crash.
 */
export declare const trackError: (message: string, isFatal?: boolean) => void;
/**
 * Tracks user logout action and cleanups persisted contexts.
 */
export declare const logout: () => void;
/**
 * Sets short lived page context which will be send along with all events happening on this page.
 * Page context is auto cleaned on url change.
 * Usually this function is called when page has finished loading necessary data from API.
 * Marketing analysts like to know what choice was given to user for selection on some pages.
 * @param props - Useful data for analytics about current page context.
 */
export declare const setPageContextProps: (props: Object) => void;
/**
 * Data which will be persisted in browser session storage and
 * will be send into Segment on every pageView or other event.
 * Typically session context is useful to track user's selections (for example: selected trial deployment type).
 * @param props
 */
export declare const setSessionContextProps: (props: Object) => void;
/**
 * Data which will be persisted in browser local storage and
 * will be send into Segment on every pageView or other event.
 * Using localStorage is helpful to track user journeys when landing URL contained some trackingIds or other markeging markers.
 * @param props
 */
export declare const setLocalContextProps: (props: Object) => void;
