// Copyright (c) 2022 Cloudera, Inc. All rights reserved.
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import { clearAllContexts, getAllContexts, clearPageContext, setApplicationContextProps, setPageContextProps as _setPageContextProps, setSessionContextProps as _setSessionContextProps, setLocalContextProps as _setLocalContextProps } from './segmentPersistence';
import { Md5 } from 'ts-md5';
var DEBUG_LOG = isDebugLogEnabled();
/**
 * Loads segment analytics javascript into browser.
 * This code snippet was copied from https://app.segment.com/cldr/sources/cdp_one_dev/overview
 * analytics.addSourceMiddleware was manually added to allow Segment to track url hash values.
 * Also note that analytics.page() call was removed from original snippet to avoid redundant pageView event in statistics.
 * @param analyticsToken
 */
var loadSegmentAnalytics = function (analyticsToken) {
    var t = document.createElement('script');
    t.type = 'text/javascript';
    t.async = true;
    t.innerText = "\n    !function(){var analytics=window.analytics=window.analytics||[];if(!analytics.initialize)if(analytics.invoked)window.console&&console.error&&console.error(\"Segment snippet included twice.\");else{analytics.invoked=!0;analytics.methods=[\"trackSubmit\",\"trackClick\",\"trackLink\",\"trackForm\",\"pageview\",\"identify\",\"reset\",\"group\",\"track\",\"ready\",\"alias\",\"debug\",\"page\",\"once\",\"off\",\"on\",\"addSourceMiddleware\",\"addIntegrationMiddleware\",\"setAnonymousId\",\"addDestinationMiddleware\"];analytics.factory=function(e){return function(){var t=Array.prototype.slice.call(arguments);t.unshift(e);analytics.push(t);return analytics}};for(var e=0;e<analytics.methods.length;e++){var key=analytics.methods[e];analytics[key]=analytics.factory(key)}analytics.load=function(key,e){var t=document.createElement(\"script\");t.type=\"text/javascript\";t.async=!0;t.src=\"https://cdn.segment.com/analytics.js/v1/\" + key + \"/analytics.min.js\";var n=document.getElementsByTagName(\"script\")[0];n.parentNode.insertBefore(t,n);analytics._loadOptions=e};analytics._writeKey=\"".concat(analyticsToken, "\";;analytics.SNIPPET_VERSION=\"4.15.3\";\n    analytics.load(\"").concat(analyticsToken, "\");\n  \n    analytics.addSourceMiddleware(({ payload, next, integrations }) => {\n      const { hash } = document.location;\n      payload.obj.context.page.hash = hash;\n      if (payload.obj.properties && payload.obj.properties.url) {\n        payload.obj.properties.hash = hash;\n      }\n      next(payload);\n    });\n  \n    }}();\n  ");
    var n = document.getElementsByTagName('script')[0];
    n.parentNode.insertBefore(t, n);
};
/**
 * Initializes Segment Analytics
 * @param analyticsToken Segment API Write Key for Dev or Prod Segment Source.
 * @param applicationContext Information about web-application like { consoleName: 'iam', isProd: true,  ... }
 */
export var initAnalytics = function (analyticsToken, applicationContext) {
    var _a;
    // eslint-disable-next-line @typescript-eslint/ban-ts-comment
    // @ts-ignore
    if ((_a = window.analytics) === null || _a === void 0 ? void 0 : _a.invoked) {
        console.error('Segment Analytics was already initialized!.');
        return;
    }
    setApplicationContextProps(applicationContext);
    loadSegmentAnalytics(analyticsToken);
    window.addEventListener('error', onError);
    window.addEventListener('unhandledrejection', trackUnhandledPromiseErrorEvent);
    if (document.body.dataset !== undefined) {
        // Register any HTML tags with data-event attribute.
        document.addEventListener('click', onDOMElementClick);
    }
};
/**
 * Listen to click events on the document and if the clicked element has analytics attached log those.
 * We are registering the click event to document and can't do filtering like jquery ('[data-event]')
 * so we need to traverse event's target's parents for cases like
 * <a data-event="x"><span>Click me</span></a> where the span is the target.
 */
function onDOMElementClick(event) {
    var target = (event.target || event.srcElement);
    var hyperlink;
    var uiElementText;
    while (target && target.parentNode) {
        if (!uiElementText) {
            uiElementText = target.innerText;
        }
        if (!hyperlink && target instanceof HTMLAnchorElement) {
            hyperlink = {
                href: target.href,
                target: target.target
            };
        }
        var data = target.dataset;
        if (data && data.event) {
            var event_1 = data.event, otherProps = __rest(data, ["event"]);
            trackEvent(event_1, __assign({ hyperlink: hyperlink, uiElementText: uiElementText }, otherProps));
            break;
        }
        target = target.parentNode;
    }
}
/**
 * If you want to debug Segment Analytics by printing out all the Segment calls to console, but not
 * actually send them to Segment. Enable this by
 * localStorage.setItem('debug-segment-analytics-to-console', "true");
 * Disable by clearing or setting to "false"
 * Alternatively you can use https://segment.com/docs/connections/sources/catalog/libraries/website/javascript/#debug
 */
function isDebugLogEnabled() {
    var result;
    try {
        var debug = localStorage.getItem('debug-segment-analytics-to-console');
        result = debug ? !!JSON.parse(debug) : false;
    }
    catch (err) {
        result = false;
    }
    return result;
}
export var emailToUserId = function (email) { return Md5.hashStr(email.trim().toLowerCase()); };
/**
 * Identifies CDP user and generates unique userId from user email for Segment Analytics.
 * All provided user info is stored in a secure way on a Segment side.
 * If some user props are too sensitive, please don't provide them.
 * Feel free to use lodash/omit function to remove any sensitive props.
 * @param user
 * @returns
 */
export function setUser(user) {
    var _a, _b;
    var cdpUserId = user.userId, traits = __rest(user, ["userId"]); // Segment uses its own userId, which is generated from email.
    var email = user.email;
    if (DEBUG_LOG) {
        console.log("Segment.Identify: ", email, __assign(__assign({}, traits), { cdpUserId: cdpUserId }));
        return;
    }
    if (email) {
        (_a = window.analytics) === null || _a === void 0 ? void 0 : _a.identify(emailToUserId(email), __assign(__assign({}, traits), { cdpUserId: cdpUserId }));
    }
    else {
        (_b = window.analytics) === null || _b === void 0 ? void 0 : _b.identify(__assign(__assign({}, traits), { cdpUserId: cdpUserId }));
    }
}
/**
 * Sends pageView event information into Segment analytics.
 * @param pageName - Optional page name.
 * @param data - Optional page properties.
 * @returns
 */
export function trackPage(pageName, data) {
    var _a;
    var _b = document.location, hash = _b.hash, pathname = _b.pathname;
    clearPageContext();
    var context = getAllContexts(onError);
    if (DEBUG_LOG) {
        console.log("Segment.Page: ", pageName || pathname + hash, { context: context, data: data });
        return;
    }
    (_a = window.analytics) === null || _a === void 0 ? void 0 : _a.page(pageName || pathname + hash, {
        context: context,
        data: data
    });
}
// Many HTML elements specify event-data-category attribute for analytics.
// We project some data-category values into special analytical dimension
// eventActor='User' to let marketing analyst know that related
// tracked events were triggered by User and not by JS callback.
var userActionEventCategories = new Set(['Email Link', 'Email Text', 'Open Link', 'User Action']);
/**
 * Sends any event into Segment analytics.
 * @param {string} eventName
 * @param {Object} data
 */
export function trackEvent(eventName, data) {
    var _a;
    var context = getAllContexts(onError);
    if (data) {
        var eventCategory = data.eventCategory, eventActor = data.eventActor;
        if (eventCategory && !eventActor && userActionEventCategories.has(eventCategory)) {
            data.eventActor = 'User';
        }
    }
    if (DEBUG_LOG) {
        console.log("Segment.Track: ", { eventName: eventName, context: context, data: data });
        return;
    }
    (_a = window.analytics) === null || _a === void 0 ? void 0 : _a.track(eventName, {
        context: context,
        data: data
    });
}
/**
 * Sends exception event into Segment along with provided error message and isFatal status;
 * @param message Error message
 * @param isFatal Does Error cause application crash.
 */
export var trackError = function (message, isFatal) {
    trackEvent('Exception', { fatal: isFatal ? 'Fatal Error' : 'Non Fatal Error', message: message });
};
/**
 * Handler for page error events.
 * @param event
 */
function onError(event) {
    var errorMsg;
    try {
        var filename = event.filename;
        // strip domain name to make it more readable for us
        filename = filename.replace(/^https?:\/\/[^\/]*/, '');
        errorMsg = "".concat(event.message, " at ").concat(filename, ":").concat(event.lineno, ":").concat(event.colno);
        var error = event.error;
        if (error && error.stack) {
            errorMsg = errorMsg + '\nStack: ' + error.stack;
        }
    }
    catch (err) {
        errorMsg = "Error in error handler. ".concat(err.message, " at ").concat(err.stack);
    }
    errorMsg = "JS Client Error: ".concat(errorMsg);
    trackError(errorMsg);
}
/**
 * For promises that have errors (rejections) that are not handled they don't
 * bubble up to a page "error" event but they will generate an  "unhandledrejection"
 * event if you use Bluebird and/or newer versions of Chrome.
 * @param event
 */
function trackUnhandledPromiseErrorEvent(event) {
    var errorMsg = '';
    try {
        var reason = void 0;
        if (event.reason) {
            // native Chrome events should report this
            reason = event.reason;
        }
        else if (event.detail && event.detail.reason) {
            // Bluebird event should report this
            reason = event.detail.reason;
        }
        else {
            // try a bunch of fallbacks
            // no easy way to test this, but the GA reports show events that
            // doesn't seem to match either of the two above approaches.
            reason = event.error || event.detail || event;
        }
        if (reason) {
            // in most cases, the reason will be an Error, but it is not guaranteed
            // as you can reject/throw any object you'd like, not just errors.
            errorMsg = reason.stack || reason.message || reason;
        }
        if ("".concat(errorMsg) === '[object Object]') {
            // sometimes we're not dealing with error objects,
            // so we'll try to serialize it so we can capture it
            errorMsg = "json: ".concat(JSON.stringify(errorMsg));
        }
    }
    catch (err) {
        errorMsg = "Error in error handler. ".concat(err.message, " at ").concat(err.stack);
    }
    errorMsg = "JS Client Unhandled Promise Error:\n".concat(errorMsg);
    trackError(errorMsg);
}
/**
 * Tracks user logout action and cleanups persisted contexts.
 */
export var logout = function () {
    trackEvent('logout');
    clearAllContexts();
};
/**
 * Sets short lived page context which will be send along with all events happening on this page.
 * Page context is auto cleaned on url change.
 * Usually this function is called when page has finished loading necessary data from API.
 * Marketing analysts like to know what choice was given to user for selection on some pages.
 * @param props - Useful data for analytics about current page context.
 */
export var setPageContextProps = function (props) {
    trackEvent("set_page_context", props);
    _setPageContextProps(props);
};
/**
 * Data which will be persisted in browser session storage and
 * will be send into Segment on every pageView or other event.
 * Typically session context is useful to track user's selections (for example: selected trial deployment type).
 * @param props
 */
export var setSessionContextProps = function (props) {
    trackEvent("set_session_context", props);
    _setSessionContextProps(props, onError);
};
/**
 * Data which will be persisted in browser local storage and
 * will be send into Segment on every pageView or other event.
 * Using localStorage is helpful to track user journeys when landing URL contained some trackingIds or other markeging markers.
 * @param props
 */
export var setLocalContextProps = function (props) {
    trackEvent("set_local_context", props);
    _setLocalContextProps(props, onError);
};
