// Copyright (c) 2022 Cloudera, Inc. All rights reserved.
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
// session context is stored in sessionStorage.getItem(SESSION_STORAGE_KEY)
var SESSION_STORAGE_KEY = 'cuix-analytics';
var LOCAL_STORAGE_KEY = 'cuix-analytics';
var context = {};
// Application Context
export var getApplicationContext = function () { return context.application; };
export var clearApplicationContext = function () {
    delete context.application;
};
export var setApplicationContextProps = function (props) {
    context.application = __assign(__assign({}, context.application), props);
};
// Page Context
export var getPageContext = function () { return context.page; };
/**
 * Collects page context properties, to enrich analytics trackEvents on this page.
 * @param  pageContext is a hashMap with key value pairs.
 */
export var setPageContextProps = function (pageContext) {
    context.page = __assign(__assign({}, context.page), pageContext);
};
export var clearPageContext = function () {
    delete context.page;
};
//  Session Storage
export var getSessionContext = function (onError) {
    try {
        var data = sessionStorage.getItem(SESSION_STORAGE_KEY);
        if (!data) {
            return;
        }
        var context_1 = JSON.parse(data);
        return context_1;
    }
    catch (error) {
        onError(error);
    }
};
export var clearSessionContext = function () {
    sessionStorage.removeItem(SESSION_STORAGE_KEY);
};
export var setSessionContext = function (sessionContext, onError) {
    if (!sessionContext || typeof sessionContext !== 'object') {
        return;
    }
    try {
        sessionStorage.setItem(SESSION_STORAGE_KEY, JSON.stringify(sessionContext));
    }
    catch (error) {
        onError(error);
    }
};
export var setSessionContextProps = function (context, onError) {
    if (!context || typeof context !== 'object') {
        return;
    }
    try {
        var sessionContext = getSessionContext(onError);
        var newContext = sessionContext ? __assign(__assign({}, sessionContext), context) : context;
        setSessionContext(newContext, onError);
    }
    catch (error) {
        onError(error);
    }
};
//  Local Storage
export var getLocalContext = function (onError) {
    try {
        var data = localStorage.getItem(LOCAL_STORAGE_KEY);
        if (!data) {
            return;
        }
        var context_2 = JSON.parse(data);
        return context_2;
    }
    catch (error) {
        onError(error);
    }
};
export var clearLocalContext = function () {
    localStorage.removeItem(LOCAL_STORAGE_KEY);
};
export var setLocalContext = function (localContext, onError) {
    if (!localContext || typeof localContext !== 'object') {
        return;
    }
    try {
        localStorage.setItem(LOCAL_STORAGE_KEY, JSON.stringify(localContext));
    }
    catch (error) {
        onError(error);
    }
};
export var setLocalContextProps = function (context, onError) {
    if (!context || typeof context !== 'object') {
        return;
    }
    try {
        var localContext = getLocalContext(onError);
        var newContext = localContext ? __assign(__assign({}, localContext), context) : context;
        setLocalContext(newContext, onError);
    }
    catch (error) {
        onError(error);
    }
};
// All Contexts
export var clearAllContexts = function () {
    clearApplicationContext();
    clearPageContext();
    clearSessionContext();
    clearLocalContext();
};
export var getAllContexts = function (onError) { return ({
    application: getApplicationContext(),
    page: getPageContext(),
    session: getSessionContext(onError),
    local: getLocalContext(onError)
}); };
