// Copyright (c) 2020 Cloudera, Inc. All rights reserved.
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
import React from 'react';
import { createStore, combineReducers, applyMiddleware } from 'redux';
import apiBusSaga from "cuix/dist/sagas/apiBusSaga";
import apiBusReducer, { actions } from "cuix/dist/reducers/apiBusReducer";
import createSagaMiddleware from 'redux-saga';
import { Provider } from 'react-redux';
import { getErrorObj } from "cuix/dist/utils/getErrorInfo";
import getRouterReducer from "cuix/dist/reducers/routerReducer";
import preferenceReducer from "cuix/dist/reducers/preferenceReducer";
/**
 * Returns a <Provider> that is setup with basic redux + apiBus saga and reducer.
 */
var getApiBusProvider = function (initialState, reducers) {
    if (initialState === void 0) { initialState = {}; }
    var sagaMiddleware = createSagaMiddleware({
        context: {
            errorHandler: function (error) {
                return getErrorObj(error);
            }
        }
    });
    var store = createStore(combineReducers(__assign({ apiBus: apiBusReducer, routing: getRouterReducer({}), preferences: preferenceReducer, auth: function (state) {
            if (state === void 0) { state = { entitlements: [] }; }
            return state;
        } }, (reducers && reducers))), initialState, applyMiddleware(sagaMiddleware));
    // Allow us to check any dispatch calls if we need to. We need to do this
    // before sagaMiddleware.run is run (afaik) as it stores its own reference
    // to the dispatch function.
    typeof jest !== 'undefined' && jest.spyOn(store, 'dispatch');
    // TS complains about this otherwise with some obtuse error so doing "as any"
    sagaMiddleware.run(apiBusSaga);
    var ApiBusProvider = function (_a) {
        var children = _a.children;
        return React.createElement(Provider, { store: store }, children);
    };
    return {
        ApiBusProvider: ApiBusProvider,
        store: store,
        placeApiBusData: function (channel, data) {
            store.dispatch(actions.submitRequest(function () { return data; }, {}, channel));
        }
    };
};
export default getApiBusProvider;
/**
 * Storybook decorator for providing the redux + apiBus context
 */
export var withApiBusDecorator = function (story) {
    var ApiBusProvider = getApiBusProvider().ApiBusProvider;
    return React.createElement(ApiBusProvider, null, story());
};
