// Copyright (c) 2020 Cloudera, Inc. All rights reserved.
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
import ApiResponse from "cdp-js/dist/lib/ApiResponse";
import { v4 as uuidv4 } from 'uuid';
/**
 * jest.spyOn(), jest.fn(), doesn't preserve the methodName and serviceName so we need
 * to preserve those manually, when spying on API calls.
 * @param fakeApi a fake API function
 */
export var spyApi = function (fakeApi) {
    var _spiedApi = jest.fn(fakeApi);
    // API fn needs methodName and serviceName to be compliant, which we loose
    // when converting to a spy.
    var spiedApi = _spiedApi;
    spiedApi.methodName = fakeApi.methodName;
    spiedApi.serviceName = fakeApi.serviceName;
    return spiedApi;
};
/**
 * Returns a pair of API calls, one normal and one that will error. They share
 * methodName, so should be considered the same API method.
 * @param methodSuffix optional suffix to used in-stead of random string
 */
export var getMockApis = function (methodSuffix) {
    if (methodSuffix === void 0) { methodSuffix = ''; }
    var methodName = "mock-api-".concat(methodSuffix || uuidv4());
    var normalApi = function (params) {
        return Promise.resolve(new ApiResponse({ obj: __assign({ data: 123 }, params) }));
    };
    normalApi.methodName = methodName;
    normalApi.serviceName = 'mockService';
    var errorApi = function (_) {
        var error = new Error('Mock error');
        error.response = {
            obj: {
                code: 'SOME_TEST_ERROR',
                message: 'some test error'
            },
            requestId: 'xyz'
        };
        return Promise.reject(error);
    };
    errorApi.methodName = methodName;
    errorApi.serviceName = 'mockService';
    return {
        normal: spyApi(normalApi),
        error: spyApi(errorApi)
    };
};
/**
 * Mock API where the response will be (predictably) different each time it is called.
 * @param methodSuffix optional suffix to used in-stead of random string
 */
export var getIncreasingMockApi = function (methodSuffix) {
    if (methodSuffix === void 0) { methodSuffix = ''; }
    var methodName = "mock-increasing-api-".concat(methodSuffix || uuidv4());
    var counter = 0;
    var increasingApi = function (params) {
        counter += 1;
        return Promise.resolve(new ApiResponse({ obj: __assign({ counter: counter }, params) }));
    };
    increasingApi.methodName = methodName;
    increasingApi.serviceName = 'mockService';
    return spyApi(increasingApi);
};
