// Copyright (c) 2018 Cloudera, Inc. All rights reserved.
var __read = (this && this.__read) || function (o, n) {
    var m = typeof Symbol === "function" && o[Symbol.iterator];
    if (!m) return o;
    var i = m.call(o), r, ar = [], e;
    try {
        while ((n === void 0 || n-- > 0) && !(r = i.next()).done) ar.push(r.value);
    }
    catch (error) { e = { error: error }; }
    finally {
        try {
            if (r && !r.done && (m = i["return"])) m.call(i);
        }
        finally { if (e) throw e.error; }
    }
    return ar;
};
var __spreadArray = (this && this.__spreadArray) || function (to, from, pack) {
    if (pack || arguments.length === 2) for (var i = 0, l = from.length, ar; i < l; i++) {
        if (ar || !(i in from)) {
            if (!ar) ar = Array.prototype.slice.call(from, 0, i);
            ar[i] = from[i];
        }
    }
    return to.concat(ar || Array.prototype.slice.call(from));
};
/**
 * Truncates middle of a string e.g.
 * 'abcdef' -> 'ab…ef'
 */
export var truncateMiddle = function (text, maxLength) {
    if (text.length <= maxLength) {
        return text;
    }
    // make sure we have an integer and that we don't
    // end returning a string longer than maxLength
    var segmentLength = (maxLength - 1) / 2;
    var segment1Length;
    var segment2Length;
    if (segmentLength === Math.floor(segmentLength)) {
        segment1Length = segmentLength;
        segment2Length = segmentLength;
    }
    else {
        segment1Length = Math.floor(segmentLength);
        segment2Length = Math.ceil(segmentLength);
    }
    segmentLength = Math.floor(segmentLength);
    return text.substr(0, segment1Length) + '…' + text.substr(-segment2Length);
};
/**
 * Truncates the end of a string
 * 'abcde' -> 'abc…'
 */
export var truncateEnd = function (text, maxLength) {
    if (text.length <= maxLength) {
        return text;
    }
    return text.substr(0, maxLength - 1) + '…';
};
/**
 * Truncates a path "smartly"
 * The first segment will be truncated at the end (if needed) and have ellipsis if truncated
 * or if we have truncated middle segments. The last segment (like filename) will be truncated
 * in the middle. Examples:
 * /my-path/some/place/to.txt => /my-path…/to.txt
 * /my-very-long-path/some-filename-that-has-many.txt => /my-very…/some…many.txt;
 */
export var truncatePath = function (path, maxLength) {
    if (path.length <= maxLength) {
        return path;
    }
    var pathDivider = '/';
    var segments = path.split(pathDivider);
    // First edge case is when we have only one segment e.g.
    //   my-path
    //   /my-path
    //   /my-path/
    //
    // here we want just middle truncation  /abcde => /a…e
    if (segments.filter(function (segment) { return segment !== ''; }).length === 1) {
        return segments
            .map(function (segment) {
            if (segment !== '') {
                segment = truncateMiddle(segment, maxLength - (segments.length - 1));
            }
            return segment;
        })
            .join('/');
    }
    // in order to keep the processing similar below, we remove any trailing or leading /
    // from our segments (and add them back later) to simplify our processing e.g. possible
    // case are a mix of:
    // absolute paths: ['', 'first-named-segment'] and
    // relative paths: ['first-named-segment'] and
    //      dir paths: ['first-named-semgnet', '']
    var isAbsolute = segments[0] === '';
    if (isAbsolute) {
        segments.shift();
        maxLength -= pathDivider.length;
    }
    var isDir = segments[segments.length - 1] === '';
    if (isDir) {
        segments.pop();
        maxLength -= pathDivider.length;
    }
    // our first design goal is that we'll spend at most half of the max available width
    // to the first segment e.g. /first-segment/second-segment/third-segment
    var halfLength = Math.floor(maxLength / 2);
    var _a = __read(segments, 1), firstSegment = _a[0];
    var isFirstSegmentTruncated = false;
    // if our first segment is more than half of our width, we'll do an initial truncation here
    // *but* we might readjust further down if there is leftover space
    if (firstSegment.length > halfLength) {
        firstSegment = truncateEnd(firstSegment, halfLength - pathDivider.length);
        isFirstSegmentTruncated = true;
    }
    // starting with the topmost segment (e.g. filename) we'll work our way down adding as
    // many path segments as we can fit.
    // If we can't fit any full segments, we take the topmost segment and trucate the middle of it
    var lengthLeft = maxLength - firstSegment.length - pathDivider.length;
    var topSegments = [];
    for (var i = segments.length - 1; i >= 1; i--) {
        var nextSegment = segments[i];
        if (nextSegment.length > lengthLeft) {
            if (!topSegments.length) {
                topSegments.push(truncateMiddle(nextSegment, lengthLeft));
                lengthLeft = 0;
            }
            break;
        }
        topSegments.push(nextSegment);
        lengthLeft = lengthLeft - nextSegment.length - pathDivider.length;
    }
    if (!isFirstSegmentTruncated && topSegments.length < segments.length - 1) {
        // if we did not truncate the first segment, **but** we do not include all sub-segments
        // we still need to add the ellipsis to indicate that
        firstSegment = firstSegment + '…';
        if (lengthLeft < 1 && topSegments.length > 1) {
            // if adding the ellipis will put us over max length, we'll remove the last middle segment
            // we added, so we stay below limit
            topSegments.pop();
        }
    }
    else if (isFirstSegmentTruncated && lengthLeft > 0) {
        // after we added the segments that could fit, there could be some length left-over
        // we'll re-adjust the first segment (if truncated) to consume that length.
        firstSegment = truncateEnd(segments[0], halfLength + lengthLeft);
    }
    topSegments.reverse();
    var newSegments = [];
    if (isAbsolute) {
        newSegments.push('');
    }
    newSegments.push.apply(newSegments, __spreadArray([firstSegment], __read(topSegments), false));
    if (isDir) {
        newSegments.push('');
    }
    return newSegments.join('/');
};
