export declare const periods: {
    MIN_10: {
        value: number;
        startOf: string;
    };
    MIN_20: {
        value: number;
        startOf: string;
    };
    MIN_30: {
        value: number;
        startOf: string;
    };
    HOUR_1: {
        value: number;
        startOf: string;
    };
    HOUR_2: {
        value: number;
        startOf: string;
    };
    HOUR_4: {
        value: number;
        startOf: string;
    };
    HOUR_6: {
        value: number;
        startOf: string;
    };
    HOUR_12: {
        value: number;
        startOf: string;
    };
    DAY_1: {
        value: number;
        startOf: string;
    };
    DAY_2: {
        value: number;
        startOf: string;
    };
    DAY_4: {
        value: number;
        startOf: string;
    };
    WEEK_1: {
        value: number;
        startOf: string;
    };
    WEEK_2: {
        value: number;
        startOf: string;
    };
    WEEK_4: {
        value: number;
        startOf: string;
    };
};
interface Options {
    startTime: number;
    endTime: number;
    maxBuckets: number;
    minBucketDuration?: number;
}
/**
 * Given a time range, generate time "buckets" that aligns nicely with time.
 * This is useful if you want to present the data to the user in time buckets, as it will present much
 * nice e.g. with a bucket from 5-6PM rather than a bucket from 5:12.124PM to 6:23.123PM.
 * It will return as many buckets we can nicely divide up into that is less than maxBuckets.
 * e.g. if you passed in 3:12am as start time and  4:30pm as end time and max 15 buckets, it would
 * probably give you hourly buckets starting at 3:00am and ending at 5:00pm
 */
export declare const getTimeBucketsConfigFor: ({ startTime, endTime, maxBuckets, minBucketDuration }: Options) => {
    /**
     * Our bucket start time, this will always be equal or less than the startTime given , but alway aligned
     * to a "nice" time.
     */
    bucketsStartTime: number;
    /**
     * Our bucket end time, this will be equal or more than our endTime, but aligned to a "nice" time.
     */
    bucketsEndTime: number;
    /**
     * Exact number of buckets it takes to fill from `bucketStartTime` to `bucketsEndTime`
     */
    numBuckets: number;
    /**
     * Duration of a single bucket, this should be one of one the "nice" values specifid in `periods`
     */
    bucketDuration: number;
};
interface GetArrayOptions {
    bucketsStartTime: number;
    numBuckets: number;
    bucketDuration: number;
}
/**
 * Creates an array of buckets given a bucket config, each with start/endTime
 */
export declare const getTimeBucketArrayFromConfig: ({ bucketsStartTime, numBuckets, bucketDuration }: GetArrayOptions) => {
    startTime: number;
    endTime: number;
}[];
export {};
