import moment from 'moment-timezone';
interface ParsedMsPart {
    floor: number;
    rounded: number;
    unit: string;
}
/**
 * @description Utilities for displaying human readable time.
 */
declare const timeUtil: {
    setDelta: (delta: number) => number;
    _currentTimezone: () => string;
    /**
     * Returns the abbrevation of current time zone (E.g., PDT)
     */
    currentTimezoneShortName: () => string;
    /**
     * Returns a moment object for the given date in user's timezone.
     * @param  {string|number|Date} date Input date. Any input that is accepted by moment.js is valid.
     * @return {Moment}
     */
    localDate: (date: any) => moment.Moment;
    /**
     * Returns a formatted moment date.
     * @param  {string|number|Date} date Input date. Any input that is accepted by moment.js is valid.
     * @param  {string} format The moment format.
     * @return {string}
     */
    formattedDate(date: any, format: string): string;
    /**
     * Returns a short date time string like "08/07/2017 1:19 PM"
     * @return {string}
     */
    shortDateTime: (date: any) => string;
    /**
     * Returns a time string like "1:19 PM"
     * @return {string}
     */
    shortTime: (date: any) => string;
    shortTimeAndMs: (date: any) => string;
    /**
     * Returns a time string like "1:19 PM"
     * @return {string}
     */
    shortDate: (date: any) => string;
    /**
     * Returns a medium date time string like "08/07/2017 1:19 PM PDT"
     * @return {string}
     */
    mediumDateTime: (date: any) => string;
    /**
     * Returns a medium time string like "1:19 PM PDT"
     * @return {string}
     */
    mediumTime: (date: any) => string;
    /**
     * Returns a long date string like "January 30, 2018"
     * @return {string}
     */
    longDate: (date: any) => string;
    /**
     * Returns a long date string like "January 30, 2018 11:20 AM PDT"
     * @return {string}
     */
    longDateTime: (date: any) => string;
    /** @return {string} */
    longTime: (date: any) => string;
    /**
     * Returns a date string of the form "1970-01-01 12:00:00 AM UTC".
     * @return {string}
     */
    cdp_12HDateTime: (date: any) => string;
    /** @return {string} */
    dateMonth: (date: any) => string;
    /** @return {string} */
    dateYear: (date: any) => string;
    /**
     * Parses a ms value into days, hours, minutes, etc.
     */
    parseMs(ms?: number): number[];
    /**
     * Rounds parts of a parsed duration object
     */
    roundParsedMs(parts: any[], units?: string[]): ParsedMsPart[];
    /**
     * Formats a duration in ms (E.g., 10h 22m)
     * @param  {number} ms       Duration in ms
     * @param  {number} parts    Number of parts we want in the formatted string
     * @param  {boolean} ignoreMs Whether to ignore milliseconds
     */
    formatMs(ms: number, parts?: number, ignoreMs?: boolean, long?: boolean): string;
    formatSeconds(seconds: number): string;
    formatNanoseconds: (nanos: any) => string;
    /**
     * Calculates the number of days left until a user's workload password expires.
     * In case it already expired, it returns a negative number.
     */
    getDaysUntil: (expirationDate?: string) => number | undefined;
    /**
     * In some cases we would like to display how many days are left
     * until something expires (e.g. a password or a trial period).
     * This function returns how many days are left in the format of
     * - 1 day
     * - 4 days
     * - less than a day
     */
    getTextOfDaysUntil: (daysLeftUntil?: number) => string | undefined;
};
export default timeUtil;
