import { WorkloadPasswordDetails } from "cdp-js/dist/api/iam/types";
/**
 * Calculates if a user's workload password change is enabled.
 * Workload passwords have a passwordMinLifetimeDate property which is the date until a workload password can not yet be changed.
 * If current date is before this date, changing workload passwords is disabled.
 */
export declare const passedMinLifetimeDate: (passwordMinLifetimeDate?: string) => boolean;
/**
 * Helper function to determine if we need to show notification about upcoming expiration of workload password.
 *
 * We show notification only when password is set, current date is beyond passwordMinLifetimeDate (if it is defined)
 * and workload password will expire in the next 10 days.
 *
 * @param {WorkloadPasswordDetails} workloadPasswordDetails details about password expiration.
 * Returns if notification should be shown, if password already expired and how many days are left until password expires.
 *    If the password already expired, daysUntilExpiration can be a negative number.
 */
export declare const getExpiredWorkloadPasswordDetails: (workloadPasswordDetails: WorkloadPasswordDetails | undefined) => {
    showNotification: boolean;
    daysUntilExpiration: number | undefined;
    expired: boolean;
} | {
    showNotification: boolean;
    daysUntilExpiration?: undefined;
    expired?: undefined;
};
